/* GL dispatch code.
 * This is code-generated from the GL API XML files from Khronos.
 * 
 * Copyright (c) 2013-2018 The Khronos Group Inc.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 */

#include "config.h"

#include <stdlib.h>
#include <string.h>
#include <stdio.h>

#include "dispatch_common.h"
#include "epoxy/gl.h"

#ifdef __GNUC__
#define EPOXY_NOINLINE __attribute__((noinline))
#elif defined (_MSC_VER)
#define EPOXY_NOINLINE __declspec(noinline)
#endif
struct dispatch_table {
    PFNGLACCUMPROC epoxy_glAccum;
    PFNGLACCUMXOESPROC epoxy_glAccumxOES;
    PFNGLACQUIREKEYEDMUTEXWIN32EXTPROC epoxy_glAcquireKeyedMutexWin32EXT;
    PFNGLACTIVEPROGRAMEXTPROC epoxy_glActiveProgramEXT;
    PFNGLACTIVESHADERPROGRAMPROC epoxy_glActiveShaderProgram;
    PFNGLACTIVESHADERPROGRAMEXTPROC epoxy_glActiveShaderProgramEXT;
    PFNGLACTIVESTENCILFACEEXTPROC epoxy_glActiveStencilFaceEXT;
    PFNGLACTIVETEXTUREPROC epoxy_glActiveTexture;
    PFNGLACTIVETEXTUREARBPROC epoxy_glActiveTextureARB;
    PFNGLACTIVEVARYINGNVPROC epoxy_glActiveVaryingNV;
    PFNGLALPHAFRAGMENTOP1ATIPROC epoxy_glAlphaFragmentOp1ATI;
    PFNGLALPHAFRAGMENTOP2ATIPROC epoxy_glAlphaFragmentOp2ATI;
    PFNGLALPHAFRAGMENTOP3ATIPROC epoxy_glAlphaFragmentOp3ATI;
    PFNGLALPHAFUNCPROC epoxy_glAlphaFunc;
    PFNGLALPHAFUNCQCOMPROC epoxy_glAlphaFuncQCOM;
    PFNGLALPHAFUNCXPROC epoxy_glAlphaFuncx;
    PFNGLALPHAFUNCXOESPROC epoxy_glAlphaFuncxOES;
    PFNGLALPHATOCOVERAGEDITHERCONTROLNVPROC epoxy_glAlphaToCoverageDitherControlNV;
    PFNGLAPPLYFRAMEBUFFERATTACHMENTCMAAINTELPROC epoxy_glApplyFramebufferAttachmentCMAAINTEL;
    PFNGLAPPLYTEXTUREEXTPROC epoxy_glApplyTextureEXT;
    PFNGLAREPROGRAMSRESIDENTNVPROC epoxy_glAreProgramsResidentNV;
    PFNGLARETEXTURESRESIDENTPROC epoxy_glAreTexturesResident;
    PFNGLARETEXTURESRESIDENTEXTPROC epoxy_glAreTexturesResidentEXT;
    PFNGLARRAYELEMENTPROC epoxy_glArrayElement;
    PFNGLARRAYELEMENTEXTPROC epoxy_glArrayElementEXT;
    PFNGLARRAYOBJECTATIPROC epoxy_glArrayObjectATI;
    PFNGLASYNCCOPYBUFFERSUBDATANVXPROC epoxy_glAsyncCopyBufferSubDataNVX;
    PFNGLASYNCCOPYIMAGESUBDATANVXPROC epoxy_glAsyncCopyImageSubDataNVX;
    PFNGLASYNCMARKERSGIXPROC epoxy_glAsyncMarkerSGIX;
    PFNGLATTACHOBJECTARBPROC epoxy_glAttachObjectARB;
    PFNGLATTACHSHADERPROC epoxy_glAttachShader;
    PFNGLBEGINPROC epoxy_glBegin_unwrapped;
    PFNGLBEGINCONDITIONALRENDERPROC epoxy_glBeginConditionalRender;
    PFNGLBEGINCONDITIONALRENDERNVPROC epoxy_glBeginConditionalRenderNV;
    PFNGLBEGINCONDITIONALRENDERNVXPROC epoxy_glBeginConditionalRenderNVX;
    PFNGLBEGINFRAGMENTSHADERATIPROC epoxy_glBeginFragmentShaderATI;
    PFNGLBEGINOCCLUSIONQUERYNVPROC epoxy_glBeginOcclusionQueryNV;
    PFNGLBEGINPERFMONITORAMDPROC epoxy_glBeginPerfMonitorAMD;
    PFNGLBEGINPERFQUERYINTELPROC epoxy_glBeginPerfQueryINTEL;
    PFNGLBEGINQUERYPROC epoxy_glBeginQuery;
    PFNGLBEGINQUERYARBPROC epoxy_glBeginQueryARB;
    PFNGLBEGINQUERYEXTPROC epoxy_glBeginQueryEXT;
    PFNGLBEGINQUERYINDEXEDPROC epoxy_glBeginQueryIndexed;
    PFNGLBEGINTRANSFORMFEEDBACKPROC epoxy_glBeginTransformFeedback;
    PFNGLBEGINTRANSFORMFEEDBACKEXTPROC epoxy_glBeginTransformFeedbackEXT;
    PFNGLBEGINTRANSFORMFEEDBACKNVPROC epoxy_glBeginTransformFeedbackNV;
    PFNGLBEGINVERTEXSHADEREXTPROC epoxy_glBeginVertexShaderEXT;
    PFNGLBEGINVIDEOCAPTURENVPROC epoxy_glBeginVideoCaptureNV;
    PFNGLBINDATTRIBLOCATIONPROC epoxy_glBindAttribLocation;
    PFNGLBINDATTRIBLOCATIONARBPROC epoxy_glBindAttribLocationARB;
    PFNGLBINDBUFFERPROC epoxy_glBindBuffer;
    PFNGLBINDBUFFERARBPROC epoxy_glBindBufferARB;
    PFNGLBINDBUFFERBASEPROC epoxy_glBindBufferBase;
    PFNGLBINDBUFFERBASEEXTPROC epoxy_glBindBufferBaseEXT;
    PFNGLBINDBUFFERBASENVPROC epoxy_glBindBufferBaseNV;
    PFNGLBINDBUFFEROFFSETEXTPROC epoxy_glBindBufferOffsetEXT;
    PFNGLBINDBUFFEROFFSETNVPROC epoxy_glBindBufferOffsetNV;
    PFNGLBINDBUFFERRANGEPROC epoxy_glBindBufferRange;
    PFNGLBINDBUFFERRANGEEXTPROC epoxy_glBindBufferRangeEXT;
    PFNGLBINDBUFFERRANGENVPROC epoxy_glBindBufferRangeNV;
    PFNGLBINDBUFFERSBASEPROC epoxy_glBindBuffersBase;
    PFNGLBINDBUFFERSRANGEPROC epoxy_glBindBuffersRange;
    PFNGLBINDFRAGDATALOCATIONPROC epoxy_glBindFragDataLocation;
    PFNGLBINDFRAGDATALOCATIONEXTPROC epoxy_glBindFragDataLocationEXT;
    PFNGLBINDFRAGDATALOCATIONINDEXEDPROC epoxy_glBindFragDataLocationIndexed;
    PFNGLBINDFRAGDATALOCATIONINDEXEDEXTPROC epoxy_glBindFragDataLocationIndexedEXT;
    PFNGLBINDFRAGMENTSHADERATIPROC epoxy_glBindFragmentShaderATI;
    PFNGLBINDFRAMEBUFFERPROC epoxy_glBindFramebuffer;
    PFNGLBINDFRAMEBUFFEREXTPROC epoxy_glBindFramebufferEXT;
    PFNGLBINDFRAMEBUFFEROESPROC epoxy_glBindFramebufferOES;
    PFNGLBINDIMAGETEXTUREPROC epoxy_glBindImageTexture;
    PFNGLBINDIMAGETEXTUREEXTPROC epoxy_glBindImageTextureEXT;
    PFNGLBINDIMAGETEXTURESPROC epoxy_glBindImageTextures;
    PFNGLBINDLIGHTPARAMETEREXTPROC epoxy_glBindLightParameterEXT;
    PFNGLBINDMATERIALPARAMETEREXTPROC epoxy_glBindMaterialParameterEXT;
    PFNGLBINDMULTITEXTUREEXTPROC epoxy_glBindMultiTextureEXT;
    PFNGLBINDPARAMETEREXTPROC epoxy_glBindParameterEXT;
    PFNGLBINDPROGRAMARBPROC epoxy_glBindProgramARB;
    PFNGLBINDPROGRAMNVPROC epoxy_glBindProgramNV;
    PFNGLBINDPROGRAMPIPELINEPROC epoxy_glBindProgramPipeline;
    PFNGLBINDPROGRAMPIPELINEEXTPROC epoxy_glBindProgramPipelineEXT;
    PFNGLBINDRENDERBUFFERPROC epoxy_glBindRenderbuffer;
    PFNGLBINDRENDERBUFFEREXTPROC epoxy_glBindRenderbufferEXT;
    PFNGLBINDRENDERBUFFEROESPROC epoxy_glBindRenderbufferOES;
    PFNGLBINDSAMPLERPROC epoxy_glBindSampler;
    PFNGLBINDSAMPLERSPROC epoxy_glBindSamplers;
    PFNGLBINDSHADINGRATEIMAGENVPROC epoxy_glBindShadingRateImageNV;
    PFNGLBINDTEXGENPARAMETEREXTPROC epoxy_glBindTexGenParameterEXT;
    PFNGLBINDTEXTUREPROC epoxy_glBindTexture;
    PFNGLBINDTEXTUREEXTPROC epoxy_glBindTextureEXT;
    PFNGLBINDTEXTUREUNITPROC epoxy_glBindTextureUnit;
    PFNGLBINDTEXTUREUNITPARAMETEREXTPROC epoxy_glBindTextureUnitParameterEXT;
    PFNGLBINDTEXTURESPROC epoxy_glBindTextures;
    PFNGLBINDTRANSFORMFEEDBACKPROC epoxy_glBindTransformFeedback;
    PFNGLBINDTRANSFORMFEEDBACKNVPROC epoxy_glBindTransformFeedbackNV;
    PFNGLBINDVERTEXARRAYPROC epoxy_glBindVertexArray;
    PFNGLBINDVERTEXARRAYAPPLEPROC epoxy_glBindVertexArrayAPPLE;
    PFNGLBINDVERTEXARRAYOESPROC epoxy_glBindVertexArrayOES;
    PFNGLBINDVERTEXBUFFERPROC epoxy_glBindVertexBuffer;
    PFNGLBINDVERTEXBUFFERSPROC epoxy_glBindVertexBuffers;
    PFNGLBINDVERTEXSHADEREXTPROC epoxy_glBindVertexShaderEXT;
    PFNGLBINDVIDEOCAPTURESTREAMBUFFERNVPROC epoxy_glBindVideoCaptureStreamBufferNV;
    PFNGLBINDVIDEOCAPTURESTREAMTEXTURENVPROC epoxy_glBindVideoCaptureStreamTextureNV;
    PFNGLBINORMAL3BEXTPROC epoxy_glBinormal3bEXT;
    PFNGLBINORMAL3BVEXTPROC epoxy_glBinormal3bvEXT;
    PFNGLBINORMAL3DEXTPROC epoxy_glBinormal3dEXT;
    PFNGLBINORMAL3DVEXTPROC epoxy_glBinormal3dvEXT;
    PFNGLBINORMAL3FEXTPROC epoxy_glBinormal3fEXT;
    PFNGLBINORMAL3FVEXTPROC epoxy_glBinormal3fvEXT;
    PFNGLBINORMAL3IEXTPROC epoxy_glBinormal3iEXT;
    PFNGLBINORMAL3IVEXTPROC epoxy_glBinormal3ivEXT;
    PFNGLBINORMAL3SEXTPROC epoxy_glBinormal3sEXT;
    PFNGLBINORMAL3SVEXTPROC epoxy_glBinormal3svEXT;
    PFNGLBINORMALPOINTEREXTPROC epoxy_glBinormalPointerEXT;
    PFNGLBITMAPPROC epoxy_glBitmap;
    PFNGLBITMAPXOESPROC epoxy_glBitmapxOES;
    PFNGLBLENDBARRIERPROC epoxy_glBlendBarrier;
    PFNGLBLENDBARRIERKHRPROC epoxy_glBlendBarrierKHR;
    PFNGLBLENDBARRIERNVPROC epoxy_glBlendBarrierNV;
    PFNGLBLENDCOLORPROC epoxy_glBlendColor;
    PFNGLBLENDCOLOREXTPROC epoxy_glBlendColorEXT;
    PFNGLBLENDCOLORXOESPROC epoxy_glBlendColorxOES;
    PFNGLBLENDEQUATIONPROC epoxy_glBlendEquation;
    PFNGLBLENDEQUATIONEXTPROC epoxy_glBlendEquationEXT;
    PFNGLBLENDEQUATIONINDEXEDAMDPROC epoxy_glBlendEquationIndexedAMD;
    PFNGLBLENDEQUATIONOESPROC epoxy_glBlendEquationOES;
    PFNGLBLENDEQUATIONSEPARATEPROC epoxy_glBlendEquationSeparate;
    PFNGLBLENDEQUATIONSEPARATEEXTPROC epoxy_glBlendEquationSeparateEXT;
    PFNGLBLENDEQUATIONSEPARATEINDEXEDAMDPROC epoxy_glBlendEquationSeparateIndexedAMD;
    PFNGLBLENDEQUATIONSEPARATEOESPROC epoxy_glBlendEquationSeparateOES;
    PFNGLBLENDEQUATIONSEPARATEIPROC epoxy_glBlendEquationSeparatei;
    PFNGLBLENDEQUATIONSEPARATEIARBPROC epoxy_glBlendEquationSeparateiARB;
    PFNGLBLENDEQUATIONSEPARATEIEXTPROC epoxy_glBlendEquationSeparateiEXT;
    PFNGLBLENDEQUATIONSEPARATEIOESPROC epoxy_glBlendEquationSeparateiOES;
    PFNGLBLENDEQUATIONIPROC epoxy_glBlendEquationi;
    PFNGLBLENDEQUATIONIARBPROC epoxy_glBlendEquationiARB;
    PFNGLBLENDEQUATIONIEXTPROC epoxy_glBlendEquationiEXT;
    PFNGLBLENDEQUATIONIOESPROC epoxy_glBlendEquationiOES;
    PFNGLBLENDFUNCPROC epoxy_glBlendFunc;
    PFNGLBLENDFUNCINDEXEDAMDPROC epoxy_glBlendFuncIndexedAMD;
    PFNGLBLENDFUNCSEPARATEPROC epoxy_glBlendFuncSeparate;
    PFNGLBLENDFUNCSEPARATEEXTPROC epoxy_glBlendFuncSeparateEXT;
    PFNGLBLENDFUNCSEPARATEINGRPROC epoxy_glBlendFuncSeparateINGR;
    PFNGLBLENDFUNCSEPARATEINDEXEDAMDPROC epoxy_glBlendFuncSeparateIndexedAMD;
    PFNGLBLENDFUNCSEPARATEOESPROC epoxy_glBlendFuncSeparateOES;
    PFNGLBLENDFUNCSEPARATEIPROC epoxy_glBlendFuncSeparatei;
    PFNGLBLENDFUNCSEPARATEIARBPROC epoxy_glBlendFuncSeparateiARB;
    PFNGLBLENDFUNCSEPARATEIEXTPROC epoxy_glBlendFuncSeparateiEXT;
    PFNGLBLENDFUNCSEPARATEIOESPROC epoxy_glBlendFuncSeparateiOES;
    PFNGLBLENDFUNCIPROC epoxy_glBlendFunci;
    PFNGLBLENDFUNCIARBPROC epoxy_glBlendFunciARB;
    PFNGLBLENDFUNCIEXTPROC epoxy_glBlendFunciEXT;
    PFNGLBLENDFUNCIOESPROC epoxy_glBlendFunciOES;
    PFNGLBLENDPARAMETERINVPROC epoxy_glBlendParameteriNV;
    PFNGLBLITFRAMEBUFFERPROC epoxy_glBlitFramebuffer;
    PFNGLBLITFRAMEBUFFERANGLEPROC epoxy_glBlitFramebufferANGLE;
    PFNGLBLITFRAMEBUFFEREXTPROC epoxy_glBlitFramebufferEXT;
    PFNGLBLITFRAMEBUFFERNVPROC epoxy_glBlitFramebufferNV;
    PFNGLBLITNAMEDFRAMEBUFFERPROC epoxy_glBlitNamedFramebuffer;
    PFNGLBUFFERADDRESSRANGENVPROC epoxy_glBufferAddressRangeNV;
    PFNGLBUFFERATTACHMEMORYNVPROC epoxy_glBufferAttachMemoryNV;
    PFNGLBUFFERDATAPROC epoxy_glBufferData;
    PFNGLBUFFERDATAARBPROC epoxy_glBufferDataARB;
    PFNGLBUFFERPAGECOMMITMENTARBPROC epoxy_glBufferPageCommitmentARB;
    PFNGLBUFFERPARAMETERIAPPLEPROC epoxy_glBufferParameteriAPPLE;
    PFNGLBUFFERSTORAGEPROC epoxy_glBufferStorage;
    PFNGLBUFFERSTORAGEEXTPROC epoxy_glBufferStorageEXT;
    PFNGLBUFFERSTORAGEEXTERNALEXTPROC epoxy_glBufferStorageExternalEXT;
    PFNGLBUFFERSTORAGEMEMEXTPROC epoxy_glBufferStorageMemEXT;
    PFNGLBUFFERSUBDATAPROC epoxy_glBufferSubData;
    PFNGLBUFFERSUBDATAARBPROC epoxy_glBufferSubDataARB;
    PFNGLCALLCOMMANDLISTNVPROC epoxy_glCallCommandListNV;
    PFNGLCALLLISTPROC epoxy_glCallList;
    PFNGLCALLLISTSPROC epoxy_glCallLists;
    PFNGLCHECKFRAMEBUFFERSTATUSPROC epoxy_glCheckFramebufferStatus;
    PFNGLCHECKFRAMEBUFFERSTATUSEXTPROC epoxy_glCheckFramebufferStatusEXT;
    PFNGLCHECKFRAMEBUFFERSTATUSOESPROC epoxy_glCheckFramebufferStatusOES;
    PFNGLCHECKNAMEDFRAMEBUFFERSTATUSPROC epoxy_glCheckNamedFramebufferStatus;
    PFNGLCHECKNAMEDFRAMEBUFFERSTATUSEXTPROC epoxy_glCheckNamedFramebufferStatusEXT;
    PFNGLCLAMPCOLORPROC epoxy_glClampColor;
    PFNGLCLAMPCOLORARBPROC epoxy_glClampColorARB;
    PFNGLCLEARPROC epoxy_glClear;
    PFNGLCLEARACCUMPROC epoxy_glClearAccum;
    PFNGLCLEARACCUMXOESPROC epoxy_glClearAccumxOES;
    PFNGLCLEARBUFFERDATAPROC epoxy_glClearBufferData;
    PFNGLCLEARBUFFERSUBDATAPROC epoxy_glClearBufferSubData;
    PFNGLCLEARBUFFERFIPROC epoxy_glClearBufferfi;
    PFNGLCLEARBUFFERFVPROC epoxy_glClearBufferfv;
    PFNGLCLEARBUFFERIVPROC epoxy_glClearBufferiv;
    PFNGLCLEARBUFFERUIVPROC epoxy_glClearBufferuiv;
    PFNGLCLEARCOLORPROC epoxy_glClearColor;
    PFNGLCLEARCOLORIIEXTPROC epoxy_glClearColorIiEXT;
    PFNGLCLEARCOLORIUIEXTPROC epoxy_glClearColorIuiEXT;
    PFNGLCLEARCOLORXPROC epoxy_glClearColorx;
    PFNGLCLEARCOLORXOESPROC epoxy_glClearColorxOES;
    PFNGLCLEARDEPTHPROC epoxy_glClearDepth;
    PFNGLCLEARDEPTHDNVPROC epoxy_glClearDepthdNV;
    PFNGLCLEARDEPTHFPROC epoxy_glClearDepthf;
    PFNGLCLEARDEPTHFOESPROC epoxy_glClearDepthfOES;
    PFNGLCLEARDEPTHXPROC epoxy_glClearDepthx;
    PFNGLCLEARDEPTHXOESPROC epoxy_glClearDepthxOES;
    PFNGLCLEARINDEXPROC epoxy_glClearIndex;
    PFNGLCLEARNAMEDBUFFERDATAPROC epoxy_glClearNamedBufferData;
    PFNGLCLEARNAMEDBUFFERDATAEXTPROC epoxy_glClearNamedBufferDataEXT;
    PFNGLCLEARNAMEDBUFFERSUBDATAPROC epoxy_glClearNamedBufferSubData;
    PFNGLCLEARNAMEDBUFFERSUBDATAEXTPROC epoxy_glClearNamedBufferSubDataEXT;
    PFNGLCLEARNAMEDFRAMEBUFFERFIPROC epoxy_glClearNamedFramebufferfi;
    PFNGLCLEARNAMEDFRAMEBUFFERFVPROC epoxy_glClearNamedFramebufferfv;
    PFNGLCLEARNAMEDFRAMEBUFFERIVPROC epoxy_glClearNamedFramebufferiv;
    PFNGLCLEARNAMEDFRAMEBUFFERUIVPROC epoxy_glClearNamedFramebufferuiv;
    PFNGLCLEARPIXELLOCALSTORAGEUIEXTPROC epoxy_glClearPixelLocalStorageuiEXT;
    PFNGLCLEARSTENCILPROC epoxy_glClearStencil;
    PFNGLCLEARTEXIMAGEPROC epoxy_glClearTexImage;
    PFNGLCLEARTEXIMAGEEXTPROC epoxy_glClearTexImageEXT;
    PFNGLCLEARTEXSUBIMAGEPROC epoxy_glClearTexSubImage;
    PFNGLCLEARTEXSUBIMAGEEXTPROC epoxy_glClearTexSubImageEXT;
    PFNGLCLIENTACTIVETEXTUREPROC epoxy_glClientActiveTexture;
    PFNGLCLIENTACTIVETEXTUREARBPROC epoxy_glClientActiveTextureARB;
    PFNGLCLIENTACTIVEVERTEXSTREAMATIPROC epoxy_glClientActiveVertexStreamATI;
    PFNGLCLIENTATTRIBDEFAULTEXTPROC epoxy_glClientAttribDefaultEXT;
    PFNGLCLIENTWAITSEMAPHOREUI64NVXPROC epoxy_glClientWaitSemaphoreui64NVX;
    PFNGLCLIENTWAITSYNCPROC epoxy_glClientWaitSync;
    PFNGLCLIENTWAITSYNCAPPLEPROC epoxy_glClientWaitSyncAPPLE;
    PFNGLCLIPCONTROLPROC epoxy_glClipControl;
    PFNGLCLIPCONTROLEXTPROC epoxy_glClipControlEXT;
    PFNGLCLIPPLANEPROC epoxy_glClipPlane;
    PFNGLCLIPPLANEFPROC epoxy_glClipPlanef;
    PFNGLCLIPPLANEFIMGPROC epoxy_glClipPlanefIMG;
    PFNGLCLIPPLANEFOESPROC epoxy_glClipPlanefOES;
    PFNGLCLIPPLANEXPROC epoxy_glClipPlanex;
    PFNGLCLIPPLANEXIMGPROC epoxy_glClipPlanexIMG;
    PFNGLCLIPPLANEXOESPROC epoxy_glClipPlanexOES;
    PFNGLCOLOR3BPROC epoxy_glColor3b;
    PFNGLCOLOR3BVPROC epoxy_glColor3bv;
    PFNGLCOLOR3DPROC epoxy_glColor3d;
    PFNGLCOLOR3DVPROC epoxy_glColor3dv;
    PFNGLCOLOR3FPROC epoxy_glColor3f;
    PFNGLCOLOR3FVERTEX3FSUNPROC epoxy_glColor3fVertex3fSUN;
    PFNGLCOLOR3FVERTEX3FVSUNPROC epoxy_glColor3fVertex3fvSUN;
    PFNGLCOLOR3FVPROC epoxy_glColor3fv;
    PFNGLCOLOR3HNVPROC epoxy_glColor3hNV;
    PFNGLCOLOR3HVNVPROC epoxy_glColor3hvNV;
    PFNGLCOLOR3IPROC epoxy_glColor3i;
    PFNGLCOLOR3IVPROC epoxy_glColor3iv;
    PFNGLCOLOR3SPROC epoxy_glColor3s;
    PFNGLCOLOR3SVPROC epoxy_glColor3sv;
    PFNGLCOLOR3UBPROC epoxy_glColor3ub;
    PFNGLCOLOR3UBVPROC epoxy_glColor3ubv;
    PFNGLCOLOR3UIPROC epoxy_glColor3ui;
    PFNGLCOLOR3UIVPROC epoxy_glColor3uiv;
    PFNGLCOLOR3USPROC epoxy_glColor3us;
    PFNGLCOLOR3USVPROC epoxy_glColor3usv;
    PFNGLCOLOR3XOESPROC epoxy_glColor3xOES;
    PFNGLCOLOR3XVOESPROC epoxy_glColor3xvOES;
    PFNGLCOLOR4BPROC epoxy_glColor4b;
    PFNGLCOLOR4BVPROC epoxy_glColor4bv;
    PFNGLCOLOR4DPROC epoxy_glColor4d;
    PFNGLCOLOR4DVPROC epoxy_glColor4dv;
    PFNGLCOLOR4FPROC epoxy_glColor4f;
    PFNGLCOLOR4FNORMAL3FVERTEX3FSUNPROC epoxy_glColor4fNormal3fVertex3fSUN;
    PFNGLCOLOR4FNORMAL3FVERTEX3FVSUNPROC epoxy_glColor4fNormal3fVertex3fvSUN;
    PFNGLCOLOR4FVPROC epoxy_glColor4fv;
    PFNGLCOLOR4HNVPROC epoxy_glColor4hNV;
    PFNGLCOLOR4HVNVPROC epoxy_glColor4hvNV;
    PFNGLCOLOR4IPROC epoxy_glColor4i;
    PFNGLCOLOR4IVPROC epoxy_glColor4iv;
    PFNGLCOLOR4SPROC epoxy_glColor4s;
    PFNGLCOLOR4SVPROC epoxy_glColor4sv;
    PFNGLCOLOR4UBPROC epoxy_glColor4ub;
    PFNGLCOLOR4UBVERTEX2FSUNPROC epoxy_glColor4ubVertex2fSUN;
    PFNGLCOLOR4UBVERTEX2FVSUNPROC epoxy_glColor4ubVertex2fvSUN;
    PFNGLCOLOR4UBVERTEX3FSUNPROC epoxy_glColor4ubVertex3fSUN;
    PFNGLCOLOR4UBVERTEX3FVSUNPROC epoxy_glColor4ubVertex3fvSUN;
    PFNGLCOLOR4UBVPROC epoxy_glColor4ubv;
    PFNGLCOLOR4UIPROC epoxy_glColor4ui;
    PFNGLCOLOR4UIVPROC epoxy_glColor4uiv;
    PFNGLCOLOR4USPROC epoxy_glColor4us;
    PFNGLCOLOR4USVPROC epoxy_glColor4usv;
    PFNGLCOLOR4XPROC epoxy_glColor4x;
    PFNGLCOLOR4XOESPROC epoxy_glColor4xOES;
    PFNGLCOLOR4XVOESPROC epoxy_glColor4xvOES;
    PFNGLCOLORFORMATNVPROC epoxy_glColorFormatNV;
    PFNGLCOLORFRAGMENTOP1ATIPROC epoxy_glColorFragmentOp1ATI;
    PFNGLCOLORFRAGMENTOP2ATIPROC epoxy_glColorFragmentOp2ATI;
    PFNGLCOLORFRAGMENTOP3ATIPROC epoxy_glColorFragmentOp3ATI;
    PFNGLCOLORMASKPROC epoxy_glColorMask;
    PFNGLCOLORMASKINDEXEDEXTPROC epoxy_glColorMaskIndexedEXT;
    PFNGLCOLORMASKIPROC epoxy_glColorMaski;
    PFNGLCOLORMASKIEXTPROC epoxy_glColorMaskiEXT;
    PFNGLCOLORMASKIOESPROC epoxy_glColorMaskiOES;
    PFNGLCOLORMATERIALPROC epoxy_glColorMaterial;
    PFNGLCOLORP3UIPROC epoxy_glColorP3ui;
    PFNGLCOLORP3UIVPROC epoxy_glColorP3uiv;
    PFNGLCOLORP4UIPROC epoxy_glColorP4ui;
    PFNGLCOLORP4UIVPROC epoxy_glColorP4uiv;
    PFNGLCOLORPOINTERPROC epoxy_glColorPointer;
    PFNGLCOLORPOINTEREXTPROC epoxy_glColorPointerEXT;
    PFNGLCOLORPOINTERLISTIBMPROC epoxy_glColorPointerListIBM;
    PFNGLCOLORPOINTERVINTELPROC epoxy_glColorPointervINTEL;
    PFNGLCOLORSUBTABLEPROC epoxy_glColorSubTable;
    PFNGLCOLORSUBTABLEEXTPROC epoxy_glColorSubTableEXT;
    PFNGLCOLORTABLEPROC epoxy_glColorTable;
    PFNGLCOLORTABLEEXTPROC epoxy_glColorTableEXT;
    PFNGLCOLORTABLEPARAMETERFVPROC epoxy_glColorTableParameterfv;
    PFNGLCOLORTABLEPARAMETERFVSGIPROC epoxy_glColorTableParameterfvSGI;
    PFNGLCOLORTABLEPARAMETERIVPROC epoxy_glColorTableParameteriv;
    PFNGLCOLORTABLEPARAMETERIVSGIPROC epoxy_glColorTableParameterivSGI;
    PFNGLCOLORTABLESGIPROC epoxy_glColorTableSGI;
    PFNGLCOMBINERINPUTNVPROC epoxy_glCombinerInputNV;
    PFNGLCOMBINEROUTPUTNVPROC epoxy_glCombinerOutputNV;
    PFNGLCOMBINERPARAMETERFNVPROC epoxy_glCombinerParameterfNV;
    PFNGLCOMBINERPARAMETERFVNVPROC epoxy_glCombinerParameterfvNV;
    PFNGLCOMBINERPARAMETERINVPROC epoxy_glCombinerParameteriNV;
    PFNGLCOMBINERPARAMETERIVNVPROC epoxy_glCombinerParameterivNV;
    PFNGLCOMBINERSTAGEPARAMETERFVNVPROC epoxy_glCombinerStageParameterfvNV;
    PFNGLCOMMANDLISTSEGMENTSNVPROC epoxy_glCommandListSegmentsNV;
    PFNGLCOMPILECOMMANDLISTNVPROC epoxy_glCompileCommandListNV;
    PFNGLCOMPILESHADERPROC epoxy_glCompileShader;
    PFNGLCOMPILESHADERARBPROC epoxy_glCompileShaderARB;
    PFNGLCOMPILESHADERINCLUDEARBPROC epoxy_glCompileShaderIncludeARB;
    PFNGLCOMPRESSEDMULTITEXIMAGE1DEXTPROC epoxy_glCompressedMultiTexImage1DEXT;
    PFNGLCOMPRESSEDMULTITEXIMAGE2DEXTPROC epoxy_glCompressedMultiTexImage2DEXT;
    PFNGLCOMPRESSEDMULTITEXIMAGE3DEXTPROC epoxy_glCompressedMultiTexImage3DEXT;
    PFNGLCOMPRESSEDMULTITEXSUBIMAGE1DEXTPROC epoxy_glCompressedMultiTexSubImage1DEXT;
    PFNGLCOMPRESSEDMULTITEXSUBIMAGE2DEXTPROC epoxy_glCompressedMultiTexSubImage2DEXT;
    PFNGLCOMPRESSEDMULTITEXSUBIMAGE3DEXTPROC epoxy_glCompressedMultiTexSubImage3DEXT;
    PFNGLCOMPRESSEDTEXIMAGE1DPROC epoxy_glCompressedTexImage1D;
    PFNGLCOMPRESSEDTEXIMAGE1DARBPROC epoxy_glCompressedTexImage1DARB;
    PFNGLCOMPRESSEDTEXIMAGE2DPROC epoxy_glCompressedTexImage2D;
    PFNGLCOMPRESSEDTEXIMAGE2DARBPROC epoxy_glCompressedTexImage2DARB;
    PFNGLCOMPRESSEDTEXIMAGE3DPROC epoxy_glCompressedTexImage3D;
    PFNGLCOMPRESSEDTEXIMAGE3DARBPROC epoxy_glCompressedTexImage3DARB;
    PFNGLCOMPRESSEDTEXIMAGE3DOESPROC epoxy_glCompressedTexImage3DOES;
    PFNGLCOMPRESSEDTEXSUBIMAGE1DPROC epoxy_glCompressedTexSubImage1D;
    PFNGLCOMPRESSEDTEXSUBIMAGE1DARBPROC epoxy_glCompressedTexSubImage1DARB;
    PFNGLCOMPRESSEDTEXSUBIMAGE2DPROC epoxy_glCompressedTexSubImage2D;
    PFNGLCOMPRESSEDTEXSUBIMAGE2DARBPROC epoxy_glCompressedTexSubImage2DARB;
    PFNGLCOMPRESSEDTEXSUBIMAGE3DPROC epoxy_glCompressedTexSubImage3D;
    PFNGLCOMPRESSEDTEXSUBIMAGE3DARBPROC epoxy_glCompressedTexSubImage3DARB;
    PFNGLCOMPRESSEDTEXSUBIMAGE3DOESPROC epoxy_glCompressedTexSubImage3DOES;
    PFNGLCOMPRESSEDTEXTUREIMAGE1DEXTPROC epoxy_glCompressedTextureImage1DEXT;
    PFNGLCOMPRESSEDTEXTUREIMAGE2DEXTPROC epoxy_glCompressedTextureImage2DEXT;
    PFNGLCOMPRESSEDTEXTUREIMAGE3DEXTPROC epoxy_glCompressedTextureImage3DEXT;
    PFNGLCOMPRESSEDTEXTURESUBIMAGE1DPROC epoxy_glCompressedTextureSubImage1D;
    PFNGLCOMPRESSEDTEXTURESUBIMAGE1DEXTPROC epoxy_glCompressedTextureSubImage1DEXT;
    PFNGLCOMPRESSEDTEXTURESUBIMAGE2DPROC epoxy_glCompressedTextureSubImage2D;
    PFNGLCOMPRESSEDTEXTURESUBIMAGE2DEXTPROC epoxy_glCompressedTextureSubImage2DEXT;
    PFNGLCOMPRESSEDTEXTURESUBIMAGE3DPROC epoxy_glCompressedTextureSubImage3D;
    PFNGLCOMPRESSEDTEXTURESUBIMAGE3DEXTPROC epoxy_glCompressedTextureSubImage3DEXT;
    PFNGLCONSERVATIVERASTERPARAMETERFNVPROC epoxy_glConservativeRasterParameterfNV;
    PFNGLCONSERVATIVERASTERPARAMETERINVPROC epoxy_glConservativeRasterParameteriNV;
    PFNGLCONVOLUTIONFILTER1DPROC epoxy_glConvolutionFilter1D;
    PFNGLCONVOLUTIONFILTER1DEXTPROC epoxy_glConvolutionFilter1DEXT;
    PFNGLCONVOLUTIONFILTER2DPROC epoxy_glConvolutionFilter2D;
    PFNGLCONVOLUTIONFILTER2DEXTPROC epoxy_glConvolutionFilter2DEXT;
    PFNGLCONVOLUTIONPARAMETERFPROC epoxy_glConvolutionParameterf;
    PFNGLCONVOLUTIONPARAMETERFEXTPROC epoxy_glConvolutionParameterfEXT;
    PFNGLCONVOLUTIONPARAMETERFVPROC epoxy_glConvolutionParameterfv;
    PFNGLCONVOLUTIONPARAMETERFVEXTPROC epoxy_glConvolutionParameterfvEXT;
    PFNGLCONVOLUTIONPARAMETERIPROC epoxy_glConvolutionParameteri;
    PFNGLCONVOLUTIONPARAMETERIEXTPROC epoxy_glConvolutionParameteriEXT;
    PFNGLCONVOLUTIONPARAMETERIVPROC epoxy_glConvolutionParameteriv;
    PFNGLCONVOLUTIONPARAMETERIVEXTPROC epoxy_glConvolutionParameterivEXT;
    PFNGLCONVOLUTIONPARAMETERXOESPROC epoxy_glConvolutionParameterxOES;
    PFNGLCONVOLUTIONPARAMETERXVOESPROC epoxy_glConvolutionParameterxvOES;
    PFNGLCOPYBUFFERSUBDATAPROC epoxy_glCopyBufferSubData;
    PFNGLCOPYBUFFERSUBDATANVPROC epoxy_glCopyBufferSubDataNV;
    PFNGLCOPYCOLORSUBTABLEPROC epoxy_glCopyColorSubTable;
    PFNGLCOPYCOLORSUBTABLEEXTPROC epoxy_glCopyColorSubTableEXT;
    PFNGLCOPYCOLORTABLEPROC epoxy_glCopyColorTable;
    PFNGLCOPYCOLORTABLESGIPROC epoxy_glCopyColorTableSGI;
    PFNGLCOPYCONVOLUTIONFILTER1DPROC epoxy_glCopyConvolutionFilter1D;
    PFNGLCOPYCONVOLUTIONFILTER1DEXTPROC epoxy_glCopyConvolutionFilter1DEXT;
    PFNGLCOPYCONVOLUTIONFILTER2DPROC epoxy_glCopyConvolutionFilter2D;
    PFNGLCOPYCONVOLUTIONFILTER2DEXTPROC epoxy_glCopyConvolutionFilter2DEXT;
    PFNGLCOPYIMAGESUBDATAPROC epoxy_glCopyImageSubData;
    PFNGLCOPYIMAGESUBDATAEXTPROC epoxy_glCopyImageSubDataEXT;
    PFNGLCOPYIMAGESUBDATANVPROC epoxy_glCopyImageSubDataNV;
    PFNGLCOPYIMAGESUBDATAOESPROC epoxy_glCopyImageSubDataOES;
    PFNGLCOPYMULTITEXIMAGE1DEXTPROC epoxy_glCopyMultiTexImage1DEXT;
    PFNGLCOPYMULTITEXIMAGE2DEXTPROC epoxy_glCopyMultiTexImage2DEXT;
    PFNGLCOPYMULTITEXSUBIMAGE1DEXTPROC epoxy_glCopyMultiTexSubImage1DEXT;
    PFNGLCOPYMULTITEXSUBIMAGE2DEXTPROC epoxy_glCopyMultiTexSubImage2DEXT;
    PFNGLCOPYMULTITEXSUBIMAGE3DEXTPROC epoxy_glCopyMultiTexSubImage3DEXT;
    PFNGLCOPYNAMEDBUFFERSUBDATAPROC epoxy_glCopyNamedBufferSubData;
    PFNGLCOPYPATHNVPROC epoxy_glCopyPathNV;
    PFNGLCOPYPIXELSPROC epoxy_glCopyPixels;
    PFNGLCOPYTEXIMAGE1DPROC epoxy_glCopyTexImage1D;
    PFNGLCOPYTEXIMAGE1DEXTPROC epoxy_glCopyTexImage1DEXT;
    PFNGLCOPYTEXIMAGE2DPROC epoxy_glCopyTexImage2D;
    PFNGLCOPYTEXIMAGE2DEXTPROC epoxy_glCopyTexImage2DEXT;
    PFNGLCOPYTEXSUBIMAGE1DPROC epoxy_glCopyTexSubImage1D;
    PFNGLCOPYTEXSUBIMAGE1DEXTPROC epoxy_glCopyTexSubImage1DEXT;
    PFNGLCOPYTEXSUBIMAGE2DPROC epoxy_glCopyTexSubImage2D;
    PFNGLCOPYTEXSUBIMAGE2DEXTPROC epoxy_glCopyTexSubImage2DEXT;
    PFNGLCOPYTEXSUBIMAGE3DPROC epoxy_glCopyTexSubImage3D;
    PFNGLCOPYTEXSUBIMAGE3DEXTPROC epoxy_glCopyTexSubImage3DEXT;
    PFNGLCOPYTEXSUBIMAGE3DOESPROC epoxy_glCopyTexSubImage3DOES;
    PFNGLCOPYTEXTUREIMAGE1DEXTPROC epoxy_glCopyTextureImage1DEXT;
    PFNGLCOPYTEXTUREIMAGE2DEXTPROC epoxy_glCopyTextureImage2DEXT;
    PFNGLCOPYTEXTURELEVELSAPPLEPROC epoxy_glCopyTextureLevelsAPPLE;
    PFNGLCOPYTEXTURESUBIMAGE1DPROC epoxy_glCopyTextureSubImage1D;
    PFNGLCOPYTEXTURESUBIMAGE1DEXTPROC epoxy_glCopyTextureSubImage1DEXT;
    PFNGLCOPYTEXTURESUBIMAGE2DPROC epoxy_glCopyTextureSubImage2D;
    PFNGLCOPYTEXTURESUBIMAGE2DEXTPROC epoxy_glCopyTextureSubImage2DEXT;
    PFNGLCOPYTEXTURESUBIMAGE3DPROC epoxy_glCopyTextureSubImage3D;
    PFNGLCOPYTEXTURESUBIMAGE3DEXTPROC epoxy_glCopyTextureSubImage3DEXT;
    PFNGLCOVERFILLPATHINSTANCEDNVPROC epoxy_glCoverFillPathInstancedNV;
    PFNGLCOVERFILLPATHNVPROC epoxy_glCoverFillPathNV;
    PFNGLCOVERSTROKEPATHINSTANCEDNVPROC epoxy_glCoverStrokePathInstancedNV;
    PFNGLCOVERSTROKEPATHNVPROC epoxy_glCoverStrokePathNV;
    PFNGLCOVERAGEMASKNVPROC epoxy_glCoverageMaskNV;
    PFNGLCOVERAGEMODULATIONNVPROC epoxy_glCoverageModulationNV;
    PFNGLCOVERAGEMODULATIONTABLENVPROC epoxy_glCoverageModulationTableNV;
    PFNGLCOVERAGEOPERATIONNVPROC epoxy_glCoverageOperationNV;
    PFNGLCREATEBUFFERSPROC epoxy_glCreateBuffers;
    PFNGLCREATECOMMANDLISTSNVPROC epoxy_glCreateCommandListsNV;
    PFNGLCREATEFRAMEBUFFERSPROC epoxy_glCreateFramebuffers;
    PFNGLCREATEMEMORYOBJECTSEXTPROC epoxy_glCreateMemoryObjectsEXT;
    PFNGLCREATEPERFQUERYINTELPROC epoxy_glCreatePerfQueryINTEL;
    PFNGLCREATEPROGRAMPROC epoxy_glCreateProgram;
    PFNGLCREATEPROGRAMOBJECTARBPROC epoxy_glCreateProgramObjectARB;
    PFNGLCREATEPROGRAMPIPELINESPROC epoxy_glCreateProgramPipelines;
    PFNGLCREATEPROGRESSFENCENVXPROC epoxy_glCreateProgressFenceNVX;
    PFNGLCREATEQUERIESPROC epoxy_glCreateQueries;
    PFNGLCREATERENDERBUFFERSPROC epoxy_glCreateRenderbuffers;
    PFNGLCREATESAMPLERSPROC epoxy_glCreateSamplers;
    PFNGLCREATESHADERPROC epoxy_glCreateShader;
    PFNGLCREATESHADEROBJECTARBPROC epoxy_glCreateShaderObjectARB;
    PFNGLCREATESHADERPROGRAMEXTPROC epoxy_glCreateShaderProgramEXT;
    PFNGLCREATESHADERPROGRAMVPROC epoxy_glCreateShaderProgramv;
    PFNGLCREATESHADERPROGRAMVEXTPROC epoxy_glCreateShaderProgramvEXT;
    PFNGLCREATESTATESNVPROC epoxy_glCreateStatesNV;
    PFNGLCREATESYNCFROMCLEVENTARBPROC epoxy_glCreateSyncFromCLeventARB;
    PFNGLCREATETEXTURESPROC epoxy_glCreateTextures;
    PFNGLCREATETRANSFORMFEEDBACKSPROC epoxy_glCreateTransformFeedbacks;
    PFNGLCREATEVERTEXARRAYSPROC epoxy_glCreateVertexArrays;
    PFNGLCULLFACEPROC epoxy_glCullFace;
    PFNGLCULLPARAMETERDVEXTPROC epoxy_glCullParameterdvEXT;
    PFNGLCULLPARAMETERFVEXTPROC epoxy_glCullParameterfvEXT;
    PFNGLCURRENTPALETTEMATRIXARBPROC epoxy_glCurrentPaletteMatrixARB;
    PFNGLCURRENTPALETTEMATRIXOESPROC epoxy_glCurrentPaletteMatrixOES;
    PFNGLDEBUGMESSAGECALLBACKPROC epoxy_glDebugMessageCallback;
    PFNGLDEBUGMESSAGECALLBACKAMDPROC epoxy_glDebugMessageCallbackAMD;
    PFNGLDEBUGMESSAGECALLBACKARBPROC epoxy_glDebugMessageCallbackARB;
    PFNGLDEBUGMESSAGECALLBACKKHRPROC epoxy_glDebugMessageCallbackKHR;
    PFNGLDEBUGMESSAGECONTROLPROC epoxy_glDebugMessageControl;
    PFNGLDEBUGMESSAGECONTROLARBPROC epoxy_glDebugMessageControlARB;
    PFNGLDEBUGMESSAGECONTROLKHRPROC epoxy_glDebugMessageControlKHR;
    PFNGLDEBUGMESSAGEENABLEAMDPROC epoxy_glDebugMessageEnableAMD;
    PFNGLDEBUGMESSAGEINSERTPROC epoxy_glDebugMessageInsert;
    PFNGLDEBUGMESSAGEINSERTAMDPROC epoxy_glDebugMessageInsertAMD;
    PFNGLDEBUGMESSAGEINSERTARBPROC epoxy_glDebugMessageInsertARB;
    PFNGLDEBUGMESSAGEINSERTKHRPROC epoxy_glDebugMessageInsertKHR;
    PFNGLDEFORMSGIXPROC epoxy_glDeformSGIX;
    PFNGLDEFORMATIONMAP3DSGIXPROC epoxy_glDeformationMap3dSGIX;
    PFNGLDEFORMATIONMAP3FSGIXPROC epoxy_glDeformationMap3fSGIX;
    PFNGLDELETEASYNCMARKERSSGIXPROC epoxy_glDeleteAsyncMarkersSGIX;
    PFNGLDELETEBUFFERSPROC epoxy_glDeleteBuffers;
    PFNGLDELETEBUFFERSARBPROC epoxy_glDeleteBuffersARB;
    PFNGLDELETECOMMANDLISTSNVPROC epoxy_glDeleteCommandListsNV;
    PFNGLDELETEFENCESAPPLEPROC epoxy_glDeleteFencesAPPLE;
    PFNGLDELETEFENCESNVPROC epoxy_glDeleteFencesNV;
    PFNGLDELETEFRAGMENTSHADERATIPROC epoxy_glDeleteFragmentShaderATI;
    PFNGLDELETEFRAMEBUFFERSPROC epoxy_glDeleteFramebuffers;
    PFNGLDELETEFRAMEBUFFERSEXTPROC epoxy_glDeleteFramebuffersEXT;
    PFNGLDELETEFRAMEBUFFERSOESPROC epoxy_glDeleteFramebuffersOES;
    PFNGLDELETELISTSPROC epoxy_glDeleteLists;
    PFNGLDELETEMEMORYOBJECTSEXTPROC epoxy_glDeleteMemoryObjectsEXT;
    PFNGLDELETENAMEDSTRINGARBPROC epoxy_glDeleteNamedStringARB;
    PFNGLDELETENAMESAMDPROC epoxy_glDeleteNamesAMD;
    PFNGLDELETEOBJECTARBPROC epoxy_glDeleteObjectARB;
    PFNGLDELETEOCCLUSIONQUERIESNVPROC epoxy_glDeleteOcclusionQueriesNV;
    PFNGLDELETEPATHSNVPROC epoxy_glDeletePathsNV;
    PFNGLDELETEPERFMONITORSAMDPROC epoxy_glDeletePerfMonitorsAMD;
    PFNGLDELETEPERFQUERYINTELPROC epoxy_glDeletePerfQueryINTEL;
    PFNGLDELETEPROGRAMPROC epoxy_glDeleteProgram;
    PFNGLDELETEPROGRAMPIPELINESPROC epoxy_glDeleteProgramPipelines;
    PFNGLDELETEPROGRAMPIPELINESEXTPROC epoxy_glDeleteProgramPipelinesEXT;
    PFNGLDELETEPROGRAMSARBPROC epoxy_glDeleteProgramsARB;
    PFNGLDELETEPROGRAMSNVPROC epoxy_glDeleteProgramsNV;
    PFNGLDELETEQUERIESPROC epoxy_glDeleteQueries;
    PFNGLDELETEQUERIESARBPROC epoxy_glDeleteQueriesARB;
    PFNGLDELETEQUERIESEXTPROC epoxy_glDeleteQueriesEXT;
    PFNGLDELETEQUERYRESOURCETAGNVPROC epoxy_glDeleteQueryResourceTagNV;
    PFNGLDELETERENDERBUFFERSPROC epoxy_glDeleteRenderbuffers;
    PFNGLDELETERENDERBUFFERSEXTPROC epoxy_glDeleteRenderbuffersEXT;
    PFNGLDELETERENDERBUFFERSOESPROC epoxy_glDeleteRenderbuffersOES;
    PFNGLDELETESAMPLERSPROC epoxy_glDeleteSamplers;
    PFNGLDELETESEMAPHORESEXTPROC epoxy_glDeleteSemaphoresEXT;
    PFNGLDELETESHADERPROC epoxy_glDeleteShader;
    PFNGLDELETESTATESNVPROC epoxy_glDeleteStatesNV;
    PFNGLDELETESYNCPROC epoxy_glDeleteSync;
    PFNGLDELETESYNCAPPLEPROC epoxy_glDeleteSyncAPPLE;
    PFNGLDELETETEXTURESPROC epoxy_glDeleteTextures;
    PFNGLDELETETEXTURESEXTPROC epoxy_glDeleteTexturesEXT;
    PFNGLDELETETRANSFORMFEEDBACKSPROC epoxy_glDeleteTransformFeedbacks;
    PFNGLDELETETRANSFORMFEEDBACKSNVPROC epoxy_glDeleteTransformFeedbacksNV;
    PFNGLDELETEVERTEXARRAYSPROC epoxy_glDeleteVertexArrays;
    PFNGLDELETEVERTEXARRAYSAPPLEPROC epoxy_glDeleteVertexArraysAPPLE;
    PFNGLDELETEVERTEXARRAYSOESPROC epoxy_glDeleteVertexArraysOES;
    PFNGLDELETEVERTEXSHADEREXTPROC epoxy_glDeleteVertexShaderEXT;
    PFNGLDEPTHBOUNDSEXTPROC epoxy_glDepthBoundsEXT;
    PFNGLDEPTHBOUNDSDNVPROC epoxy_glDepthBoundsdNV;
    PFNGLDEPTHFUNCPROC epoxy_glDepthFunc;
    PFNGLDEPTHMASKPROC epoxy_glDepthMask;
    PFNGLDEPTHRANGEPROC epoxy_glDepthRange;
    PFNGLDEPTHRANGEARRAYFVNVPROC epoxy_glDepthRangeArrayfvNV;
    PFNGLDEPTHRANGEARRAYFVOESPROC epoxy_glDepthRangeArrayfvOES;
    PFNGLDEPTHRANGEARRAYVPROC epoxy_glDepthRangeArrayv;
    PFNGLDEPTHRANGEINDEXEDPROC epoxy_glDepthRangeIndexed;
    PFNGLDEPTHRANGEINDEXEDFNVPROC epoxy_glDepthRangeIndexedfNV;
    PFNGLDEPTHRANGEINDEXEDFOESPROC epoxy_glDepthRangeIndexedfOES;
    PFNGLDEPTHRANGEDNVPROC epoxy_glDepthRangedNV;
    PFNGLDEPTHRANGEFPROC epoxy_glDepthRangef;
    PFNGLDEPTHRANGEFOESPROC epoxy_glDepthRangefOES;
    PFNGLDEPTHRANGEXPROC epoxy_glDepthRangex;
    PFNGLDEPTHRANGEXOESPROC epoxy_glDepthRangexOES;
    PFNGLDETACHOBJECTARBPROC epoxy_glDetachObjectARB;
    PFNGLDETACHSHADERPROC epoxy_glDetachShader;
    PFNGLDETAILTEXFUNCSGISPROC epoxy_glDetailTexFuncSGIS;
    PFNGLDISABLEPROC epoxy_glDisable;
    PFNGLDISABLECLIENTSTATEPROC epoxy_glDisableClientState;
    PFNGLDISABLECLIENTSTATEINDEXEDEXTPROC epoxy_glDisableClientStateIndexedEXT;
    PFNGLDISABLECLIENTSTATEIEXTPROC epoxy_glDisableClientStateiEXT;
    PFNGLDISABLEDRIVERCONTROLQCOMPROC epoxy_glDisableDriverControlQCOM;
    PFNGLDISABLEINDEXEDEXTPROC epoxy_glDisableIndexedEXT;
    PFNGLDISABLEVARIANTCLIENTSTATEEXTPROC epoxy_glDisableVariantClientStateEXT;
    PFNGLDISABLEVERTEXARRAYATTRIBPROC epoxy_glDisableVertexArrayAttrib;
    PFNGLDISABLEVERTEXARRAYATTRIBEXTPROC epoxy_glDisableVertexArrayAttribEXT;
    PFNGLDISABLEVERTEXARRAYEXTPROC epoxy_glDisableVertexArrayEXT;
    PFNGLDISABLEVERTEXATTRIBAPPLEPROC epoxy_glDisableVertexAttribAPPLE;
    PFNGLDISABLEVERTEXATTRIBARRAYPROC epoxy_glDisableVertexAttribArray;
    PFNGLDISABLEVERTEXATTRIBARRAYARBPROC epoxy_glDisableVertexAttribArrayARB;
    PFNGLDISABLEIPROC epoxy_glDisablei;
    PFNGLDISABLEIEXTPROC epoxy_glDisableiEXT;
    PFNGLDISABLEINVPROC epoxy_glDisableiNV;
    PFNGLDISABLEIOESPROC epoxy_glDisableiOES;
    PFNGLDISCARDFRAMEBUFFEREXTPROC epoxy_glDiscardFramebufferEXT;
    PFNGLDISPATCHCOMPUTEPROC epoxy_glDispatchCompute;
    PFNGLDISPATCHCOMPUTEGROUPSIZEARBPROC epoxy_glDispatchComputeGroupSizeARB;
    PFNGLDISPATCHCOMPUTEINDIRECTPROC epoxy_glDispatchComputeIndirect;
    PFNGLDRAWARRAYSPROC epoxy_glDrawArrays;
    PFNGLDRAWARRAYSEXTPROC epoxy_glDrawArraysEXT;
    PFNGLDRAWARRAYSINDIRECTPROC epoxy_glDrawArraysIndirect;
    PFNGLDRAWARRAYSINSTANCEDPROC epoxy_glDrawArraysInstanced;
    PFNGLDRAWARRAYSINSTANCEDANGLEPROC epoxy_glDrawArraysInstancedANGLE;
    PFNGLDRAWARRAYSINSTANCEDARBPROC epoxy_glDrawArraysInstancedARB;
    PFNGLDRAWARRAYSINSTANCEDBASEINSTANCEPROC epoxy_glDrawArraysInstancedBaseInstance;
    PFNGLDRAWARRAYSINSTANCEDBASEINSTANCEEXTPROC epoxy_glDrawArraysInstancedBaseInstanceEXT;
    PFNGLDRAWARRAYSINSTANCEDEXTPROC epoxy_glDrawArraysInstancedEXT;
    PFNGLDRAWARRAYSINSTANCEDNVPROC epoxy_glDrawArraysInstancedNV;
    PFNGLDRAWBUFFERPROC epoxy_glDrawBuffer;
    PFNGLDRAWBUFFERSPROC epoxy_glDrawBuffers;
    PFNGLDRAWBUFFERSARBPROC epoxy_glDrawBuffersARB;
    PFNGLDRAWBUFFERSATIPROC epoxy_glDrawBuffersATI;
    PFNGLDRAWBUFFERSEXTPROC epoxy_glDrawBuffersEXT;
    PFNGLDRAWBUFFERSINDEXEDEXTPROC epoxy_glDrawBuffersIndexedEXT;
    PFNGLDRAWBUFFERSNVPROC epoxy_glDrawBuffersNV;
    PFNGLDRAWCOMMANDSADDRESSNVPROC epoxy_glDrawCommandsAddressNV;
    PFNGLDRAWCOMMANDSNVPROC epoxy_glDrawCommandsNV;
    PFNGLDRAWCOMMANDSSTATESADDRESSNVPROC epoxy_glDrawCommandsStatesAddressNV;
    PFNGLDRAWCOMMANDSSTATESNVPROC epoxy_glDrawCommandsStatesNV;
    PFNGLDRAWELEMENTARRAYAPPLEPROC epoxy_glDrawElementArrayAPPLE;
    PFNGLDRAWELEMENTARRAYATIPROC epoxy_glDrawElementArrayATI;
    PFNGLDRAWELEMENTSPROC epoxy_glDrawElements;
    PFNGLDRAWELEMENTSBASEVERTEXPROC epoxy_glDrawElementsBaseVertex;
    PFNGLDRAWELEMENTSBASEVERTEXEXTPROC epoxy_glDrawElementsBaseVertexEXT;
    PFNGLDRAWELEMENTSBASEVERTEXOESPROC epoxy_glDrawElementsBaseVertexOES;
    PFNGLDRAWELEMENTSINDIRECTPROC epoxy_glDrawElementsIndirect;
    PFNGLDRAWELEMENTSINSTANCEDPROC epoxy_glDrawElementsInstanced;
    PFNGLDRAWELEMENTSINSTANCEDANGLEPROC epoxy_glDrawElementsInstancedANGLE;
    PFNGLDRAWELEMENTSINSTANCEDARBPROC epoxy_glDrawElementsInstancedARB;
    PFNGLDRAWELEMENTSINSTANCEDBASEINSTANCEPROC epoxy_glDrawElementsInstancedBaseInstance;
    PFNGLDRAWELEMENTSINSTANCEDBASEINSTANCEEXTPROC epoxy_glDrawElementsInstancedBaseInstanceEXT;
    PFNGLDRAWELEMENTSINSTANCEDBASEVERTEXPROC epoxy_glDrawElementsInstancedBaseVertex;
    PFNGLDRAWELEMENTSINSTANCEDBASEVERTEXBASEINSTANCEPROC epoxy_glDrawElementsInstancedBaseVertexBaseInstance;
    PFNGLDRAWELEMENTSINSTANCEDBASEVERTEXBASEINSTANCEEXTPROC epoxy_glDrawElementsInstancedBaseVertexBaseInstanceEXT;
    PFNGLDRAWELEMENTSINSTANCEDBASEVERTEXEXTPROC epoxy_glDrawElementsInstancedBaseVertexEXT;
    PFNGLDRAWELEMENTSINSTANCEDBASEVERTEXOESPROC epoxy_glDrawElementsInstancedBaseVertexOES;
    PFNGLDRAWELEMENTSINSTANCEDEXTPROC epoxy_glDrawElementsInstancedEXT;
    PFNGLDRAWELEMENTSINSTANCEDNVPROC epoxy_glDrawElementsInstancedNV;
    PFNGLDRAWMESHARRAYSSUNPROC epoxy_glDrawMeshArraysSUN;
    PFNGLDRAWMESHTASKSINDIRECTNVPROC epoxy_glDrawMeshTasksIndirectNV;
    PFNGLDRAWMESHTASKSNVPROC epoxy_glDrawMeshTasksNV;
    PFNGLDRAWPIXELSPROC epoxy_glDrawPixels;
    PFNGLDRAWRANGEELEMENTARRAYAPPLEPROC epoxy_glDrawRangeElementArrayAPPLE;
    PFNGLDRAWRANGEELEMENTARRAYATIPROC epoxy_glDrawRangeElementArrayATI;
    PFNGLDRAWRANGEELEMENTSPROC epoxy_glDrawRangeElements;
    PFNGLDRAWRANGEELEMENTSBASEVERTEXPROC epoxy_glDrawRangeElementsBaseVertex;
    PFNGLDRAWRANGEELEMENTSBASEVERTEXEXTPROC epoxy_glDrawRangeElementsBaseVertexEXT;
    PFNGLDRAWRANGEELEMENTSBASEVERTEXOESPROC epoxy_glDrawRangeElementsBaseVertexOES;
    PFNGLDRAWRANGEELEMENTSEXTPROC epoxy_glDrawRangeElementsEXT;
    PFNGLDRAWTEXFOESPROC epoxy_glDrawTexfOES;
    PFNGLDRAWTEXFVOESPROC epoxy_glDrawTexfvOES;
    PFNGLDRAWTEXIOESPROC epoxy_glDrawTexiOES;
    PFNGLDRAWTEXIVOESPROC epoxy_glDrawTexivOES;
    PFNGLDRAWTEXSOESPROC epoxy_glDrawTexsOES;
    PFNGLDRAWTEXSVOESPROC epoxy_glDrawTexsvOES;
    PFNGLDRAWTEXTURENVPROC epoxy_glDrawTextureNV;
    PFNGLDRAWTEXXOESPROC epoxy_glDrawTexxOES;
    PFNGLDRAWTEXXVOESPROC epoxy_glDrawTexxvOES;
    PFNGLDRAWTRANSFORMFEEDBACKPROC epoxy_glDrawTransformFeedback;
    PFNGLDRAWTRANSFORMFEEDBACKEXTPROC epoxy_glDrawTransformFeedbackEXT;
    PFNGLDRAWTRANSFORMFEEDBACKINSTANCEDPROC epoxy_glDrawTransformFeedbackInstanced;
    PFNGLDRAWTRANSFORMFEEDBACKINSTANCEDEXTPROC epoxy_glDrawTransformFeedbackInstancedEXT;
    PFNGLDRAWTRANSFORMFEEDBACKNVPROC epoxy_glDrawTransformFeedbackNV;
    PFNGLDRAWTRANSFORMFEEDBACKSTREAMPROC epoxy_glDrawTransformFeedbackStream;
    PFNGLDRAWTRANSFORMFEEDBACKSTREAMINSTANCEDPROC epoxy_glDrawTransformFeedbackStreamInstanced;
    PFNGLDRAWVKIMAGENVPROC epoxy_glDrawVkImageNV;
    PFNGLEGLIMAGETARGETRENDERBUFFERSTORAGEOESPROC epoxy_glEGLImageTargetRenderbufferStorageOES;
    PFNGLEGLIMAGETARGETTEXSTORAGEEXTPROC epoxy_glEGLImageTargetTexStorageEXT;
    PFNGLEGLIMAGETARGETTEXTURE2DOESPROC epoxy_glEGLImageTargetTexture2DOES;
    PFNGLEGLIMAGETARGETTEXTURESTORAGEEXTPROC epoxy_glEGLImageTargetTextureStorageEXT;
    PFNGLEDGEFLAGPROC epoxy_glEdgeFlag;
    PFNGLEDGEFLAGFORMATNVPROC epoxy_glEdgeFlagFormatNV;
    PFNGLEDGEFLAGPOINTERPROC epoxy_glEdgeFlagPointer;
    PFNGLEDGEFLAGPOINTEREXTPROC epoxy_glEdgeFlagPointerEXT;
    PFNGLEDGEFLAGPOINTERLISTIBMPROC epoxy_glEdgeFlagPointerListIBM;
    PFNGLEDGEFLAGVPROC epoxy_glEdgeFlagv;
    PFNGLELEMENTPOINTERAPPLEPROC epoxy_glElementPointerAPPLE;
    PFNGLELEMENTPOINTERATIPROC epoxy_glElementPointerATI;
    PFNGLENABLEPROC epoxy_glEnable;
    PFNGLENABLECLIENTSTATEPROC epoxy_glEnableClientState;
    PFNGLENABLECLIENTSTATEINDEXEDEXTPROC epoxy_glEnableClientStateIndexedEXT;
    PFNGLENABLECLIENTSTATEIEXTPROC epoxy_glEnableClientStateiEXT;
    PFNGLENABLEDRIVERCONTROLQCOMPROC epoxy_glEnableDriverControlQCOM;
    PFNGLENABLEINDEXEDEXTPROC epoxy_glEnableIndexedEXT;
    PFNGLENABLEVARIANTCLIENTSTATEEXTPROC epoxy_glEnableVariantClientStateEXT;
    PFNGLENABLEVERTEXARRAYATTRIBPROC epoxy_glEnableVertexArrayAttrib;
    PFNGLENABLEVERTEXARRAYATTRIBEXTPROC epoxy_glEnableVertexArrayAttribEXT;
    PFNGLENABLEVERTEXARRAYEXTPROC epoxy_glEnableVertexArrayEXT;
    PFNGLENABLEVERTEXATTRIBAPPLEPROC epoxy_glEnableVertexAttribAPPLE;
    PFNGLENABLEVERTEXATTRIBARRAYPROC epoxy_glEnableVertexAttribArray;
    PFNGLENABLEVERTEXATTRIBARRAYARBPROC epoxy_glEnableVertexAttribArrayARB;
    PFNGLENABLEIPROC epoxy_glEnablei;
    PFNGLENABLEIEXTPROC epoxy_glEnableiEXT;
    PFNGLENABLEINVPROC epoxy_glEnableiNV;
    PFNGLENABLEIOESPROC epoxy_glEnableiOES;
    PFNGLENDPROC epoxy_glEnd_unwrapped;
    PFNGLENDCONDITIONALRENDERPROC epoxy_glEndConditionalRender;
    PFNGLENDCONDITIONALRENDERNVPROC epoxy_glEndConditionalRenderNV;
    PFNGLENDCONDITIONALRENDERNVXPROC epoxy_glEndConditionalRenderNVX;
    PFNGLENDFRAGMENTSHADERATIPROC epoxy_glEndFragmentShaderATI;
    PFNGLENDLISTPROC epoxy_glEndList;
    PFNGLENDOCCLUSIONQUERYNVPROC epoxy_glEndOcclusionQueryNV;
    PFNGLENDPERFMONITORAMDPROC epoxy_glEndPerfMonitorAMD;
    PFNGLENDPERFQUERYINTELPROC epoxy_glEndPerfQueryINTEL;
    PFNGLENDQUERYPROC epoxy_glEndQuery;
    PFNGLENDQUERYARBPROC epoxy_glEndQueryARB;
    PFNGLENDQUERYEXTPROC epoxy_glEndQueryEXT;
    PFNGLENDQUERYINDEXEDPROC epoxy_glEndQueryIndexed;
    PFNGLENDTILINGQCOMPROC epoxy_glEndTilingQCOM;
    PFNGLENDTRANSFORMFEEDBACKPROC epoxy_glEndTransformFeedback;
    PFNGLENDTRANSFORMFEEDBACKEXTPROC epoxy_glEndTransformFeedbackEXT;
    PFNGLENDTRANSFORMFEEDBACKNVPROC epoxy_glEndTransformFeedbackNV;
    PFNGLENDVERTEXSHADEREXTPROC epoxy_glEndVertexShaderEXT;
    PFNGLENDVIDEOCAPTURENVPROC epoxy_glEndVideoCaptureNV;
    PFNGLEVALCOORD1DPROC epoxy_glEvalCoord1d;
    PFNGLEVALCOORD1DVPROC epoxy_glEvalCoord1dv;
    PFNGLEVALCOORD1FPROC epoxy_glEvalCoord1f;
    PFNGLEVALCOORD1FVPROC epoxy_glEvalCoord1fv;
    PFNGLEVALCOORD1XOESPROC epoxy_glEvalCoord1xOES;
    PFNGLEVALCOORD1XVOESPROC epoxy_glEvalCoord1xvOES;
    PFNGLEVALCOORD2DPROC epoxy_glEvalCoord2d;
    PFNGLEVALCOORD2DVPROC epoxy_glEvalCoord2dv;
    PFNGLEVALCOORD2FPROC epoxy_glEvalCoord2f;
    PFNGLEVALCOORD2FVPROC epoxy_glEvalCoord2fv;
    PFNGLEVALCOORD2XOESPROC epoxy_glEvalCoord2xOES;
    PFNGLEVALCOORD2XVOESPROC epoxy_glEvalCoord2xvOES;
    PFNGLEVALMAPSNVPROC epoxy_glEvalMapsNV;
    PFNGLEVALMESH1PROC epoxy_glEvalMesh1;
    PFNGLEVALMESH2PROC epoxy_glEvalMesh2;
    PFNGLEVALPOINT1PROC epoxy_glEvalPoint1;
    PFNGLEVALPOINT2PROC epoxy_glEvalPoint2;
    PFNGLEVALUATEDEPTHVALUESARBPROC epoxy_glEvaluateDepthValuesARB;
    PFNGLEXECUTEPROGRAMNVPROC epoxy_glExecuteProgramNV;
    PFNGLEXTGETBUFFERPOINTERVQCOMPROC epoxy_glExtGetBufferPointervQCOM;
    PFNGLEXTGETBUFFERSQCOMPROC epoxy_glExtGetBuffersQCOM;
    PFNGLEXTGETFRAMEBUFFERSQCOMPROC epoxy_glExtGetFramebuffersQCOM;
    PFNGLEXTGETPROGRAMBINARYSOURCEQCOMPROC epoxy_glExtGetProgramBinarySourceQCOM;
    PFNGLEXTGETPROGRAMSQCOMPROC epoxy_glExtGetProgramsQCOM;
    PFNGLEXTGETRENDERBUFFERSQCOMPROC epoxy_glExtGetRenderbuffersQCOM;
    PFNGLEXTGETSHADERSQCOMPROC epoxy_glExtGetShadersQCOM;
    PFNGLEXTGETTEXLEVELPARAMETERIVQCOMPROC epoxy_glExtGetTexLevelParameterivQCOM;
    PFNGLEXTGETTEXSUBIMAGEQCOMPROC epoxy_glExtGetTexSubImageQCOM;
    PFNGLEXTGETTEXTURESQCOMPROC epoxy_glExtGetTexturesQCOM;
    PFNGLEXTISPROGRAMBINARYQCOMPROC epoxy_glExtIsProgramBinaryQCOM;
    PFNGLEXTTEXOBJECTSTATEOVERRIDEIQCOMPROC epoxy_glExtTexObjectStateOverrideiQCOM;
    PFNGLEXTRACTCOMPONENTEXTPROC epoxy_glExtractComponentEXT;
    PFNGLFEEDBACKBUFFERPROC epoxy_glFeedbackBuffer;
    PFNGLFEEDBACKBUFFERXOESPROC epoxy_glFeedbackBufferxOES;
    PFNGLFENCESYNCPROC epoxy_glFenceSync;
    PFNGLFENCESYNCAPPLEPROC epoxy_glFenceSyncAPPLE;
    PFNGLFINALCOMBINERINPUTNVPROC epoxy_glFinalCombinerInputNV;
    PFNGLFINISHPROC epoxy_glFinish;
    PFNGLFINISHASYNCSGIXPROC epoxy_glFinishAsyncSGIX;
    PFNGLFINISHFENCEAPPLEPROC epoxy_glFinishFenceAPPLE;
    PFNGLFINISHFENCENVPROC epoxy_glFinishFenceNV;
    PFNGLFINISHOBJECTAPPLEPROC epoxy_glFinishObjectAPPLE;
    PFNGLFINISHTEXTURESUNXPROC epoxy_glFinishTextureSUNX;
    PFNGLFLUSHPROC epoxy_glFlush;
    PFNGLFLUSHMAPPEDBUFFERRANGEPROC epoxy_glFlushMappedBufferRange;
    PFNGLFLUSHMAPPEDBUFFERRANGEAPPLEPROC epoxy_glFlushMappedBufferRangeAPPLE;
    PFNGLFLUSHMAPPEDBUFFERRANGEEXTPROC epoxy_glFlushMappedBufferRangeEXT;
    PFNGLFLUSHMAPPEDNAMEDBUFFERRANGEPROC epoxy_glFlushMappedNamedBufferRange;
    PFNGLFLUSHMAPPEDNAMEDBUFFERRANGEEXTPROC epoxy_glFlushMappedNamedBufferRangeEXT;
    PFNGLFLUSHPIXELDATARANGENVPROC epoxy_glFlushPixelDataRangeNV;
    PFNGLFLUSHRASTERSGIXPROC epoxy_glFlushRasterSGIX;
    PFNGLFLUSHSTATICDATAIBMPROC epoxy_glFlushStaticDataIBM;
    PFNGLFLUSHVERTEXARRAYRANGEAPPLEPROC epoxy_glFlushVertexArrayRangeAPPLE;
    PFNGLFLUSHVERTEXARRAYRANGENVPROC epoxy_glFlushVertexArrayRangeNV;
    PFNGLFOGCOORDFORMATNVPROC epoxy_glFogCoordFormatNV;
    PFNGLFOGCOORDPOINTERPROC epoxy_glFogCoordPointer;
    PFNGLFOGCOORDPOINTEREXTPROC epoxy_glFogCoordPointerEXT;
    PFNGLFOGCOORDPOINTERLISTIBMPROC epoxy_glFogCoordPointerListIBM;
    PFNGLFOGCOORDDPROC epoxy_glFogCoordd;
    PFNGLFOGCOORDDEXTPROC epoxy_glFogCoorddEXT;
    PFNGLFOGCOORDDVPROC epoxy_glFogCoorddv;
    PFNGLFOGCOORDDVEXTPROC epoxy_glFogCoorddvEXT;
    PFNGLFOGCOORDFPROC epoxy_glFogCoordf;
    PFNGLFOGCOORDFEXTPROC epoxy_glFogCoordfEXT;
    PFNGLFOGCOORDFVPROC epoxy_glFogCoordfv;
    PFNGLFOGCOORDFVEXTPROC epoxy_glFogCoordfvEXT;
    PFNGLFOGCOORDHNVPROC epoxy_glFogCoordhNV;
    PFNGLFOGCOORDHVNVPROC epoxy_glFogCoordhvNV;
    PFNGLFOGFUNCSGISPROC epoxy_glFogFuncSGIS;
    PFNGLFOGFPROC epoxy_glFogf;
    PFNGLFOGFVPROC epoxy_glFogfv;
    PFNGLFOGIPROC epoxy_glFogi;
    PFNGLFOGIVPROC epoxy_glFogiv;
    PFNGLFOGXPROC epoxy_glFogx;
    PFNGLFOGXOESPROC epoxy_glFogxOES;
    PFNGLFOGXVPROC epoxy_glFogxv;
    PFNGLFOGXVOESPROC epoxy_glFogxvOES;
    PFNGLFRAGMENTCOLORMATERIALSGIXPROC epoxy_glFragmentColorMaterialSGIX;
    PFNGLFRAGMENTCOVERAGECOLORNVPROC epoxy_glFragmentCoverageColorNV;
    PFNGLFRAGMENTLIGHTMODELFSGIXPROC epoxy_glFragmentLightModelfSGIX;
    PFNGLFRAGMENTLIGHTMODELFVSGIXPROC epoxy_glFragmentLightModelfvSGIX;
    PFNGLFRAGMENTLIGHTMODELISGIXPROC epoxy_glFragmentLightModeliSGIX;
    PFNGLFRAGMENTLIGHTMODELIVSGIXPROC epoxy_glFragmentLightModelivSGIX;
    PFNGLFRAGMENTLIGHTFSGIXPROC epoxy_glFragmentLightfSGIX;
    PFNGLFRAGMENTLIGHTFVSGIXPROC epoxy_glFragmentLightfvSGIX;
    PFNGLFRAGMENTLIGHTISGIXPROC epoxy_glFragmentLightiSGIX;
    PFNGLFRAGMENTLIGHTIVSGIXPROC epoxy_glFragmentLightivSGIX;
    PFNGLFRAGMENTMATERIALFSGIXPROC epoxy_glFragmentMaterialfSGIX;
    PFNGLFRAGMENTMATERIALFVSGIXPROC epoxy_glFragmentMaterialfvSGIX;
    PFNGLFRAGMENTMATERIALISGIXPROC epoxy_glFragmentMaterialiSGIX;
    PFNGLFRAGMENTMATERIALIVSGIXPROC epoxy_glFragmentMaterialivSGIX;
    PFNGLFRAMETERMINATORGREMEDYPROC epoxy_glFrameTerminatorGREMEDY;
    PFNGLFRAMEZOOMSGIXPROC epoxy_glFrameZoomSGIX;
    PFNGLFRAMEBUFFERDRAWBUFFEREXTPROC epoxy_glFramebufferDrawBufferEXT;
    PFNGLFRAMEBUFFERDRAWBUFFERSEXTPROC epoxy_glFramebufferDrawBuffersEXT;
    PFNGLFRAMEBUFFERFETCHBARRIEREXTPROC epoxy_glFramebufferFetchBarrierEXT;
    PFNGLFRAMEBUFFERFETCHBARRIERQCOMPROC epoxy_glFramebufferFetchBarrierQCOM;
    PFNGLFRAMEBUFFERFOVEATIONCONFIGQCOMPROC epoxy_glFramebufferFoveationConfigQCOM;
    PFNGLFRAMEBUFFERFOVEATIONPARAMETERSQCOMPROC epoxy_glFramebufferFoveationParametersQCOM;
    PFNGLFRAMEBUFFERPARAMETERIPROC epoxy_glFramebufferParameteri;
    PFNGLFRAMEBUFFERPARAMETERIMESAPROC epoxy_glFramebufferParameteriMESA;
    PFNGLFRAMEBUFFERPIXELLOCALSTORAGESIZEEXTPROC epoxy_glFramebufferPixelLocalStorageSizeEXT;
    PFNGLFRAMEBUFFERREADBUFFEREXTPROC epoxy_glFramebufferReadBufferEXT;
    PFNGLFRAMEBUFFERRENDERBUFFERPROC epoxy_glFramebufferRenderbuffer;
    PFNGLFRAMEBUFFERRENDERBUFFEREXTPROC epoxy_glFramebufferRenderbufferEXT;
    PFNGLFRAMEBUFFERRENDERBUFFEROESPROC epoxy_glFramebufferRenderbufferOES;
    PFNGLFRAMEBUFFERSAMPLELOCATIONSFVARBPROC epoxy_glFramebufferSampleLocationsfvARB;
    PFNGLFRAMEBUFFERSAMPLELOCATIONSFVNVPROC epoxy_glFramebufferSampleLocationsfvNV;
    PFNGLFRAMEBUFFERSAMPLEPOSITIONSFVAMDPROC epoxy_glFramebufferSamplePositionsfvAMD;
    PFNGLFRAMEBUFFERTEXTUREPROC epoxy_glFramebufferTexture;
    PFNGLFRAMEBUFFERTEXTURE1DPROC epoxy_glFramebufferTexture1D;
    PFNGLFRAMEBUFFERTEXTURE1DEXTPROC epoxy_glFramebufferTexture1DEXT;
    PFNGLFRAMEBUFFERTEXTURE2DPROC epoxy_glFramebufferTexture2D;
    PFNGLFRAMEBUFFERTEXTURE2DDOWNSAMPLEIMGPROC epoxy_glFramebufferTexture2DDownsampleIMG;
    PFNGLFRAMEBUFFERTEXTURE2DEXTPROC epoxy_glFramebufferTexture2DEXT;
    PFNGLFRAMEBUFFERTEXTURE2DMULTISAMPLEEXTPROC epoxy_glFramebufferTexture2DMultisampleEXT;
    PFNGLFRAMEBUFFERTEXTURE2DMULTISAMPLEIMGPROC epoxy_glFramebufferTexture2DMultisampleIMG;
    PFNGLFRAMEBUFFERTEXTURE2DOESPROC epoxy_glFramebufferTexture2DOES;
    PFNGLFRAMEBUFFERTEXTURE3DPROC epoxy_glFramebufferTexture3D;
    PFNGLFRAMEBUFFERTEXTURE3DEXTPROC epoxy_glFramebufferTexture3DEXT;
    PFNGLFRAMEBUFFERTEXTURE3DOESPROC epoxy_glFramebufferTexture3DOES;
    PFNGLFRAMEBUFFERTEXTUREARBPROC epoxy_glFramebufferTextureARB;
    PFNGLFRAMEBUFFERTEXTUREEXTPROC epoxy_glFramebufferTextureEXT;
    PFNGLFRAMEBUFFERTEXTUREFACEARBPROC epoxy_glFramebufferTextureFaceARB;
    PFNGLFRAMEBUFFERTEXTUREFACEEXTPROC epoxy_glFramebufferTextureFaceEXT;
    PFNGLFRAMEBUFFERTEXTURELAYERPROC epoxy_glFramebufferTextureLayer;
    PFNGLFRAMEBUFFERTEXTURELAYERARBPROC epoxy_glFramebufferTextureLayerARB;
    PFNGLFRAMEBUFFERTEXTURELAYERDOWNSAMPLEIMGPROC epoxy_glFramebufferTextureLayerDownsampleIMG;
    PFNGLFRAMEBUFFERTEXTURELAYEREXTPROC epoxy_glFramebufferTextureLayerEXT;
    PFNGLFRAMEBUFFERTEXTUREMULTISAMPLEMULTIVIEWOVRPROC epoxy_glFramebufferTextureMultisampleMultiviewOVR;
    PFNGLFRAMEBUFFERTEXTUREMULTIVIEWOVRPROC epoxy_glFramebufferTextureMultiviewOVR;
    PFNGLFRAMEBUFFERTEXTUREOESPROC epoxy_glFramebufferTextureOES;
    PFNGLFREEOBJECTBUFFERATIPROC epoxy_glFreeObjectBufferATI;
    PFNGLFRONTFACEPROC epoxy_glFrontFace;
    PFNGLFRUSTUMPROC epoxy_glFrustum;
    PFNGLFRUSTUMFPROC epoxy_glFrustumf;
    PFNGLFRUSTUMFOESPROC epoxy_glFrustumfOES;
    PFNGLFRUSTUMXPROC epoxy_glFrustumx;
    PFNGLFRUSTUMXOESPROC epoxy_glFrustumxOES;
    PFNGLGENASYNCMARKERSSGIXPROC epoxy_glGenAsyncMarkersSGIX;
    PFNGLGENBUFFERSPROC epoxy_glGenBuffers;
    PFNGLGENBUFFERSARBPROC epoxy_glGenBuffersARB;
    PFNGLGENFENCESAPPLEPROC epoxy_glGenFencesAPPLE;
    PFNGLGENFENCESNVPROC epoxy_glGenFencesNV;
    PFNGLGENFRAGMENTSHADERSATIPROC epoxy_glGenFragmentShadersATI;
    PFNGLGENFRAMEBUFFERSPROC epoxy_glGenFramebuffers;
    PFNGLGENFRAMEBUFFERSEXTPROC epoxy_glGenFramebuffersEXT;
    PFNGLGENFRAMEBUFFERSOESPROC epoxy_glGenFramebuffersOES;
    PFNGLGENLISTSPROC epoxy_glGenLists;
    PFNGLGENNAMESAMDPROC epoxy_glGenNamesAMD;
    PFNGLGENOCCLUSIONQUERIESNVPROC epoxy_glGenOcclusionQueriesNV;
    PFNGLGENPATHSNVPROC epoxy_glGenPathsNV;
    PFNGLGENPERFMONITORSAMDPROC epoxy_glGenPerfMonitorsAMD;
    PFNGLGENPROGRAMPIPELINESPROC epoxy_glGenProgramPipelines;
    PFNGLGENPROGRAMPIPELINESEXTPROC epoxy_glGenProgramPipelinesEXT;
    PFNGLGENPROGRAMSARBPROC epoxy_glGenProgramsARB;
    PFNGLGENPROGRAMSNVPROC epoxy_glGenProgramsNV;
    PFNGLGENQUERIESPROC epoxy_glGenQueries;
    PFNGLGENQUERIESARBPROC epoxy_glGenQueriesARB;
    PFNGLGENQUERIESEXTPROC epoxy_glGenQueriesEXT;
    PFNGLGENQUERYRESOURCETAGNVPROC epoxy_glGenQueryResourceTagNV;
    PFNGLGENRENDERBUFFERSPROC epoxy_glGenRenderbuffers;
    PFNGLGENRENDERBUFFERSEXTPROC epoxy_glGenRenderbuffersEXT;
    PFNGLGENRENDERBUFFERSOESPROC epoxy_glGenRenderbuffersOES;
    PFNGLGENSAMPLERSPROC epoxy_glGenSamplers;
    PFNGLGENSEMAPHORESEXTPROC epoxy_glGenSemaphoresEXT;
    PFNGLGENSYMBOLSEXTPROC epoxy_glGenSymbolsEXT;
    PFNGLGENTEXTURESPROC epoxy_glGenTextures;
    PFNGLGENTEXTURESEXTPROC epoxy_glGenTexturesEXT;
    PFNGLGENTRANSFORMFEEDBACKSPROC epoxy_glGenTransformFeedbacks;
    PFNGLGENTRANSFORMFEEDBACKSNVPROC epoxy_glGenTransformFeedbacksNV;
    PFNGLGENVERTEXARRAYSPROC epoxy_glGenVertexArrays;
    PFNGLGENVERTEXARRAYSAPPLEPROC epoxy_glGenVertexArraysAPPLE;
    PFNGLGENVERTEXARRAYSOESPROC epoxy_glGenVertexArraysOES;
    PFNGLGENVERTEXSHADERSEXTPROC epoxy_glGenVertexShadersEXT;
    PFNGLGENERATEMIPMAPPROC epoxy_glGenerateMipmap;
    PFNGLGENERATEMIPMAPEXTPROC epoxy_glGenerateMipmapEXT;
    PFNGLGENERATEMIPMAPOESPROC epoxy_glGenerateMipmapOES;
    PFNGLGENERATEMULTITEXMIPMAPEXTPROC epoxy_glGenerateMultiTexMipmapEXT;
    PFNGLGENERATETEXTUREMIPMAPPROC epoxy_glGenerateTextureMipmap;
    PFNGLGENERATETEXTUREMIPMAPEXTPROC epoxy_glGenerateTextureMipmapEXT;
    PFNGLGETACTIVEATOMICCOUNTERBUFFERIVPROC epoxy_glGetActiveAtomicCounterBufferiv;
    PFNGLGETACTIVEATTRIBPROC epoxy_glGetActiveAttrib;
    PFNGLGETACTIVEATTRIBARBPROC epoxy_glGetActiveAttribARB;
    PFNGLGETACTIVESUBROUTINENAMEPROC epoxy_glGetActiveSubroutineName;
    PFNGLGETACTIVESUBROUTINEUNIFORMNAMEPROC epoxy_glGetActiveSubroutineUniformName;
    PFNGLGETACTIVESUBROUTINEUNIFORMIVPROC epoxy_glGetActiveSubroutineUniformiv;
    PFNGLGETACTIVEUNIFORMPROC epoxy_glGetActiveUniform;
    PFNGLGETACTIVEUNIFORMARBPROC epoxy_glGetActiveUniformARB;
    PFNGLGETACTIVEUNIFORMBLOCKNAMEPROC epoxy_glGetActiveUniformBlockName;
    PFNGLGETACTIVEUNIFORMBLOCKIVPROC epoxy_glGetActiveUniformBlockiv;
    PFNGLGETACTIVEUNIFORMNAMEPROC epoxy_glGetActiveUniformName;
    PFNGLGETACTIVEUNIFORMSIVPROC epoxy_glGetActiveUniformsiv;
    PFNGLGETACTIVEVARYINGNVPROC epoxy_glGetActiveVaryingNV;
    PFNGLGETARRAYOBJECTFVATIPROC epoxy_glGetArrayObjectfvATI;
    PFNGLGETARRAYOBJECTIVATIPROC epoxy_glGetArrayObjectivATI;
    PFNGLGETATTACHEDOBJECTSARBPROC epoxy_glGetAttachedObjectsARB;
    PFNGLGETATTACHEDSHADERSPROC epoxy_glGetAttachedShaders;
    PFNGLGETATTRIBLOCATIONPROC epoxy_glGetAttribLocation;
    PFNGLGETATTRIBLOCATIONARBPROC epoxy_glGetAttribLocationARB;
    PFNGLGETBOOLEANINDEXEDVEXTPROC epoxy_glGetBooleanIndexedvEXT;
    PFNGLGETBOOLEANI_VPROC epoxy_glGetBooleani_v;
    PFNGLGETBOOLEANVPROC epoxy_glGetBooleanv;
    PFNGLGETBUFFERPARAMETERI64VPROC epoxy_glGetBufferParameteri64v;
    PFNGLGETBUFFERPARAMETERIVPROC epoxy_glGetBufferParameteriv;
    PFNGLGETBUFFERPARAMETERIVARBPROC epoxy_glGetBufferParameterivARB;
    PFNGLGETBUFFERPARAMETERUI64VNVPROC epoxy_glGetBufferParameterui64vNV;
    PFNGLGETBUFFERPOINTERVPROC epoxy_glGetBufferPointerv;
    PFNGLGETBUFFERPOINTERVARBPROC epoxy_glGetBufferPointervARB;
    PFNGLGETBUFFERPOINTERVOESPROC epoxy_glGetBufferPointervOES;
    PFNGLGETBUFFERSUBDATAPROC epoxy_glGetBufferSubData;
    PFNGLGETBUFFERSUBDATAARBPROC epoxy_glGetBufferSubDataARB;
    PFNGLGETCLIPPLANEPROC epoxy_glGetClipPlane;
    PFNGLGETCLIPPLANEFPROC epoxy_glGetClipPlanef;
    PFNGLGETCLIPPLANEFOESPROC epoxy_glGetClipPlanefOES;
    PFNGLGETCLIPPLANEXPROC epoxy_glGetClipPlanex;
    PFNGLGETCLIPPLANEXOESPROC epoxy_glGetClipPlanexOES;
    PFNGLGETCOLORTABLEPROC epoxy_glGetColorTable;
    PFNGLGETCOLORTABLEEXTPROC epoxy_glGetColorTableEXT;
    PFNGLGETCOLORTABLEPARAMETERFVPROC epoxy_glGetColorTableParameterfv;
    PFNGLGETCOLORTABLEPARAMETERFVEXTPROC epoxy_glGetColorTableParameterfvEXT;
    PFNGLGETCOLORTABLEPARAMETERFVSGIPROC epoxy_glGetColorTableParameterfvSGI;
    PFNGLGETCOLORTABLEPARAMETERIVPROC epoxy_glGetColorTableParameteriv;
    PFNGLGETCOLORTABLEPARAMETERIVEXTPROC epoxy_glGetColorTableParameterivEXT;
    PFNGLGETCOLORTABLEPARAMETERIVSGIPROC epoxy_glGetColorTableParameterivSGI;
    PFNGLGETCOLORTABLESGIPROC epoxy_glGetColorTableSGI;
    PFNGLGETCOMBINERINPUTPARAMETERFVNVPROC epoxy_glGetCombinerInputParameterfvNV;
    PFNGLGETCOMBINERINPUTPARAMETERIVNVPROC epoxy_glGetCombinerInputParameterivNV;
    PFNGLGETCOMBINEROUTPUTPARAMETERFVNVPROC epoxy_glGetCombinerOutputParameterfvNV;
    PFNGLGETCOMBINEROUTPUTPARAMETERIVNVPROC epoxy_glGetCombinerOutputParameterivNV;
    PFNGLGETCOMBINERSTAGEPARAMETERFVNVPROC epoxy_glGetCombinerStageParameterfvNV;
    PFNGLGETCOMMANDHEADERNVPROC epoxy_glGetCommandHeaderNV;
    PFNGLGETCOMPRESSEDMULTITEXIMAGEEXTPROC epoxy_glGetCompressedMultiTexImageEXT;
    PFNGLGETCOMPRESSEDTEXIMAGEPROC epoxy_glGetCompressedTexImage;
    PFNGLGETCOMPRESSEDTEXIMAGEARBPROC epoxy_glGetCompressedTexImageARB;
    PFNGLGETCOMPRESSEDTEXTUREIMAGEPROC epoxy_glGetCompressedTextureImage;
    PFNGLGETCOMPRESSEDTEXTUREIMAGEEXTPROC epoxy_glGetCompressedTextureImageEXT;
    PFNGLGETCOMPRESSEDTEXTURESUBIMAGEPROC epoxy_glGetCompressedTextureSubImage;
    PFNGLGETCONVOLUTIONFILTERPROC epoxy_glGetConvolutionFilter;
    PFNGLGETCONVOLUTIONFILTEREXTPROC epoxy_glGetConvolutionFilterEXT;
    PFNGLGETCONVOLUTIONPARAMETERFVPROC epoxy_glGetConvolutionParameterfv;
    PFNGLGETCONVOLUTIONPARAMETERFVEXTPROC epoxy_glGetConvolutionParameterfvEXT;
    PFNGLGETCONVOLUTIONPARAMETERIVPROC epoxy_glGetConvolutionParameteriv;
    PFNGLGETCONVOLUTIONPARAMETERIVEXTPROC epoxy_glGetConvolutionParameterivEXT;
    PFNGLGETCONVOLUTIONPARAMETERXVOESPROC epoxy_glGetConvolutionParameterxvOES;
    PFNGLGETCOVERAGEMODULATIONTABLENVPROC epoxy_glGetCoverageModulationTableNV;
    PFNGLGETDEBUGMESSAGELOGPROC epoxy_glGetDebugMessageLog;
    PFNGLGETDEBUGMESSAGELOGAMDPROC epoxy_glGetDebugMessageLogAMD;
    PFNGLGETDEBUGMESSAGELOGARBPROC epoxy_glGetDebugMessageLogARB;
    PFNGLGETDEBUGMESSAGELOGKHRPROC epoxy_glGetDebugMessageLogKHR;
    PFNGLGETDETAILTEXFUNCSGISPROC epoxy_glGetDetailTexFuncSGIS;
    PFNGLGETDOUBLEINDEXEDVEXTPROC epoxy_glGetDoubleIndexedvEXT;
    PFNGLGETDOUBLEI_VPROC epoxy_glGetDoublei_v;
    PFNGLGETDOUBLEI_VEXTPROC epoxy_glGetDoublei_vEXT;
    PFNGLGETDOUBLEVPROC epoxy_glGetDoublev;
    PFNGLGETDRIVERCONTROLSTRINGQCOMPROC epoxy_glGetDriverControlStringQCOM;
    PFNGLGETDRIVERCONTROLSQCOMPROC epoxy_glGetDriverControlsQCOM;
    PFNGLGETERRORPROC epoxy_glGetError;
    PFNGLGETFENCEIVNVPROC epoxy_glGetFenceivNV;
    PFNGLGETFINALCOMBINERINPUTPARAMETERFVNVPROC epoxy_glGetFinalCombinerInputParameterfvNV;
    PFNGLGETFINALCOMBINERINPUTPARAMETERIVNVPROC epoxy_glGetFinalCombinerInputParameterivNV;
    PFNGLGETFIRSTPERFQUERYIDINTELPROC epoxy_glGetFirstPerfQueryIdINTEL;
    PFNGLGETFIXEDVPROC epoxy_glGetFixedv;
    PFNGLGETFIXEDVOESPROC epoxy_glGetFixedvOES;
    PFNGLGETFLOATINDEXEDVEXTPROC epoxy_glGetFloatIndexedvEXT;
    PFNGLGETFLOATI_VPROC epoxy_glGetFloati_v;
    PFNGLGETFLOATI_VEXTPROC epoxy_glGetFloati_vEXT;
    PFNGLGETFLOATI_VNVPROC epoxy_glGetFloati_vNV;
    PFNGLGETFLOATI_VOESPROC epoxy_glGetFloati_vOES;
    PFNGLGETFLOATVPROC epoxy_glGetFloatv;
    PFNGLGETFOGFUNCSGISPROC epoxy_glGetFogFuncSGIS;
    PFNGLGETFRAGDATAINDEXPROC epoxy_glGetFragDataIndex;
    PFNGLGETFRAGDATAINDEXEXTPROC epoxy_glGetFragDataIndexEXT;
    PFNGLGETFRAGDATALOCATIONPROC epoxy_glGetFragDataLocation;
    PFNGLGETFRAGDATALOCATIONEXTPROC epoxy_glGetFragDataLocationEXT;
    PFNGLGETFRAGMENTLIGHTFVSGIXPROC epoxy_glGetFragmentLightfvSGIX;
    PFNGLGETFRAGMENTLIGHTIVSGIXPROC epoxy_glGetFragmentLightivSGIX;
    PFNGLGETFRAGMENTMATERIALFVSGIXPROC epoxy_glGetFragmentMaterialfvSGIX;
    PFNGLGETFRAGMENTMATERIALIVSGIXPROC epoxy_glGetFragmentMaterialivSGIX;
    PFNGLGETFRAMEBUFFERATTACHMENTPARAMETERIVPROC epoxy_glGetFramebufferAttachmentParameteriv;
    PFNGLGETFRAMEBUFFERATTACHMENTPARAMETERIVEXTPROC epoxy_glGetFramebufferAttachmentParameterivEXT;
    PFNGLGETFRAMEBUFFERATTACHMENTPARAMETERIVOESPROC epoxy_glGetFramebufferAttachmentParameterivOES;
    PFNGLGETFRAMEBUFFERPARAMETERFVAMDPROC epoxy_glGetFramebufferParameterfvAMD;
    PFNGLGETFRAMEBUFFERPARAMETERIVPROC epoxy_glGetFramebufferParameteriv;
    PFNGLGETFRAMEBUFFERPARAMETERIVEXTPROC epoxy_glGetFramebufferParameterivEXT;
    PFNGLGETFRAMEBUFFERPARAMETERIVMESAPROC epoxy_glGetFramebufferParameterivMESA;
    PFNGLGETFRAMEBUFFERPIXELLOCALSTORAGESIZEEXTPROC epoxy_glGetFramebufferPixelLocalStorageSizeEXT;
    PFNGLGETGRAPHICSRESETSTATUSPROC epoxy_glGetGraphicsResetStatus;
    PFNGLGETGRAPHICSRESETSTATUSARBPROC epoxy_glGetGraphicsResetStatusARB;
    PFNGLGETGRAPHICSRESETSTATUSEXTPROC epoxy_glGetGraphicsResetStatusEXT;
    PFNGLGETGRAPHICSRESETSTATUSKHRPROC epoxy_glGetGraphicsResetStatusKHR;
    PFNGLGETHANDLEARBPROC epoxy_glGetHandleARB;
    PFNGLGETHISTOGRAMPROC epoxy_glGetHistogram;
    PFNGLGETHISTOGRAMEXTPROC epoxy_glGetHistogramEXT;
    PFNGLGETHISTOGRAMPARAMETERFVPROC epoxy_glGetHistogramParameterfv;
    PFNGLGETHISTOGRAMPARAMETERFVEXTPROC epoxy_glGetHistogramParameterfvEXT;
    PFNGLGETHISTOGRAMPARAMETERIVPROC epoxy_glGetHistogramParameteriv;
    PFNGLGETHISTOGRAMPARAMETERIVEXTPROC epoxy_glGetHistogramParameterivEXT;
    PFNGLGETHISTOGRAMPARAMETERXVOESPROC epoxy_glGetHistogramParameterxvOES;
    PFNGLGETIMAGEHANDLEARBPROC epoxy_glGetImageHandleARB;
    PFNGLGETIMAGEHANDLENVPROC epoxy_glGetImageHandleNV;
    PFNGLGETIMAGETRANSFORMPARAMETERFVHPPROC epoxy_glGetImageTransformParameterfvHP;
    PFNGLGETIMAGETRANSFORMPARAMETERIVHPPROC epoxy_glGetImageTransformParameterivHP;
    PFNGLGETINFOLOGARBPROC epoxy_glGetInfoLogARB;
    PFNGLGETINSTRUMENTSSGIXPROC epoxy_glGetInstrumentsSGIX;
    PFNGLGETINTEGER64I_VPROC epoxy_glGetInteger64i_v;
    PFNGLGETINTEGER64VPROC epoxy_glGetInteger64v;
    PFNGLGETINTEGER64VAPPLEPROC epoxy_glGetInteger64vAPPLE;
    PFNGLGETINTEGERINDEXEDVEXTPROC epoxy_glGetIntegerIndexedvEXT;
    PFNGLGETINTEGERI_VPROC epoxy_glGetIntegeri_v;
    PFNGLGETINTEGERI_VEXTPROC epoxy_glGetIntegeri_vEXT;
    PFNGLGETINTEGERUI64I_VNVPROC epoxy_glGetIntegerui64i_vNV;
    PFNGLGETINTEGERUI64VNVPROC epoxy_glGetIntegerui64vNV;
    PFNGLGETINTEGERVPROC epoxy_glGetIntegerv;
    PFNGLGETINTERNALFORMATSAMPLEIVNVPROC epoxy_glGetInternalformatSampleivNV;
    PFNGLGETINTERNALFORMATI64VPROC epoxy_glGetInternalformati64v;
    PFNGLGETINTERNALFORMATIVPROC epoxy_glGetInternalformativ;
    PFNGLGETINVARIANTBOOLEANVEXTPROC epoxy_glGetInvariantBooleanvEXT;
    PFNGLGETINVARIANTFLOATVEXTPROC epoxy_glGetInvariantFloatvEXT;
    PFNGLGETINVARIANTINTEGERVEXTPROC epoxy_glGetInvariantIntegervEXT;
    PFNGLGETLIGHTFVPROC epoxy_glGetLightfv;
    PFNGLGETLIGHTIVPROC epoxy_glGetLightiv;
    PFNGLGETLIGHTXOESPROC epoxy_glGetLightxOES;
    PFNGLGETLIGHTXVPROC epoxy_glGetLightxv;
    PFNGLGETLIGHTXVOESPROC epoxy_glGetLightxvOES;
    PFNGLGETLISTPARAMETERFVSGIXPROC epoxy_glGetListParameterfvSGIX;
    PFNGLGETLISTPARAMETERIVSGIXPROC epoxy_glGetListParameterivSGIX;
    PFNGLGETLOCALCONSTANTBOOLEANVEXTPROC epoxy_glGetLocalConstantBooleanvEXT;
    PFNGLGETLOCALCONSTANTFLOATVEXTPROC epoxy_glGetLocalConstantFloatvEXT;
    PFNGLGETLOCALCONSTANTINTEGERVEXTPROC epoxy_glGetLocalConstantIntegervEXT;
    PFNGLGETMAPATTRIBPARAMETERFVNVPROC epoxy_glGetMapAttribParameterfvNV;
    PFNGLGETMAPATTRIBPARAMETERIVNVPROC epoxy_glGetMapAttribParameterivNV;
    PFNGLGETMAPCONTROLPOINTSNVPROC epoxy_glGetMapControlPointsNV;
    PFNGLGETMAPPARAMETERFVNVPROC epoxy_glGetMapParameterfvNV;
    PFNGLGETMAPPARAMETERIVNVPROC epoxy_glGetMapParameterivNV;
    PFNGLGETMAPDVPROC epoxy_glGetMapdv;
    PFNGLGETMAPFVPROC epoxy_glGetMapfv;
    PFNGLGETMAPIVPROC epoxy_glGetMapiv;
    PFNGLGETMAPXVOESPROC epoxy_glGetMapxvOES;
    PFNGLGETMATERIALFVPROC epoxy_glGetMaterialfv;
    PFNGLGETMATERIALIVPROC epoxy_glGetMaterialiv;
    PFNGLGETMATERIALXOESPROC epoxy_glGetMaterialxOES;
    PFNGLGETMATERIALXVPROC epoxy_glGetMaterialxv;
    PFNGLGETMATERIALXVOESPROC epoxy_glGetMaterialxvOES;
    PFNGLGETMEMORYOBJECTDETACHEDRESOURCESUIVNVPROC epoxy_glGetMemoryObjectDetachedResourcesuivNV;
    PFNGLGETMEMORYOBJECTPARAMETERIVEXTPROC epoxy_glGetMemoryObjectParameterivEXT;
    PFNGLGETMINMAXPROC epoxy_glGetMinmax;
    PFNGLGETMINMAXEXTPROC epoxy_glGetMinmaxEXT;
    PFNGLGETMINMAXPARAMETERFVPROC epoxy_glGetMinmaxParameterfv;
    PFNGLGETMINMAXPARAMETERFVEXTPROC epoxy_glGetMinmaxParameterfvEXT;
    PFNGLGETMINMAXPARAMETERIVPROC epoxy_glGetMinmaxParameteriv;
    PFNGLGETMINMAXPARAMETERIVEXTPROC epoxy_glGetMinmaxParameterivEXT;
    PFNGLGETMULTITEXENVFVEXTPROC epoxy_glGetMultiTexEnvfvEXT;
    PFNGLGETMULTITEXENVIVEXTPROC epoxy_glGetMultiTexEnvivEXT;
    PFNGLGETMULTITEXGENDVEXTPROC epoxy_glGetMultiTexGendvEXT;
    PFNGLGETMULTITEXGENFVEXTPROC epoxy_glGetMultiTexGenfvEXT;
    PFNGLGETMULTITEXGENIVEXTPROC epoxy_glGetMultiTexGenivEXT;
    PFNGLGETMULTITEXIMAGEEXTPROC epoxy_glGetMultiTexImageEXT;
    PFNGLGETMULTITEXLEVELPARAMETERFVEXTPROC epoxy_glGetMultiTexLevelParameterfvEXT;
    PFNGLGETMULTITEXLEVELPARAMETERIVEXTPROC epoxy_glGetMultiTexLevelParameterivEXT;
    PFNGLGETMULTITEXPARAMETERIIVEXTPROC epoxy_glGetMultiTexParameterIivEXT;
    PFNGLGETMULTITEXPARAMETERIUIVEXTPROC epoxy_glGetMultiTexParameterIuivEXT;
    PFNGLGETMULTITEXPARAMETERFVEXTPROC epoxy_glGetMultiTexParameterfvEXT;
    PFNGLGETMULTITEXPARAMETERIVEXTPROC epoxy_glGetMultiTexParameterivEXT;
    PFNGLGETMULTISAMPLEFVPROC epoxy_glGetMultisamplefv;
    PFNGLGETMULTISAMPLEFVNVPROC epoxy_glGetMultisamplefvNV;
    PFNGLGETNAMEDBUFFERPARAMETERI64VPROC epoxy_glGetNamedBufferParameteri64v;
    PFNGLGETNAMEDBUFFERPARAMETERIVPROC epoxy_glGetNamedBufferParameteriv;
    PFNGLGETNAMEDBUFFERPARAMETERIVEXTPROC epoxy_glGetNamedBufferParameterivEXT;
    PFNGLGETNAMEDBUFFERPARAMETERUI64VNVPROC epoxy_glGetNamedBufferParameterui64vNV;
    PFNGLGETNAMEDBUFFERPOINTERVPROC epoxy_glGetNamedBufferPointerv;
    PFNGLGETNAMEDBUFFERPOINTERVEXTPROC epoxy_glGetNamedBufferPointervEXT;
    PFNGLGETNAMEDBUFFERSUBDATAPROC epoxy_glGetNamedBufferSubData;
    PFNGLGETNAMEDBUFFERSUBDATAEXTPROC epoxy_glGetNamedBufferSubDataEXT;
    PFNGLGETNAMEDFRAMEBUFFERATTACHMENTPARAMETERIVPROC epoxy_glGetNamedFramebufferAttachmentParameteriv;
    PFNGLGETNAMEDFRAMEBUFFERATTACHMENTPARAMETERIVEXTPROC epoxy_glGetNamedFramebufferAttachmentParameterivEXT;
    PFNGLGETNAMEDFRAMEBUFFERPARAMETERFVAMDPROC epoxy_glGetNamedFramebufferParameterfvAMD;
    PFNGLGETNAMEDFRAMEBUFFERPARAMETERIVPROC epoxy_glGetNamedFramebufferParameteriv;
    PFNGLGETNAMEDFRAMEBUFFERPARAMETERIVEXTPROC epoxy_glGetNamedFramebufferParameterivEXT;
    PFNGLGETNAMEDPROGRAMLOCALPARAMETERIIVEXTPROC epoxy_glGetNamedProgramLocalParameterIivEXT;
    PFNGLGETNAMEDPROGRAMLOCALPARAMETERIUIVEXTPROC epoxy_glGetNamedProgramLocalParameterIuivEXT;
    PFNGLGETNAMEDPROGRAMLOCALPARAMETERDVEXTPROC epoxy_glGetNamedProgramLocalParameterdvEXT;
    PFNGLGETNAMEDPROGRAMLOCALPARAMETERFVEXTPROC epoxy_glGetNamedProgramLocalParameterfvEXT;
    PFNGLGETNAMEDPROGRAMSTRINGEXTPROC epoxy_glGetNamedProgramStringEXT;
    PFNGLGETNAMEDPROGRAMIVEXTPROC epoxy_glGetNamedProgramivEXT;
    PFNGLGETNAMEDRENDERBUFFERPARAMETERIVPROC epoxy_glGetNamedRenderbufferParameteriv;
    PFNGLGETNAMEDRENDERBUFFERPARAMETERIVEXTPROC epoxy_glGetNamedRenderbufferParameterivEXT;
    PFNGLGETNAMEDSTRINGARBPROC epoxy_glGetNamedStringARB;
    PFNGLGETNAMEDSTRINGIVARBPROC epoxy_glGetNamedStringivARB;
    PFNGLGETNEXTPERFQUERYIDINTELPROC epoxy_glGetNextPerfQueryIdINTEL;
    PFNGLGETOBJECTBUFFERFVATIPROC epoxy_glGetObjectBufferfvATI;
    PFNGLGETOBJECTBUFFERIVATIPROC epoxy_glGetObjectBufferivATI;
    PFNGLGETOBJECTLABELPROC epoxy_glGetObjectLabel;
    PFNGLGETOBJECTLABELEXTPROC epoxy_glGetObjectLabelEXT;
    PFNGLGETOBJECTLABELKHRPROC epoxy_glGetObjectLabelKHR;
    PFNGLGETOBJECTPARAMETERFVARBPROC epoxy_glGetObjectParameterfvARB;
    PFNGLGETOBJECTPARAMETERIVAPPLEPROC epoxy_glGetObjectParameterivAPPLE;
    PFNGLGETOBJECTPARAMETERIVARBPROC epoxy_glGetObjectParameterivARB;
    PFNGLGETOBJECTPTRLABELPROC epoxy_glGetObjectPtrLabel;
    PFNGLGETOBJECTPTRLABELKHRPROC epoxy_glGetObjectPtrLabelKHR;
    PFNGLGETOCCLUSIONQUERYIVNVPROC epoxy_glGetOcclusionQueryivNV;
    PFNGLGETOCCLUSIONQUERYUIVNVPROC epoxy_glGetOcclusionQueryuivNV;
    PFNGLGETPATHCOLORGENFVNVPROC epoxy_glGetPathColorGenfvNV;
    PFNGLGETPATHCOLORGENIVNVPROC epoxy_glGetPathColorGenivNV;
    PFNGLGETPATHCOMMANDSNVPROC epoxy_glGetPathCommandsNV;
    PFNGLGETPATHCOORDSNVPROC epoxy_glGetPathCoordsNV;
    PFNGLGETPATHDASHARRAYNVPROC epoxy_glGetPathDashArrayNV;
    PFNGLGETPATHLENGTHNVPROC epoxy_glGetPathLengthNV;
    PFNGLGETPATHMETRICRANGENVPROC epoxy_glGetPathMetricRangeNV;
    PFNGLGETPATHMETRICSNVPROC epoxy_glGetPathMetricsNV;
    PFNGLGETPATHPARAMETERFVNVPROC epoxy_glGetPathParameterfvNV;
    PFNGLGETPATHPARAMETERIVNVPROC epoxy_glGetPathParameterivNV;
    PFNGLGETPATHSPACINGNVPROC epoxy_glGetPathSpacingNV;
    PFNGLGETPATHTEXGENFVNVPROC epoxy_glGetPathTexGenfvNV;
    PFNGLGETPATHTEXGENIVNVPROC epoxy_glGetPathTexGenivNV;
    PFNGLGETPERFCOUNTERINFOINTELPROC epoxy_glGetPerfCounterInfoINTEL;
    PFNGLGETPERFMONITORCOUNTERDATAAMDPROC epoxy_glGetPerfMonitorCounterDataAMD;
    PFNGLGETPERFMONITORCOUNTERINFOAMDPROC epoxy_glGetPerfMonitorCounterInfoAMD;
    PFNGLGETPERFMONITORCOUNTERSTRINGAMDPROC epoxy_glGetPerfMonitorCounterStringAMD;
    PFNGLGETPERFMONITORCOUNTERSAMDPROC epoxy_glGetPerfMonitorCountersAMD;
    PFNGLGETPERFMONITORGROUPSTRINGAMDPROC epoxy_glGetPerfMonitorGroupStringAMD;
    PFNGLGETPERFMONITORGROUPSAMDPROC epoxy_glGetPerfMonitorGroupsAMD;
    PFNGLGETPERFQUERYDATAINTELPROC epoxy_glGetPerfQueryDataINTEL;
    PFNGLGETPERFQUERYIDBYNAMEINTELPROC epoxy_glGetPerfQueryIdByNameINTEL;
    PFNGLGETPERFQUERYINFOINTELPROC epoxy_glGetPerfQueryInfoINTEL;
    PFNGLGETPIXELMAPFVPROC epoxy_glGetPixelMapfv;
    PFNGLGETPIXELMAPUIVPROC epoxy_glGetPixelMapuiv;
    PFNGLGETPIXELMAPUSVPROC epoxy_glGetPixelMapusv;
    PFNGLGETPIXELMAPXVPROC epoxy_glGetPixelMapxv;
    PFNGLGETPIXELTEXGENPARAMETERFVSGISPROC epoxy_glGetPixelTexGenParameterfvSGIS;
    PFNGLGETPIXELTEXGENPARAMETERIVSGISPROC epoxy_glGetPixelTexGenParameterivSGIS;
    PFNGLGETPIXELTRANSFORMPARAMETERFVEXTPROC epoxy_glGetPixelTransformParameterfvEXT;
    PFNGLGETPIXELTRANSFORMPARAMETERIVEXTPROC epoxy_glGetPixelTransformParameterivEXT;
    PFNGLGETPOINTERINDEXEDVEXTPROC epoxy_glGetPointerIndexedvEXT;
    PFNGLGETPOINTERI_VEXTPROC epoxy_glGetPointeri_vEXT;
    PFNGLGETPOINTERVPROC epoxy_glGetPointerv;
    PFNGLGETPOINTERVEXTPROC epoxy_glGetPointervEXT;
    PFNGLGETPOINTERVKHRPROC epoxy_glGetPointervKHR;
    PFNGLGETPOLYGONSTIPPLEPROC epoxy_glGetPolygonStipple;
    PFNGLGETPROGRAMBINARYPROC epoxy_glGetProgramBinary;
    PFNGLGETPROGRAMBINARYOESPROC epoxy_glGetProgramBinaryOES;
    PFNGLGETPROGRAMENVPARAMETERIIVNVPROC epoxy_glGetProgramEnvParameterIivNV;
    PFNGLGETPROGRAMENVPARAMETERIUIVNVPROC epoxy_glGetProgramEnvParameterIuivNV;
    PFNGLGETPROGRAMENVPARAMETERDVARBPROC epoxy_glGetProgramEnvParameterdvARB;
    PFNGLGETPROGRAMENVPARAMETERFVARBPROC epoxy_glGetProgramEnvParameterfvARB;
    PFNGLGETPROGRAMINFOLOGPROC epoxy_glGetProgramInfoLog;
    PFNGLGETPROGRAMINTERFACEIVPROC epoxy_glGetProgramInterfaceiv;
    PFNGLGETPROGRAMLOCALPARAMETERIIVNVPROC epoxy_glGetProgramLocalParameterIivNV;
    PFNGLGETPROGRAMLOCALPARAMETERIUIVNVPROC epoxy_glGetProgramLocalParameterIuivNV;
    PFNGLGETPROGRAMLOCALPARAMETERDVARBPROC epoxy_glGetProgramLocalParameterdvARB;
    PFNGLGETPROGRAMLOCALPARAMETERFVARBPROC epoxy_glGetProgramLocalParameterfvARB;
    PFNGLGETPROGRAMNAMEDPARAMETERDVNVPROC epoxy_glGetProgramNamedParameterdvNV;
    PFNGLGETPROGRAMNAMEDPARAMETERFVNVPROC epoxy_glGetProgramNamedParameterfvNV;
    PFNGLGETPROGRAMPARAMETERDVNVPROC epoxy_glGetProgramParameterdvNV;
    PFNGLGETPROGRAMPARAMETERFVNVPROC epoxy_glGetProgramParameterfvNV;
    PFNGLGETPROGRAMPIPELINEINFOLOGPROC epoxy_glGetProgramPipelineInfoLog;
    PFNGLGETPROGRAMPIPELINEINFOLOGEXTPROC epoxy_glGetProgramPipelineInfoLogEXT;
    PFNGLGETPROGRAMPIPELINEIVPROC epoxy_glGetProgramPipelineiv;
    PFNGLGETPROGRAMPIPELINEIVEXTPROC epoxy_glGetProgramPipelineivEXT;
    PFNGLGETPROGRAMRESOURCEINDEXPROC epoxy_glGetProgramResourceIndex;
    PFNGLGETPROGRAMRESOURCELOCATIONPROC epoxy_glGetProgramResourceLocation;
    PFNGLGETPROGRAMRESOURCELOCATIONINDEXPROC epoxy_glGetProgramResourceLocationIndex;
    PFNGLGETPROGRAMRESOURCELOCATIONINDEXEXTPROC epoxy_glGetProgramResourceLocationIndexEXT;
    PFNGLGETPROGRAMRESOURCENAMEPROC epoxy_glGetProgramResourceName;
    PFNGLGETPROGRAMRESOURCEFVNVPROC epoxy_glGetProgramResourcefvNV;
    PFNGLGETPROGRAMRESOURCEIVPROC epoxy_glGetProgramResourceiv;
    PFNGLGETPROGRAMSTAGEIVPROC epoxy_glGetProgramStageiv;
    PFNGLGETPROGRAMSTRINGARBPROC epoxy_glGetProgramStringARB;
    PFNGLGETPROGRAMSTRINGNVPROC epoxy_glGetProgramStringNV;
    PFNGLGETPROGRAMSUBROUTINEPARAMETERUIVNVPROC epoxy_glGetProgramSubroutineParameteruivNV;
    PFNGLGETPROGRAMIVPROC epoxy_glGetProgramiv;
    PFNGLGETPROGRAMIVARBPROC epoxy_glGetProgramivARB;
    PFNGLGETPROGRAMIVNVPROC epoxy_glGetProgramivNV;
    PFNGLGETQUERYBUFFEROBJECTI64VPROC epoxy_glGetQueryBufferObjecti64v;
    PFNGLGETQUERYBUFFEROBJECTIVPROC epoxy_glGetQueryBufferObjectiv;
    PFNGLGETQUERYBUFFEROBJECTUI64VPROC epoxy_glGetQueryBufferObjectui64v;
    PFNGLGETQUERYBUFFEROBJECTUIVPROC epoxy_glGetQueryBufferObjectuiv;
    PFNGLGETQUERYINDEXEDIVPROC epoxy_glGetQueryIndexediv;
    PFNGLGETQUERYOBJECTI64VPROC epoxy_glGetQueryObjecti64v;
    PFNGLGETQUERYOBJECTI64VEXTPROC epoxy_glGetQueryObjecti64vEXT;
    PFNGLGETQUERYOBJECTIVPROC epoxy_glGetQueryObjectiv;
    PFNGLGETQUERYOBJECTIVARBPROC epoxy_glGetQueryObjectivARB;
    PFNGLGETQUERYOBJECTIVEXTPROC epoxy_glGetQueryObjectivEXT;
    PFNGLGETQUERYOBJECTUI64VPROC epoxy_glGetQueryObjectui64v;
    PFNGLGETQUERYOBJECTUI64VEXTPROC epoxy_glGetQueryObjectui64vEXT;
    PFNGLGETQUERYOBJECTUIVPROC epoxy_glGetQueryObjectuiv;
    PFNGLGETQUERYOBJECTUIVARBPROC epoxy_glGetQueryObjectuivARB;
    PFNGLGETQUERYOBJECTUIVEXTPROC epoxy_glGetQueryObjectuivEXT;
    PFNGLGETQUERYIVPROC epoxy_glGetQueryiv;
    PFNGLGETQUERYIVARBPROC epoxy_glGetQueryivARB;
    PFNGLGETQUERYIVEXTPROC epoxy_glGetQueryivEXT;
    PFNGLGETRENDERBUFFERPARAMETERIVPROC epoxy_glGetRenderbufferParameteriv;
    PFNGLGETRENDERBUFFERPARAMETERIVEXTPROC epoxy_glGetRenderbufferParameterivEXT;
    PFNGLGETRENDERBUFFERPARAMETERIVOESPROC epoxy_glGetRenderbufferParameterivOES;
    PFNGLGETSAMPLERPARAMETERIIVPROC epoxy_glGetSamplerParameterIiv;
    PFNGLGETSAMPLERPARAMETERIIVEXTPROC epoxy_glGetSamplerParameterIivEXT;
    PFNGLGETSAMPLERPARAMETERIIVOESPROC epoxy_glGetSamplerParameterIivOES;
    PFNGLGETSAMPLERPARAMETERIUIVPROC epoxy_glGetSamplerParameterIuiv;
    PFNGLGETSAMPLERPARAMETERIUIVEXTPROC epoxy_glGetSamplerParameterIuivEXT;
    PFNGLGETSAMPLERPARAMETERIUIVOESPROC epoxy_glGetSamplerParameterIuivOES;
    PFNGLGETSAMPLERPARAMETERFVPROC epoxy_glGetSamplerParameterfv;
    PFNGLGETSAMPLERPARAMETERIVPROC epoxy_glGetSamplerParameteriv;
    PFNGLGETSEMAPHOREPARAMETERUI64VEXTPROC epoxy_glGetSemaphoreParameterui64vEXT;
    PFNGLGETSEPARABLEFILTERPROC epoxy_glGetSeparableFilter;
    PFNGLGETSEPARABLEFILTEREXTPROC epoxy_glGetSeparableFilterEXT;
    PFNGLGETSHADERINFOLOGPROC epoxy_glGetShaderInfoLog;
    PFNGLGETSHADERPRECISIONFORMATPROC epoxy_glGetShaderPrecisionFormat;
    PFNGLGETSHADERSOURCEPROC epoxy_glGetShaderSource;
    PFNGLGETSHADERSOURCEARBPROC epoxy_glGetShaderSourceARB;
    PFNGLGETSHADERIVPROC epoxy_glGetShaderiv;
    PFNGLGETSHADINGRATEIMAGEPALETTENVPROC epoxy_glGetShadingRateImagePaletteNV;
    PFNGLGETSHADINGRATESAMPLELOCATIONIVNVPROC epoxy_glGetShadingRateSampleLocationivNV;
    PFNGLGETSHARPENTEXFUNCSGISPROC epoxy_glGetSharpenTexFuncSGIS;
    PFNGLGETSTAGEINDEXNVPROC epoxy_glGetStageIndexNV;
    PFNGLGETSTRINGPROC epoxy_glGetString;
    PFNGLGETSTRINGIPROC epoxy_glGetStringi;
    PFNGLGETSUBROUTINEINDEXPROC epoxy_glGetSubroutineIndex;
    PFNGLGETSUBROUTINEUNIFORMLOCATIONPROC epoxy_glGetSubroutineUniformLocation;
    PFNGLGETSYNCIVPROC epoxy_glGetSynciv;
    PFNGLGETSYNCIVAPPLEPROC epoxy_glGetSyncivAPPLE;
    PFNGLGETTEXBUMPPARAMETERFVATIPROC epoxy_glGetTexBumpParameterfvATI;
    PFNGLGETTEXBUMPPARAMETERIVATIPROC epoxy_glGetTexBumpParameterivATI;
    PFNGLGETTEXENVFVPROC epoxy_glGetTexEnvfv;
    PFNGLGETTEXENVIVPROC epoxy_glGetTexEnviv;
    PFNGLGETTEXENVXVPROC epoxy_glGetTexEnvxv;
    PFNGLGETTEXENVXVOESPROC epoxy_glGetTexEnvxvOES;
    PFNGLGETTEXFILTERFUNCSGISPROC epoxy_glGetTexFilterFuncSGIS;
    PFNGLGETTEXGENDVPROC epoxy_glGetTexGendv;
    PFNGLGETTEXGENFVPROC epoxy_glGetTexGenfv;
    PFNGLGETTEXGENFVOESPROC epoxy_glGetTexGenfvOES;
    PFNGLGETTEXGENIVPROC epoxy_glGetTexGeniv;
    PFNGLGETTEXGENIVOESPROC epoxy_glGetTexGenivOES;
    PFNGLGETTEXGENXVOESPROC epoxy_glGetTexGenxvOES;
    PFNGLGETTEXIMAGEPROC epoxy_glGetTexImage;
    PFNGLGETTEXLEVELPARAMETERFVPROC epoxy_glGetTexLevelParameterfv;
    PFNGLGETTEXLEVELPARAMETERIVPROC epoxy_glGetTexLevelParameteriv;
    PFNGLGETTEXLEVELPARAMETERXVOESPROC epoxy_glGetTexLevelParameterxvOES;
    PFNGLGETTEXPARAMETERIIVPROC epoxy_glGetTexParameterIiv;
    PFNGLGETTEXPARAMETERIIVEXTPROC epoxy_glGetTexParameterIivEXT;
    PFNGLGETTEXPARAMETERIIVOESPROC epoxy_glGetTexParameterIivOES;
    PFNGLGETTEXPARAMETERIUIVPROC epoxy_glGetTexParameterIuiv;
    PFNGLGETTEXPARAMETERIUIVEXTPROC epoxy_glGetTexParameterIuivEXT;
    PFNGLGETTEXPARAMETERIUIVOESPROC epoxy_glGetTexParameterIuivOES;
    PFNGLGETTEXPARAMETERPOINTERVAPPLEPROC epoxy_glGetTexParameterPointervAPPLE;
    PFNGLGETTEXPARAMETERFVPROC epoxy_glGetTexParameterfv;
    PFNGLGETTEXPARAMETERIVPROC epoxy_glGetTexParameteriv;
    PFNGLGETTEXPARAMETERXVPROC epoxy_glGetTexParameterxv;
    PFNGLGETTEXPARAMETERXVOESPROC epoxy_glGetTexParameterxvOES;
    PFNGLGETTEXTUREHANDLEARBPROC epoxy_glGetTextureHandleARB;
    PFNGLGETTEXTUREHANDLEIMGPROC epoxy_glGetTextureHandleIMG;
    PFNGLGETTEXTUREHANDLENVPROC epoxy_glGetTextureHandleNV;
    PFNGLGETTEXTUREIMAGEPROC epoxy_glGetTextureImage;
    PFNGLGETTEXTUREIMAGEEXTPROC epoxy_glGetTextureImageEXT;
    PFNGLGETTEXTURELEVELPARAMETERFVPROC epoxy_glGetTextureLevelParameterfv;
    PFNGLGETTEXTURELEVELPARAMETERFVEXTPROC epoxy_glGetTextureLevelParameterfvEXT;
    PFNGLGETTEXTURELEVELPARAMETERIVPROC epoxy_glGetTextureLevelParameteriv;
    PFNGLGETTEXTURELEVELPARAMETERIVEXTPROC epoxy_glGetTextureLevelParameterivEXT;
    PFNGLGETTEXTUREPARAMETERIIVPROC epoxy_glGetTextureParameterIiv;
    PFNGLGETTEXTUREPARAMETERIIVEXTPROC epoxy_glGetTextureParameterIivEXT;
    PFNGLGETTEXTUREPARAMETERIUIVPROC epoxy_glGetTextureParameterIuiv;
    PFNGLGETTEXTUREPARAMETERIUIVEXTPROC epoxy_glGetTextureParameterIuivEXT;
    PFNGLGETTEXTUREPARAMETERFVPROC epoxy_glGetTextureParameterfv;
    PFNGLGETTEXTUREPARAMETERFVEXTPROC epoxy_glGetTextureParameterfvEXT;
    PFNGLGETTEXTUREPARAMETERIVPROC epoxy_glGetTextureParameteriv;
    PFNGLGETTEXTUREPARAMETERIVEXTPROC epoxy_glGetTextureParameterivEXT;
    PFNGLGETTEXTURESAMPLERHANDLEARBPROC epoxy_glGetTextureSamplerHandleARB;
    PFNGLGETTEXTURESAMPLERHANDLEIMGPROC epoxy_glGetTextureSamplerHandleIMG;
    PFNGLGETTEXTURESAMPLERHANDLENVPROC epoxy_glGetTextureSamplerHandleNV;
    PFNGLGETTEXTURESUBIMAGEPROC epoxy_glGetTextureSubImage;
    PFNGLGETTRACKMATRIXIVNVPROC epoxy_glGetTrackMatrixivNV;
    PFNGLGETTRANSFORMFEEDBACKVARYINGPROC epoxy_glGetTransformFeedbackVarying;
    PFNGLGETTRANSFORMFEEDBACKVARYINGEXTPROC epoxy_glGetTransformFeedbackVaryingEXT;
    PFNGLGETTRANSFORMFEEDBACKVARYINGNVPROC epoxy_glGetTransformFeedbackVaryingNV;
    PFNGLGETTRANSFORMFEEDBACKI64_VPROC epoxy_glGetTransformFeedbacki64_v;
    PFNGLGETTRANSFORMFEEDBACKI_VPROC epoxy_glGetTransformFeedbacki_v;
    PFNGLGETTRANSFORMFEEDBACKIVPROC epoxy_glGetTransformFeedbackiv;
    PFNGLGETTRANSLATEDSHADERSOURCEANGLEPROC epoxy_glGetTranslatedShaderSourceANGLE;
    PFNGLGETUNIFORMBLOCKINDEXPROC epoxy_glGetUniformBlockIndex;
    PFNGLGETUNIFORMBUFFERSIZEEXTPROC epoxy_glGetUniformBufferSizeEXT;
    PFNGLGETUNIFORMINDICESPROC epoxy_glGetUniformIndices;
    PFNGLGETUNIFORMLOCATIONPROC epoxy_glGetUniformLocation;
    PFNGLGETUNIFORMLOCATIONARBPROC epoxy_glGetUniformLocationARB;
    PFNGLGETUNIFORMOFFSETEXTPROC epoxy_glGetUniformOffsetEXT;
    PFNGLGETUNIFORMSUBROUTINEUIVPROC epoxy_glGetUniformSubroutineuiv;
    PFNGLGETUNIFORMDVPROC epoxy_glGetUniformdv;
    PFNGLGETUNIFORMFVPROC epoxy_glGetUniformfv;
    PFNGLGETUNIFORMFVARBPROC epoxy_glGetUniformfvARB;
    PFNGLGETUNIFORMI64VARBPROC epoxy_glGetUniformi64vARB;
    PFNGLGETUNIFORMI64VNVPROC epoxy_glGetUniformi64vNV;
    PFNGLGETUNIFORMIVPROC epoxy_glGetUniformiv;
    PFNGLGETUNIFORMIVARBPROC epoxy_glGetUniformivARB;
    PFNGLGETUNIFORMUI64VARBPROC epoxy_glGetUniformui64vARB;
    PFNGLGETUNIFORMUI64VNVPROC epoxy_glGetUniformui64vNV;
    PFNGLGETUNIFORMUIVPROC epoxy_glGetUniformuiv;
    PFNGLGETUNIFORMUIVEXTPROC epoxy_glGetUniformuivEXT;
    PFNGLGETUNSIGNEDBYTEI_VEXTPROC epoxy_glGetUnsignedBytei_vEXT;
    PFNGLGETUNSIGNEDBYTEVEXTPROC epoxy_glGetUnsignedBytevEXT;
    PFNGLGETVARIANTARRAYOBJECTFVATIPROC epoxy_glGetVariantArrayObjectfvATI;
    PFNGLGETVARIANTARRAYOBJECTIVATIPROC epoxy_glGetVariantArrayObjectivATI;
    PFNGLGETVARIANTBOOLEANVEXTPROC epoxy_glGetVariantBooleanvEXT;
    PFNGLGETVARIANTFLOATVEXTPROC epoxy_glGetVariantFloatvEXT;
    PFNGLGETVARIANTINTEGERVEXTPROC epoxy_glGetVariantIntegervEXT;
    PFNGLGETVARIANTPOINTERVEXTPROC epoxy_glGetVariantPointervEXT;
    PFNGLGETVARYINGLOCATIONNVPROC epoxy_glGetVaryingLocationNV;
    PFNGLGETVERTEXARRAYINDEXED64IVPROC epoxy_glGetVertexArrayIndexed64iv;
    PFNGLGETVERTEXARRAYINDEXEDIVPROC epoxy_glGetVertexArrayIndexediv;
    PFNGLGETVERTEXARRAYINTEGERI_VEXTPROC epoxy_glGetVertexArrayIntegeri_vEXT;
    PFNGLGETVERTEXARRAYINTEGERVEXTPROC epoxy_glGetVertexArrayIntegervEXT;
    PFNGLGETVERTEXARRAYPOINTERI_VEXTPROC epoxy_glGetVertexArrayPointeri_vEXT;
    PFNGLGETVERTEXARRAYPOINTERVEXTPROC epoxy_glGetVertexArrayPointervEXT;
    PFNGLGETVERTEXARRAYIVPROC epoxy_glGetVertexArrayiv;
    PFNGLGETVERTEXATTRIBARRAYOBJECTFVATIPROC epoxy_glGetVertexAttribArrayObjectfvATI;
    PFNGLGETVERTEXATTRIBARRAYOBJECTIVATIPROC epoxy_glGetVertexAttribArrayObjectivATI;
    PFNGLGETVERTEXATTRIBIIVPROC epoxy_glGetVertexAttribIiv;
    PFNGLGETVERTEXATTRIBIIVEXTPROC epoxy_glGetVertexAttribIivEXT;
    PFNGLGETVERTEXATTRIBIUIVPROC epoxy_glGetVertexAttribIuiv;
    PFNGLGETVERTEXATTRIBIUIVEXTPROC epoxy_glGetVertexAttribIuivEXT;
    PFNGLGETVERTEXATTRIBLDVPROC epoxy_glGetVertexAttribLdv;
    PFNGLGETVERTEXATTRIBLDVEXTPROC epoxy_glGetVertexAttribLdvEXT;
    PFNGLGETVERTEXATTRIBLI64VNVPROC epoxy_glGetVertexAttribLi64vNV;
    PFNGLGETVERTEXATTRIBLUI64VARBPROC epoxy_glGetVertexAttribLui64vARB;
    PFNGLGETVERTEXATTRIBLUI64VNVPROC epoxy_glGetVertexAttribLui64vNV;
    PFNGLGETVERTEXATTRIBPOINTERVPROC epoxy_glGetVertexAttribPointerv;
    PFNGLGETVERTEXATTRIBPOINTERVARBPROC epoxy_glGetVertexAttribPointervARB;
    PFNGLGETVERTEXATTRIBPOINTERVNVPROC epoxy_glGetVertexAttribPointervNV;
    PFNGLGETVERTEXATTRIBDVPROC epoxy_glGetVertexAttribdv;
    PFNGLGETVERTEXATTRIBDVARBPROC epoxy_glGetVertexAttribdvARB;
    PFNGLGETVERTEXATTRIBDVNVPROC epoxy_glGetVertexAttribdvNV;
    PFNGLGETVERTEXATTRIBFVPROC epoxy_glGetVertexAttribfv;
    PFNGLGETVERTEXATTRIBFVARBPROC epoxy_glGetVertexAttribfvARB;
    PFNGLGETVERTEXATTRIBFVNVPROC epoxy_glGetVertexAttribfvNV;
    PFNGLGETVERTEXATTRIBIVPROC epoxy_glGetVertexAttribiv;
    PFNGLGETVERTEXATTRIBIVARBPROC epoxy_glGetVertexAttribivARB;
    PFNGLGETVERTEXATTRIBIVNVPROC epoxy_glGetVertexAttribivNV;
    PFNGLGETVIDEOCAPTURESTREAMDVNVPROC epoxy_glGetVideoCaptureStreamdvNV;
    PFNGLGETVIDEOCAPTURESTREAMFVNVPROC epoxy_glGetVideoCaptureStreamfvNV;
    PFNGLGETVIDEOCAPTURESTREAMIVNVPROC epoxy_glGetVideoCaptureStreamivNV;
    PFNGLGETVIDEOCAPTUREIVNVPROC epoxy_glGetVideoCaptureivNV;
    PFNGLGETVIDEOI64VNVPROC epoxy_glGetVideoi64vNV;
    PFNGLGETVIDEOIVNVPROC epoxy_glGetVideoivNV;
    PFNGLGETVIDEOUI64VNVPROC epoxy_glGetVideoui64vNV;
    PFNGLGETVIDEOUIVNVPROC epoxy_glGetVideouivNV;
    PFNGLGETVKPROCADDRNVPROC epoxy_glGetVkProcAddrNV;
    PFNGLGETNCOLORTABLEPROC epoxy_glGetnColorTable;
    PFNGLGETNCOLORTABLEARBPROC epoxy_glGetnColorTableARB;
    PFNGLGETNCOMPRESSEDTEXIMAGEPROC epoxy_glGetnCompressedTexImage;
    PFNGLGETNCOMPRESSEDTEXIMAGEARBPROC epoxy_glGetnCompressedTexImageARB;
    PFNGLGETNCONVOLUTIONFILTERPROC epoxy_glGetnConvolutionFilter;
    PFNGLGETNCONVOLUTIONFILTERARBPROC epoxy_glGetnConvolutionFilterARB;
    PFNGLGETNHISTOGRAMPROC epoxy_glGetnHistogram;
    PFNGLGETNHISTOGRAMARBPROC epoxy_glGetnHistogramARB;
    PFNGLGETNMAPDVPROC epoxy_glGetnMapdv;
    PFNGLGETNMAPDVARBPROC epoxy_glGetnMapdvARB;
    PFNGLGETNMAPFVPROC epoxy_glGetnMapfv;
    PFNGLGETNMAPFVARBPROC epoxy_glGetnMapfvARB;
    PFNGLGETNMAPIVPROC epoxy_glGetnMapiv;
    PFNGLGETNMAPIVARBPROC epoxy_glGetnMapivARB;
    PFNGLGETNMINMAXPROC epoxy_glGetnMinmax;
    PFNGLGETNMINMAXARBPROC epoxy_glGetnMinmaxARB;
    PFNGLGETNPIXELMAPFVPROC epoxy_glGetnPixelMapfv;
    PFNGLGETNPIXELMAPFVARBPROC epoxy_glGetnPixelMapfvARB;
    PFNGLGETNPIXELMAPUIVPROC epoxy_glGetnPixelMapuiv;
    PFNGLGETNPIXELMAPUIVARBPROC epoxy_glGetnPixelMapuivARB;
    PFNGLGETNPIXELMAPUSVPROC epoxy_glGetnPixelMapusv;
    PFNGLGETNPIXELMAPUSVARBPROC epoxy_glGetnPixelMapusvARB;
    PFNGLGETNPOLYGONSTIPPLEPROC epoxy_glGetnPolygonStipple;
    PFNGLGETNPOLYGONSTIPPLEARBPROC epoxy_glGetnPolygonStippleARB;
    PFNGLGETNSEPARABLEFILTERPROC epoxy_glGetnSeparableFilter;
    PFNGLGETNSEPARABLEFILTERARBPROC epoxy_glGetnSeparableFilterARB;
    PFNGLGETNTEXIMAGEPROC epoxy_glGetnTexImage;
    PFNGLGETNTEXIMAGEARBPROC epoxy_glGetnTexImageARB;
    PFNGLGETNUNIFORMDVPROC epoxy_glGetnUniformdv;
    PFNGLGETNUNIFORMDVARBPROC epoxy_glGetnUniformdvARB;
    PFNGLGETNUNIFORMFVPROC epoxy_glGetnUniformfv;
    PFNGLGETNUNIFORMFVARBPROC epoxy_glGetnUniformfvARB;
    PFNGLGETNUNIFORMFVEXTPROC epoxy_glGetnUniformfvEXT;
    PFNGLGETNUNIFORMFVKHRPROC epoxy_glGetnUniformfvKHR;
    PFNGLGETNUNIFORMI64VARBPROC epoxy_glGetnUniformi64vARB;
    PFNGLGETNUNIFORMIVPROC epoxy_glGetnUniformiv;
    PFNGLGETNUNIFORMIVARBPROC epoxy_glGetnUniformivARB;
    PFNGLGETNUNIFORMIVEXTPROC epoxy_glGetnUniformivEXT;
    PFNGLGETNUNIFORMIVKHRPROC epoxy_glGetnUniformivKHR;
    PFNGLGETNUNIFORMUI64VARBPROC epoxy_glGetnUniformui64vARB;
    PFNGLGETNUNIFORMUIVPROC epoxy_glGetnUniformuiv;
    PFNGLGETNUNIFORMUIVARBPROC epoxy_glGetnUniformuivARB;
    PFNGLGETNUNIFORMUIVKHRPROC epoxy_glGetnUniformuivKHR;
    PFNGLGLOBALALPHAFACTORBSUNPROC epoxy_glGlobalAlphaFactorbSUN;
    PFNGLGLOBALALPHAFACTORDSUNPROC epoxy_glGlobalAlphaFactordSUN;
    PFNGLGLOBALALPHAFACTORFSUNPROC epoxy_glGlobalAlphaFactorfSUN;
    PFNGLGLOBALALPHAFACTORISUNPROC epoxy_glGlobalAlphaFactoriSUN;
    PFNGLGLOBALALPHAFACTORSSUNPROC epoxy_glGlobalAlphaFactorsSUN;
    PFNGLGLOBALALPHAFACTORUBSUNPROC epoxy_glGlobalAlphaFactorubSUN;
    PFNGLGLOBALALPHAFACTORUISUNPROC epoxy_glGlobalAlphaFactoruiSUN;
    PFNGLGLOBALALPHAFACTORUSSUNPROC epoxy_glGlobalAlphaFactorusSUN;
    PFNGLHINTPROC epoxy_glHint;
    PFNGLHINTPGIPROC epoxy_glHintPGI;
    PFNGLHISTOGRAMPROC epoxy_glHistogram;
    PFNGLHISTOGRAMEXTPROC epoxy_glHistogramEXT;
    PFNGLIGLOOINTERFACESGIXPROC epoxy_glIglooInterfaceSGIX;
    PFNGLIMAGETRANSFORMPARAMETERFHPPROC epoxy_glImageTransformParameterfHP;
    PFNGLIMAGETRANSFORMPARAMETERFVHPPROC epoxy_glImageTransformParameterfvHP;
    PFNGLIMAGETRANSFORMPARAMETERIHPPROC epoxy_glImageTransformParameteriHP;
    PFNGLIMAGETRANSFORMPARAMETERIVHPPROC epoxy_glImageTransformParameterivHP;
    PFNGLIMPORTMEMORYFDEXTPROC epoxy_glImportMemoryFdEXT;
    PFNGLIMPORTMEMORYWIN32HANDLEEXTPROC epoxy_glImportMemoryWin32HandleEXT;
    PFNGLIMPORTMEMORYWIN32NAMEEXTPROC epoxy_glImportMemoryWin32NameEXT;
    PFNGLIMPORTSEMAPHOREFDEXTPROC epoxy_glImportSemaphoreFdEXT;
    PFNGLIMPORTSEMAPHOREWIN32HANDLEEXTPROC epoxy_glImportSemaphoreWin32HandleEXT;
    PFNGLIMPORTSEMAPHOREWIN32NAMEEXTPROC epoxy_glImportSemaphoreWin32NameEXT;
    PFNGLIMPORTSYNCEXTPROC epoxy_glImportSyncEXT;
    PFNGLINDEXFORMATNVPROC epoxy_glIndexFormatNV;
    PFNGLINDEXFUNCEXTPROC epoxy_glIndexFuncEXT;
    PFNGLINDEXMASKPROC epoxy_glIndexMask;
    PFNGLINDEXMATERIALEXTPROC epoxy_glIndexMaterialEXT;
    PFNGLINDEXPOINTERPROC epoxy_glIndexPointer;
    PFNGLINDEXPOINTEREXTPROC epoxy_glIndexPointerEXT;
    PFNGLINDEXPOINTERLISTIBMPROC epoxy_glIndexPointerListIBM;
    PFNGLINDEXDPROC epoxy_glIndexd;
    PFNGLINDEXDVPROC epoxy_glIndexdv;
    PFNGLINDEXFPROC epoxy_glIndexf;
    PFNGLINDEXFVPROC epoxy_glIndexfv;
    PFNGLINDEXIPROC epoxy_glIndexi;
    PFNGLINDEXIVPROC epoxy_glIndexiv;
    PFNGLINDEXSPROC epoxy_glIndexs;
    PFNGLINDEXSVPROC epoxy_glIndexsv;
    PFNGLINDEXUBPROC epoxy_glIndexub;
    PFNGLINDEXUBVPROC epoxy_glIndexubv;
    PFNGLINDEXXOESPROC epoxy_glIndexxOES;
    PFNGLINDEXXVOESPROC epoxy_glIndexxvOES;
    PFNGLINITNAMESPROC epoxy_glInitNames;
    PFNGLINSERTCOMPONENTEXTPROC epoxy_glInsertComponentEXT;
    PFNGLINSERTEVENTMARKEREXTPROC epoxy_glInsertEventMarkerEXT;
    PFNGLINSTRUMENTSBUFFERSGIXPROC epoxy_glInstrumentsBufferSGIX;
    PFNGLINTERLEAVEDARRAYSPROC epoxy_glInterleavedArrays;
    PFNGLINTERPOLATEPATHSNVPROC epoxy_glInterpolatePathsNV;
    PFNGLINVALIDATEBUFFERDATAPROC epoxy_glInvalidateBufferData;
    PFNGLINVALIDATEBUFFERSUBDATAPROC epoxy_glInvalidateBufferSubData;
    PFNGLINVALIDATEFRAMEBUFFERPROC epoxy_glInvalidateFramebuffer;
    PFNGLINVALIDATENAMEDFRAMEBUFFERDATAPROC epoxy_glInvalidateNamedFramebufferData;
    PFNGLINVALIDATENAMEDFRAMEBUFFERSUBDATAPROC epoxy_glInvalidateNamedFramebufferSubData;
    PFNGLINVALIDATESUBFRAMEBUFFERPROC epoxy_glInvalidateSubFramebuffer;
    PFNGLINVALIDATETEXIMAGEPROC epoxy_glInvalidateTexImage;
    PFNGLINVALIDATETEXSUBIMAGEPROC epoxy_glInvalidateTexSubImage;
    PFNGLISASYNCMARKERSGIXPROC epoxy_glIsAsyncMarkerSGIX;
    PFNGLISBUFFERPROC epoxy_glIsBuffer;
    PFNGLISBUFFERARBPROC epoxy_glIsBufferARB;
    PFNGLISBUFFERRESIDENTNVPROC epoxy_glIsBufferResidentNV;
    PFNGLISCOMMANDLISTNVPROC epoxy_glIsCommandListNV;
    PFNGLISENABLEDPROC epoxy_glIsEnabled;
    PFNGLISENABLEDINDEXEDEXTPROC epoxy_glIsEnabledIndexedEXT;
    PFNGLISENABLEDIPROC epoxy_glIsEnabledi;
    PFNGLISENABLEDIEXTPROC epoxy_glIsEnablediEXT;
    PFNGLISENABLEDINVPROC epoxy_glIsEnablediNV;
    PFNGLISENABLEDIOESPROC epoxy_glIsEnablediOES;
    PFNGLISFENCEAPPLEPROC epoxy_glIsFenceAPPLE;
    PFNGLISFENCENVPROC epoxy_glIsFenceNV;
    PFNGLISFRAMEBUFFERPROC epoxy_glIsFramebuffer;
    PFNGLISFRAMEBUFFEREXTPROC epoxy_glIsFramebufferEXT;
    PFNGLISFRAMEBUFFEROESPROC epoxy_glIsFramebufferOES;
    PFNGLISIMAGEHANDLERESIDENTARBPROC epoxy_glIsImageHandleResidentARB;
    PFNGLISIMAGEHANDLERESIDENTNVPROC epoxy_glIsImageHandleResidentNV;
    PFNGLISLISTPROC epoxy_glIsList;
    PFNGLISMEMORYOBJECTEXTPROC epoxy_glIsMemoryObjectEXT;
    PFNGLISNAMEAMDPROC epoxy_glIsNameAMD;
    PFNGLISNAMEDBUFFERRESIDENTNVPROC epoxy_glIsNamedBufferResidentNV;
    PFNGLISNAMEDSTRINGARBPROC epoxy_glIsNamedStringARB;
    PFNGLISOBJECTBUFFERATIPROC epoxy_glIsObjectBufferATI;
    PFNGLISOCCLUSIONQUERYNVPROC epoxy_glIsOcclusionQueryNV;
    PFNGLISPATHNVPROC epoxy_glIsPathNV;
    PFNGLISPOINTINFILLPATHNVPROC epoxy_glIsPointInFillPathNV;
    PFNGLISPOINTINSTROKEPATHNVPROC epoxy_glIsPointInStrokePathNV;
    PFNGLISPROGRAMPROC epoxy_glIsProgram;
    PFNGLISPROGRAMARBPROC epoxy_glIsProgramARB;
    PFNGLISPROGRAMNVPROC epoxy_glIsProgramNV;
    PFNGLISPROGRAMPIPELINEPROC epoxy_glIsProgramPipeline;
    PFNGLISPROGRAMPIPELINEEXTPROC epoxy_glIsProgramPipelineEXT;
    PFNGLISQUERYPROC epoxy_glIsQuery;
    PFNGLISQUERYARBPROC epoxy_glIsQueryARB;
    PFNGLISQUERYEXTPROC epoxy_glIsQueryEXT;
    PFNGLISRENDERBUFFERPROC epoxy_glIsRenderbuffer;
    PFNGLISRENDERBUFFEREXTPROC epoxy_glIsRenderbufferEXT;
    PFNGLISRENDERBUFFEROESPROC epoxy_glIsRenderbufferOES;
    PFNGLISSAMPLERPROC epoxy_glIsSampler;
    PFNGLISSEMAPHOREEXTPROC epoxy_glIsSemaphoreEXT;
    PFNGLISSHADERPROC epoxy_glIsShader;
    PFNGLISSTATENVPROC epoxy_glIsStateNV;
    PFNGLISSYNCPROC epoxy_glIsSync;
    PFNGLISSYNCAPPLEPROC epoxy_glIsSyncAPPLE;
    PFNGLISTEXTUREPROC epoxy_glIsTexture;
    PFNGLISTEXTUREEXTPROC epoxy_glIsTextureEXT;
    PFNGLISTEXTUREHANDLERESIDENTARBPROC epoxy_glIsTextureHandleResidentARB;
    PFNGLISTEXTUREHANDLERESIDENTNVPROC epoxy_glIsTextureHandleResidentNV;
    PFNGLISTRANSFORMFEEDBACKPROC epoxy_glIsTransformFeedback;
    PFNGLISTRANSFORMFEEDBACKNVPROC epoxy_glIsTransformFeedbackNV;
    PFNGLISVARIANTENABLEDEXTPROC epoxy_glIsVariantEnabledEXT;
    PFNGLISVERTEXARRAYPROC epoxy_glIsVertexArray;
    PFNGLISVERTEXARRAYAPPLEPROC epoxy_glIsVertexArrayAPPLE;
    PFNGLISVERTEXARRAYOESPROC epoxy_glIsVertexArrayOES;
    PFNGLISVERTEXATTRIBENABLEDAPPLEPROC epoxy_glIsVertexAttribEnabledAPPLE;
    PFNGLLGPUCOPYIMAGESUBDATANVXPROC epoxy_glLGPUCopyImageSubDataNVX;
    PFNGLLGPUINTERLOCKNVXPROC epoxy_glLGPUInterlockNVX;
    PFNGLLGPUNAMEDBUFFERSUBDATANVXPROC epoxy_glLGPUNamedBufferSubDataNVX;
    PFNGLLABELOBJECTEXTPROC epoxy_glLabelObjectEXT;
    PFNGLLIGHTENVISGIXPROC epoxy_glLightEnviSGIX;
    PFNGLLIGHTMODELFPROC epoxy_glLightModelf;
    PFNGLLIGHTMODELFVPROC epoxy_glLightModelfv;
    PFNGLLIGHTMODELIPROC epoxy_glLightModeli;
    PFNGLLIGHTMODELIVPROC epoxy_glLightModeliv;
    PFNGLLIGHTMODELXPROC epoxy_glLightModelx;
    PFNGLLIGHTMODELXOESPROC epoxy_glLightModelxOES;
    PFNGLLIGHTMODELXVPROC epoxy_glLightModelxv;
    PFNGLLIGHTMODELXVOESPROC epoxy_glLightModelxvOES;
    PFNGLLIGHTFPROC epoxy_glLightf;
    PFNGLLIGHTFVPROC epoxy_glLightfv;
    PFNGLLIGHTIPROC epoxy_glLighti;
    PFNGLLIGHTIVPROC epoxy_glLightiv;
    PFNGLLIGHTXPROC epoxy_glLightx;
    PFNGLLIGHTXOESPROC epoxy_glLightxOES;
    PFNGLLIGHTXVPROC epoxy_glLightxv;
    PFNGLLIGHTXVOESPROC epoxy_glLightxvOES;
    PFNGLLINESTIPPLEPROC epoxy_glLineStipple;
    PFNGLLINEWIDTHPROC epoxy_glLineWidth;
    PFNGLLINEWIDTHXPROC epoxy_glLineWidthx;
    PFNGLLINEWIDTHXOESPROC epoxy_glLineWidthxOES;
    PFNGLLINKPROGRAMPROC epoxy_glLinkProgram;
    PFNGLLINKPROGRAMARBPROC epoxy_glLinkProgramARB;
    PFNGLLISTBASEPROC epoxy_glListBase;
    PFNGLLISTDRAWCOMMANDSSTATESCLIENTNVPROC epoxy_glListDrawCommandsStatesClientNV;
    PFNGLLISTPARAMETERFSGIXPROC epoxy_glListParameterfSGIX;
    PFNGLLISTPARAMETERFVSGIXPROC epoxy_glListParameterfvSGIX;
    PFNGLLISTPARAMETERISGIXPROC epoxy_glListParameteriSGIX;
    PFNGLLISTPARAMETERIVSGIXPROC epoxy_glListParameterivSGIX;
    PFNGLLOADIDENTITYPROC epoxy_glLoadIdentity;
    PFNGLLOADIDENTITYDEFORMATIONMAPSGIXPROC epoxy_glLoadIdentityDeformationMapSGIX;
    PFNGLLOADMATRIXDPROC epoxy_glLoadMatrixd;
    PFNGLLOADMATRIXFPROC epoxy_glLoadMatrixf;
    PFNGLLOADMATRIXXPROC epoxy_glLoadMatrixx;
    PFNGLLOADMATRIXXOESPROC epoxy_glLoadMatrixxOES;
    PFNGLLOADNAMEPROC epoxy_glLoadName;
    PFNGLLOADPALETTEFROMMODELVIEWMATRIXOESPROC epoxy_glLoadPaletteFromModelViewMatrixOES;
    PFNGLLOADPROGRAMNVPROC epoxy_glLoadProgramNV;
    PFNGLLOADTRANSPOSEMATRIXDPROC epoxy_glLoadTransposeMatrixd;
    PFNGLLOADTRANSPOSEMATRIXDARBPROC epoxy_glLoadTransposeMatrixdARB;
    PFNGLLOADTRANSPOSEMATRIXFPROC epoxy_glLoadTransposeMatrixf;
    PFNGLLOADTRANSPOSEMATRIXFARBPROC epoxy_glLoadTransposeMatrixfARB;
    PFNGLLOADTRANSPOSEMATRIXXOESPROC epoxy_glLoadTransposeMatrixxOES;
    PFNGLLOCKARRAYSEXTPROC epoxy_glLockArraysEXT;
    PFNGLLOGICOPPROC epoxy_glLogicOp;
    PFNGLMAKEBUFFERNONRESIDENTNVPROC epoxy_glMakeBufferNonResidentNV;
    PFNGLMAKEBUFFERRESIDENTNVPROC epoxy_glMakeBufferResidentNV;
    PFNGLMAKEIMAGEHANDLENONRESIDENTARBPROC epoxy_glMakeImageHandleNonResidentARB;
    PFNGLMAKEIMAGEHANDLENONRESIDENTNVPROC epoxy_glMakeImageHandleNonResidentNV;
    PFNGLMAKEIMAGEHANDLERESIDENTARBPROC epoxy_glMakeImageHandleResidentARB;
    PFNGLMAKEIMAGEHANDLERESIDENTNVPROC epoxy_glMakeImageHandleResidentNV;
    PFNGLMAKENAMEDBUFFERNONRESIDENTNVPROC epoxy_glMakeNamedBufferNonResidentNV;
    PFNGLMAKENAMEDBUFFERRESIDENTNVPROC epoxy_glMakeNamedBufferResidentNV;
    PFNGLMAKETEXTUREHANDLENONRESIDENTARBPROC epoxy_glMakeTextureHandleNonResidentARB;
    PFNGLMAKETEXTUREHANDLENONRESIDENTNVPROC epoxy_glMakeTextureHandleNonResidentNV;
    PFNGLMAKETEXTUREHANDLERESIDENTARBPROC epoxy_glMakeTextureHandleResidentARB;
    PFNGLMAKETEXTUREHANDLERESIDENTNVPROC epoxy_glMakeTextureHandleResidentNV;
    PFNGLMAP1DPROC epoxy_glMap1d;
    PFNGLMAP1FPROC epoxy_glMap1f;
    PFNGLMAP1XOESPROC epoxy_glMap1xOES;
    PFNGLMAP2DPROC epoxy_glMap2d;
    PFNGLMAP2FPROC epoxy_glMap2f;
    PFNGLMAP2XOESPROC epoxy_glMap2xOES;
    PFNGLMAPBUFFERPROC epoxy_glMapBuffer;
    PFNGLMAPBUFFERARBPROC epoxy_glMapBufferARB;
    PFNGLMAPBUFFEROESPROC epoxy_glMapBufferOES;
    PFNGLMAPBUFFERRANGEPROC epoxy_glMapBufferRange;
    PFNGLMAPBUFFERRANGEEXTPROC epoxy_glMapBufferRangeEXT;
    PFNGLMAPCONTROLPOINTSNVPROC epoxy_glMapControlPointsNV;
    PFNGLMAPGRID1DPROC epoxy_glMapGrid1d;
    PFNGLMAPGRID1FPROC epoxy_glMapGrid1f;
    PFNGLMAPGRID1XOESPROC epoxy_glMapGrid1xOES;
    PFNGLMAPGRID2DPROC epoxy_glMapGrid2d;
    PFNGLMAPGRID2FPROC epoxy_glMapGrid2f;
    PFNGLMAPGRID2XOESPROC epoxy_glMapGrid2xOES;
    PFNGLMAPNAMEDBUFFERPROC epoxy_glMapNamedBuffer;
    PFNGLMAPNAMEDBUFFEREXTPROC epoxy_glMapNamedBufferEXT;
    PFNGLMAPNAMEDBUFFERRANGEPROC epoxy_glMapNamedBufferRange;
    PFNGLMAPNAMEDBUFFERRANGEEXTPROC epoxy_glMapNamedBufferRangeEXT;
    PFNGLMAPOBJECTBUFFERATIPROC epoxy_glMapObjectBufferATI;
    PFNGLMAPPARAMETERFVNVPROC epoxy_glMapParameterfvNV;
    PFNGLMAPPARAMETERIVNVPROC epoxy_glMapParameterivNV;
    PFNGLMAPTEXTURE2DINTELPROC epoxy_glMapTexture2DINTEL;
    PFNGLMAPVERTEXATTRIB1DAPPLEPROC epoxy_glMapVertexAttrib1dAPPLE;
    PFNGLMAPVERTEXATTRIB1FAPPLEPROC epoxy_glMapVertexAttrib1fAPPLE;
    PFNGLMAPVERTEXATTRIB2DAPPLEPROC epoxy_glMapVertexAttrib2dAPPLE;
    PFNGLMAPVERTEXATTRIB2FAPPLEPROC epoxy_glMapVertexAttrib2fAPPLE;
    PFNGLMATERIALFPROC epoxy_glMaterialf;
    PFNGLMATERIALFVPROC epoxy_glMaterialfv;
    PFNGLMATERIALIPROC epoxy_glMateriali;
    PFNGLMATERIALIVPROC epoxy_glMaterialiv;
    PFNGLMATERIALXPROC epoxy_glMaterialx;
    PFNGLMATERIALXOESPROC epoxy_glMaterialxOES;
    PFNGLMATERIALXVPROC epoxy_glMaterialxv;
    PFNGLMATERIALXVOESPROC epoxy_glMaterialxvOES;
    PFNGLMATRIXFRUSTUMEXTPROC epoxy_glMatrixFrustumEXT;
    PFNGLMATRIXINDEXPOINTERARBPROC epoxy_glMatrixIndexPointerARB;
    PFNGLMATRIXINDEXPOINTEROESPROC epoxy_glMatrixIndexPointerOES;
    PFNGLMATRIXINDEXUBVARBPROC epoxy_glMatrixIndexubvARB;
    PFNGLMATRIXINDEXUIVARBPROC epoxy_glMatrixIndexuivARB;
    PFNGLMATRIXINDEXUSVARBPROC epoxy_glMatrixIndexusvARB;
    PFNGLMATRIXLOAD3X2FNVPROC epoxy_glMatrixLoad3x2fNV;
    PFNGLMATRIXLOAD3X3FNVPROC epoxy_glMatrixLoad3x3fNV;
    PFNGLMATRIXLOADIDENTITYEXTPROC epoxy_glMatrixLoadIdentityEXT;
    PFNGLMATRIXLOADTRANSPOSE3X3FNVPROC epoxy_glMatrixLoadTranspose3x3fNV;
    PFNGLMATRIXLOADTRANSPOSEDEXTPROC epoxy_glMatrixLoadTransposedEXT;
    PFNGLMATRIXLOADTRANSPOSEFEXTPROC epoxy_glMatrixLoadTransposefEXT;
    PFNGLMATRIXLOADDEXTPROC epoxy_glMatrixLoaddEXT;
    PFNGLMATRIXLOADFEXTPROC epoxy_glMatrixLoadfEXT;
    PFNGLMATRIXMODEPROC epoxy_glMatrixMode;
    PFNGLMATRIXMULT3X2FNVPROC epoxy_glMatrixMult3x2fNV;
    PFNGLMATRIXMULT3X3FNVPROC epoxy_glMatrixMult3x3fNV;
    PFNGLMATRIXMULTTRANSPOSE3X3FNVPROC epoxy_glMatrixMultTranspose3x3fNV;
    PFNGLMATRIXMULTTRANSPOSEDEXTPROC epoxy_glMatrixMultTransposedEXT;
    PFNGLMATRIXMULTTRANSPOSEFEXTPROC epoxy_glMatrixMultTransposefEXT;
    PFNGLMATRIXMULTDEXTPROC epoxy_glMatrixMultdEXT;
    PFNGLMATRIXMULTFEXTPROC epoxy_glMatrixMultfEXT;
    PFNGLMATRIXORTHOEXTPROC epoxy_glMatrixOrthoEXT;
    PFNGLMATRIXPOPEXTPROC epoxy_glMatrixPopEXT;
    PFNGLMATRIXPUSHEXTPROC epoxy_glMatrixPushEXT;
    PFNGLMATRIXROTATEDEXTPROC epoxy_glMatrixRotatedEXT;
    PFNGLMATRIXROTATEFEXTPROC epoxy_glMatrixRotatefEXT;
    PFNGLMATRIXSCALEDEXTPROC epoxy_glMatrixScaledEXT;
    PFNGLMATRIXSCALEFEXTPROC epoxy_glMatrixScalefEXT;
    PFNGLMATRIXTRANSLATEDEXTPROC epoxy_glMatrixTranslatedEXT;
    PFNGLMATRIXTRANSLATEFEXTPROC epoxy_glMatrixTranslatefEXT;
    PFNGLMAXSHADERCOMPILERTHREADSARBPROC epoxy_glMaxShaderCompilerThreadsARB;
    PFNGLMAXSHADERCOMPILERTHREADSKHRPROC epoxy_glMaxShaderCompilerThreadsKHR;
    PFNGLMEMORYBARRIERPROC epoxy_glMemoryBarrier;
    PFNGLMEMORYBARRIERBYREGIONPROC epoxy_glMemoryBarrierByRegion;
    PFNGLMEMORYBARRIEREXTPROC epoxy_glMemoryBarrierEXT;
    PFNGLMEMORYOBJECTPARAMETERIVEXTPROC epoxy_glMemoryObjectParameterivEXT;
    PFNGLMINSAMPLESHADINGPROC epoxy_glMinSampleShading;
    PFNGLMINSAMPLESHADINGARBPROC epoxy_glMinSampleShadingARB;
    PFNGLMINSAMPLESHADINGOESPROC epoxy_glMinSampleShadingOES;
    PFNGLMINMAXPROC epoxy_glMinmax;
    PFNGLMINMAXEXTPROC epoxy_glMinmaxEXT;
    PFNGLMULTMATRIXDPROC epoxy_glMultMatrixd;
    PFNGLMULTMATRIXFPROC epoxy_glMultMatrixf;
    PFNGLMULTMATRIXXPROC epoxy_glMultMatrixx;
    PFNGLMULTMATRIXXOESPROC epoxy_glMultMatrixxOES;
    PFNGLMULTTRANSPOSEMATRIXDPROC epoxy_glMultTransposeMatrixd;
    PFNGLMULTTRANSPOSEMATRIXDARBPROC epoxy_glMultTransposeMatrixdARB;
    PFNGLMULTTRANSPOSEMATRIXFPROC epoxy_glMultTransposeMatrixf;
    PFNGLMULTTRANSPOSEMATRIXFARBPROC epoxy_glMultTransposeMatrixfARB;
    PFNGLMULTTRANSPOSEMATRIXXOESPROC epoxy_glMultTransposeMatrixxOES;
    PFNGLMULTIDRAWARRAYSPROC epoxy_glMultiDrawArrays;
    PFNGLMULTIDRAWARRAYSEXTPROC epoxy_glMultiDrawArraysEXT;
    PFNGLMULTIDRAWARRAYSINDIRECTPROC epoxy_glMultiDrawArraysIndirect;
    PFNGLMULTIDRAWARRAYSINDIRECTAMDPROC epoxy_glMultiDrawArraysIndirectAMD;
    PFNGLMULTIDRAWARRAYSINDIRECTBINDLESSCOUNTNVPROC epoxy_glMultiDrawArraysIndirectBindlessCountNV;
    PFNGLMULTIDRAWARRAYSINDIRECTBINDLESSNVPROC epoxy_glMultiDrawArraysIndirectBindlessNV;
    PFNGLMULTIDRAWARRAYSINDIRECTCOUNTPROC epoxy_glMultiDrawArraysIndirectCount;
    PFNGLMULTIDRAWARRAYSINDIRECTCOUNTARBPROC epoxy_glMultiDrawArraysIndirectCountARB;
    PFNGLMULTIDRAWARRAYSINDIRECTEXTPROC epoxy_glMultiDrawArraysIndirectEXT;
    PFNGLMULTIDRAWELEMENTARRAYAPPLEPROC epoxy_glMultiDrawElementArrayAPPLE;
    PFNGLMULTIDRAWELEMENTSPROC epoxy_glMultiDrawElements;
    PFNGLMULTIDRAWELEMENTSBASEVERTEXPROC epoxy_glMultiDrawElementsBaseVertex;
    PFNGLMULTIDRAWELEMENTSBASEVERTEXEXTPROC epoxy_glMultiDrawElementsBaseVertexEXT;
    PFNGLMULTIDRAWELEMENTSEXTPROC epoxy_glMultiDrawElementsEXT;
    PFNGLMULTIDRAWELEMENTSINDIRECTPROC epoxy_glMultiDrawElementsIndirect;
    PFNGLMULTIDRAWELEMENTSINDIRECTAMDPROC epoxy_glMultiDrawElementsIndirectAMD;
    PFNGLMULTIDRAWELEMENTSINDIRECTBINDLESSCOUNTNVPROC epoxy_glMultiDrawElementsIndirectBindlessCountNV;
    PFNGLMULTIDRAWELEMENTSINDIRECTBINDLESSNVPROC epoxy_glMultiDrawElementsIndirectBindlessNV;
    PFNGLMULTIDRAWELEMENTSINDIRECTCOUNTPROC epoxy_glMultiDrawElementsIndirectCount;
    PFNGLMULTIDRAWELEMENTSINDIRECTCOUNTARBPROC epoxy_glMultiDrawElementsIndirectCountARB;
    PFNGLMULTIDRAWELEMENTSINDIRECTEXTPROC epoxy_glMultiDrawElementsIndirectEXT;
    PFNGLMULTIDRAWMESHTASKSINDIRECTCOUNTNVPROC epoxy_glMultiDrawMeshTasksIndirectCountNV;
    PFNGLMULTIDRAWMESHTASKSINDIRECTNVPROC epoxy_glMultiDrawMeshTasksIndirectNV;
    PFNGLMULTIDRAWRANGEELEMENTARRAYAPPLEPROC epoxy_glMultiDrawRangeElementArrayAPPLE;
    PFNGLMULTIMODEDRAWARRAYSIBMPROC epoxy_glMultiModeDrawArraysIBM;
    PFNGLMULTIMODEDRAWELEMENTSIBMPROC epoxy_glMultiModeDrawElementsIBM;
    PFNGLMULTITEXBUFFEREXTPROC epoxy_glMultiTexBufferEXT;
    PFNGLMULTITEXCOORD1BOESPROC epoxy_glMultiTexCoord1bOES;
    PFNGLMULTITEXCOORD1BVOESPROC epoxy_glMultiTexCoord1bvOES;
    PFNGLMULTITEXCOORD1DPROC epoxy_glMultiTexCoord1d;
    PFNGLMULTITEXCOORD1DARBPROC epoxy_glMultiTexCoord1dARB;
    PFNGLMULTITEXCOORD1DVPROC epoxy_glMultiTexCoord1dv;
    PFNGLMULTITEXCOORD1DVARBPROC epoxy_glMultiTexCoord1dvARB;
    PFNGLMULTITEXCOORD1FPROC epoxy_glMultiTexCoord1f;
    PFNGLMULTITEXCOORD1FARBPROC epoxy_glMultiTexCoord1fARB;
    PFNGLMULTITEXCOORD1FVPROC epoxy_glMultiTexCoord1fv;
    PFNGLMULTITEXCOORD1FVARBPROC epoxy_glMultiTexCoord1fvARB;
    PFNGLMULTITEXCOORD1HNVPROC epoxy_glMultiTexCoord1hNV;
    PFNGLMULTITEXCOORD1HVNVPROC epoxy_glMultiTexCoord1hvNV;
    PFNGLMULTITEXCOORD1IPROC epoxy_glMultiTexCoord1i;
    PFNGLMULTITEXCOORD1IARBPROC epoxy_glMultiTexCoord1iARB;
    PFNGLMULTITEXCOORD1IVPROC epoxy_glMultiTexCoord1iv;
    PFNGLMULTITEXCOORD1IVARBPROC epoxy_glMultiTexCoord1ivARB;
    PFNGLMULTITEXCOORD1SPROC epoxy_glMultiTexCoord1s;
    PFNGLMULTITEXCOORD1SARBPROC epoxy_glMultiTexCoord1sARB;
    PFNGLMULTITEXCOORD1SVPROC epoxy_glMultiTexCoord1sv;
    PFNGLMULTITEXCOORD1SVARBPROC epoxy_glMultiTexCoord1svARB;
    PFNGLMULTITEXCOORD1XOESPROC epoxy_glMultiTexCoord1xOES;
    PFNGLMULTITEXCOORD1XVOESPROC epoxy_glMultiTexCoord1xvOES;
    PFNGLMULTITEXCOORD2BOESPROC epoxy_glMultiTexCoord2bOES;
    PFNGLMULTITEXCOORD2BVOESPROC epoxy_glMultiTexCoord2bvOES;
    PFNGLMULTITEXCOORD2DPROC epoxy_glMultiTexCoord2d;
    PFNGLMULTITEXCOORD2DARBPROC epoxy_glMultiTexCoord2dARB;
    PFNGLMULTITEXCOORD2DVPROC epoxy_glMultiTexCoord2dv;
    PFNGLMULTITEXCOORD2DVARBPROC epoxy_glMultiTexCoord2dvARB;
    PFNGLMULTITEXCOORD2FPROC epoxy_glMultiTexCoord2f;
    PFNGLMULTITEXCOORD2FARBPROC epoxy_glMultiTexCoord2fARB;
    PFNGLMULTITEXCOORD2FVPROC epoxy_glMultiTexCoord2fv;
    PFNGLMULTITEXCOORD2FVARBPROC epoxy_glMultiTexCoord2fvARB;
    PFNGLMULTITEXCOORD2HNVPROC epoxy_glMultiTexCoord2hNV;
    PFNGLMULTITEXCOORD2HVNVPROC epoxy_glMultiTexCoord2hvNV;
    PFNGLMULTITEXCOORD2IPROC epoxy_glMultiTexCoord2i;
    PFNGLMULTITEXCOORD2IARBPROC epoxy_glMultiTexCoord2iARB;
    PFNGLMULTITEXCOORD2IVPROC epoxy_glMultiTexCoord2iv;
    PFNGLMULTITEXCOORD2IVARBPROC epoxy_glMultiTexCoord2ivARB;
    PFNGLMULTITEXCOORD2SPROC epoxy_glMultiTexCoord2s;
    PFNGLMULTITEXCOORD2SARBPROC epoxy_glMultiTexCoord2sARB;
    PFNGLMULTITEXCOORD2SVPROC epoxy_glMultiTexCoord2sv;
    PFNGLMULTITEXCOORD2SVARBPROC epoxy_glMultiTexCoord2svARB;
    PFNGLMULTITEXCOORD2XOESPROC epoxy_glMultiTexCoord2xOES;
    PFNGLMULTITEXCOORD2XVOESPROC epoxy_glMultiTexCoord2xvOES;
    PFNGLMULTITEXCOORD3BOESPROC epoxy_glMultiTexCoord3bOES;
    PFNGLMULTITEXCOORD3BVOESPROC epoxy_glMultiTexCoord3bvOES;
    PFNGLMULTITEXCOORD3DPROC epoxy_glMultiTexCoord3d;
    PFNGLMULTITEXCOORD3DARBPROC epoxy_glMultiTexCoord3dARB;
    PFNGLMULTITEXCOORD3DVPROC epoxy_glMultiTexCoord3dv;
    PFNGLMULTITEXCOORD3DVARBPROC epoxy_glMultiTexCoord3dvARB;
    PFNGLMULTITEXCOORD3FPROC epoxy_glMultiTexCoord3f;
    PFNGLMULTITEXCOORD3FARBPROC epoxy_glMultiTexCoord3fARB;
    PFNGLMULTITEXCOORD3FVPROC epoxy_glMultiTexCoord3fv;
    PFNGLMULTITEXCOORD3FVARBPROC epoxy_glMultiTexCoord3fvARB;
    PFNGLMULTITEXCOORD3HNVPROC epoxy_glMultiTexCoord3hNV;
    PFNGLMULTITEXCOORD3HVNVPROC epoxy_glMultiTexCoord3hvNV;
    PFNGLMULTITEXCOORD3IPROC epoxy_glMultiTexCoord3i;
    PFNGLMULTITEXCOORD3IARBPROC epoxy_glMultiTexCoord3iARB;
    PFNGLMULTITEXCOORD3IVPROC epoxy_glMultiTexCoord3iv;
    PFNGLMULTITEXCOORD3IVARBPROC epoxy_glMultiTexCoord3ivARB;
    PFNGLMULTITEXCOORD3SPROC epoxy_glMultiTexCoord3s;
    PFNGLMULTITEXCOORD3SARBPROC epoxy_glMultiTexCoord3sARB;
    PFNGLMULTITEXCOORD3SVPROC epoxy_glMultiTexCoord3sv;
    PFNGLMULTITEXCOORD3SVARBPROC epoxy_glMultiTexCoord3svARB;
    PFNGLMULTITEXCOORD3XOESPROC epoxy_glMultiTexCoord3xOES;
    PFNGLMULTITEXCOORD3XVOESPROC epoxy_glMultiTexCoord3xvOES;
    PFNGLMULTITEXCOORD4BOESPROC epoxy_glMultiTexCoord4bOES;
    PFNGLMULTITEXCOORD4BVOESPROC epoxy_glMultiTexCoord4bvOES;
    PFNGLMULTITEXCOORD4DPROC epoxy_glMultiTexCoord4d;
    PFNGLMULTITEXCOORD4DARBPROC epoxy_glMultiTexCoord4dARB;
    PFNGLMULTITEXCOORD4DVPROC epoxy_glMultiTexCoord4dv;
    PFNGLMULTITEXCOORD4DVARBPROC epoxy_glMultiTexCoord4dvARB;
    PFNGLMULTITEXCOORD4FPROC epoxy_glMultiTexCoord4f;
    PFNGLMULTITEXCOORD4FARBPROC epoxy_glMultiTexCoord4fARB;
    PFNGLMULTITEXCOORD4FVPROC epoxy_glMultiTexCoord4fv;
    PFNGLMULTITEXCOORD4FVARBPROC epoxy_glMultiTexCoord4fvARB;
    PFNGLMULTITEXCOORD4HNVPROC epoxy_glMultiTexCoord4hNV;
    PFNGLMULTITEXCOORD4HVNVPROC epoxy_glMultiTexCoord4hvNV;
    PFNGLMULTITEXCOORD4IPROC epoxy_glMultiTexCoord4i;
    PFNGLMULTITEXCOORD4IARBPROC epoxy_glMultiTexCoord4iARB;
    PFNGLMULTITEXCOORD4IVPROC epoxy_glMultiTexCoord4iv;
    PFNGLMULTITEXCOORD4IVARBPROC epoxy_glMultiTexCoord4ivARB;
    PFNGLMULTITEXCOORD4SPROC epoxy_glMultiTexCoord4s;
    PFNGLMULTITEXCOORD4SARBPROC epoxy_glMultiTexCoord4sARB;
    PFNGLMULTITEXCOORD4SVPROC epoxy_glMultiTexCoord4sv;
    PFNGLMULTITEXCOORD4SVARBPROC epoxy_glMultiTexCoord4svARB;
    PFNGLMULTITEXCOORD4XPROC epoxy_glMultiTexCoord4x;
    PFNGLMULTITEXCOORD4XOESPROC epoxy_glMultiTexCoord4xOES;
    PFNGLMULTITEXCOORD4XVOESPROC epoxy_glMultiTexCoord4xvOES;
    PFNGLMULTITEXCOORDP1UIPROC epoxy_glMultiTexCoordP1ui;
    PFNGLMULTITEXCOORDP1UIVPROC epoxy_glMultiTexCoordP1uiv;
    PFNGLMULTITEXCOORDP2UIPROC epoxy_glMultiTexCoordP2ui;
    PFNGLMULTITEXCOORDP2UIVPROC epoxy_glMultiTexCoordP2uiv;
    PFNGLMULTITEXCOORDP3UIPROC epoxy_glMultiTexCoordP3ui;
    PFNGLMULTITEXCOORDP3UIVPROC epoxy_glMultiTexCoordP3uiv;
    PFNGLMULTITEXCOORDP4UIPROC epoxy_glMultiTexCoordP4ui;
    PFNGLMULTITEXCOORDP4UIVPROC epoxy_glMultiTexCoordP4uiv;
    PFNGLMULTITEXCOORDPOINTEREXTPROC epoxy_glMultiTexCoordPointerEXT;
    PFNGLMULTITEXENVFEXTPROC epoxy_glMultiTexEnvfEXT;
    PFNGLMULTITEXENVFVEXTPROC epoxy_glMultiTexEnvfvEXT;
    PFNGLMULTITEXENVIEXTPROC epoxy_glMultiTexEnviEXT;
    PFNGLMULTITEXENVIVEXTPROC epoxy_glMultiTexEnvivEXT;
    PFNGLMULTITEXGENDEXTPROC epoxy_glMultiTexGendEXT;
    PFNGLMULTITEXGENDVEXTPROC epoxy_glMultiTexGendvEXT;
    PFNGLMULTITEXGENFEXTPROC epoxy_glMultiTexGenfEXT;
    PFNGLMULTITEXGENFVEXTPROC epoxy_glMultiTexGenfvEXT;
    PFNGLMULTITEXGENIEXTPROC epoxy_glMultiTexGeniEXT;
    PFNGLMULTITEXGENIVEXTPROC epoxy_glMultiTexGenivEXT;
    PFNGLMULTITEXIMAGE1DEXTPROC epoxy_glMultiTexImage1DEXT;
    PFNGLMULTITEXIMAGE2DEXTPROC epoxy_glMultiTexImage2DEXT;
    PFNGLMULTITEXIMAGE3DEXTPROC epoxy_glMultiTexImage3DEXT;
    PFNGLMULTITEXPARAMETERIIVEXTPROC epoxy_glMultiTexParameterIivEXT;
    PFNGLMULTITEXPARAMETERIUIVEXTPROC epoxy_glMultiTexParameterIuivEXT;
    PFNGLMULTITEXPARAMETERFEXTPROC epoxy_glMultiTexParameterfEXT;
    PFNGLMULTITEXPARAMETERFVEXTPROC epoxy_glMultiTexParameterfvEXT;
    PFNGLMULTITEXPARAMETERIEXTPROC epoxy_glMultiTexParameteriEXT;
    PFNGLMULTITEXPARAMETERIVEXTPROC epoxy_glMultiTexParameterivEXT;
    PFNGLMULTITEXRENDERBUFFEREXTPROC epoxy_glMultiTexRenderbufferEXT;
    PFNGLMULTITEXSUBIMAGE1DEXTPROC epoxy_glMultiTexSubImage1DEXT;
    PFNGLMULTITEXSUBIMAGE2DEXTPROC epoxy_glMultiTexSubImage2DEXT;
    PFNGLMULTITEXSUBIMAGE3DEXTPROC epoxy_glMultiTexSubImage3DEXT;
    PFNGLMULTICASTBARRIERNVPROC epoxy_glMulticastBarrierNV;
    PFNGLMULTICASTBLITFRAMEBUFFERNVPROC epoxy_glMulticastBlitFramebufferNV;
    PFNGLMULTICASTBUFFERSUBDATANVPROC epoxy_glMulticastBufferSubDataNV;
    PFNGLMULTICASTCOPYBUFFERSUBDATANVPROC epoxy_glMulticastCopyBufferSubDataNV;
    PFNGLMULTICASTCOPYIMAGESUBDATANVPROC epoxy_glMulticastCopyImageSubDataNV;
    PFNGLMULTICASTFRAMEBUFFERSAMPLELOCATIONSFVNVPROC epoxy_glMulticastFramebufferSampleLocationsfvNV;
    PFNGLMULTICASTGETQUERYOBJECTI64VNVPROC epoxy_glMulticastGetQueryObjecti64vNV;
    PFNGLMULTICASTGETQUERYOBJECTIVNVPROC epoxy_glMulticastGetQueryObjectivNV;
    PFNGLMULTICASTGETQUERYOBJECTUI64VNVPROC epoxy_glMulticastGetQueryObjectui64vNV;
    PFNGLMULTICASTGETQUERYOBJECTUIVNVPROC epoxy_glMulticastGetQueryObjectuivNV;
    PFNGLMULTICASTSCISSORARRAYVNVXPROC epoxy_glMulticastScissorArrayvNVX;
    PFNGLMULTICASTVIEWPORTARRAYVNVXPROC epoxy_glMulticastViewportArrayvNVX;
    PFNGLMULTICASTVIEWPORTPOSITIONWSCALENVXPROC epoxy_glMulticastViewportPositionWScaleNVX;
    PFNGLMULTICASTWAITSYNCNVPROC epoxy_glMulticastWaitSyncNV;
    PFNGLNAMEDBUFFERATTACHMEMORYNVPROC epoxy_glNamedBufferAttachMemoryNV;
    PFNGLNAMEDBUFFERDATAPROC epoxy_glNamedBufferData;
    PFNGLNAMEDBUFFERDATAEXTPROC epoxy_glNamedBufferDataEXT;
    PFNGLNAMEDBUFFERPAGECOMMITMENTARBPROC epoxy_glNamedBufferPageCommitmentARB;
    PFNGLNAMEDBUFFERPAGECOMMITMENTEXTPROC epoxy_glNamedBufferPageCommitmentEXT;
    PFNGLNAMEDBUFFERSTORAGEPROC epoxy_glNamedBufferStorage;
    PFNGLNAMEDBUFFERSTORAGEEXTPROC epoxy_glNamedBufferStorageEXT;
    PFNGLNAMEDBUFFERSTORAGEEXTERNALEXTPROC epoxy_glNamedBufferStorageExternalEXT;
    PFNGLNAMEDBUFFERSTORAGEMEMEXTPROC epoxy_glNamedBufferStorageMemEXT;
    PFNGLNAMEDBUFFERSUBDATAPROC epoxy_glNamedBufferSubData;
    PFNGLNAMEDBUFFERSUBDATAEXTPROC epoxy_glNamedBufferSubDataEXT;
    PFNGLNAMEDCOPYBUFFERSUBDATAEXTPROC epoxy_glNamedCopyBufferSubDataEXT;
    PFNGLNAMEDFRAMEBUFFERDRAWBUFFERPROC epoxy_glNamedFramebufferDrawBuffer;
    PFNGLNAMEDFRAMEBUFFERDRAWBUFFERSPROC epoxy_glNamedFramebufferDrawBuffers;
    PFNGLNAMEDFRAMEBUFFERPARAMETERIPROC epoxy_glNamedFramebufferParameteri;
    PFNGLNAMEDFRAMEBUFFERPARAMETERIEXTPROC epoxy_glNamedFramebufferParameteriEXT;
    PFNGLNAMEDFRAMEBUFFERREADBUFFERPROC epoxy_glNamedFramebufferReadBuffer;
    PFNGLNAMEDFRAMEBUFFERRENDERBUFFERPROC epoxy_glNamedFramebufferRenderbuffer;
    PFNGLNAMEDFRAMEBUFFERRENDERBUFFEREXTPROC epoxy_glNamedFramebufferRenderbufferEXT;
    PFNGLNAMEDFRAMEBUFFERSAMPLELOCATIONSFVARBPROC epoxy_glNamedFramebufferSampleLocationsfvARB;
    PFNGLNAMEDFRAMEBUFFERSAMPLELOCATIONSFVNVPROC epoxy_glNamedFramebufferSampleLocationsfvNV;
    PFNGLNAMEDFRAMEBUFFERSAMPLEPOSITIONSFVAMDPROC epoxy_glNamedFramebufferSamplePositionsfvAMD;
    PFNGLNAMEDFRAMEBUFFERTEXTUREPROC epoxy_glNamedFramebufferTexture;
    PFNGLNAMEDFRAMEBUFFERTEXTURE1DEXTPROC epoxy_glNamedFramebufferTexture1DEXT;
    PFNGLNAMEDFRAMEBUFFERTEXTURE2DEXTPROC epoxy_glNamedFramebufferTexture2DEXT;
    PFNGLNAMEDFRAMEBUFFERTEXTURE3DEXTPROC epoxy_glNamedFramebufferTexture3DEXT;
    PFNGLNAMEDFRAMEBUFFERTEXTUREEXTPROC epoxy_glNamedFramebufferTextureEXT;
    PFNGLNAMEDFRAMEBUFFERTEXTUREFACEEXTPROC epoxy_glNamedFramebufferTextureFaceEXT;
    PFNGLNAMEDFRAMEBUFFERTEXTURELAYERPROC epoxy_glNamedFramebufferTextureLayer;
    PFNGLNAMEDFRAMEBUFFERTEXTURELAYEREXTPROC epoxy_glNamedFramebufferTextureLayerEXT;
    PFNGLNAMEDPROGRAMLOCALPARAMETER4DEXTPROC epoxy_glNamedProgramLocalParameter4dEXT;
    PFNGLNAMEDPROGRAMLOCALPARAMETER4DVEXTPROC epoxy_glNamedProgramLocalParameter4dvEXT;
    PFNGLNAMEDPROGRAMLOCALPARAMETER4FEXTPROC epoxy_glNamedProgramLocalParameter4fEXT;
    PFNGLNAMEDPROGRAMLOCALPARAMETER4FVEXTPROC epoxy_glNamedProgramLocalParameter4fvEXT;
    PFNGLNAMEDPROGRAMLOCALPARAMETERI4IEXTPROC epoxy_glNamedProgramLocalParameterI4iEXT;
    PFNGLNAMEDPROGRAMLOCALPARAMETERI4IVEXTPROC epoxy_glNamedProgramLocalParameterI4ivEXT;
    PFNGLNAMEDPROGRAMLOCALPARAMETERI4UIEXTPROC epoxy_glNamedProgramLocalParameterI4uiEXT;
    PFNGLNAMEDPROGRAMLOCALPARAMETERI4UIVEXTPROC epoxy_glNamedProgramLocalParameterI4uivEXT;
    PFNGLNAMEDPROGRAMLOCALPARAMETERS4FVEXTPROC epoxy_glNamedProgramLocalParameters4fvEXT;
    PFNGLNAMEDPROGRAMLOCALPARAMETERSI4IVEXTPROC epoxy_glNamedProgramLocalParametersI4ivEXT;
    PFNGLNAMEDPROGRAMLOCALPARAMETERSI4UIVEXTPROC epoxy_glNamedProgramLocalParametersI4uivEXT;
    PFNGLNAMEDPROGRAMSTRINGEXTPROC epoxy_glNamedProgramStringEXT;
    PFNGLNAMEDRENDERBUFFERSTORAGEPROC epoxy_glNamedRenderbufferStorage;
    PFNGLNAMEDRENDERBUFFERSTORAGEEXTPROC epoxy_glNamedRenderbufferStorageEXT;
    PFNGLNAMEDRENDERBUFFERSTORAGEMULTISAMPLEPROC epoxy_glNamedRenderbufferStorageMultisample;
    PFNGLNAMEDRENDERBUFFERSTORAGEMULTISAMPLEADVANCEDAMDPROC epoxy_glNamedRenderbufferStorageMultisampleAdvancedAMD;
    PFNGLNAMEDRENDERBUFFERSTORAGEMULTISAMPLECOVERAGEEXTPROC epoxy_glNamedRenderbufferStorageMultisampleCoverageEXT;
    PFNGLNAMEDRENDERBUFFERSTORAGEMULTISAMPLEEXTPROC epoxy_glNamedRenderbufferStorageMultisampleEXT;
    PFNGLNAMEDSTRINGARBPROC epoxy_glNamedStringARB;
    PFNGLNEWLISTPROC epoxy_glNewList;
    PFNGLNEWOBJECTBUFFERATIPROC epoxy_glNewObjectBufferATI;
    PFNGLNORMAL3BPROC epoxy_glNormal3b;
    PFNGLNORMAL3BVPROC epoxy_glNormal3bv;
    PFNGLNORMAL3DPROC epoxy_glNormal3d;
    PFNGLNORMAL3DVPROC epoxy_glNormal3dv;
    PFNGLNORMAL3FPROC epoxy_glNormal3f;
    PFNGLNORMAL3FVERTEX3FSUNPROC epoxy_glNormal3fVertex3fSUN;
    PFNGLNORMAL3FVERTEX3FVSUNPROC epoxy_glNormal3fVertex3fvSUN;
    PFNGLNORMAL3FVPROC epoxy_glNormal3fv;
    PFNGLNORMAL3HNVPROC epoxy_glNormal3hNV;
    PFNGLNORMAL3HVNVPROC epoxy_glNormal3hvNV;
    PFNGLNORMAL3IPROC epoxy_glNormal3i;
    PFNGLNORMAL3IVPROC epoxy_glNormal3iv;
    PFNGLNORMAL3SPROC epoxy_glNormal3s;
    PFNGLNORMAL3SVPROC epoxy_glNormal3sv;
    PFNGLNORMAL3XPROC epoxy_glNormal3x;
    PFNGLNORMAL3XOESPROC epoxy_glNormal3xOES;
    PFNGLNORMAL3XVOESPROC epoxy_glNormal3xvOES;
    PFNGLNORMALFORMATNVPROC epoxy_glNormalFormatNV;
    PFNGLNORMALP3UIPROC epoxy_glNormalP3ui;
    PFNGLNORMALP3UIVPROC epoxy_glNormalP3uiv;
    PFNGLNORMALPOINTERPROC epoxy_glNormalPointer;
    PFNGLNORMALPOINTEREXTPROC epoxy_glNormalPointerEXT;
    PFNGLNORMALPOINTERLISTIBMPROC epoxy_glNormalPointerListIBM;
    PFNGLNORMALPOINTERVINTELPROC epoxy_glNormalPointervINTEL;
    PFNGLNORMALSTREAM3BATIPROC epoxy_glNormalStream3bATI;
    PFNGLNORMALSTREAM3BVATIPROC epoxy_glNormalStream3bvATI;
    PFNGLNORMALSTREAM3DATIPROC epoxy_glNormalStream3dATI;
    PFNGLNORMALSTREAM3DVATIPROC epoxy_glNormalStream3dvATI;
    PFNGLNORMALSTREAM3FATIPROC epoxy_glNormalStream3fATI;
    PFNGLNORMALSTREAM3FVATIPROC epoxy_glNormalStream3fvATI;
    PFNGLNORMALSTREAM3IATIPROC epoxy_glNormalStream3iATI;
    PFNGLNORMALSTREAM3IVATIPROC epoxy_glNormalStream3ivATI;
    PFNGLNORMALSTREAM3SATIPROC epoxy_glNormalStream3sATI;
    PFNGLNORMALSTREAM3SVATIPROC epoxy_glNormalStream3svATI;
    PFNGLOBJECTLABELPROC epoxy_glObjectLabel;
    PFNGLOBJECTLABELKHRPROC epoxy_glObjectLabelKHR;
    PFNGLOBJECTPTRLABELPROC epoxy_glObjectPtrLabel;
    PFNGLOBJECTPTRLABELKHRPROC epoxy_glObjectPtrLabelKHR;
    PFNGLOBJECTPURGEABLEAPPLEPROC epoxy_glObjectPurgeableAPPLE;
    PFNGLOBJECTUNPURGEABLEAPPLEPROC epoxy_glObjectUnpurgeableAPPLE;
    PFNGLORTHOPROC epoxy_glOrtho;
    PFNGLORTHOFPROC epoxy_glOrthof;
    PFNGLORTHOFOESPROC epoxy_glOrthofOES;
    PFNGLORTHOXPROC epoxy_glOrthox;
    PFNGLORTHOXOESPROC epoxy_glOrthoxOES;
    PFNGLPNTRIANGLESFATIPROC epoxy_glPNTrianglesfATI;
    PFNGLPNTRIANGLESIATIPROC epoxy_glPNTrianglesiATI;
    PFNGLPASSTEXCOORDATIPROC epoxy_glPassTexCoordATI;
    PFNGLPASSTHROUGHPROC epoxy_glPassThrough;
    PFNGLPASSTHROUGHXOESPROC epoxy_glPassThroughxOES;
    PFNGLPATCHPARAMETERFVPROC epoxy_glPatchParameterfv;
    PFNGLPATCHPARAMETERIPROC epoxy_glPatchParameteri;
    PFNGLPATCHPARAMETERIEXTPROC epoxy_glPatchParameteriEXT;
    PFNGLPATCHPARAMETERIOESPROC epoxy_glPatchParameteriOES;
    PFNGLPATHCOLORGENNVPROC epoxy_glPathColorGenNV;
    PFNGLPATHCOMMANDSNVPROC epoxy_glPathCommandsNV;
    PFNGLPATHCOORDSNVPROC epoxy_glPathCoordsNV;
    PFNGLPATHCOVERDEPTHFUNCNVPROC epoxy_glPathCoverDepthFuncNV;
    PFNGLPATHDASHARRAYNVPROC epoxy_glPathDashArrayNV;
    PFNGLPATHFOGGENNVPROC epoxy_glPathFogGenNV;
    PFNGLPATHGLYPHINDEXARRAYNVPROC epoxy_glPathGlyphIndexArrayNV;
    PFNGLPATHGLYPHINDEXRANGENVPROC epoxy_glPathGlyphIndexRangeNV;
    PFNGLPATHGLYPHRANGENVPROC epoxy_glPathGlyphRangeNV;
    PFNGLPATHGLYPHSNVPROC epoxy_glPathGlyphsNV;
    PFNGLPATHMEMORYGLYPHINDEXARRAYNVPROC epoxy_glPathMemoryGlyphIndexArrayNV;
    PFNGLPATHPARAMETERFNVPROC epoxy_glPathParameterfNV;
    PFNGLPATHPARAMETERFVNVPROC epoxy_glPathParameterfvNV;
    PFNGLPATHPARAMETERINVPROC epoxy_glPathParameteriNV;
    PFNGLPATHPARAMETERIVNVPROC epoxy_glPathParameterivNV;
    PFNGLPATHSTENCILDEPTHOFFSETNVPROC epoxy_glPathStencilDepthOffsetNV;
    PFNGLPATHSTENCILFUNCNVPROC epoxy_glPathStencilFuncNV;
    PFNGLPATHSTRINGNVPROC epoxy_glPathStringNV;
    PFNGLPATHSUBCOMMANDSNVPROC epoxy_glPathSubCommandsNV;
    PFNGLPATHSUBCOORDSNVPROC epoxy_glPathSubCoordsNV;
    PFNGLPATHTEXGENNVPROC epoxy_glPathTexGenNV;
    PFNGLPAUSETRANSFORMFEEDBACKPROC epoxy_glPauseTransformFeedback;
    PFNGLPAUSETRANSFORMFEEDBACKNVPROC epoxy_glPauseTransformFeedbackNV;
    PFNGLPIXELDATARANGENVPROC epoxy_glPixelDataRangeNV;
    PFNGLPIXELMAPFVPROC epoxy_glPixelMapfv;
    PFNGLPIXELMAPUIVPROC epoxy_glPixelMapuiv;
    PFNGLPIXELMAPUSVPROC epoxy_glPixelMapusv;
    PFNGLPIXELMAPXPROC epoxy_glPixelMapx;
    PFNGLPIXELSTOREFPROC epoxy_glPixelStoref;
    PFNGLPIXELSTOREIPROC epoxy_glPixelStorei;
    PFNGLPIXELSTOREXPROC epoxy_glPixelStorex;
    PFNGLPIXELTEXGENPARAMETERFSGISPROC epoxy_glPixelTexGenParameterfSGIS;
    PFNGLPIXELTEXGENPARAMETERFVSGISPROC epoxy_glPixelTexGenParameterfvSGIS;
    PFNGLPIXELTEXGENPARAMETERISGISPROC epoxy_glPixelTexGenParameteriSGIS;
    PFNGLPIXELTEXGENPARAMETERIVSGISPROC epoxy_glPixelTexGenParameterivSGIS;
    PFNGLPIXELTEXGENSGIXPROC epoxy_glPixelTexGenSGIX;
    PFNGLPIXELTRANSFERFPROC epoxy_glPixelTransferf;
    PFNGLPIXELTRANSFERIPROC epoxy_glPixelTransferi;
    PFNGLPIXELTRANSFERXOESPROC epoxy_glPixelTransferxOES;
    PFNGLPIXELTRANSFORMPARAMETERFEXTPROC epoxy_glPixelTransformParameterfEXT;
    PFNGLPIXELTRANSFORMPARAMETERFVEXTPROC epoxy_glPixelTransformParameterfvEXT;
    PFNGLPIXELTRANSFORMPARAMETERIEXTPROC epoxy_glPixelTransformParameteriEXT;
    PFNGLPIXELTRANSFORMPARAMETERIVEXTPROC epoxy_glPixelTransformParameterivEXT;
    PFNGLPIXELZOOMPROC epoxy_glPixelZoom;
    PFNGLPIXELZOOMXOESPROC epoxy_glPixelZoomxOES;
    PFNGLPOINTALONGPATHNVPROC epoxy_glPointAlongPathNV;
    PFNGLPOINTPARAMETERFPROC epoxy_glPointParameterf;
    PFNGLPOINTPARAMETERFARBPROC epoxy_glPointParameterfARB;
    PFNGLPOINTPARAMETERFEXTPROC epoxy_glPointParameterfEXT;
    PFNGLPOINTPARAMETERFSGISPROC epoxy_glPointParameterfSGIS;
    PFNGLPOINTPARAMETERFVPROC epoxy_glPointParameterfv;
    PFNGLPOINTPARAMETERFVARBPROC epoxy_glPointParameterfvARB;
    PFNGLPOINTPARAMETERFVEXTPROC epoxy_glPointParameterfvEXT;
    PFNGLPOINTPARAMETERFVSGISPROC epoxy_glPointParameterfvSGIS;
    PFNGLPOINTPARAMETERIPROC epoxy_glPointParameteri;
    PFNGLPOINTPARAMETERINVPROC epoxy_glPointParameteriNV;
    PFNGLPOINTPARAMETERIVPROC epoxy_glPointParameteriv;
    PFNGLPOINTPARAMETERIVNVPROC epoxy_glPointParameterivNV;
    PFNGLPOINTPARAMETERXPROC epoxy_glPointParameterx;
    PFNGLPOINTPARAMETERXOESPROC epoxy_glPointParameterxOES;
    PFNGLPOINTPARAMETERXVPROC epoxy_glPointParameterxv;
    PFNGLPOINTPARAMETERXVOESPROC epoxy_glPointParameterxvOES;
    PFNGLPOINTSIZEPROC epoxy_glPointSize;
    PFNGLPOINTSIZEPOINTEROESPROC epoxy_glPointSizePointerOES;
    PFNGLPOINTSIZEXPROC epoxy_glPointSizex;
    PFNGLPOINTSIZEXOESPROC epoxy_glPointSizexOES;
    PFNGLPOLLASYNCSGIXPROC epoxy_glPollAsyncSGIX;
    PFNGLPOLLINSTRUMENTSSGIXPROC epoxy_glPollInstrumentsSGIX;
    PFNGLPOLYGONMODEPROC epoxy_glPolygonMode;
    PFNGLPOLYGONMODENVPROC epoxy_glPolygonModeNV;
    PFNGLPOLYGONOFFSETPROC epoxy_glPolygonOffset;
    PFNGLPOLYGONOFFSETCLAMPPROC epoxy_glPolygonOffsetClamp;
    PFNGLPOLYGONOFFSETCLAMPEXTPROC epoxy_glPolygonOffsetClampEXT;
    PFNGLPOLYGONOFFSETEXTPROC epoxy_glPolygonOffsetEXT;
    PFNGLPOLYGONOFFSETXPROC epoxy_glPolygonOffsetx;
    PFNGLPOLYGONOFFSETXOESPROC epoxy_glPolygonOffsetxOES;
    PFNGLPOLYGONSTIPPLEPROC epoxy_glPolygonStipple;
    PFNGLPOPATTRIBPROC epoxy_glPopAttrib;
    PFNGLPOPCLIENTATTRIBPROC epoxy_glPopClientAttrib;
    PFNGLPOPDEBUGGROUPPROC epoxy_glPopDebugGroup;
    PFNGLPOPDEBUGGROUPKHRPROC epoxy_glPopDebugGroupKHR;
    PFNGLPOPGROUPMARKEREXTPROC epoxy_glPopGroupMarkerEXT;
    PFNGLPOPMATRIXPROC epoxy_glPopMatrix;
    PFNGLPOPNAMEPROC epoxy_glPopName;
    PFNGLPRESENTFRAMEDUALFILLNVPROC epoxy_glPresentFrameDualFillNV;
    PFNGLPRESENTFRAMEKEYEDNVPROC epoxy_glPresentFrameKeyedNV;
    PFNGLPRIMITIVEBOUNDINGBOXPROC epoxy_glPrimitiveBoundingBox;
    PFNGLPRIMITIVEBOUNDINGBOXARBPROC epoxy_glPrimitiveBoundingBoxARB;
    PFNGLPRIMITIVEBOUNDINGBOXEXTPROC epoxy_glPrimitiveBoundingBoxEXT;
    PFNGLPRIMITIVEBOUNDINGBOXOESPROC epoxy_glPrimitiveBoundingBoxOES;
    PFNGLPRIMITIVERESTARTINDEXPROC epoxy_glPrimitiveRestartIndex;
    PFNGLPRIMITIVERESTARTINDEXNVPROC epoxy_glPrimitiveRestartIndexNV;
    PFNGLPRIMITIVERESTARTNVPROC epoxy_glPrimitiveRestartNV;
    PFNGLPRIORITIZETEXTURESPROC epoxy_glPrioritizeTextures;
    PFNGLPRIORITIZETEXTURESEXTPROC epoxy_glPrioritizeTexturesEXT;
    PFNGLPRIORITIZETEXTURESXOESPROC epoxy_glPrioritizeTexturesxOES;
    PFNGLPROGRAMBINARYPROC epoxy_glProgramBinary;
    PFNGLPROGRAMBINARYOESPROC epoxy_glProgramBinaryOES;
    PFNGLPROGRAMBUFFERPARAMETERSIIVNVPROC epoxy_glProgramBufferParametersIivNV;
    PFNGLPROGRAMBUFFERPARAMETERSIUIVNVPROC epoxy_glProgramBufferParametersIuivNV;
    PFNGLPROGRAMBUFFERPARAMETERSFVNVPROC epoxy_glProgramBufferParametersfvNV;
    PFNGLPROGRAMENVPARAMETER4DARBPROC epoxy_glProgramEnvParameter4dARB;
    PFNGLPROGRAMENVPARAMETER4DVARBPROC epoxy_glProgramEnvParameter4dvARB;
    PFNGLPROGRAMENVPARAMETER4FARBPROC epoxy_glProgramEnvParameter4fARB;
    PFNGLPROGRAMENVPARAMETER4FVARBPROC epoxy_glProgramEnvParameter4fvARB;
    PFNGLPROGRAMENVPARAMETERI4INVPROC epoxy_glProgramEnvParameterI4iNV;
    PFNGLPROGRAMENVPARAMETERI4IVNVPROC epoxy_glProgramEnvParameterI4ivNV;
    PFNGLPROGRAMENVPARAMETERI4UINVPROC epoxy_glProgramEnvParameterI4uiNV;
    PFNGLPROGRAMENVPARAMETERI4UIVNVPROC epoxy_glProgramEnvParameterI4uivNV;
    PFNGLPROGRAMENVPARAMETERS4FVEXTPROC epoxy_glProgramEnvParameters4fvEXT;
    PFNGLPROGRAMENVPARAMETERSI4IVNVPROC epoxy_glProgramEnvParametersI4ivNV;
    PFNGLPROGRAMENVPARAMETERSI4UIVNVPROC epoxy_glProgramEnvParametersI4uivNV;
    PFNGLPROGRAMLOCALPARAMETER4DARBPROC epoxy_glProgramLocalParameter4dARB;
    PFNGLPROGRAMLOCALPARAMETER4DVARBPROC epoxy_glProgramLocalParameter4dvARB;
    PFNGLPROGRAMLOCALPARAMETER4FARBPROC epoxy_glProgramLocalParameter4fARB;
    PFNGLPROGRAMLOCALPARAMETER4FVARBPROC epoxy_glProgramLocalParameter4fvARB;
    PFNGLPROGRAMLOCALPARAMETERI4INVPROC epoxy_glProgramLocalParameterI4iNV;
    PFNGLPROGRAMLOCALPARAMETERI4IVNVPROC epoxy_glProgramLocalParameterI4ivNV;
    PFNGLPROGRAMLOCALPARAMETERI4UINVPROC epoxy_glProgramLocalParameterI4uiNV;
    PFNGLPROGRAMLOCALPARAMETERI4UIVNVPROC epoxy_glProgramLocalParameterI4uivNV;
    PFNGLPROGRAMLOCALPARAMETERS4FVEXTPROC epoxy_glProgramLocalParameters4fvEXT;
    PFNGLPROGRAMLOCALPARAMETERSI4IVNVPROC epoxy_glProgramLocalParametersI4ivNV;
    PFNGLPROGRAMLOCALPARAMETERSI4UIVNVPROC epoxy_glProgramLocalParametersI4uivNV;
    PFNGLPROGRAMNAMEDPARAMETER4DNVPROC epoxy_glProgramNamedParameter4dNV;
    PFNGLPROGRAMNAMEDPARAMETER4DVNVPROC epoxy_glProgramNamedParameter4dvNV;
    PFNGLPROGRAMNAMEDPARAMETER4FNVPROC epoxy_glProgramNamedParameter4fNV;
    PFNGLPROGRAMNAMEDPARAMETER4FVNVPROC epoxy_glProgramNamedParameter4fvNV;
    PFNGLPROGRAMPARAMETER4DNVPROC epoxy_glProgramParameter4dNV;
    PFNGLPROGRAMPARAMETER4DVNVPROC epoxy_glProgramParameter4dvNV;
    PFNGLPROGRAMPARAMETER4FNVPROC epoxy_glProgramParameter4fNV;
    PFNGLPROGRAMPARAMETER4FVNVPROC epoxy_glProgramParameter4fvNV;
    PFNGLPROGRAMPARAMETERIPROC epoxy_glProgramParameteri;
    PFNGLPROGRAMPARAMETERIARBPROC epoxy_glProgramParameteriARB;
    PFNGLPROGRAMPARAMETERIEXTPROC epoxy_glProgramParameteriEXT;
    PFNGLPROGRAMPARAMETERS4DVNVPROC epoxy_glProgramParameters4dvNV;
    PFNGLPROGRAMPARAMETERS4FVNVPROC epoxy_glProgramParameters4fvNV;
    PFNGLPROGRAMPATHFRAGMENTINPUTGENNVPROC epoxy_glProgramPathFragmentInputGenNV;
    PFNGLPROGRAMSTRINGARBPROC epoxy_glProgramStringARB;
    PFNGLPROGRAMSUBROUTINEPARAMETERSUIVNVPROC epoxy_glProgramSubroutineParametersuivNV;
    PFNGLPROGRAMUNIFORM1DPROC epoxy_glProgramUniform1d;
    PFNGLPROGRAMUNIFORM1DEXTPROC epoxy_glProgramUniform1dEXT;
    PFNGLPROGRAMUNIFORM1DVPROC epoxy_glProgramUniform1dv;
    PFNGLPROGRAMUNIFORM1DVEXTPROC epoxy_glProgramUniform1dvEXT;
    PFNGLPROGRAMUNIFORM1FPROC epoxy_glProgramUniform1f;
    PFNGLPROGRAMUNIFORM1FEXTPROC epoxy_glProgramUniform1fEXT;
    PFNGLPROGRAMUNIFORM1FVPROC epoxy_glProgramUniform1fv;
    PFNGLPROGRAMUNIFORM1FVEXTPROC epoxy_glProgramUniform1fvEXT;
    PFNGLPROGRAMUNIFORM1IPROC epoxy_glProgramUniform1i;
    PFNGLPROGRAMUNIFORM1I64ARBPROC epoxy_glProgramUniform1i64ARB;
    PFNGLPROGRAMUNIFORM1I64NVPROC epoxy_glProgramUniform1i64NV;
    PFNGLPROGRAMUNIFORM1I64VARBPROC epoxy_glProgramUniform1i64vARB;
    PFNGLPROGRAMUNIFORM1I64VNVPROC epoxy_glProgramUniform1i64vNV;
    PFNGLPROGRAMUNIFORM1IEXTPROC epoxy_glProgramUniform1iEXT;
    PFNGLPROGRAMUNIFORM1IVPROC epoxy_glProgramUniform1iv;
    PFNGLPROGRAMUNIFORM1IVEXTPROC epoxy_glProgramUniform1ivEXT;
    PFNGLPROGRAMUNIFORM1UIPROC epoxy_glProgramUniform1ui;
    PFNGLPROGRAMUNIFORM1UI64ARBPROC epoxy_glProgramUniform1ui64ARB;
    PFNGLPROGRAMUNIFORM1UI64NVPROC epoxy_glProgramUniform1ui64NV;
    PFNGLPROGRAMUNIFORM1UI64VARBPROC epoxy_glProgramUniform1ui64vARB;
    PFNGLPROGRAMUNIFORM1UI64VNVPROC epoxy_glProgramUniform1ui64vNV;
    PFNGLPROGRAMUNIFORM1UIEXTPROC epoxy_glProgramUniform1uiEXT;
    PFNGLPROGRAMUNIFORM1UIVPROC epoxy_glProgramUniform1uiv;
    PFNGLPROGRAMUNIFORM1UIVEXTPROC epoxy_glProgramUniform1uivEXT;
    PFNGLPROGRAMUNIFORM2DPROC epoxy_glProgramUniform2d;
    PFNGLPROGRAMUNIFORM2DEXTPROC epoxy_glProgramUniform2dEXT;
    PFNGLPROGRAMUNIFORM2DVPROC epoxy_glProgramUniform2dv;
    PFNGLPROGRAMUNIFORM2DVEXTPROC epoxy_glProgramUniform2dvEXT;
    PFNGLPROGRAMUNIFORM2FPROC epoxy_glProgramUniform2f;
    PFNGLPROGRAMUNIFORM2FEXTPROC epoxy_glProgramUniform2fEXT;
    PFNGLPROGRAMUNIFORM2FVPROC epoxy_glProgramUniform2fv;
    PFNGLPROGRAMUNIFORM2FVEXTPROC epoxy_glProgramUniform2fvEXT;
    PFNGLPROGRAMUNIFORM2IPROC epoxy_glProgramUniform2i;
    PFNGLPROGRAMUNIFORM2I64ARBPROC epoxy_glProgramUniform2i64ARB;
    PFNGLPROGRAMUNIFORM2I64NVPROC epoxy_glProgramUniform2i64NV;
    PFNGLPROGRAMUNIFORM2I64VARBPROC epoxy_glProgramUniform2i64vARB;
    PFNGLPROGRAMUNIFORM2I64VNVPROC epoxy_glProgramUniform2i64vNV;
    PFNGLPROGRAMUNIFORM2IEXTPROC epoxy_glProgramUniform2iEXT;
    PFNGLPROGRAMUNIFORM2IVPROC epoxy_glProgramUniform2iv;
    PFNGLPROGRAMUNIFORM2IVEXTPROC epoxy_glProgramUniform2ivEXT;
    PFNGLPROGRAMUNIFORM2UIPROC epoxy_glProgramUniform2ui;
    PFNGLPROGRAMUNIFORM2UI64ARBPROC epoxy_glProgramUniform2ui64ARB;
    PFNGLPROGRAMUNIFORM2UI64NVPROC epoxy_glProgramUniform2ui64NV;
    PFNGLPROGRAMUNIFORM2UI64VARBPROC epoxy_glProgramUniform2ui64vARB;
    PFNGLPROGRAMUNIFORM2UI64VNVPROC epoxy_glProgramUniform2ui64vNV;
    PFNGLPROGRAMUNIFORM2UIEXTPROC epoxy_glProgramUniform2uiEXT;
    PFNGLPROGRAMUNIFORM2UIVPROC epoxy_glProgramUniform2uiv;
    PFNGLPROGRAMUNIFORM2UIVEXTPROC epoxy_glProgramUniform2uivEXT;
    PFNGLPROGRAMUNIFORM3DPROC epoxy_glProgramUniform3d;
    PFNGLPROGRAMUNIFORM3DEXTPROC epoxy_glProgramUniform3dEXT;
    PFNGLPROGRAMUNIFORM3DVPROC epoxy_glProgramUniform3dv;
    PFNGLPROGRAMUNIFORM3DVEXTPROC epoxy_glProgramUniform3dvEXT;
    PFNGLPROGRAMUNIFORM3FPROC epoxy_glProgramUniform3f;
    PFNGLPROGRAMUNIFORM3FEXTPROC epoxy_glProgramUniform3fEXT;
    PFNGLPROGRAMUNIFORM3FVPROC epoxy_glProgramUniform3fv;
    PFNGLPROGRAMUNIFORM3FVEXTPROC epoxy_glProgramUniform3fvEXT;
    PFNGLPROGRAMUNIFORM3IPROC epoxy_glProgramUniform3i;
    PFNGLPROGRAMUNIFORM3I64ARBPROC epoxy_glProgramUniform3i64ARB;
    PFNGLPROGRAMUNIFORM3I64NVPROC epoxy_glProgramUniform3i64NV;
    PFNGLPROGRAMUNIFORM3I64VARBPROC epoxy_glProgramUniform3i64vARB;
    PFNGLPROGRAMUNIFORM3I64VNVPROC epoxy_glProgramUniform3i64vNV;
    PFNGLPROGRAMUNIFORM3IEXTPROC epoxy_glProgramUniform3iEXT;
    PFNGLPROGRAMUNIFORM3IVPROC epoxy_glProgramUniform3iv;
    PFNGLPROGRAMUNIFORM3IVEXTPROC epoxy_glProgramUniform3ivEXT;
    PFNGLPROGRAMUNIFORM3UIPROC epoxy_glProgramUniform3ui;
    PFNGLPROGRAMUNIFORM3UI64ARBPROC epoxy_glProgramUniform3ui64ARB;
    PFNGLPROGRAMUNIFORM3UI64NVPROC epoxy_glProgramUniform3ui64NV;
    PFNGLPROGRAMUNIFORM3UI64VARBPROC epoxy_glProgramUniform3ui64vARB;
    PFNGLPROGRAMUNIFORM3UI64VNVPROC epoxy_glProgramUniform3ui64vNV;
    PFNGLPROGRAMUNIFORM3UIEXTPROC epoxy_glProgramUniform3uiEXT;
    PFNGLPROGRAMUNIFORM3UIVPROC epoxy_glProgramUniform3uiv;
    PFNGLPROGRAMUNIFORM3UIVEXTPROC epoxy_glProgramUniform3uivEXT;
    PFNGLPROGRAMUNIFORM4DPROC epoxy_glProgramUniform4d;
    PFNGLPROGRAMUNIFORM4DEXTPROC epoxy_glProgramUniform4dEXT;
    PFNGLPROGRAMUNIFORM4DVPROC epoxy_glProgramUniform4dv;
    PFNGLPROGRAMUNIFORM4DVEXTPROC epoxy_glProgramUniform4dvEXT;
    PFNGLPROGRAMUNIFORM4FPROC epoxy_glProgramUniform4f;
    PFNGLPROGRAMUNIFORM4FEXTPROC epoxy_glProgramUniform4fEXT;
    PFNGLPROGRAMUNIFORM4FVPROC epoxy_glProgramUniform4fv;
    PFNGLPROGRAMUNIFORM4FVEXTPROC epoxy_glProgramUniform4fvEXT;
    PFNGLPROGRAMUNIFORM4IPROC epoxy_glProgramUniform4i;
    PFNGLPROGRAMUNIFORM4I64ARBPROC epoxy_glProgramUniform4i64ARB;
    PFNGLPROGRAMUNIFORM4I64NVPROC epoxy_glProgramUniform4i64NV;
    PFNGLPROGRAMUNIFORM4I64VARBPROC epoxy_glProgramUniform4i64vARB;
    PFNGLPROGRAMUNIFORM4I64VNVPROC epoxy_glProgramUniform4i64vNV;
    PFNGLPROGRAMUNIFORM4IEXTPROC epoxy_glProgramUniform4iEXT;
    PFNGLPROGRAMUNIFORM4IVPROC epoxy_glProgramUniform4iv;
    PFNGLPROGRAMUNIFORM4IVEXTPROC epoxy_glProgramUniform4ivEXT;
    PFNGLPROGRAMUNIFORM4UIPROC epoxy_glProgramUniform4ui;
    PFNGLPROGRAMUNIFORM4UI64ARBPROC epoxy_glProgramUniform4ui64ARB;
    PFNGLPROGRAMUNIFORM4UI64NVPROC epoxy_glProgramUniform4ui64NV;
    PFNGLPROGRAMUNIFORM4UI64VARBPROC epoxy_glProgramUniform4ui64vARB;
    PFNGLPROGRAMUNIFORM4UI64VNVPROC epoxy_glProgramUniform4ui64vNV;
    PFNGLPROGRAMUNIFORM4UIEXTPROC epoxy_glProgramUniform4uiEXT;
    PFNGLPROGRAMUNIFORM4UIVPROC epoxy_glProgramUniform4uiv;
    PFNGLPROGRAMUNIFORM4UIVEXTPROC epoxy_glProgramUniform4uivEXT;
    PFNGLPROGRAMUNIFORMHANDLEUI64ARBPROC epoxy_glProgramUniformHandleui64ARB;
    PFNGLPROGRAMUNIFORMHANDLEUI64IMGPROC epoxy_glProgramUniformHandleui64IMG;
    PFNGLPROGRAMUNIFORMHANDLEUI64NVPROC epoxy_glProgramUniformHandleui64NV;
    PFNGLPROGRAMUNIFORMHANDLEUI64VARBPROC epoxy_glProgramUniformHandleui64vARB;
    PFNGLPROGRAMUNIFORMHANDLEUI64VIMGPROC epoxy_glProgramUniformHandleui64vIMG;
    PFNGLPROGRAMUNIFORMHANDLEUI64VNVPROC epoxy_glProgramUniformHandleui64vNV;
    PFNGLPROGRAMUNIFORMMATRIX2DVPROC epoxy_glProgramUniformMatrix2dv;
    PFNGLPROGRAMUNIFORMMATRIX2DVEXTPROC epoxy_glProgramUniformMatrix2dvEXT;
    PFNGLPROGRAMUNIFORMMATRIX2FVPROC epoxy_glProgramUniformMatrix2fv;
    PFNGLPROGRAMUNIFORMMATRIX2FVEXTPROC epoxy_glProgramUniformMatrix2fvEXT;
    PFNGLPROGRAMUNIFORMMATRIX2X3DVPROC epoxy_glProgramUniformMatrix2x3dv;
    PFNGLPROGRAMUNIFORMMATRIX2X3DVEXTPROC epoxy_glProgramUniformMatrix2x3dvEXT;
    PFNGLPROGRAMUNIFORMMATRIX2X3FVPROC epoxy_glProgramUniformMatrix2x3fv;
    PFNGLPROGRAMUNIFORMMATRIX2X3FVEXTPROC epoxy_glProgramUniformMatrix2x3fvEXT;
    PFNGLPROGRAMUNIFORMMATRIX2X4DVPROC epoxy_glProgramUniformMatrix2x4dv;
    PFNGLPROGRAMUNIFORMMATRIX2X4DVEXTPROC epoxy_glProgramUniformMatrix2x4dvEXT;
    PFNGLPROGRAMUNIFORMMATRIX2X4FVPROC epoxy_glProgramUniformMatrix2x4fv;
    PFNGLPROGRAMUNIFORMMATRIX2X4FVEXTPROC epoxy_glProgramUniformMatrix2x4fvEXT;
    PFNGLPROGRAMUNIFORMMATRIX3DVPROC epoxy_glProgramUniformMatrix3dv;
    PFNGLPROGRAMUNIFORMMATRIX3DVEXTPROC epoxy_glProgramUniformMatrix3dvEXT;
    PFNGLPROGRAMUNIFORMMATRIX3FVPROC epoxy_glProgramUniformMatrix3fv;
    PFNGLPROGRAMUNIFORMMATRIX3FVEXTPROC epoxy_glProgramUniformMatrix3fvEXT;
    PFNGLPROGRAMUNIFORMMATRIX3X2DVPROC epoxy_glProgramUniformMatrix3x2dv;
    PFNGLPROGRAMUNIFORMMATRIX3X2DVEXTPROC epoxy_glProgramUniformMatrix3x2dvEXT;
    PFNGLPROGRAMUNIFORMMATRIX3X2FVPROC epoxy_glProgramUniformMatrix3x2fv;
    PFNGLPROGRAMUNIFORMMATRIX3X2FVEXTPROC epoxy_glProgramUniformMatrix3x2fvEXT;
    PFNGLPROGRAMUNIFORMMATRIX3X4DVPROC epoxy_glProgramUniformMatrix3x4dv;
    PFNGLPROGRAMUNIFORMMATRIX3X4DVEXTPROC epoxy_glProgramUniformMatrix3x4dvEXT;
    PFNGLPROGRAMUNIFORMMATRIX3X4FVPROC epoxy_glProgramUniformMatrix3x4fv;
    PFNGLPROGRAMUNIFORMMATRIX3X4FVEXTPROC epoxy_glProgramUniformMatrix3x4fvEXT;
    PFNGLPROGRAMUNIFORMMATRIX4DVPROC epoxy_glProgramUniformMatrix4dv;
    PFNGLPROGRAMUNIFORMMATRIX4DVEXTPROC epoxy_glProgramUniformMatrix4dvEXT;
    PFNGLPROGRAMUNIFORMMATRIX4FVPROC epoxy_glProgramUniformMatrix4fv;
    PFNGLPROGRAMUNIFORMMATRIX4FVEXTPROC epoxy_glProgramUniformMatrix4fvEXT;
    PFNGLPROGRAMUNIFORMMATRIX4X2DVPROC epoxy_glProgramUniformMatrix4x2dv;
    PFNGLPROGRAMUNIFORMMATRIX4X2DVEXTPROC epoxy_glProgramUniformMatrix4x2dvEXT;
    PFNGLPROGRAMUNIFORMMATRIX4X2FVPROC epoxy_glProgramUniformMatrix4x2fv;
    PFNGLPROGRAMUNIFORMMATRIX4X2FVEXTPROC epoxy_glProgramUniformMatrix4x2fvEXT;
    PFNGLPROGRAMUNIFORMMATRIX4X3DVPROC epoxy_glProgramUniformMatrix4x3dv;
    PFNGLPROGRAMUNIFORMMATRIX4X3DVEXTPROC epoxy_glProgramUniformMatrix4x3dvEXT;
    PFNGLPROGRAMUNIFORMMATRIX4X3FVPROC epoxy_glProgramUniformMatrix4x3fv;
    PFNGLPROGRAMUNIFORMMATRIX4X3FVEXTPROC epoxy_glProgramUniformMatrix4x3fvEXT;
    PFNGLPROGRAMUNIFORMUI64NVPROC epoxy_glProgramUniformui64NV;
    PFNGLPROGRAMUNIFORMUI64VNVPROC epoxy_glProgramUniformui64vNV;
    PFNGLPROGRAMVERTEXLIMITNVPROC epoxy_glProgramVertexLimitNV;
    PFNGLPROVOKINGVERTEXPROC epoxy_glProvokingVertex;
    PFNGLPROVOKINGVERTEXEXTPROC epoxy_glProvokingVertexEXT;
    PFNGLPUSHATTRIBPROC epoxy_glPushAttrib;
    PFNGLPUSHCLIENTATTRIBPROC epoxy_glPushClientAttrib;
    PFNGLPUSHCLIENTATTRIBDEFAULTEXTPROC epoxy_glPushClientAttribDefaultEXT;
    PFNGLPUSHDEBUGGROUPPROC epoxy_glPushDebugGroup;
    PFNGLPUSHDEBUGGROUPKHRPROC epoxy_glPushDebugGroupKHR;
    PFNGLPUSHGROUPMARKEREXTPROC epoxy_glPushGroupMarkerEXT;
    PFNGLPUSHMATRIXPROC epoxy_glPushMatrix;
    PFNGLPUSHNAMEPROC epoxy_glPushName;
    PFNGLQUERYCOUNTERPROC epoxy_glQueryCounter;
    PFNGLQUERYCOUNTEREXTPROC epoxy_glQueryCounterEXT;
    PFNGLQUERYMATRIXXOESPROC epoxy_glQueryMatrixxOES;
    PFNGLQUERYOBJECTPARAMETERUIAMDPROC epoxy_glQueryObjectParameteruiAMD;
    PFNGLQUERYRESOURCENVPROC epoxy_glQueryResourceNV;
    PFNGLQUERYRESOURCETAGNVPROC epoxy_glQueryResourceTagNV;
    PFNGLRASTERPOS2DPROC epoxy_glRasterPos2d;
    PFNGLRASTERPOS2DVPROC epoxy_glRasterPos2dv;
    PFNGLRASTERPOS2FPROC epoxy_glRasterPos2f;
    PFNGLRASTERPOS2FVPROC epoxy_glRasterPos2fv;
    PFNGLRASTERPOS2IPROC epoxy_glRasterPos2i;
    PFNGLRASTERPOS2IVPROC epoxy_glRasterPos2iv;
    PFNGLRASTERPOS2SPROC epoxy_glRasterPos2s;
    PFNGLRASTERPOS2SVPROC epoxy_glRasterPos2sv;
    PFNGLRASTERPOS2XOESPROC epoxy_glRasterPos2xOES;
    PFNGLRASTERPOS2XVOESPROC epoxy_glRasterPos2xvOES;
    PFNGLRASTERPOS3DPROC epoxy_glRasterPos3d;
    PFNGLRASTERPOS3DVPROC epoxy_glRasterPos3dv;
    PFNGLRASTERPOS3FPROC epoxy_glRasterPos3f;
    PFNGLRASTERPOS3FVPROC epoxy_glRasterPos3fv;
    PFNGLRASTERPOS3IPROC epoxy_glRasterPos3i;
    PFNGLRASTERPOS3IVPROC epoxy_glRasterPos3iv;
    PFNGLRASTERPOS3SPROC epoxy_glRasterPos3s;
    PFNGLRASTERPOS3SVPROC epoxy_glRasterPos3sv;
    PFNGLRASTERPOS3XOESPROC epoxy_glRasterPos3xOES;
    PFNGLRASTERPOS3XVOESPROC epoxy_glRasterPos3xvOES;
    PFNGLRASTERPOS4DPROC epoxy_glRasterPos4d;
    PFNGLRASTERPOS4DVPROC epoxy_glRasterPos4dv;
    PFNGLRASTERPOS4FPROC epoxy_glRasterPos4f;
    PFNGLRASTERPOS4FVPROC epoxy_glRasterPos4fv;
    PFNGLRASTERPOS4IPROC epoxy_glRasterPos4i;
    PFNGLRASTERPOS4IVPROC epoxy_glRasterPos4iv;
    PFNGLRASTERPOS4SPROC epoxy_glRasterPos4s;
    PFNGLRASTERPOS4SVPROC epoxy_glRasterPos4sv;
    PFNGLRASTERPOS4XOESPROC epoxy_glRasterPos4xOES;
    PFNGLRASTERPOS4XVOESPROC epoxy_glRasterPos4xvOES;
    PFNGLRASTERSAMPLESEXTPROC epoxy_glRasterSamplesEXT;
    PFNGLREADBUFFERPROC epoxy_glReadBuffer;
    PFNGLREADBUFFERINDEXEDEXTPROC epoxy_glReadBufferIndexedEXT;
    PFNGLREADBUFFERNVPROC epoxy_glReadBufferNV;
    PFNGLREADINSTRUMENTSSGIXPROC epoxy_glReadInstrumentsSGIX;
    PFNGLREADPIXELSPROC epoxy_glReadPixels;
    PFNGLREADNPIXELSPROC epoxy_glReadnPixels;
    PFNGLREADNPIXELSARBPROC epoxy_glReadnPixelsARB;
    PFNGLREADNPIXELSEXTPROC epoxy_glReadnPixelsEXT;
    PFNGLREADNPIXELSKHRPROC epoxy_glReadnPixelsKHR;
    PFNGLRECTDPROC epoxy_glRectd;
    PFNGLRECTDVPROC epoxy_glRectdv;
    PFNGLRECTFPROC epoxy_glRectf;
    PFNGLRECTFVPROC epoxy_glRectfv;
    PFNGLRECTIPROC epoxy_glRecti;
    PFNGLRECTIVPROC epoxy_glRectiv;
    PFNGLRECTSPROC epoxy_glRects;
    PFNGLRECTSVPROC epoxy_glRectsv;
    PFNGLRECTXOESPROC epoxy_glRectxOES;
    PFNGLRECTXVOESPROC epoxy_glRectxvOES;
    PFNGLREFERENCEPLANESGIXPROC epoxy_glReferencePlaneSGIX;
    PFNGLRELEASEKEYEDMUTEXWIN32EXTPROC epoxy_glReleaseKeyedMutexWin32EXT;
    PFNGLRELEASESHADERCOMPILERPROC epoxy_glReleaseShaderCompiler;
    PFNGLRENDERGPUMASKNVPROC epoxy_glRenderGpuMaskNV;
    PFNGLRENDERMODEPROC epoxy_glRenderMode;
    PFNGLRENDERBUFFERSTORAGEPROC epoxy_glRenderbufferStorage;
    PFNGLRENDERBUFFERSTORAGEEXTPROC epoxy_glRenderbufferStorageEXT;
    PFNGLRENDERBUFFERSTORAGEMULTISAMPLEPROC epoxy_glRenderbufferStorageMultisample;
    PFNGLRENDERBUFFERSTORAGEMULTISAMPLEANGLEPROC epoxy_glRenderbufferStorageMultisampleANGLE;
    PFNGLRENDERBUFFERSTORAGEMULTISAMPLEAPPLEPROC epoxy_glRenderbufferStorageMultisampleAPPLE;
    PFNGLRENDERBUFFERSTORAGEMULTISAMPLEADVANCEDAMDPROC epoxy_glRenderbufferStorageMultisampleAdvancedAMD;
    PFNGLRENDERBUFFERSTORAGEMULTISAMPLECOVERAGENVPROC epoxy_glRenderbufferStorageMultisampleCoverageNV;
    PFNGLRENDERBUFFERSTORAGEMULTISAMPLEEXTPROC epoxy_glRenderbufferStorageMultisampleEXT;
    PFNGLRENDERBUFFERSTORAGEMULTISAMPLEIMGPROC epoxy_glRenderbufferStorageMultisampleIMG;
    PFNGLRENDERBUFFERSTORAGEMULTISAMPLENVPROC epoxy_glRenderbufferStorageMultisampleNV;
    PFNGLRENDERBUFFERSTORAGEOESPROC epoxy_glRenderbufferStorageOES;
    PFNGLREPLACEMENTCODEPOINTERSUNPROC epoxy_glReplacementCodePointerSUN;
    PFNGLREPLACEMENTCODEUBSUNPROC epoxy_glReplacementCodeubSUN;
    PFNGLREPLACEMENTCODEUBVSUNPROC epoxy_glReplacementCodeubvSUN;
    PFNGLREPLACEMENTCODEUICOLOR3FVERTEX3FSUNPROC epoxy_glReplacementCodeuiColor3fVertex3fSUN;
    PFNGLREPLACEMENTCODEUICOLOR3FVERTEX3FVSUNPROC epoxy_glReplacementCodeuiColor3fVertex3fvSUN;
    PFNGLREPLACEMENTCODEUICOLOR4FNORMAL3FVERTEX3FSUNPROC epoxy_glReplacementCodeuiColor4fNormal3fVertex3fSUN;
    PFNGLREPLACEMENTCODEUICOLOR4FNORMAL3FVERTEX3FVSUNPROC epoxy_glReplacementCodeuiColor4fNormal3fVertex3fvSUN;
    PFNGLREPLACEMENTCODEUICOLOR4UBVERTEX3FSUNPROC epoxy_glReplacementCodeuiColor4ubVertex3fSUN;
    PFNGLREPLACEMENTCODEUICOLOR4UBVERTEX3FVSUNPROC epoxy_glReplacementCodeuiColor4ubVertex3fvSUN;
    PFNGLREPLACEMENTCODEUINORMAL3FVERTEX3FSUNPROC epoxy_glReplacementCodeuiNormal3fVertex3fSUN;
    PFNGLREPLACEMENTCODEUINORMAL3FVERTEX3FVSUNPROC epoxy_glReplacementCodeuiNormal3fVertex3fvSUN;
    PFNGLREPLACEMENTCODEUISUNPROC epoxy_glReplacementCodeuiSUN;
    PFNGLREPLACEMENTCODEUITEXCOORD2FCOLOR4FNORMAL3FVERTEX3FSUNPROC epoxy_glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fSUN;
    PFNGLREPLACEMENTCODEUITEXCOORD2FCOLOR4FNORMAL3FVERTEX3FVSUNPROC epoxy_glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fvSUN;
    PFNGLREPLACEMENTCODEUITEXCOORD2FNORMAL3FVERTEX3FSUNPROC epoxy_glReplacementCodeuiTexCoord2fNormal3fVertex3fSUN;
    PFNGLREPLACEMENTCODEUITEXCOORD2FNORMAL3FVERTEX3FVSUNPROC epoxy_glReplacementCodeuiTexCoord2fNormal3fVertex3fvSUN;
    PFNGLREPLACEMENTCODEUITEXCOORD2FVERTEX3FSUNPROC epoxy_glReplacementCodeuiTexCoord2fVertex3fSUN;
    PFNGLREPLACEMENTCODEUITEXCOORD2FVERTEX3FVSUNPROC epoxy_glReplacementCodeuiTexCoord2fVertex3fvSUN;
    PFNGLREPLACEMENTCODEUIVERTEX3FSUNPROC epoxy_glReplacementCodeuiVertex3fSUN;
    PFNGLREPLACEMENTCODEUIVERTEX3FVSUNPROC epoxy_glReplacementCodeuiVertex3fvSUN;
    PFNGLREPLACEMENTCODEUIVSUNPROC epoxy_glReplacementCodeuivSUN;
    PFNGLREPLACEMENTCODEUSSUNPROC epoxy_glReplacementCodeusSUN;
    PFNGLREPLACEMENTCODEUSVSUNPROC epoxy_glReplacementCodeusvSUN;
    PFNGLREQUESTRESIDENTPROGRAMSNVPROC epoxy_glRequestResidentProgramsNV;
    PFNGLRESETHISTOGRAMPROC epoxy_glResetHistogram;
    PFNGLRESETHISTOGRAMEXTPROC epoxy_glResetHistogramEXT;
    PFNGLRESETMEMORYOBJECTPARAMETERNVPROC epoxy_glResetMemoryObjectParameterNV;
    PFNGLRESETMINMAXPROC epoxy_glResetMinmax;
    PFNGLRESETMINMAXEXTPROC epoxy_glResetMinmaxEXT;
    PFNGLRESIZEBUFFERSMESAPROC epoxy_glResizeBuffersMESA;
    PFNGLRESOLVEDEPTHVALUESNVPROC epoxy_glResolveDepthValuesNV;
    PFNGLRESOLVEMULTISAMPLEFRAMEBUFFERAPPLEPROC epoxy_glResolveMultisampleFramebufferAPPLE;
    PFNGLRESUMETRANSFORMFEEDBACKPROC epoxy_glResumeTransformFeedback;
    PFNGLRESUMETRANSFORMFEEDBACKNVPROC epoxy_glResumeTransformFeedbackNV;
    PFNGLROTATEDPROC epoxy_glRotated;
    PFNGLROTATEFPROC epoxy_glRotatef;
    PFNGLROTATEXPROC epoxy_glRotatex;
    PFNGLROTATEXOESPROC epoxy_glRotatexOES;
    PFNGLSAMPLECOVERAGEPROC epoxy_glSampleCoverage;
    PFNGLSAMPLECOVERAGEARBPROC epoxy_glSampleCoverageARB;
    PFNGLSAMPLECOVERAGEXPROC epoxy_glSampleCoveragex;
    PFNGLSAMPLECOVERAGEXOESPROC epoxy_glSampleCoveragexOES;
    PFNGLSAMPLEMAPATIPROC epoxy_glSampleMapATI;
    PFNGLSAMPLEMASKEXTPROC epoxy_glSampleMaskEXT;
    PFNGLSAMPLEMASKINDEXEDNVPROC epoxy_glSampleMaskIndexedNV;
    PFNGLSAMPLEMASKSGISPROC epoxy_glSampleMaskSGIS;
    PFNGLSAMPLEMASKIPROC epoxy_glSampleMaski;
    PFNGLSAMPLEPATTERNEXTPROC epoxy_glSamplePatternEXT;
    PFNGLSAMPLEPATTERNSGISPROC epoxy_glSamplePatternSGIS;
    PFNGLSAMPLERPARAMETERIIVPROC epoxy_glSamplerParameterIiv;
    PFNGLSAMPLERPARAMETERIIVEXTPROC epoxy_glSamplerParameterIivEXT;
    PFNGLSAMPLERPARAMETERIIVOESPROC epoxy_glSamplerParameterIivOES;
    PFNGLSAMPLERPARAMETERIUIVPROC epoxy_glSamplerParameterIuiv;
    PFNGLSAMPLERPARAMETERIUIVEXTPROC epoxy_glSamplerParameterIuivEXT;
    PFNGLSAMPLERPARAMETERIUIVOESPROC epoxy_glSamplerParameterIuivOES;
    PFNGLSAMPLERPARAMETERFPROC epoxy_glSamplerParameterf;
    PFNGLSAMPLERPARAMETERFVPROC epoxy_glSamplerParameterfv;
    PFNGLSAMPLERPARAMETERIPROC epoxy_glSamplerParameteri;
    PFNGLSAMPLERPARAMETERIVPROC epoxy_glSamplerParameteriv;
    PFNGLSCALEDPROC epoxy_glScaled;
    PFNGLSCALEFPROC epoxy_glScalef;
    PFNGLSCALEXPROC epoxy_glScalex;
    PFNGLSCALEXOESPROC epoxy_glScalexOES;
    PFNGLSCISSORPROC epoxy_glScissor;
    PFNGLSCISSORARRAYVPROC epoxy_glScissorArrayv;
    PFNGLSCISSORARRAYVNVPROC epoxy_glScissorArrayvNV;
    PFNGLSCISSORARRAYVOESPROC epoxy_glScissorArrayvOES;
    PFNGLSCISSOREXCLUSIVEARRAYVNVPROC epoxy_glScissorExclusiveArrayvNV;
    PFNGLSCISSOREXCLUSIVENVPROC epoxy_glScissorExclusiveNV;
    PFNGLSCISSORINDEXEDPROC epoxy_glScissorIndexed;
    PFNGLSCISSORINDEXEDNVPROC epoxy_glScissorIndexedNV;
    PFNGLSCISSORINDEXEDOESPROC epoxy_glScissorIndexedOES;
    PFNGLSCISSORINDEXEDVPROC epoxy_glScissorIndexedv;
    PFNGLSCISSORINDEXEDVNVPROC epoxy_glScissorIndexedvNV;
    PFNGLSCISSORINDEXEDVOESPROC epoxy_glScissorIndexedvOES;
    PFNGLSECONDARYCOLOR3BPROC epoxy_glSecondaryColor3b;
    PFNGLSECONDARYCOLOR3BEXTPROC epoxy_glSecondaryColor3bEXT;
    PFNGLSECONDARYCOLOR3BVPROC epoxy_glSecondaryColor3bv;
    PFNGLSECONDARYCOLOR3BVEXTPROC epoxy_glSecondaryColor3bvEXT;
    PFNGLSECONDARYCOLOR3DPROC epoxy_glSecondaryColor3d;
    PFNGLSECONDARYCOLOR3DEXTPROC epoxy_glSecondaryColor3dEXT;
    PFNGLSECONDARYCOLOR3DVPROC epoxy_glSecondaryColor3dv;
    PFNGLSECONDARYCOLOR3DVEXTPROC epoxy_glSecondaryColor3dvEXT;
    PFNGLSECONDARYCOLOR3FPROC epoxy_glSecondaryColor3f;
    PFNGLSECONDARYCOLOR3FEXTPROC epoxy_glSecondaryColor3fEXT;
    PFNGLSECONDARYCOLOR3FVPROC epoxy_glSecondaryColor3fv;
    PFNGLSECONDARYCOLOR3FVEXTPROC epoxy_glSecondaryColor3fvEXT;
    PFNGLSECONDARYCOLOR3HNVPROC epoxy_glSecondaryColor3hNV;
    PFNGLSECONDARYCOLOR3HVNVPROC epoxy_glSecondaryColor3hvNV;
    PFNGLSECONDARYCOLOR3IPROC epoxy_glSecondaryColor3i;
    PFNGLSECONDARYCOLOR3IEXTPROC epoxy_glSecondaryColor3iEXT;
    PFNGLSECONDARYCOLOR3IVPROC epoxy_glSecondaryColor3iv;
    PFNGLSECONDARYCOLOR3IVEXTPROC epoxy_glSecondaryColor3ivEXT;
    PFNGLSECONDARYCOLOR3SPROC epoxy_glSecondaryColor3s;
    PFNGLSECONDARYCOLOR3SEXTPROC epoxy_glSecondaryColor3sEXT;
    PFNGLSECONDARYCOLOR3SVPROC epoxy_glSecondaryColor3sv;
    PFNGLSECONDARYCOLOR3SVEXTPROC epoxy_glSecondaryColor3svEXT;
    PFNGLSECONDARYCOLOR3UBPROC epoxy_glSecondaryColor3ub;
    PFNGLSECONDARYCOLOR3UBEXTPROC epoxy_glSecondaryColor3ubEXT;
    PFNGLSECONDARYCOLOR3UBVPROC epoxy_glSecondaryColor3ubv;
    PFNGLSECONDARYCOLOR3UBVEXTPROC epoxy_glSecondaryColor3ubvEXT;
    PFNGLSECONDARYCOLOR3UIPROC epoxy_glSecondaryColor3ui;
    PFNGLSECONDARYCOLOR3UIEXTPROC epoxy_glSecondaryColor3uiEXT;
    PFNGLSECONDARYCOLOR3UIVPROC epoxy_glSecondaryColor3uiv;
    PFNGLSECONDARYCOLOR3UIVEXTPROC epoxy_glSecondaryColor3uivEXT;
    PFNGLSECONDARYCOLOR3USPROC epoxy_glSecondaryColor3us;
    PFNGLSECONDARYCOLOR3USEXTPROC epoxy_glSecondaryColor3usEXT;
    PFNGLSECONDARYCOLOR3USVPROC epoxy_glSecondaryColor3usv;
    PFNGLSECONDARYCOLOR3USVEXTPROC epoxy_glSecondaryColor3usvEXT;
    PFNGLSECONDARYCOLORFORMATNVPROC epoxy_glSecondaryColorFormatNV;
    PFNGLSECONDARYCOLORP3UIPROC epoxy_glSecondaryColorP3ui;
    PFNGLSECONDARYCOLORP3UIVPROC epoxy_glSecondaryColorP3uiv;
    PFNGLSECONDARYCOLORPOINTERPROC epoxy_glSecondaryColorPointer;
    PFNGLSECONDARYCOLORPOINTEREXTPROC epoxy_glSecondaryColorPointerEXT;
    PFNGLSECONDARYCOLORPOINTERLISTIBMPROC epoxy_glSecondaryColorPointerListIBM;
    PFNGLSELECTBUFFERPROC epoxy_glSelectBuffer;
    PFNGLSELECTPERFMONITORCOUNTERSAMDPROC epoxy_glSelectPerfMonitorCountersAMD;
    PFNGLSEMAPHOREPARAMETERUI64VEXTPROC epoxy_glSemaphoreParameterui64vEXT;
    PFNGLSEPARABLEFILTER2DPROC epoxy_glSeparableFilter2D;
    PFNGLSEPARABLEFILTER2DEXTPROC epoxy_glSeparableFilter2DEXT;
    PFNGLSETFENCEAPPLEPROC epoxy_glSetFenceAPPLE;
    PFNGLSETFENCENVPROC epoxy_glSetFenceNV;
    PFNGLSETFRAGMENTSHADERCONSTANTATIPROC epoxy_glSetFragmentShaderConstantATI;
    PFNGLSETINVARIANTEXTPROC epoxy_glSetInvariantEXT;
    PFNGLSETLOCALCONSTANTEXTPROC epoxy_glSetLocalConstantEXT;
    PFNGLSETMULTISAMPLEFVAMDPROC epoxy_glSetMultisamplefvAMD;
    PFNGLSHADEMODELPROC epoxy_glShadeModel;
    PFNGLSHADERBINARYPROC epoxy_glShaderBinary;
    PFNGLSHADEROP1EXTPROC epoxy_glShaderOp1EXT;
    PFNGLSHADEROP2EXTPROC epoxy_glShaderOp2EXT;
    PFNGLSHADEROP3EXTPROC epoxy_glShaderOp3EXT;
    PFNGLSHADERSOURCEPROC epoxy_glShaderSource;
    PFNGLSHADERSOURCEARBPROC epoxy_glShaderSourceARB;
    PFNGLSHADERSTORAGEBLOCKBINDINGPROC epoxy_glShaderStorageBlockBinding;
    PFNGLSHADINGRATEIMAGEBARRIERNVPROC epoxy_glShadingRateImageBarrierNV;
    PFNGLSHADINGRATEIMAGEPALETTENVPROC epoxy_glShadingRateImagePaletteNV;
    PFNGLSHADINGRATESAMPLEORDERCUSTOMNVPROC epoxy_glShadingRateSampleOrderCustomNV;
    PFNGLSHADINGRATESAMPLEORDERNVPROC epoxy_glShadingRateSampleOrderNV;
    PFNGLSHARPENTEXFUNCSGISPROC epoxy_glSharpenTexFuncSGIS;
    PFNGLSIGNALSEMAPHOREEXTPROC epoxy_glSignalSemaphoreEXT;
    PFNGLSIGNALSEMAPHOREUI64NVXPROC epoxy_glSignalSemaphoreui64NVX;
    PFNGLSIGNALVKFENCENVPROC epoxy_glSignalVkFenceNV;
    PFNGLSIGNALVKSEMAPHORENVPROC epoxy_glSignalVkSemaphoreNV;
    PFNGLSPECIALIZESHADERPROC epoxy_glSpecializeShader;
    PFNGLSPECIALIZESHADERARBPROC epoxy_glSpecializeShaderARB;
    PFNGLSPRITEPARAMETERFSGIXPROC epoxy_glSpriteParameterfSGIX;
    PFNGLSPRITEPARAMETERFVSGIXPROC epoxy_glSpriteParameterfvSGIX;
    PFNGLSPRITEPARAMETERISGIXPROC epoxy_glSpriteParameteriSGIX;
    PFNGLSPRITEPARAMETERIVSGIXPROC epoxy_glSpriteParameterivSGIX;
    PFNGLSTARTINSTRUMENTSSGIXPROC epoxy_glStartInstrumentsSGIX;
    PFNGLSTARTTILINGQCOMPROC epoxy_glStartTilingQCOM;
    PFNGLSTATECAPTURENVPROC epoxy_glStateCaptureNV;
    PFNGLSTENCILCLEARTAGEXTPROC epoxy_glStencilClearTagEXT;
    PFNGLSTENCILFILLPATHINSTANCEDNVPROC epoxy_glStencilFillPathInstancedNV;
    PFNGLSTENCILFILLPATHNVPROC epoxy_glStencilFillPathNV;
    PFNGLSTENCILFUNCPROC epoxy_glStencilFunc;
    PFNGLSTENCILFUNCSEPARATEPROC epoxy_glStencilFuncSeparate;
    PFNGLSTENCILFUNCSEPARATEATIPROC epoxy_glStencilFuncSeparateATI;
    PFNGLSTENCILMASKPROC epoxy_glStencilMask;
    PFNGLSTENCILMASKSEPARATEPROC epoxy_glStencilMaskSeparate;
    PFNGLSTENCILOPPROC epoxy_glStencilOp;
    PFNGLSTENCILOPSEPARATEPROC epoxy_glStencilOpSeparate;
    PFNGLSTENCILOPSEPARATEATIPROC epoxy_glStencilOpSeparateATI;
    PFNGLSTENCILOPVALUEAMDPROC epoxy_glStencilOpValueAMD;
    PFNGLSTENCILSTROKEPATHINSTANCEDNVPROC epoxy_glStencilStrokePathInstancedNV;
    PFNGLSTENCILSTROKEPATHNVPROC epoxy_glStencilStrokePathNV;
    PFNGLSTENCILTHENCOVERFILLPATHINSTANCEDNVPROC epoxy_glStencilThenCoverFillPathInstancedNV;
    PFNGLSTENCILTHENCOVERFILLPATHNVPROC epoxy_glStencilThenCoverFillPathNV;
    PFNGLSTENCILTHENCOVERSTROKEPATHINSTANCEDNVPROC epoxy_glStencilThenCoverStrokePathInstancedNV;
    PFNGLSTENCILTHENCOVERSTROKEPATHNVPROC epoxy_glStencilThenCoverStrokePathNV;
    PFNGLSTOPINSTRUMENTSSGIXPROC epoxy_glStopInstrumentsSGIX;
    PFNGLSTRINGMARKERGREMEDYPROC epoxy_glStringMarkerGREMEDY;
    PFNGLSUBPIXELPRECISIONBIASNVPROC epoxy_glSubpixelPrecisionBiasNV;
    PFNGLSWIZZLEEXTPROC epoxy_glSwizzleEXT;
    PFNGLSYNCTEXTUREINTELPROC epoxy_glSyncTextureINTEL;
    PFNGLTAGSAMPLEBUFFERSGIXPROC epoxy_glTagSampleBufferSGIX;
    PFNGLTANGENT3BEXTPROC epoxy_glTangent3bEXT;
    PFNGLTANGENT3BVEXTPROC epoxy_glTangent3bvEXT;
    PFNGLTANGENT3DEXTPROC epoxy_glTangent3dEXT;
    PFNGLTANGENT3DVEXTPROC epoxy_glTangent3dvEXT;
    PFNGLTANGENT3FEXTPROC epoxy_glTangent3fEXT;
    PFNGLTANGENT3FVEXTPROC epoxy_glTangent3fvEXT;
    PFNGLTANGENT3IEXTPROC epoxy_glTangent3iEXT;
    PFNGLTANGENT3IVEXTPROC epoxy_glTangent3ivEXT;
    PFNGLTANGENT3SEXTPROC epoxy_glTangent3sEXT;
    PFNGLTANGENT3SVEXTPROC epoxy_glTangent3svEXT;
    PFNGLTANGENTPOINTEREXTPROC epoxy_glTangentPointerEXT;
    PFNGLTBUFFERMASK3DFXPROC epoxy_glTbufferMask3DFX;
    PFNGLTESSELLATIONFACTORAMDPROC epoxy_glTessellationFactorAMD;
    PFNGLTESSELLATIONMODEAMDPROC epoxy_glTessellationModeAMD;
    PFNGLTESTFENCEAPPLEPROC epoxy_glTestFenceAPPLE;
    PFNGLTESTFENCENVPROC epoxy_glTestFenceNV;
    PFNGLTESTOBJECTAPPLEPROC epoxy_glTestObjectAPPLE;
    PFNGLTEXATTACHMEMORYNVPROC epoxy_glTexAttachMemoryNV;
    PFNGLTEXBUFFERPROC epoxy_glTexBuffer;
    PFNGLTEXBUFFERARBPROC epoxy_glTexBufferARB;
    PFNGLTEXBUFFEREXTPROC epoxy_glTexBufferEXT;
    PFNGLTEXBUFFEROESPROC epoxy_glTexBufferOES;
    PFNGLTEXBUFFERRANGEPROC epoxy_glTexBufferRange;
    PFNGLTEXBUFFERRANGEEXTPROC epoxy_glTexBufferRangeEXT;
    PFNGLTEXBUFFERRANGEOESPROC epoxy_glTexBufferRangeOES;
    PFNGLTEXBUMPPARAMETERFVATIPROC epoxy_glTexBumpParameterfvATI;
    PFNGLTEXBUMPPARAMETERIVATIPROC epoxy_glTexBumpParameterivATI;
    PFNGLTEXCOORD1BOESPROC epoxy_glTexCoord1bOES;
    PFNGLTEXCOORD1BVOESPROC epoxy_glTexCoord1bvOES;
    PFNGLTEXCOORD1DPROC epoxy_glTexCoord1d;
    PFNGLTEXCOORD1DVPROC epoxy_glTexCoord1dv;
    PFNGLTEXCOORD1FPROC epoxy_glTexCoord1f;
    PFNGLTEXCOORD1FVPROC epoxy_glTexCoord1fv;
    PFNGLTEXCOORD1HNVPROC epoxy_glTexCoord1hNV;
    PFNGLTEXCOORD1HVNVPROC epoxy_glTexCoord1hvNV;
    PFNGLTEXCOORD1IPROC epoxy_glTexCoord1i;
    PFNGLTEXCOORD1IVPROC epoxy_glTexCoord1iv;
    PFNGLTEXCOORD1SPROC epoxy_glTexCoord1s;
    PFNGLTEXCOORD1SVPROC epoxy_glTexCoord1sv;
    PFNGLTEXCOORD1XOESPROC epoxy_glTexCoord1xOES;
    PFNGLTEXCOORD1XVOESPROC epoxy_glTexCoord1xvOES;
    PFNGLTEXCOORD2BOESPROC epoxy_glTexCoord2bOES;
    PFNGLTEXCOORD2BVOESPROC epoxy_glTexCoord2bvOES;
    PFNGLTEXCOORD2DPROC epoxy_glTexCoord2d;
    PFNGLTEXCOORD2DVPROC epoxy_glTexCoord2dv;
    PFNGLTEXCOORD2FPROC epoxy_glTexCoord2f;
    PFNGLTEXCOORD2FCOLOR3FVERTEX3FSUNPROC epoxy_glTexCoord2fColor3fVertex3fSUN;
    PFNGLTEXCOORD2FCOLOR3FVERTEX3FVSUNPROC epoxy_glTexCoord2fColor3fVertex3fvSUN;
    PFNGLTEXCOORD2FCOLOR4FNORMAL3FVERTEX3FSUNPROC epoxy_glTexCoord2fColor4fNormal3fVertex3fSUN;
    PFNGLTEXCOORD2FCOLOR4FNORMAL3FVERTEX3FVSUNPROC epoxy_glTexCoord2fColor4fNormal3fVertex3fvSUN;
    PFNGLTEXCOORD2FCOLOR4UBVERTEX3FSUNPROC epoxy_glTexCoord2fColor4ubVertex3fSUN;
    PFNGLTEXCOORD2FCOLOR4UBVERTEX3FVSUNPROC epoxy_glTexCoord2fColor4ubVertex3fvSUN;
    PFNGLTEXCOORD2FNORMAL3FVERTEX3FSUNPROC epoxy_glTexCoord2fNormal3fVertex3fSUN;
    PFNGLTEXCOORD2FNORMAL3FVERTEX3FVSUNPROC epoxy_glTexCoord2fNormal3fVertex3fvSUN;
    PFNGLTEXCOORD2FVERTEX3FSUNPROC epoxy_glTexCoord2fVertex3fSUN;
    PFNGLTEXCOORD2FVERTEX3FVSUNPROC epoxy_glTexCoord2fVertex3fvSUN;
    PFNGLTEXCOORD2FVPROC epoxy_glTexCoord2fv;
    PFNGLTEXCOORD2HNVPROC epoxy_glTexCoord2hNV;
    PFNGLTEXCOORD2HVNVPROC epoxy_glTexCoord2hvNV;
    PFNGLTEXCOORD2IPROC epoxy_glTexCoord2i;
    PFNGLTEXCOORD2IVPROC epoxy_glTexCoord2iv;
    PFNGLTEXCOORD2SPROC epoxy_glTexCoord2s;
    PFNGLTEXCOORD2SVPROC epoxy_glTexCoord2sv;
    PFNGLTEXCOORD2XOESPROC epoxy_glTexCoord2xOES;
    PFNGLTEXCOORD2XVOESPROC epoxy_glTexCoord2xvOES;
    PFNGLTEXCOORD3BOESPROC epoxy_glTexCoord3bOES;
    PFNGLTEXCOORD3BVOESPROC epoxy_glTexCoord3bvOES;
    PFNGLTEXCOORD3DPROC epoxy_glTexCoord3d;
    PFNGLTEXCOORD3DVPROC epoxy_glTexCoord3dv;
    PFNGLTEXCOORD3FPROC epoxy_glTexCoord3f;
    PFNGLTEXCOORD3FVPROC epoxy_glTexCoord3fv;
    PFNGLTEXCOORD3HNVPROC epoxy_glTexCoord3hNV;
    PFNGLTEXCOORD3HVNVPROC epoxy_glTexCoord3hvNV;
    PFNGLTEXCOORD3IPROC epoxy_glTexCoord3i;
    PFNGLTEXCOORD3IVPROC epoxy_glTexCoord3iv;
    PFNGLTEXCOORD3SPROC epoxy_glTexCoord3s;
    PFNGLTEXCOORD3SVPROC epoxy_glTexCoord3sv;
    PFNGLTEXCOORD3XOESPROC epoxy_glTexCoord3xOES;
    PFNGLTEXCOORD3XVOESPROC epoxy_glTexCoord3xvOES;
    PFNGLTEXCOORD4BOESPROC epoxy_glTexCoord4bOES;
    PFNGLTEXCOORD4BVOESPROC epoxy_glTexCoord4bvOES;
    PFNGLTEXCOORD4DPROC epoxy_glTexCoord4d;
    PFNGLTEXCOORD4DVPROC epoxy_glTexCoord4dv;
    PFNGLTEXCOORD4FPROC epoxy_glTexCoord4f;
    PFNGLTEXCOORD4FCOLOR4FNORMAL3FVERTEX4FSUNPROC epoxy_glTexCoord4fColor4fNormal3fVertex4fSUN;
    PFNGLTEXCOORD4FCOLOR4FNORMAL3FVERTEX4FVSUNPROC epoxy_glTexCoord4fColor4fNormal3fVertex4fvSUN;
    PFNGLTEXCOORD4FVERTEX4FSUNPROC epoxy_glTexCoord4fVertex4fSUN;
    PFNGLTEXCOORD4FVERTEX4FVSUNPROC epoxy_glTexCoord4fVertex4fvSUN;
    PFNGLTEXCOORD4FVPROC epoxy_glTexCoord4fv;
    PFNGLTEXCOORD4HNVPROC epoxy_glTexCoord4hNV;
    PFNGLTEXCOORD4HVNVPROC epoxy_glTexCoord4hvNV;
    PFNGLTEXCOORD4IPROC epoxy_glTexCoord4i;
    PFNGLTEXCOORD4IVPROC epoxy_glTexCoord4iv;
    PFNGLTEXCOORD4SPROC epoxy_glTexCoord4s;
    PFNGLTEXCOORD4SVPROC epoxy_glTexCoord4sv;
    PFNGLTEXCOORD4XOESPROC epoxy_glTexCoord4xOES;
    PFNGLTEXCOORD4XVOESPROC epoxy_glTexCoord4xvOES;
    PFNGLTEXCOORDFORMATNVPROC epoxy_glTexCoordFormatNV;
    PFNGLTEXCOORDP1UIPROC epoxy_glTexCoordP1ui;
    PFNGLTEXCOORDP1UIVPROC epoxy_glTexCoordP1uiv;
    PFNGLTEXCOORDP2UIPROC epoxy_glTexCoordP2ui;
    PFNGLTEXCOORDP2UIVPROC epoxy_glTexCoordP2uiv;
    PFNGLTEXCOORDP3UIPROC epoxy_glTexCoordP3ui;
    PFNGLTEXCOORDP3UIVPROC epoxy_glTexCoordP3uiv;
    PFNGLTEXCOORDP4UIPROC epoxy_glTexCoordP4ui;
    PFNGLTEXCOORDP4UIVPROC epoxy_glTexCoordP4uiv;
    PFNGLTEXCOORDPOINTERPROC epoxy_glTexCoordPointer;
    PFNGLTEXCOORDPOINTEREXTPROC epoxy_glTexCoordPointerEXT;
    PFNGLTEXCOORDPOINTERLISTIBMPROC epoxy_glTexCoordPointerListIBM;
    PFNGLTEXCOORDPOINTERVINTELPROC epoxy_glTexCoordPointervINTEL;
    PFNGLTEXENVFPROC epoxy_glTexEnvf;
    PFNGLTEXENVFVPROC epoxy_glTexEnvfv;
    PFNGLTEXENVIPROC epoxy_glTexEnvi;
    PFNGLTEXENVIVPROC epoxy_glTexEnviv;
    PFNGLTEXENVXPROC epoxy_glTexEnvx;
    PFNGLTEXENVXOESPROC epoxy_glTexEnvxOES;
    PFNGLTEXENVXVPROC epoxy_glTexEnvxv;
    PFNGLTEXENVXVOESPROC epoxy_glTexEnvxvOES;
    PFNGLTEXFILTERFUNCSGISPROC epoxy_glTexFilterFuncSGIS;
    PFNGLTEXGENDPROC epoxy_glTexGend;
    PFNGLTEXGENDVPROC epoxy_glTexGendv;
    PFNGLTEXGENFPROC epoxy_glTexGenf;
    PFNGLTEXGENFOESPROC epoxy_glTexGenfOES;
    PFNGLTEXGENFVPROC epoxy_glTexGenfv;
    PFNGLTEXGENFVOESPROC epoxy_glTexGenfvOES;
    PFNGLTEXGENIPROC epoxy_glTexGeni;
    PFNGLTEXGENIOESPROC epoxy_glTexGeniOES;
    PFNGLTEXGENIVPROC epoxy_glTexGeniv;
    PFNGLTEXGENIVOESPROC epoxy_glTexGenivOES;
    PFNGLTEXGENXOESPROC epoxy_glTexGenxOES;
    PFNGLTEXGENXVOESPROC epoxy_glTexGenxvOES;
    PFNGLTEXIMAGE1DPROC epoxy_glTexImage1D;
    PFNGLTEXIMAGE2DPROC epoxy_glTexImage2D;
    PFNGLTEXIMAGE2DMULTISAMPLEPROC epoxy_glTexImage2DMultisample;
    PFNGLTEXIMAGE2DMULTISAMPLECOVERAGENVPROC epoxy_glTexImage2DMultisampleCoverageNV;
    PFNGLTEXIMAGE3DPROC epoxy_glTexImage3D;
    PFNGLTEXIMAGE3DEXTPROC epoxy_glTexImage3DEXT;
    PFNGLTEXIMAGE3DMULTISAMPLEPROC epoxy_glTexImage3DMultisample;
    PFNGLTEXIMAGE3DMULTISAMPLECOVERAGENVPROC epoxy_glTexImage3DMultisampleCoverageNV;
    PFNGLTEXIMAGE3DOESPROC epoxy_glTexImage3DOES;
    PFNGLTEXIMAGE4DSGISPROC epoxy_glTexImage4DSGIS;
    PFNGLTEXPAGECOMMITMENTARBPROC epoxy_glTexPageCommitmentARB;
    PFNGLTEXPAGECOMMITMENTEXTPROC epoxy_glTexPageCommitmentEXT;
    PFNGLTEXPARAMETERIIVPROC epoxy_glTexParameterIiv;
    PFNGLTEXPARAMETERIIVEXTPROC epoxy_glTexParameterIivEXT;
    PFNGLTEXPARAMETERIIVOESPROC epoxy_glTexParameterIivOES;
    PFNGLTEXPARAMETERIUIVPROC epoxy_glTexParameterIuiv;
    PFNGLTEXPARAMETERIUIVEXTPROC epoxy_glTexParameterIuivEXT;
    PFNGLTEXPARAMETERIUIVOESPROC epoxy_glTexParameterIuivOES;
    PFNGLTEXPARAMETERFPROC epoxy_glTexParameterf;
    PFNGLTEXPARAMETERFVPROC epoxy_glTexParameterfv;
    PFNGLTEXPARAMETERIPROC epoxy_glTexParameteri;
    PFNGLTEXPARAMETERIVPROC epoxy_glTexParameteriv;
    PFNGLTEXPARAMETERXPROC epoxy_glTexParameterx;
    PFNGLTEXPARAMETERXOESPROC epoxy_glTexParameterxOES;
    PFNGLTEXPARAMETERXVPROC epoxy_glTexParameterxv;
    PFNGLTEXPARAMETERXVOESPROC epoxy_glTexParameterxvOES;
    PFNGLTEXRENDERBUFFERNVPROC epoxy_glTexRenderbufferNV;
    PFNGLTEXSTORAGE1DPROC epoxy_glTexStorage1D;
    PFNGLTEXSTORAGE1DEXTPROC epoxy_glTexStorage1DEXT;
    PFNGLTEXSTORAGE2DPROC epoxy_glTexStorage2D;
    PFNGLTEXSTORAGE2DEXTPROC epoxy_glTexStorage2DEXT;
    PFNGLTEXSTORAGE2DMULTISAMPLEPROC epoxy_glTexStorage2DMultisample;
    PFNGLTEXSTORAGE3DPROC epoxy_glTexStorage3D;
    PFNGLTEXSTORAGE3DEXTPROC epoxy_glTexStorage3DEXT;
    PFNGLTEXSTORAGE3DMULTISAMPLEPROC epoxy_glTexStorage3DMultisample;
    PFNGLTEXSTORAGE3DMULTISAMPLEOESPROC epoxy_glTexStorage3DMultisampleOES;
    PFNGLTEXSTORAGEMEM1DEXTPROC epoxy_glTexStorageMem1DEXT;
    PFNGLTEXSTORAGEMEM2DEXTPROC epoxy_glTexStorageMem2DEXT;
    PFNGLTEXSTORAGEMEM2DMULTISAMPLEEXTPROC epoxy_glTexStorageMem2DMultisampleEXT;
    PFNGLTEXSTORAGEMEM3DEXTPROC epoxy_glTexStorageMem3DEXT;
    PFNGLTEXSTORAGEMEM3DMULTISAMPLEEXTPROC epoxy_glTexStorageMem3DMultisampleEXT;
    PFNGLTEXSTORAGESPARSEAMDPROC epoxy_glTexStorageSparseAMD;
    PFNGLTEXSUBIMAGE1DPROC epoxy_glTexSubImage1D;
    PFNGLTEXSUBIMAGE1DEXTPROC epoxy_glTexSubImage1DEXT;
    PFNGLTEXSUBIMAGE2DPROC epoxy_glTexSubImage2D;
    PFNGLTEXSUBIMAGE2DEXTPROC epoxy_glTexSubImage2DEXT;
    PFNGLTEXSUBIMAGE3DPROC epoxy_glTexSubImage3D;
    PFNGLTEXSUBIMAGE3DEXTPROC epoxy_glTexSubImage3DEXT;
    PFNGLTEXSUBIMAGE3DOESPROC epoxy_glTexSubImage3DOES;
    PFNGLTEXSUBIMAGE4DSGISPROC epoxy_glTexSubImage4DSGIS;
    PFNGLTEXTUREATTACHMEMORYNVPROC epoxy_glTextureAttachMemoryNV;
    PFNGLTEXTUREBARRIERPROC epoxy_glTextureBarrier;
    PFNGLTEXTUREBARRIERNVPROC epoxy_glTextureBarrierNV;
    PFNGLTEXTUREBUFFERPROC epoxy_glTextureBuffer;
    PFNGLTEXTUREBUFFEREXTPROC epoxy_glTextureBufferEXT;
    PFNGLTEXTUREBUFFERRANGEPROC epoxy_glTextureBufferRange;
    PFNGLTEXTUREBUFFERRANGEEXTPROC epoxy_glTextureBufferRangeEXT;
    PFNGLTEXTURECOLORMASKSGISPROC epoxy_glTextureColorMaskSGIS;
    PFNGLTEXTUREFOVEATIONPARAMETERSQCOMPROC epoxy_glTextureFoveationParametersQCOM;
    PFNGLTEXTUREIMAGE1DEXTPROC epoxy_glTextureImage1DEXT;
    PFNGLTEXTUREIMAGE2DEXTPROC epoxy_glTextureImage2DEXT;
    PFNGLTEXTUREIMAGE2DMULTISAMPLECOVERAGENVPROC epoxy_glTextureImage2DMultisampleCoverageNV;
    PFNGLTEXTUREIMAGE2DMULTISAMPLENVPROC epoxy_glTextureImage2DMultisampleNV;
    PFNGLTEXTUREIMAGE3DEXTPROC epoxy_glTextureImage3DEXT;
    PFNGLTEXTUREIMAGE3DMULTISAMPLECOVERAGENVPROC epoxy_glTextureImage3DMultisampleCoverageNV;
    PFNGLTEXTUREIMAGE3DMULTISAMPLENVPROC epoxy_glTextureImage3DMultisampleNV;
    PFNGLTEXTURELIGHTEXTPROC epoxy_glTextureLightEXT;
    PFNGLTEXTUREMATERIALEXTPROC epoxy_glTextureMaterialEXT;
    PFNGLTEXTURENORMALEXTPROC epoxy_glTextureNormalEXT;
    PFNGLTEXTUREPAGECOMMITMENTEXTPROC epoxy_glTexturePageCommitmentEXT;
    PFNGLTEXTUREPARAMETERIIVPROC epoxy_glTextureParameterIiv;
    PFNGLTEXTUREPARAMETERIIVEXTPROC epoxy_glTextureParameterIivEXT;
    PFNGLTEXTUREPARAMETERIUIVPROC epoxy_glTextureParameterIuiv;
    PFNGLTEXTUREPARAMETERIUIVEXTPROC epoxy_glTextureParameterIuivEXT;
    PFNGLTEXTUREPARAMETERFPROC epoxy_glTextureParameterf;
    PFNGLTEXTUREPARAMETERFEXTPROC epoxy_glTextureParameterfEXT;
    PFNGLTEXTUREPARAMETERFVPROC epoxy_glTextureParameterfv;
    PFNGLTEXTUREPARAMETERFVEXTPROC epoxy_glTextureParameterfvEXT;
    PFNGLTEXTUREPARAMETERIPROC epoxy_glTextureParameteri;
    PFNGLTEXTUREPARAMETERIEXTPROC epoxy_glTextureParameteriEXT;
    PFNGLTEXTUREPARAMETERIVPROC epoxy_glTextureParameteriv;
    PFNGLTEXTUREPARAMETERIVEXTPROC epoxy_glTextureParameterivEXT;
    PFNGLTEXTURERANGEAPPLEPROC epoxy_glTextureRangeAPPLE;
    PFNGLTEXTURERENDERBUFFEREXTPROC epoxy_glTextureRenderbufferEXT;
    PFNGLTEXTURESTORAGE1DPROC epoxy_glTextureStorage1D;
    PFNGLTEXTURESTORAGE1DEXTPROC epoxy_glTextureStorage1DEXT;
    PFNGLTEXTURESTORAGE2DPROC epoxy_glTextureStorage2D;
    PFNGLTEXTURESTORAGE2DEXTPROC epoxy_glTextureStorage2DEXT;
    PFNGLTEXTURESTORAGE2DMULTISAMPLEPROC epoxy_glTextureStorage2DMultisample;
    PFNGLTEXTURESTORAGE2DMULTISAMPLEEXTPROC epoxy_glTextureStorage2DMultisampleEXT;
    PFNGLTEXTURESTORAGE3DPROC epoxy_glTextureStorage3D;
    PFNGLTEXTURESTORAGE3DEXTPROC epoxy_glTextureStorage3DEXT;
    PFNGLTEXTURESTORAGE3DMULTISAMPLEPROC epoxy_glTextureStorage3DMultisample;
    PFNGLTEXTURESTORAGE3DMULTISAMPLEEXTPROC epoxy_glTextureStorage3DMultisampleEXT;
    PFNGLTEXTURESTORAGEMEM1DEXTPROC epoxy_glTextureStorageMem1DEXT;
    PFNGLTEXTURESTORAGEMEM2DEXTPROC epoxy_glTextureStorageMem2DEXT;
    PFNGLTEXTURESTORAGEMEM2DMULTISAMPLEEXTPROC epoxy_glTextureStorageMem2DMultisampleEXT;
    PFNGLTEXTURESTORAGEMEM3DEXTPROC epoxy_glTextureStorageMem3DEXT;
    PFNGLTEXTURESTORAGEMEM3DMULTISAMPLEEXTPROC epoxy_glTextureStorageMem3DMultisampleEXT;
    PFNGLTEXTURESTORAGESPARSEAMDPROC epoxy_glTextureStorageSparseAMD;
    PFNGLTEXTURESUBIMAGE1DPROC epoxy_glTextureSubImage1D;
    PFNGLTEXTURESUBIMAGE1DEXTPROC epoxy_glTextureSubImage1DEXT;
    PFNGLTEXTURESUBIMAGE2DPROC epoxy_glTextureSubImage2D;
    PFNGLTEXTURESUBIMAGE2DEXTPROC epoxy_glTextureSubImage2DEXT;
    PFNGLTEXTURESUBIMAGE3DPROC epoxy_glTextureSubImage3D;
    PFNGLTEXTURESUBIMAGE3DEXTPROC epoxy_glTextureSubImage3DEXT;
    PFNGLTEXTUREVIEWPROC epoxy_glTextureView;
    PFNGLTEXTUREVIEWEXTPROC epoxy_glTextureViewEXT;
    PFNGLTEXTUREVIEWOESPROC epoxy_glTextureViewOES;
    PFNGLTRACKMATRIXNVPROC epoxy_glTrackMatrixNV;
    PFNGLTRANSFORMFEEDBACKATTRIBSNVPROC epoxy_glTransformFeedbackAttribsNV;
    PFNGLTRANSFORMFEEDBACKBUFFERBASEPROC epoxy_glTransformFeedbackBufferBase;
    PFNGLTRANSFORMFEEDBACKBUFFERRANGEPROC epoxy_glTransformFeedbackBufferRange;
    PFNGLTRANSFORMFEEDBACKSTREAMATTRIBSNVPROC epoxy_glTransformFeedbackStreamAttribsNV;
    PFNGLTRANSFORMFEEDBACKVARYINGSPROC epoxy_glTransformFeedbackVaryings;
    PFNGLTRANSFORMFEEDBACKVARYINGSEXTPROC epoxy_glTransformFeedbackVaryingsEXT;
    PFNGLTRANSFORMFEEDBACKVARYINGSNVPROC epoxy_glTransformFeedbackVaryingsNV;
    PFNGLTRANSFORMPATHNVPROC epoxy_glTransformPathNV;
    PFNGLTRANSLATEDPROC epoxy_glTranslated;
    PFNGLTRANSLATEFPROC epoxy_glTranslatef;
    PFNGLTRANSLATEXPROC epoxy_glTranslatex;
    PFNGLTRANSLATEXOESPROC epoxy_glTranslatexOES;
    PFNGLUNIFORM1DPROC epoxy_glUniform1d;
    PFNGLUNIFORM1DVPROC epoxy_glUniform1dv;
    PFNGLUNIFORM1FPROC epoxy_glUniform1f;
    PFNGLUNIFORM1FARBPROC epoxy_glUniform1fARB;
    PFNGLUNIFORM1FVPROC epoxy_glUniform1fv;
    PFNGLUNIFORM1FVARBPROC epoxy_glUniform1fvARB;
    PFNGLUNIFORM1IPROC epoxy_glUniform1i;
    PFNGLUNIFORM1I64ARBPROC epoxy_glUniform1i64ARB;
    PFNGLUNIFORM1I64NVPROC epoxy_glUniform1i64NV;
    PFNGLUNIFORM1I64VARBPROC epoxy_glUniform1i64vARB;
    PFNGLUNIFORM1I64VNVPROC epoxy_glUniform1i64vNV;
    PFNGLUNIFORM1IARBPROC epoxy_glUniform1iARB;
    PFNGLUNIFORM1IVPROC epoxy_glUniform1iv;
    PFNGLUNIFORM1IVARBPROC epoxy_glUniform1ivARB;
    PFNGLUNIFORM1UIPROC epoxy_glUniform1ui;
    PFNGLUNIFORM1UI64ARBPROC epoxy_glUniform1ui64ARB;
    PFNGLUNIFORM1UI64NVPROC epoxy_glUniform1ui64NV;
    PFNGLUNIFORM1UI64VARBPROC epoxy_glUniform1ui64vARB;
    PFNGLUNIFORM1UI64VNVPROC epoxy_glUniform1ui64vNV;
    PFNGLUNIFORM1UIEXTPROC epoxy_glUniform1uiEXT;
    PFNGLUNIFORM1UIVPROC epoxy_glUniform1uiv;
    PFNGLUNIFORM1UIVEXTPROC epoxy_glUniform1uivEXT;
    PFNGLUNIFORM2DPROC epoxy_glUniform2d;
    PFNGLUNIFORM2DVPROC epoxy_glUniform2dv;
    PFNGLUNIFORM2FPROC epoxy_glUniform2f;
    PFNGLUNIFORM2FARBPROC epoxy_glUniform2fARB;
    PFNGLUNIFORM2FVPROC epoxy_glUniform2fv;
    PFNGLUNIFORM2FVARBPROC epoxy_glUniform2fvARB;
    PFNGLUNIFORM2IPROC epoxy_glUniform2i;
    PFNGLUNIFORM2I64ARBPROC epoxy_glUniform2i64ARB;
    PFNGLUNIFORM2I64NVPROC epoxy_glUniform2i64NV;
    PFNGLUNIFORM2I64VARBPROC epoxy_glUniform2i64vARB;
    PFNGLUNIFORM2I64VNVPROC epoxy_glUniform2i64vNV;
    PFNGLUNIFORM2IARBPROC epoxy_glUniform2iARB;
    PFNGLUNIFORM2IVPROC epoxy_glUniform2iv;
    PFNGLUNIFORM2IVARBPROC epoxy_glUniform2ivARB;
    PFNGLUNIFORM2UIPROC epoxy_glUniform2ui;
    PFNGLUNIFORM2UI64ARBPROC epoxy_glUniform2ui64ARB;
    PFNGLUNIFORM2UI64NVPROC epoxy_glUniform2ui64NV;
    PFNGLUNIFORM2UI64VARBPROC epoxy_glUniform2ui64vARB;
    PFNGLUNIFORM2UI64VNVPROC epoxy_glUniform2ui64vNV;
    PFNGLUNIFORM2UIEXTPROC epoxy_glUniform2uiEXT;
    PFNGLUNIFORM2UIVPROC epoxy_glUniform2uiv;
    PFNGLUNIFORM2UIVEXTPROC epoxy_glUniform2uivEXT;
    PFNGLUNIFORM3DPROC epoxy_glUniform3d;
    PFNGLUNIFORM3DVPROC epoxy_glUniform3dv;
    PFNGLUNIFORM3FPROC epoxy_glUniform3f;
    PFNGLUNIFORM3FARBPROC epoxy_glUniform3fARB;
    PFNGLUNIFORM3FVPROC epoxy_glUniform3fv;
    PFNGLUNIFORM3FVARBPROC epoxy_glUniform3fvARB;
    PFNGLUNIFORM3IPROC epoxy_glUniform3i;
    PFNGLUNIFORM3I64ARBPROC epoxy_glUniform3i64ARB;
    PFNGLUNIFORM3I64NVPROC epoxy_glUniform3i64NV;
    PFNGLUNIFORM3I64VARBPROC epoxy_glUniform3i64vARB;
    PFNGLUNIFORM3I64VNVPROC epoxy_glUniform3i64vNV;
    PFNGLUNIFORM3IARBPROC epoxy_glUniform3iARB;
    PFNGLUNIFORM3IVPROC epoxy_glUniform3iv;
    PFNGLUNIFORM3IVARBPROC epoxy_glUniform3ivARB;
    PFNGLUNIFORM3UIPROC epoxy_glUniform3ui;
    PFNGLUNIFORM3UI64ARBPROC epoxy_glUniform3ui64ARB;
    PFNGLUNIFORM3UI64NVPROC epoxy_glUniform3ui64NV;
    PFNGLUNIFORM3UI64VARBPROC epoxy_glUniform3ui64vARB;
    PFNGLUNIFORM3UI64VNVPROC epoxy_glUniform3ui64vNV;
    PFNGLUNIFORM3UIEXTPROC epoxy_glUniform3uiEXT;
    PFNGLUNIFORM3UIVPROC epoxy_glUniform3uiv;
    PFNGLUNIFORM3UIVEXTPROC epoxy_glUniform3uivEXT;
    PFNGLUNIFORM4DPROC epoxy_glUniform4d;
    PFNGLUNIFORM4DVPROC epoxy_glUniform4dv;
    PFNGLUNIFORM4FPROC epoxy_glUniform4f;
    PFNGLUNIFORM4FARBPROC epoxy_glUniform4fARB;
    PFNGLUNIFORM4FVPROC epoxy_glUniform4fv;
    PFNGLUNIFORM4FVARBPROC epoxy_glUniform4fvARB;
    PFNGLUNIFORM4IPROC epoxy_glUniform4i;
    PFNGLUNIFORM4I64ARBPROC epoxy_glUniform4i64ARB;
    PFNGLUNIFORM4I64NVPROC epoxy_glUniform4i64NV;
    PFNGLUNIFORM4I64VARBPROC epoxy_glUniform4i64vARB;
    PFNGLUNIFORM4I64VNVPROC epoxy_glUniform4i64vNV;
    PFNGLUNIFORM4IARBPROC epoxy_glUniform4iARB;
    PFNGLUNIFORM4IVPROC epoxy_glUniform4iv;
    PFNGLUNIFORM4IVARBPROC epoxy_glUniform4ivARB;
    PFNGLUNIFORM4UIPROC epoxy_glUniform4ui;
    PFNGLUNIFORM4UI64ARBPROC epoxy_glUniform4ui64ARB;
    PFNGLUNIFORM4UI64NVPROC epoxy_glUniform4ui64NV;
    PFNGLUNIFORM4UI64VARBPROC epoxy_glUniform4ui64vARB;
    PFNGLUNIFORM4UI64VNVPROC epoxy_glUniform4ui64vNV;
    PFNGLUNIFORM4UIEXTPROC epoxy_glUniform4uiEXT;
    PFNGLUNIFORM4UIVPROC epoxy_glUniform4uiv;
    PFNGLUNIFORM4UIVEXTPROC epoxy_glUniform4uivEXT;
    PFNGLUNIFORMBLOCKBINDINGPROC epoxy_glUniformBlockBinding;
    PFNGLUNIFORMBUFFEREXTPROC epoxy_glUniformBufferEXT;
    PFNGLUNIFORMHANDLEUI64ARBPROC epoxy_glUniformHandleui64ARB;
    PFNGLUNIFORMHANDLEUI64IMGPROC epoxy_glUniformHandleui64IMG;
    PFNGLUNIFORMHANDLEUI64NVPROC epoxy_glUniformHandleui64NV;
    PFNGLUNIFORMHANDLEUI64VARBPROC epoxy_glUniformHandleui64vARB;
    PFNGLUNIFORMHANDLEUI64VIMGPROC epoxy_glUniformHandleui64vIMG;
    PFNGLUNIFORMHANDLEUI64VNVPROC epoxy_glUniformHandleui64vNV;
    PFNGLUNIFORMMATRIX2DVPROC epoxy_glUniformMatrix2dv;
    PFNGLUNIFORMMATRIX2FVPROC epoxy_glUniformMatrix2fv;
    PFNGLUNIFORMMATRIX2FVARBPROC epoxy_glUniformMatrix2fvARB;
    PFNGLUNIFORMMATRIX2X3DVPROC epoxy_glUniformMatrix2x3dv;
    PFNGLUNIFORMMATRIX2X3FVPROC epoxy_glUniformMatrix2x3fv;
    PFNGLUNIFORMMATRIX2X3FVNVPROC epoxy_glUniformMatrix2x3fvNV;
    PFNGLUNIFORMMATRIX2X4DVPROC epoxy_glUniformMatrix2x4dv;
    PFNGLUNIFORMMATRIX2X4FVPROC epoxy_glUniformMatrix2x4fv;
    PFNGLUNIFORMMATRIX2X4FVNVPROC epoxy_glUniformMatrix2x4fvNV;
    PFNGLUNIFORMMATRIX3DVPROC epoxy_glUniformMatrix3dv;
    PFNGLUNIFORMMATRIX3FVPROC epoxy_glUniformMatrix3fv;
    PFNGLUNIFORMMATRIX3FVARBPROC epoxy_glUniformMatrix3fvARB;
    PFNGLUNIFORMMATRIX3X2DVPROC epoxy_glUniformMatrix3x2dv;
    PFNGLUNIFORMMATRIX3X2FVPROC epoxy_glUniformMatrix3x2fv;
    PFNGLUNIFORMMATRIX3X2FVNVPROC epoxy_glUniformMatrix3x2fvNV;
    PFNGLUNIFORMMATRIX3X4DVPROC epoxy_glUniformMatrix3x4dv;
    PFNGLUNIFORMMATRIX3X4FVPROC epoxy_glUniformMatrix3x4fv;
    PFNGLUNIFORMMATRIX3X4FVNVPROC epoxy_glUniformMatrix3x4fvNV;
    PFNGLUNIFORMMATRIX4DVPROC epoxy_glUniformMatrix4dv;
    PFNGLUNIFORMMATRIX4FVPROC epoxy_glUniformMatrix4fv;
    PFNGLUNIFORMMATRIX4FVARBPROC epoxy_glUniformMatrix4fvARB;
    PFNGLUNIFORMMATRIX4X2DVPROC epoxy_glUniformMatrix4x2dv;
    PFNGLUNIFORMMATRIX4X2FVPROC epoxy_glUniformMatrix4x2fv;
    PFNGLUNIFORMMATRIX4X2FVNVPROC epoxy_glUniformMatrix4x2fvNV;
    PFNGLUNIFORMMATRIX4X3DVPROC epoxy_glUniformMatrix4x3dv;
    PFNGLUNIFORMMATRIX4X3FVPROC epoxy_glUniformMatrix4x3fv;
    PFNGLUNIFORMMATRIX4X3FVNVPROC epoxy_glUniformMatrix4x3fvNV;
    PFNGLUNIFORMSUBROUTINESUIVPROC epoxy_glUniformSubroutinesuiv;
    PFNGLUNIFORMUI64NVPROC epoxy_glUniformui64NV;
    PFNGLUNIFORMUI64VNVPROC epoxy_glUniformui64vNV;
    PFNGLUNLOCKARRAYSEXTPROC epoxy_glUnlockArraysEXT;
    PFNGLUNMAPBUFFERPROC epoxy_glUnmapBuffer;
    PFNGLUNMAPBUFFERARBPROC epoxy_glUnmapBufferARB;
    PFNGLUNMAPBUFFEROESPROC epoxy_glUnmapBufferOES;
    PFNGLUNMAPNAMEDBUFFERPROC epoxy_glUnmapNamedBuffer;
    PFNGLUNMAPNAMEDBUFFEREXTPROC epoxy_glUnmapNamedBufferEXT;
    PFNGLUNMAPOBJECTBUFFERATIPROC epoxy_glUnmapObjectBufferATI;
    PFNGLUNMAPTEXTURE2DINTELPROC epoxy_glUnmapTexture2DINTEL;
    PFNGLUPDATEOBJECTBUFFERATIPROC epoxy_glUpdateObjectBufferATI;
    PFNGLUPLOADGPUMASKNVXPROC epoxy_glUploadGpuMaskNVX;
    PFNGLUSEPROGRAMPROC epoxy_glUseProgram;
    PFNGLUSEPROGRAMOBJECTARBPROC epoxy_glUseProgramObjectARB;
    PFNGLUSEPROGRAMSTAGESPROC epoxy_glUseProgramStages;
    PFNGLUSEPROGRAMSTAGESEXTPROC epoxy_glUseProgramStagesEXT;
    PFNGLUSESHADERPROGRAMEXTPROC epoxy_glUseShaderProgramEXT;
    PFNGLVDPAUFININVPROC epoxy_glVDPAUFiniNV;
    PFNGLVDPAUGETSURFACEIVNVPROC epoxy_glVDPAUGetSurfaceivNV;
    PFNGLVDPAUINITNVPROC epoxy_glVDPAUInitNV;
    PFNGLVDPAUISSURFACENVPROC epoxy_glVDPAUIsSurfaceNV;
    PFNGLVDPAUMAPSURFACESNVPROC epoxy_glVDPAUMapSurfacesNV;
    PFNGLVDPAUREGISTEROUTPUTSURFACENVPROC epoxy_glVDPAURegisterOutputSurfaceNV;
    PFNGLVDPAUREGISTERVIDEOSURFACENVPROC epoxy_glVDPAURegisterVideoSurfaceNV;
    PFNGLVDPAUREGISTERVIDEOSURFACEWITHPICTURESTRUCTURENVPROC epoxy_glVDPAURegisterVideoSurfaceWithPictureStructureNV;
    PFNGLVDPAUSURFACEACCESSNVPROC epoxy_glVDPAUSurfaceAccessNV;
    PFNGLVDPAUUNMAPSURFACESNVPROC epoxy_glVDPAUUnmapSurfacesNV;
    PFNGLVDPAUUNREGISTERSURFACENVPROC epoxy_glVDPAUUnregisterSurfaceNV;
    PFNGLVALIDATEPROGRAMPROC epoxy_glValidateProgram;
    PFNGLVALIDATEPROGRAMARBPROC epoxy_glValidateProgramARB;
    PFNGLVALIDATEPROGRAMPIPELINEPROC epoxy_glValidateProgramPipeline;
    PFNGLVALIDATEPROGRAMPIPELINEEXTPROC epoxy_glValidateProgramPipelineEXT;
    PFNGLVARIANTARRAYOBJECTATIPROC epoxy_glVariantArrayObjectATI;
    PFNGLVARIANTPOINTEREXTPROC epoxy_glVariantPointerEXT;
    PFNGLVARIANTBVEXTPROC epoxy_glVariantbvEXT;
    PFNGLVARIANTDVEXTPROC epoxy_glVariantdvEXT;
    PFNGLVARIANTFVEXTPROC epoxy_glVariantfvEXT;
    PFNGLVARIANTIVEXTPROC epoxy_glVariantivEXT;
    PFNGLVARIANTSVEXTPROC epoxy_glVariantsvEXT;
    PFNGLVARIANTUBVEXTPROC epoxy_glVariantubvEXT;
    PFNGLVARIANTUIVEXTPROC epoxy_glVariantuivEXT;
    PFNGLVARIANTUSVEXTPROC epoxy_glVariantusvEXT;
    PFNGLVERTEX2BOESPROC epoxy_glVertex2bOES;
    PFNGLVERTEX2BVOESPROC epoxy_glVertex2bvOES;
    PFNGLVERTEX2DPROC epoxy_glVertex2d;
    PFNGLVERTEX2DVPROC epoxy_glVertex2dv;
    PFNGLVERTEX2FPROC epoxy_glVertex2f;
    PFNGLVERTEX2FVPROC epoxy_glVertex2fv;
    PFNGLVERTEX2HNVPROC epoxy_glVertex2hNV;
    PFNGLVERTEX2HVNVPROC epoxy_glVertex2hvNV;
    PFNGLVERTEX2IPROC epoxy_glVertex2i;
    PFNGLVERTEX2IVPROC epoxy_glVertex2iv;
    PFNGLVERTEX2SPROC epoxy_glVertex2s;
    PFNGLVERTEX2SVPROC epoxy_glVertex2sv;
    PFNGLVERTEX2XOESPROC epoxy_glVertex2xOES;
    PFNGLVERTEX2XVOESPROC epoxy_glVertex2xvOES;
    PFNGLVERTEX3BOESPROC epoxy_glVertex3bOES;
    PFNGLVERTEX3BVOESPROC epoxy_glVertex3bvOES;
    PFNGLVERTEX3DPROC epoxy_glVertex3d;
    PFNGLVERTEX3DVPROC epoxy_glVertex3dv;
    PFNGLVERTEX3FPROC epoxy_glVertex3f;
    PFNGLVERTEX3FVPROC epoxy_glVertex3fv;
    PFNGLVERTEX3HNVPROC epoxy_glVertex3hNV;
    PFNGLVERTEX3HVNVPROC epoxy_glVertex3hvNV;
    PFNGLVERTEX3IPROC epoxy_glVertex3i;
    PFNGLVERTEX3IVPROC epoxy_glVertex3iv;
    PFNGLVERTEX3SPROC epoxy_glVertex3s;
    PFNGLVERTEX3SVPROC epoxy_glVertex3sv;
    PFNGLVERTEX3XOESPROC epoxy_glVertex3xOES;
    PFNGLVERTEX3XVOESPROC epoxy_glVertex3xvOES;
    PFNGLVERTEX4BOESPROC epoxy_glVertex4bOES;
    PFNGLVERTEX4BVOESPROC epoxy_glVertex4bvOES;
    PFNGLVERTEX4DPROC epoxy_glVertex4d;
    PFNGLVERTEX4DVPROC epoxy_glVertex4dv;
    PFNGLVERTEX4FPROC epoxy_glVertex4f;
    PFNGLVERTEX4FVPROC epoxy_glVertex4fv;
    PFNGLVERTEX4HNVPROC epoxy_glVertex4hNV;
    PFNGLVERTEX4HVNVPROC epoxy_glVertex4hvNV;
    PFNGLVERTEX4IPROC epoxy_glVertex4i;
    PFNGLVERTEX4IVPROC epoxy_glVertex4iv;
    PFNGLVERTEX4SPROC epoxy_glVertex4s;
    PFNGLVERTEX4SVPROC epoxy_glVertex4sv;
    PFNGLVERTEX4XOESPROC epoxy_glVertex4xOES;
    PFNGLVERTEX4XVOESPROC epoxy_glVertex4xvOES;
    PFNGLVERTEXARRAYATTRIBBINDINGPROC epoxy_glVertexArrayAttribBinding;
    PFNGLVERTEXARRAYATTRIBFORMATPROC epoxy_glVertexArrayAttribFormat;
    PFNGLVERTEXARRAYATTRIBIFORMATPROC epoxy_glVertexArrayAttribIFormat;
    PFNGLVERTEXARRAYATTRIBLFORMATPROC epoxy_glVertexArrayAttribLFormat;
    PFNGLVERTEXARRAYBINDVERTEXBUFFEREXTPROC epoxy_glVertexArrayBindVertexBufferEXT;
    PFNGLVERTEXARRAYBINDINGDIVISORPROC epoxy_glVertexArrayBindingDivisor;
    PFNGLVERTEXARRAYCOLOROFFSETEXTPROC epoxy_glVertexArrayColorOffsetEXT;
    PFNGLVERTEXARRAYEDGEFLAGOFFSETEXTPROC epoxy_glVertexArrayEdgeFlagOffsetEXT;
    PFNGLVERTEXARRAYELEMENTBUFFERPROC epoxy_glVertexArrayElementBuffer;
    PFNGLVERTEXARRAYFOGCOORDOFFSETEXTPROC epoxy_glVertexArrayFogCoordOffsetEXT;
    PFNGLVERTEXARRAYINDEXOFFSETEXTPROC epoxy_glVertexArrayIndexOffsetEXT;
    PFNGLVERTEXARRAYMULTITEXCOORDOFFSETEXTPROC epoxy_glVertexArrayMultiTexCoordOffsetEXT;
    PFNGLVERTEXARRAYNORMALOFFSETEXTPROC epoxy_glVertexArrayNormalOffsetEXT;
    PFNGLVERTEXARRAYPARAMETERIAPPLEPROC epoxy_glVertexArrayParameteriAPPLE;
    PFNGLVERTEXARRAYRANGEAPPLEPROC epoxy_glVertexArrayRangeAPPLE;
    PFNGLVERTEXARRAYRANGENVPROC epoxy_glVertexArrayRangeNV;
    PFNGLVERTEXARRAYSECONDARYCOLOROFFSETEXTPROC epoxy_glVertexArraySecondaryColorOffsetEXT;
    PFNGLVERTEXARRAYTEXCOORDOFFSETEXTPROC epoxy_glVertexArrayTexCoordOffsetEXT;
    PFNGLVERTEXARRAYVERTEXATTRIBBINDINGEXTPROC epoxy_glVertexArrayVertexAttribBindingEXT;
    PFNGLVERTEXARRAYVERTEXATTRIBDIVISOREXTPROC epoxy_glVertexArrayVertexAttribDivisorEXT;
    PFNGLVERTEXARRAYVERTEXATTRIBFORMATEXTPROC epoxy_glVertexArrayVertexAttribFormatEXT;
    PFNGLVERTEXARRAYVERTEXATTRIBIFORMATEXTPROC epoxy_glVertexArrayVertexAttribIFormatEXT;
    PFNGLVERTEXARRAYVERTEXATTRIBIOFFSETEXTPROC epoxy_glVertexArrayVertexAttribIOffsetEXT;
    PFNGLVERTEXARRAYVERTEXATTRIBLFORMATEXTPROC epoxy_glVertexArrayVertexAttribLFormatEXT;
    PFNGLVERTEXARRAYVERTEXATTRIBLOFFSETEXTPROC epoxy_glVertexArrayVertexAttribLOffsetEXT;
    PFNGLVERTEXARRAYVERTEXATTRIBOFFSETEXTPROC epoxy_glVertexArrayVertexAttribOffsetEXT;
    PFNGLVERTEXARRAYVERTEXBINDINGDIVISOREXTPROC epoxy_glVertexArrayVertexBindingDivisorEXT;
    PFNGLVERTEXARRAYVERTEXBUFFERPROC epoxy_glVertexArrayVertexBuffer;
    PFNGLVERTEXARRAYVERTEXBUFFERSPROC epoxy_glVertexArrayVertexBuffers;
    PFNGLVERTEXARRAYVERTEXOFFSETEXTPROC epoxy_glVertexArrayVertexOffsetEXT;
    PFNGLVERTEXATTRIB1DPROC epoxy_glVertexAttrib1d;
    PFNGLVERTEXATTRIB1DARBPROC epoxy_glVertexAttrib1dARB;
    PFNGLVERTEXATTRIB1DNVPROC epoxy_glVertexAttrib1dNV;
    PFNGLVERTEXATTRIB1DVPROC epoxy_glVertexAttrib1dv;
    PFNGLVERTEXATTRIB1DVARBPROC epoxy_glVertexAttrib1dvARB;
    PFNGLVERTEXATTRIB1DVNVPROC epoxy_glVertexAttrib1dvNV;
    PFNGLVERTEXATTRIB1FPROC epoxy_glVertexAttrib1f;
    PFNGLVERTEXATTRIB1FARBPROC epoxy_glVertexAttrib1fARB;
    PFNGLVERTEXATTRIB1FNVPROC epoxy_glVertexAttrib1fNV;
    PFNGLVERTEXATTRIB1FVPROC epoxy_glVertexAttrib1fv;
    PFNGLVERTEXATTRIB1FVARBPROC epoxy_glVertexAttrib1fvARB;
    PFNGLVERTEXATTRIB1FVNVPROC epoxy_glVertexAttrib1fvNV;
    PFNGLVERTEXATTRIB1HNVPROC epoxy_glVertexAttrib1hNV;
    PFNGLVERTEXATTRIB1HVNVPROC epoxy_glVertexAttrib1hvNV;
    PFNGLVERTEXATTRIB1SPROC epoxy_glVertexAttrib1s;
    PFNGLVERTEXATTRIB1SARBPROC epoxy_glVertexAttrib1sARB;
    PFNGLVERTEXATTRIB1SNVPROC epoxy_glVertexAttrib1sNV;
    PFNGLVERTEXATTRIB1SVPROC epoxy_glVertexAttrib1sv;
    PFNGLVERTEXATTRIB1SVARBPROC epoxy_glVertexAttrib1svARB;
    PFNGLVERTEXATTRIB1SVNVPROC epoxy_glVertexAttrib1svNV;
    PFNGLVERTEXATTRIB2DPROC epoxy_glVertexAttrib2d;
    PFNGLVERTEXATTRIB2DARBPROC epoxy_glVertexAttrib2dARB;
    PFNGLVERTEXATTRIB2DNVPROC epoxy_glVertexAttrib2dNV;
    PFNGLVERTEXATTRIB2DVPROC epoxy_glVertexAttrib2dv;
    PFNGLVERTEXATTRIB2DVARBPROC epoxy_glVertexAttrib2dvARB;
    PFNGLVERTEXATTRIB2DVNVPROC epoxy_glVertexAttrib2dvNV;
    PFNGLVERTEXATTRIB2FPROC epoxy_glVertexAttrib2f;
    PFNGLVERTEXATTRIB2FARBPROC epoxy_glVertexAttrib2fARB;
    PFNGLVERTEXATTRIB2FNVPROC epoxy_glVertexAttrib2fNV;
    PFNGLVERTEXATTRIB2FVPROC epoxy_glVertexAttrib2fv;
    PFNGLVERTEXATTRIB2FVARBPROC epoxy_glVertexAttrib2fvARB;
    PFNGLVERTEXATTRIB2FVNVPROC epoxy_glVertexAttrib2fvNV;
    PFNGLVERTEXATTRIB2HNVPROC epoxy_glVertexAttrib2hNV;
    PFNGLVERTEXATTRIB2HVNVPROC epoxy_glVertexAttrib2hvNV;
    PFNGLVERTEXATTRIB2SPROC epoxy_glVertexAttrib2s;
    PFNGLVERTEXATTRIB2SARBPROC epoxy_glVertexAttrib2sARB;
    PFNGLVERTEXATTRIB2SNVPROC epoxy_glVertexAttrib2sNV;
    PFNGLVERTEXATTRIB2SVPROC epoxy_glVertexAttrib2sv;
    PFNGLVERTEXATTRIB2SVARBPROC epoxy_glVertexAttrib2svARB;
    PFNGLVERTEXATTRIB2SVNVPROC epoxy_glVertexAttrib2svNV;
    PFNGLVERTEXATTRIB3DPROC epoxy_glVertexAttrib3d;
    PFNGLVERTEXATTRIB3DARBPROC epoxy_glVertexAttrib3dARB;
    PFNGLVERTEXATTRIB3DNVPROC epoxy_glVertexAttrib3dNV;
    PFNGLVERTEXATTRIB3DVPROC epoxy_glVertexAttrib3dv;
    PFNGLVERTEXATTRIB3DVARBPROC epoxy_glVertexAttrib3dvARB;
    PFNGLVERTEXATTRIB3DVNVPROC epoxy_glVertexAttrib3dvNV;
    PFNGLVERTEXATTRIB3FPROC epoxy_glVertexAttrib3f;
    PFNGLVERTEXATTRIB3FARBPROC epoxy_glVertexAttrib3fARB;
    PFNGLVERTEXATTRIB3FNVPROC epoxy_glVertexAttrib3fNV;
    PFNGLVERTEXATTRIB3FVPROC epoxy_glVertexAttrib3fv;
    PFNGLVERTEXATTRIB3FVARBPROC epoxy_glVertexAttrib3fvARB;
    PFNGLVERTEXATTRIB3FVNVPROC epoxy_glVertexAttrib3fvNV;
    PFNGLVERTEXATTRIB3HNVPROC epoxy_glVertexAttrib3hNV;
    PFNGLVERTEXATTRIB3HVNVPROC epoxy_glVertexAttrib3hvNV;
    PFNGLVERTEXATTRIB3SPROC epoxy_glVertexAttrib3s;
    PFNGLVERTEXATTRIB3SARBPROC epoxy_glVertexAttrib3sARB;
    PFNGLVERTEXATTRIB3SNVPROC epoxy_glVertexAttrib3sNV;
    PFNGLVERTEXATTRIB3SVPROC epoxy_glVertexAttrib3sv;
    PFNGLVERTEXATTRIB3SVARBPROC epoxy_glVertexAttrib3svARB;
    PFNGLVERTEXATTRIB3SVNVPROC epoxy_glVertexAttrib3svNV;
    PFNGLVERTEXATTRIB4NBVPROC epoxy_glVertexAttrib4Nbv;
    PFNGLVERTEXATTRIB4NBVARBPROC epoxy_glVertexAttrib4NbvARB;
    PFNGLVERTEXATTRIB4NIVPROC epoxy_glVertexAttrib4Niv;
    PFNGLVERTEXATTRIB4NIVARBPROC epoxy_glVertexAttrib4NivARB;
    PFNGLVERTEXATTRIB4NSVPROC epoxy_glVertexAttrib4Nsv;
    PFNGLVERTEXATTRIB4NSVARBPROC epoxy_glVertexAttrib4NsvARB;
    PFNGLVERTEXATTRIB4NUBPROC epoxy_glVertexAttrib4Nub;
    PFNGLVERTEXATTRIB4NUBARBPROC epoxy_glVertexAttrib4NubARB;
    PFNGLVERTEXATTRIB4NUBVPROC epoxy_glVertexAttrib4Nubv;
    PFNGLVERTEXATTRIB4NUBVARBPROC epoxy_glVertexAttrib4NubvARB;
    PFNGLVERTEXATTRIB4NUIVPROC epoxy_glVertexAttrib4Nuiv;
    PFNGLVERTEXATTRIB4NUIVARBPROC epoxy_glVertexAttrib4NuivARB;
    PFNGLVERTEXATTRIB4NUSVPROC epoxy_glVertexAttrib4Nusv;
    PFNGLVERTEXATTRIB4NUSVARBPROC epoxy_glVertexAttrib4NusvARB;
    PFNGLVERTEXATTRIB4BVPROC epoxy_glVertexAttrib4bv;
    PFNGLVERTEXATTRIB4BVARBPROC epoxy_glVertexAttrib4bvARB;
    PFNGLVERTEXATTRIB4DPROC epoxy_glVertexAttrib4d;
    PFNGLVERTEXATTRIB4DARBPROC epoxy_glVertexAttrib4dARB;
    PFNGLVERTEXATTRIB4DNVPROC epoxy_glVertexAttrib4dNV;
    PFNGLVERTEXATTRIB4DVPROC epoxy_glVertexAttrib4dv;
    PFNGLVERTEXATTRIB4DVARBPROC epoxy_glVertexAttrib4dvARB;
    PFNGLVERTEXATTRIB4DVNVPROC epoxy_glVertexAttrib4dvNV;
    PFNGLVERTEXATTRIB4FPROC epoxy_glVertexAttrib4f;
    PFNGLVERTEXATTRIB4FARBPROC epoxy_glVertexAttrib4fARB;
    PFNGLVERTEXATTRIB4FNVPROC epoxy_glVertexAttrib4fNV;
    PFNGLVERTEXATTRIB4FVPROC epoxy_glVertexAttrib4fv;
    PFNGLVERTEXATTRIB4FVARBPROC epoxy_glVertexAttrib4fvARB;
    PFNGLVERTEXATTRIB4FVNVPROC epoxy_glVertexAttrib4fvNV;
    PFNGLVERTEXATTRIB4HNVPROC epoxy_glVertexAttrib4hNV;
    PFNGLVERTEXATTRIB4HVNVPROC epoxy_glVertexAttrib4hvNV;
    PFNGLVERTEXATTRIB4IVPROC epoxy_glVertexAttrib4iv;
    PFNGLVERTEXATTRIB4IVARBPROC epoxy_glVertexAttrib4ivARB;
    PFNGLVERTEXATTRIB4SPROC epoxy_glVertexAttrib4s;
    PFNGLVERTEXATTRIB4SARBPROC epoxy_glVertexAttrib4sARB;
    PFNGLVERTEXATTRIB4SNVPROC epoxy_glVertexAttrib4sNV;
    PFNGLVERTEXATTRIB4SVPROC epoxy_glVertexAttrib4sv;
    PFNGLVERTEXATTRIB4SVARBPROC epoxy_glVertexAttrib4svARB;
    PFNGLVERTEXATTRIB4SVNVPROC epoxy_glVertexAttrib4svNV;
    PFNGLVERTEXATTRIB4UBNVPROC epoxy_glVertexAttrib4ubNV;
    PFNGLVERTEXATTRIB4UBVPROC epoxy_glVertexAttrib4ubv;
    PFNGLVERTEXATTRIB4UBVARBPROC epoxy_glVertexAttrib4ubvARB;
    PFNGLVERTEXATTRIB4UBVNVPROC epoxy_glVertexAttrib4ubvNV;
    PFNGLVERTEXATTRIB4UIVPROC epoxy_glVertexAttrib4uiv;
    PFNGLVERTEXATTRIB4UIVARBPROC epoxy_glVertexAttrib4uivARB;
    PFNGLVERTEXATTRIB4USVPROC epoxy_glVertexAttrib4usv;
    PFNGLVERTEXATTRIB4USVARBPROC epoxy_glVertexAttrib4usvARB;
    PFNGLVERTEXATTRIBARRAYOBJECTATIPROC epoxy_glVertexAttribArrayObjectATI;
    PFNGLVERTEXATTRIBBINDINGPROC epoxy_glVertexAttribBinding;
    PFNGLVERTEXATTRIBDIVISORPROC epoxy_glVertexAttribDivisor;
    PFNGLVERTEXATTRIBDIVISORANGLEPROC epoxy_glVertexAttribDivisorANGLE;
    PFNGLVERTEXATTRIBDIVISORARBPROC epoxy_glVertexAttribDivisorARB;
    PFNGLVERTEXATTRIBDIVISOREXTPROC epoxy_glVertexAttribDivisorEXT;
    PFNGLVERTEXATTRIBDIVISORNVPROC epoxy_glVertexAttribDivisorNV;
    PFNGLVERTEXATTRIBFORMATPROC epoxy_glVertexAttribFormat;
    PFNGLVERTEXATTRIBFORMATNVPROC epoxy_glVertexAttribFormatNV;
    PFNGLVERTEXATTRIBI1IPROC epoxy_glVertexAttribI1i;
    PFNGLVERTEXATTRIBI1IEXTPROC epoxy_glVertexAttribI1iEXT;
    PFNGLVERTEXATTRIBI1IVPROC epoxy_glVertexAttribI1iv;
    PFNGLVERTEXATTRIBI1IVEXTPROC epoxy_glVertexAttribI1ivEXT;
    PFNGLVERTEXATTRIBI1UIPROC epoxy_glVertexAttribI1ui;
    PFNGLVERTEXATTRIBI1UIEXTPROC epoxy_glVertexAttribI1uiEXT;
    PFNGLVERTEXATTRIBI1UIVPROC epoxy_glVertexAttribI1uiv;
    PFNGLVERTEXATTRIBI1UIVEXTPROC epoxy_glVertexAttribI1uivEXT;
    PFNGLVERTEXATTRIBI2IPROC epoxy_glVertexAttribI2i;
    PFNGLVERTEXATTRIBI2IEXTPROC epoxy_glVertexAttribI2iEXT;
    PFNGLVERTEXATTRIBI2IVPROC epoxy_glVertexAttribI2iv;
    PFNGLVERTEXATTRIBI2IVEXTPROC epoxy_glVertexAttribI2ivEXT;
    PFNGLVERTEXATTRIBI2UIPROC epoxy_glVertexAttribI2ui;
    PFNGLVERTEXATTRIBI2UIEXTPROC epoxy_glVertexAttribI2uiEXT;
    PFNGLVERTEXATTRIBI2UIVPROC epoxy_glVertexAttribI2uiv;
    PFNGLVERTEXATTRIBI2UIVEXTPROC epoxy_glVertexAttribI2uivEXT;
    PFNGLVERTEXATTRIBI3IPROC epoxy_glVertexAttribI3i;
    PFNGLVERTEXATTRIBI3IEXTPROC epoxy_glVertexAttribI3iEXT;
    PFNGLVERTEXATTRIBI3IVPROC epoxy_glVertexAttribI3iv;
    PFNGLVERTEXATTRIBI3IVEXTPROC epoxy_glVertexAttribI3ivEXT;
    PFNGLVERTEXATTRIBI3UIPROC epoxy_glVertexAttribI3ui;
    PFNGLVERTEXATTRIBI3UIEXTPROC epoxy_glVertexAttribI3uiEXT;
    PFNGLVERTEXATTRIBI3UIVPROC epoxy_glVertexAttribI3uiv;
    PFNGLVERTEXATTRIBI3UIVEXTPROC epoxy_glVertexAttribI3uivEXT;
    PFNGLVERTEXATTRIBI4BVPROC epoxy_glVertexAttribI4bv;
    PFNGLVERTEXATTRIBI4BVEXTPROC epoxy_glVertexAttribI4bvEXT;
    PFNGLVERTEXATTRIBI4IPROC epoxy_glVertexAttribI4i;
    PFNGLVERTEXATTRIBI4IEXTPROC epoxy_glVertexAttribI4iEXT;
    PFNGLVERTEXATTRIBI4IVPROC epoxy_glVertexAttribI4iv;
    PFNGLVERTEXATTRIBI4IVEXTPROC epoxy_glVertexAttribI4ivEXT;
    PFNGLVERTEXATTRIBI4SVPROC epoxy_glVertexAttribI4sv;
    PFNGLVERTEXATTRIBI4SVEXTPROC epoxy_glVertexAttribI4svEXT;
    PFNGLVERTEXATTRIBI4UBVPROC epoxy_glVertexAttribI4ubv;
    PFNGLVERTEXATTRIBI4UBVEXTPROC epoxy_glVertexAttribI4ubvEXT;
    PFNGLVERTEXATTRIBI4UIPROC epoxy_glVertexAttribI4ui;
    PFNGLVERTEXATTRIBI4UIEXTPROC epoxy_glVertexAttribI4uiEXT;
    PFNGLVERTEXATTRIBI4UIVPROC epoxy_glVertexAttribI4uiv;
    PFNGLVERTEXATTRIBI4UIVEXTPROC epoxy_glVertexAttribI4uivEXT;
    PFNGLVERTEXATTRIBI4USVPROC epoxy_glVertexAttribI4usv;
    PFNGLVERTEXATTRIBI4USVEXTPROC epoxy_glVertexAttribI4usvEXT;
    PFNGLVERTEXATTRIBIFORMATPROC epoxy_glVertexAttribIFormat;
    PFNGLVERTEXATTRIBIFORMATNVPROC epoxy_glVertexAttribIFormatNV;
    PFNGLVERTEXATTRIBIPOINTERPROC epoxy_glVertexAttribIPointer;
    PFNGLVERTEXATTRIBIPOINTEREXTPROC epoxy_glVertexAttribIPointerEXT;
    PFNGLVERTEXATTRIBL1DPROC epoxy_glVertexAttribL1d;
    PFNGLVERTEXATTRIBL1DEXTPROC epoxy_glVertexAttribL1dEXT;
    PFNGLVERTEXATTRIBL1DVPROC epoxy_glVertexAttribL1dv;
    PFNGLVERTEXATTRIBL1DVEXTPROC epoxy_glVertexAttribL1dvEXT;
    PFNGLVERTEXATTRIBL1I64NVPROC epoxy_glVertexAttribL1i64NV;
    PFNGLVERTEXATTRIBL1I64VNVPROC epoxy_glVertexAttribL1i64vNV;
    PFNGLVERTEXATTRIBL1UI64ARBPROC epoxy_glVertexAttribL1ui64ARB;
    PFNGLVERTEXATTRIBL1UI64NVPROC epoxy_glVertexAttribL1ui64NV;
    PFNGLVERTEXATTRIBL1UI64VARBPROC epoxy_glVertexAttribL1ui64vARB;
    PFNGLVERTEXATTRIBL1UI64VNVPROC epoxy_glVertexAttribL1ui64vNV;
    PFNGLVERTEXATTRIBL2DPROC epoxy_glVertexAttribL2d;
    PFNGLVERTEXATTRIBL2DEXTPROC epoxy_glVertexAttribL2dEXT;
    PFNGLVERTEXATTRIBL2DVPROC epoxy_glVertexAttribL2dv;
    PFNGLVERTEXATTRIBL2DVEXTPROC epoxy_glVertexAttribL2dvEXT;
    PFNGLVERTEXATTRIBL2I64NVPROC epoxy_glVertexAttribL2i64NV;
    PFNGLVERTEXATTRIBL2I64VNVPROC epoxy_glVertexAttribL2i64vNV;
    PFNGLVERTEXATTRIBL2UI64NVPROC epoxy_glVertexAttribL2ui64NV;
    PFNGLVERTEXATTRIBL2UI64VNVPROC epoxy_glVertexAttribL2ui64vNV;
    PFNGLVERTEXATTRIBL3DPROC epoxy_glVertexAttribL3d;
    PFNGLVERTEXATTRIBL3DEXTPROC epoxy_glVertexAttribL3dEXT;
    PFNGLVERTEXATTRIBL3DVPROC epoxy_glVertexAttribL3dv;
    PFNGLVERTEXATTRIBL3DVEXTPROC epoxy_glVertexAttribL3dvEXT;
    PFNGLVERTEXATTRIBL3I64NVPROC epoxy_glVertexAttribL3i64NV;
    PFNGLVERTEXATTRIBL3I64VNVPROC epoxy_glVertexAttribL3i64vNV;
    PFNGLVERTEXATTRIBL3UI64NVPROC epoxy_glVertexAttribL3ui64NV;
    PFNGLVERTEXATTRIBL3UI64VNVPROC epoxy_glVertexAttribL3ui64vNV;
    PFNGLVERTEXATTRIBL4DPROC epoxy_glVertexAttribL4d;
    PFNGLVERTEXATTRIBL4DEXTPROC epoxy_glVertexAttribL4dEXT;
    PFNGLVERTEXATTRIBL4DVPROC epoxy_glVertexAttribL4dv;
    PFNGLVERTEXATTRIBL4DVEXTPROC epoxy_glVertexAttribL4dvEXT;
    PFNGLVERTEXATTRIBL4I64NVPROC epoxy_glVertexAttribL4i64NV;
    PFNGLVERTEXATTRIBL4I64VNVPROC epoxy_glVertexAttribL4i64vNV;
    PFNGLVERTEXATTRIBL4UI64NVPROC epoxy_glVertexAttribL4ui64NV;
    PFNGLVERTEXATTRIBL4UI64VNVPROC epoxy_glVertexAttribL4ui64vNV;
    PFNGLVERTEXATTRIBLFORMATPROC epoxy_glVertexAttribLFormat;
    PFNGLVERTEXATTRIBLFORMATNVPROC epoxy_glVertexAttribLFormatNV;
    PFNGLVERTEXATTRIBLPOINTERPROC epoxy_glVertexAttribLPointer;
    PFNGLVERTEXATTRIBLPOINTEREXTPROC epoxy_glVertexAttribLPointerEXT;
    PFNGLVERTEXATTRIBP1UIPROC epoxy_glVertexAttribP1ui;
    PFNGLVERTEXATTRIBP1UIVPROC epoxy_glVertexAttribP1uiv;
    PFNGLVERTEXATTRIBP2UIPROC epoxy_glVertexAttribP2ui;
    PFNGLVERTEXATTRIBP2UIVPROC epoxy_glVertexAttribP2uiv;
    PFNGLVERTEXATTRIBP3UIPROC epoxy_glVertexAttribP3ui;
    PFNGLVERTEXATTRIBP3UIVPROC epoxy_glVertexAttribP3uiv;
    PFNGLVERTEXATTRIBP4UIPROC epoxy_glVertexAttribP4ui;
    PFNGLVERTEXATTRIBP4UIVPROC epoxy_glVertexAttribP4uiv;
    PFNGLVERTEXATTRIBPARAMETERIAMDPROC epoxy_glVertexAttribParameteriAMD;
    PFNGLVERTEXATTRIBPOINTERPROC epoxy_glVertexAttribPointer;
    PFNGLVERTEXATTRIBPOINTERARBPROC epoxy_glVertexAttribPointerARB;
    PFNGLVERTEXATTRIBPOINTERNVPROC epoxy_glVertexAttribPointerNV;
    PFNGLVERTEXATTRIBS1DVNVPROC epoxy_glVertexAttribs1dvNV;
    PFNGLVERTEXATTRIBS1FVNVPROC epoxy_glVertexAttribs1fvNV;
    PFNGLVERTEXATTRIBS1HVNVPROC epoxy_glVertexAttribs1hvNV;
    PFNGLVERTEXATTRIBS1SVNVPROC epoxy_glVertexAttribs1svNV;
    PFNGLVERTEXATTRIBS2DVNVPROC epoxy_glVertexAttribs2dvNV;
    PFNGLVERTEXATTRIBS2FVNVPROC epoxy_glVertexAttribs2fvNV;
    PFNGLVERTEXATTRIBS2HVNVPROC epoxy_glVertexAttribs2hvNV;
    PFNGLVERTEXATTRIBS2SVNVPROC epoxy_glVertexAttribs2svNV;
    PFNGLVERTEXATTRIBS3DVNVPROC epoxy_glVertexAttribs3dvNV;
    PFNGLVERTEXATTRIBS3FVNVPROC epoxy_glVertexAttribs3fvNV;
    PFNGLVERTEXATTRIBS3HVNVPROC epoxy_glVertexAttribs3hvNV;
    PFNGLVERTEXATTRIBS3SVNVPROC epoxy_glVertexAttribs3svNV;
    PFNGLVERTEXATTRIBS4DVNVPROC epoxy_glVertexAttribs4dvNV;
    PFNGLVERTEXATTRIBS4FVNVPROC epoxy_glVertexAttribs4fvNV;
    PFNGLVERTEXATTRIBS4HVNVPROC epoxy_glVertexAttribs4hvNV;
    PFNGLVERTEXATTRIBS4SVNVPROC epoxy_glVertexAttribs4svNV;
    PFNGLVERTEXATTRIBS4UBVNVPROC epoxy_glVertexAttribs4ubvNV;
    PFNGLVERTEXBINDINGDIVISORPROC epoxy_glVertexBindingDivisor;
    PFNGLVERTEXBLENDARBPROC epoxy_glVertexBlendARB;
    PFNGLVERTEXBLENDENVFATIPROC epoxy_glVertexBlendEnvfATI;
    PFNGLVERTEXBLENDENVIATIPROC epoxy_glVertexBlendEnviATI;
    PFNGLVERTEXFORMATNVPROC epoxy_glVertexFormatNV;
    PFNGLVERTEXP2UIPROC epoxy_glVertexP2ui;
    PFNGLVERTEXP2UIVPROC epoxy_glVertexP2uiv;
    PFNGLVERTEXP3UIPROC epoxy_glVertexP3ui;
    PFNGLVERTEXP3UIVPROC epoxy_glVertexP3uiv;
    PFNGLVERTEXP4UIPROC epoxy_glVertexP4ui;
    PFNGLVERTEXP4UIVPROC epoxy_glVertexP4uiv;
    PFNGLVERTEXPOINTERPROC epoxy_glVertexPointer;
    PFNGLVERTEXPOINTEREXTPROC epoxy_glVertexPointerEXT;
    PFNGLVERTEXPOINTERLISTIBMPROC epoxy_glVertexPointerListIBM;
    PFNGLVERTEXPOINTERVINTELPROC epoxy_glVertexPointervINTEL;
    PFNGLVERTEXSTREAM1DATIPROC epoxy_glVertexStream1dATI;
    PFNGLVERTEXSTREAM1DVATIPROC epoxy_glVertexStream1dvATI;
    PFNGLVERTEXSTREAM1FATIPROC epoxy_glVertexStream1fATI;
    PFNGLVERTEXSTREAM1FVATIPROC epoxy_glVertexStream1fvATI;
    PFNGLVERTEXSTREAM1IATIPROC epoxy_glVertexStream1iATI;
    PFNGLVERTEXSTREAM1IVATIPROC epoxy_glVertexStream1ivATI;
    PFNGLVERTEXSTREAM1SATIPROC epoxy_glVertexStream1sATI;
    PFNGLVERTEXSTREAM1SVATIPROC epoxy_glVertexStream1svATI;
    PFNGLVERTEXSTREAM2DATIPROC epoxy_glVertexStream2dATI;
    PFNGLVERTEXSTREAM2DVATIPROC epoxy_glVertexStream2dvATI;
    PFNGLVERTEXSTREAM2FATIPROC epoxy_glVertexStream2fATI;
    PFNGLVERTEXSTREAM2FVATIPROC epoxy_glVertexStream2fvATI;
    PFNGLVERTEXSTREAM2IATIPROC epoxy_glVertexStream2iATI;
    PFNGLVERTEXSTREAM2IVATIPROC epoxy_glVertexStream2ivATI;
    PFNGLVERTEXSTREAM2SATIPROC epoxy_glVertexStream2sATI;
    PFNGLVERTEXSTREAM2SVATIPROC epoxy_glVertexStream2svATI;
    PFNGLVERTEXSTREAM3DATIPROC epoxy_glVertexStream3dATI;
    PFNGLVERTEXSTREAM3DVATIPROC epoxy_glVertexStream3dvATI;
    PFNGLVERTEXSTREAM3FATIPROC epoxy_glVertexStream3fATI;
    PFNGLVERTEXSTREAM3FVATIPROC epoxy_glVertexStream3fvATI;
    PFNGLVERTEXSTREAM3IATIPROC epoxy_glVertexStream3iATI;
    PFNGLVERTEXSTREAM3IVATIPROC epoxy_glVertexStream3ivATI;
    PFNGLVERTEXSTREAM3SATIPROC epoxy_glVertexStream3sATI;
    PFNGLVERTEXSTREAM3SVATIPROC epoxy_glVertexStream3svATI;
    PFNGLVERTEXSTREAM4DATIPROC epoxy_glVertexStream4dATI;
    PFNGLVERTEXSTREAM4DVATIPROC epoxy_glVertexStream4dvATI;
    PFNGLVERTEXSTREAM4FATIPROC epoxy_glVertexStream4fATI;
    PFNGLVERTEXSTREAM4FVATIPROC epoxy_glVertexStream4fvATI;
    PFNGLVERTEXSTREAM4IATIPROC epoxy_glVertexStream4iATI;
    PFNGLVERTEXSTREAM4IVATIPROC epoxy_glVertexStream4ivATI;
    PFNGLVERTEXSTREAM4SATIPROC epoxy_glVertexStream4sATI;
    PFNGLVERTEXSTREAM4SVATIPROC epoxy_glVertexStream4svATI;
    PFNGLVERTEXWEIGHTPOINTEREXTPROC epoxy_glVertexWeightPointerEXT;
    PFNGLVERTEXWEIGHTFEXTPROC epoxy_glVertexWeightfEXT;
    PFNGLVERTEXWEIGHTFVEXTPROC epoxy_glVertexWeightfvEXT;
    PFNGLVERTEXWEIGHTHNVPROC epoxy_glVertexWeighthNV;
    PFNGLVERTEXWEIGHTHVNVPROC epoxy_glVertexWeighthvNV;
    PFNGLVIDEOCAPTURENVPROC epoxy_glVideoCaptureNV;
    PFNGLVIDEOCAPTURESTREAMPARAMETERDVNVPROC epoxy_glVideoCaptureStreamParameterdvNV;
    PFNGLVIDEOCAPTURESTREAMPARAMETERFVNVPROC epoxy_glVideoCaptureStreamParameterfvNV;
    PFNGLVIDEOCAPTURESTREAMPARAMETERIVNVPROC epoxy_glVideoCaptureStreamParameterivNV;
    PFNGLVIEWPORTPROC epoxy_glViewport;
    PFNGLVIEWPORTARRAYVPROC epoxy_glViewportArrayv;
    PFNGLVIEWPORTARRAYVNVPROC epoxy_glViewportArrayvNV;
    PFNGLVIEWPORTARRAYVOESPROC epoxy_glViewportArrayvOES;
    PFNGLVIEWPORTINDEXEDFPROC epoxy_glViewportIndexedf;
    PFNGLVIEWPORTINDEXEDFNVPROC epoxy_glViewportIndexedfNV;
    PFNGLVIEWPORTINDEXEDFOESPROC epoxy_glViewportIndexedfOES;
    PFNGLVIEWPORTINDEXEDFVPROC epoxy_glViewportIndexedfv;
    PFNGLVIEWPORTINDEXEDFVNVPROC epoxy_glViewportIndexedfvNV;
    PFNGLVIEWPORTINDEXEDFVOESPROC epoxy_glViewportIndexedfvOES;
    PFNGLVIEWPORTPOSITIONWSCALENVPROC epoxy_glViewportPositionWScaleNV;
    PFNGLVIEWPORTSWIZZLENVPROC epoxy_glViewportSwizzleNV;
    PFNGLWAITSEMAPHOREEXTPROC epoxy_glWaitSemaphoreEXT;
    PFNGLWAITSEMAPHOREUI64NVXPROC epoxy_glWaitSemaphoreui64NVX;
    PFNGLWAITSYNCPROC epoxy_glWaitSync;
    PFNGLWAITSYNCAPPLEPROC epoxy_glWaitSyncAPPLE;
    PFNGLWAITVKSEMAPHORENVPROC epoxy_glWaitVkSemaphoreNV;
    PFNGLWEIGHTPATHSNVPROC epoxy_glWeightPathsNV;
    PFNGLWEIGHTPOINTERARBPROC epoxy_glWeightPointerARB;
    PFNGLWEIGHTPOINTEROESPROC epoxy_glWeightPointerOES;
    PFNGLWEIGHTBVARBPROC epoxy_glWeightbvARB;
    PFNGLWEIGHTDVARBPROC epoxy_glWeightdvARB;
    PFNGLWEIGHTFVARBPROC epoxy_glWeightfvARB;
    PFNGLWEIGHTIVARBPROC epoxy_glWeightivARB;
    PFNGLWEIGHTSVARBPROC epoxy_glWeightsvARB;
    PFNGLWEIGHTUBVARBPROC epoxy_glWeightubvARB;
    PFNGLWEIGHTUIVARBPROC epoxy_glWeightuivARB;
    PFNGLWEIGHTUSVARBPROC epoxy_glWeightusvARB;
    PFNGLWINDOWPOS2DPROC epoxy_glWindowPos2d;
    PFNGLWINDOWPOS2DARBPROC epoxy_glWindowPos2dARB;
    PFNGLWINDOWPOS2DMESAPROC epoxy_glWindowPos2dMESA;
    PFNGLWINDOWPOS2DVPROC epoxy_glWindowPos2dv;
    PFNGLWINDOWPOS2DVARBPROC epoxy_glWindowPos2dvARB;
    PFNGLWINDOWPOS2DVMESAPROC epoxy_glWindowPos2dvMESA;
    PFNGLWINDOWPOS2FPROC epoxy_glWindowPos2f;
    PFNGLWINDOWPOS2FARBPROC epoxy_glWindowPos2fARB;
    PFNGLWINDOWPOS2FMESAPROC epoxy_glWindowPos2fMESA;
    PFNGLWINDOWPOS2FVPROC epoxy_glWindowPos2fv;
    PFNGLWINDOWPOS2FVARBPROC epoxy_glWindowPos2fvARB;
    PFNGLWINDOWPOS2FVMESAPROC epoxy_glWindowPos2fvMESA;
    PFNGLWINDOWPOS2IPROC epoxy_glWindowPos2i;
    PFNGLWINDOWPOS2IARBPROC epoxy_glWindowPos2iARB;
    PFNGLWINDOWPOS2IMESAPROC epoxy_glWindowPos2iMESA;
    PFNGLWINDOWPOS2IVPROC epoxy_glWindowPos2iv;
    PFNGLWINDOWPOS2IVARBPROC epoxy_glWindowPos2ivARB;
    PFNGLWINDOWPOS2IVMESAPROC epoxy_glWindowPos2ivMESA;
    PFNGLWINDOWPOS2SPROC epoxy_glWindowPos2s;
    PFNGLWINDOWPOS2SARBPROC epoxy_glWindowPos2sARB;
    PFNGLWINDOWPOS2SMESAPROC epoxy_glWindowPos2sMESA;
    PFNGLWINDOWPOS2SVPROC epoxy_glWindowPos2sv;
    PFNGLWINDOWPOS2SVARBPROC epoxy_glWindowPos2svARB;
    PFNGLWINDOWPOS2SVMESAPROC epoxy_glWindowPos2svMESA;
    PFNGLWINDOWPOS3DPROC epoxy_glWindowPos3d;
    PFNGLWINDOWPOS3DARBPROC epoxy_glWindowPos3dARB;
    PFNGLWINDOWPOS3DMESAPROC epoxy_glWindowPos3dMESA;
    PFNGLWINDOWPOS3DVPROC epoxy_glWindowPos3dv;
    PFNGLWINDOWPOS3DVARBPROC epoxy_glWindowPos3dvARB;
    PFNGLWINDOWPOS3DVMESAPROC epoxy_glWindowPos3dvMESA;
    PFNGLWINDOWPOS3FPROC epoxy_glWindowPos3f;
    PFNGLWINDOWPOS3FARBPROC epoxy_glWindowPos3fARB;
    PFNGLWINDOWPOS3FMESAPROC epoxy_glWindowPos3fMESA;
    PFNGLWINDOWPOS3FVPROC epoxy_glWindowPos3fv;
    PFNGLWINDOWPOS3FVARBPROC epoxy_glWindowPos3fvARB;
    PFNGLWINDOWPOS3FVMESAPROC epoxy_glWindowPos3fvMESA;
    PFNGLWINDOWPOS3IPROC epoxy_glWindowPos3i;
    PFNGLWINDOWPOS3IARBPROC epoxy_glWindowPos3iARB;
    PFNGLWINDOWPOS3IMESAPROC epoxy_glWindowPos3iMESA;
    PFNGLWINDOWPOS3IVPROC epoxy_glWindowPos3iv;
    PFNGLWINDOWPOS3IVARBPROC epoxy_glWindowPos3ivARB;
    PFNGLWINDOWPOS3IVMESAPROC epoxy_glWindowPos3ivMESA;
    PFNGLWINDOWPOS3SPROC epoxy_glWindowPos3s;
    PFNGLWINDOWPOS3SARBPROC epoxy_glWindowPos3sARB;
    PFNGLWINDOWPOS3SMESAPROC epoxy_glWindowPos3sMESA;
    PFNGLWINDOWPOS3SVPROC epoxy_glWindowPos3sv;
    PFNGLWINDOWPOS3SVARBPROC epoxy_glWindowPos3svARB;
    PFNGLWINDOWPOS3SVMESAPROC epoxy_glWindowPos3svMESA;
    PFNGLWINDOWPOS4DMESAPROC epoxy_glWindowPos4dMESA;
    PFNGLWINDOWPOS4DVMESAPROC epoxy_glWindowPos4dvMESA;
    PFNGLWINDOWPOS4FMESAPROC epoxy_glWindowPos4fMESA;
    PFNGLWINDOWPOS4FVMESAPROC epoxy_glWindowPos4fvMESA;
    PFNGLWINDOWPOS4IMESAPROC epoxy_glWindowPos4iMESA;
    PFNGLWINDOWPOS4IVMESAPROC epoxy_glWindowPos4ivMESA;
    PFNGLWINDOWPOS4SMESAPROC epoxy_glWindowPos4sMESA;
    PFNGLWINDOWPOS4SVMESAPROC epoxy_glWindowPos4svMESA;
    PFNGLWINDOWRECTANGLESEXTPROC epoxy_glWindowRectanglesEXT;
    PFNGLWRITEMASKEXTPROC epoxy_glWriteMaskEXT;
};

#if USING_DISPATCH_TABLE
static inline struct dispatch_table *
get_dispatch_table(void);

#endif

enum gl_provider {
    gl_provider_terminator = 0,
    PROVIDER_Desktop_OpenGL_1_0,
    PROVIDER_Desktop_OpenGL_1_1,
    PROVIDER_Desktop_OpenGL_1_2,
    PROVIDER_Desktop_OpenGL_1_3,
    PROVIDER_Desktop_OpenGL_1_4,
    PROVIDER_Desktop_OpenGL_1_5,
    PROVIDER_Desktop_OpenGL_2_0,
    PROVIDER_Desktop_OpenGL_2_1,
    PROVIDER_Desktop_OpenGL_3_0,
    PROVIDER_Desktop_OpenGL_3_1,
    PROVIDER_Desktop_OpenGL_3_2,
    PROVIDER_Desktop_OpenGL_3_3,
    PROVIDER_Desktop_OpenGL_4_0,
    PROVIDER_Desktop_OpenGL_4_1,
    PROVIDER_Desktop_OpenGL_4_2,
    PROVIDER_Desktop_OpenGL_4_3,
    PROVIDER_Desktop_OpenGL_4_4,
    PROVIDER_Desktop_OpenGL_4_5,
    PROVIDER_Desktop_OpenGL_4_6,
    PROVIDER_GL_3DFX_tbuffer,
    PROVIDER_GL_AMD_debug_output,
    PROVIDER_GL_AMD_draw_buffers_blend,
    PROVIDER_GL_AMD_framebuffer_multisample_advanced,
    PROVIDER_GL_AMD_framebuffer_sample_positions,
    PROVIDER_GL_AMD_gpu_shader_int64,
    PROVIDER_GL_AMD_interleaved_elements,
    PROVIDER_GL_AMD_multi_draw_indirect,
    PROVIDER_GL_AMD_name_gen_delete,
    PROVIDER_GL_AMD_occlusion_query_event,
    PROVIDER_GL_AMD_performance_monitor,
    PROVIDER_GL_AMD_sample_positions,
    PROVIDER_GL_AMD_sparse_texture,
    PROVIDER_GL_AMD_stencil_operation_extended,
    PROVIDER_GL_AMD_vertex_shader_tessellator,
    PROVIDER_GL_ANGLE_framebuffer_blit,
    PROVIDER_GL_ANGLE_framebuffer_multisample,
    PROVIDER_GL_ANGLE_instanced_arrays,
    PROVIDER_GL_ANGLE_translated_shader_source,
    PROVIDER_GL_APPLE_copy_texture_levels,
    PROVIDER_GL_APPLE_element_array,
    PROVIDER_GL_APPLE_fence,
    PROVIDER_GL_APPLE_flush_buffer_range,
    PROVIDER_GL_APPLE_framebuffer_multisample,
    PROVIDER_GL_APPLE_object_purgeable,
    PROVIDER_GL_APPLE_sync,
    PROVIDER_GL_APPLE_texture_range,
    PROVIDER_GL_APPLE_vertex_array_object,
    PROVIDER_GL_APPLE_vertex_array_range,
    PROVIDER_GL_APPLE_vertex_program_evaluators,
    PROVIDER_GL_ARB_ES2_compatibility,
    PROVIDER_GL_ARB_ES3_1_compatibility,
    PROVIDER_GL_ARB_ES3_2_compatibility,
    PROVIDER_GL_ARB_base_instance,
    PROVIDER_GL_ARB_bindless_texture,
    PROVIDER_GL_ARB_blend_func_extended,
    PROVIDER_GL_ARB_buffer_storage,
    PROVIDER_GL_ARB_cl_event,
    PROVIDER_GL_ARB_clear_buffer_object,
    PROVIDER_GL_ARB_clear_texture,
    PROVIDER_GL_ARB_clip_control,
    PROVIDER_GL_ARB_color_buffer_float,
    PROVIDER_GL_ARB_compute_shader,
    PROVIDER_GL_ARB_compute_variable_group_size,
    PROVIDER_GL_ARB_copy_buffer,
    PROVIDER_GL_ARB_copy_image,
    PROVIDER_GL_ARB_debug_output,
    PROVIDER_GL_ARB_direct_state_access,
    PROVIDER_GL_ARB_draw_buffers,
    PROVIDER_GL_ARB_draw_buffers_blend,
    PROVIDER_GL_ARB_draw_elements_base_vertex,
    PROVIDER_GL_ARB_draw_indirect,
    PROVIDER_GL_ARB_draw_instanced,
    PROVIDER_GL_ARB_fragment_program,
    PROVIDER_GL_ARB_framebuffer_no_attachments,
    PROVIDER_GL_ARB_framebuffer_object,
    PROVIDER_GL_ARB_geometry_shader4,
    PROVIDER_GL_ARB_get_program_binary,
    PROVIDER_GL_ARB_get_texture_sub_image,
    PROVIDER_GL_ARB_gl_spirv,
    PROVIDER_GL_ARB_gpu_shader_fp64,
    PROVIDER_GL_ARB_gpu_shader_int64,
    PROVIDER_GL_ARB_imaging,
    PROVIDER_GL_ARB_indirect_parameters,
    PROVIDER_GL_ARB_instanced_arrays,
    PROVIDER_GL_ARB_internalformat_query,
    PROVIDER_GL_ARB_internalformat_query2,
    PROVIDER_GL_ARB_invalidate_subdata,
    PROVIDER_GL_ARB_map_buffer_range,
    PROVIDER_GL_ARB_matrix_palette,
    PROVIDER_GL_ARB_multi_bind,
    PROVIDER_GL_ARB_multi_draw_indirect,
    PROVIDER_GL_ARB_multisample,
    PROVIDER_GL_ARB_multitexture,
    PROVIDER_GL_ARB_occlusion_query,
    PROVIDER_GL_ARB_parallel_shader_compile,
    PROVIDER_GL_ARB_point_parameters,
    PROVIDER_GL_ARB_polygon_offset_clamp,
    PROVIDER_GL_ARB_program_interface_query,
    PROVIDER_GL_ARB_provoking_vertex,
    PROVIDER_GL_ARB_robustness,
    PROVIDER_GL_ARB_sample_locations,
    PROVIDER_GL_ARB_sample_shading,
    PROVIDER_GL_ARB_sampler_objects,
    PROVIDER_GL_ARB_separate_shader_objects,
    PROVIDER_GL_ARB_shader_atomic_counters,
    PROVIDER_GL_ARB_shader_image_load_store,
    PROVIDER_GL_ARB_shader_objects,
    PROVIDER_GL_ARB_shader_storage_buffer_object,
    PROVIDER_GL_ARB_shader_subroutine,
    PROVIDER_GL_ARB_shading_language_include,
    PROVIDER_GL_ARB_sparse_buffer,
    PROVIDER_GL_ARB_sparse_texture,
    PROVIDER_GL_ARB_sync,
    PROVIDER_GL_ARB_tessellation_shader,
    PROVIDER_GL_ARB_texture_barrier,
    PROVIDER_GL_ARB_texture_buffer_object,
    PROVIDER_GL_ARB_texture_buffer_range,
    PROVIDER_GL_ARB_texture_compression,
    PROVIDER_GL_ARB_texture_multisample,
    PROVIDER_GL_ARB_texture_storage,
    PROVIDER_GL_ARB_texture_storage_multisample,
    PROVIDER_GL_ARB_texture_view,
    PROVIDER_GL_ARB_timer_query,
    PROVIDER_GL_ARB_transform_feedback2,
    PROVIDER_GL_ARB_transform_feedback3,
    PROVIDER_GL_ARB_transform_feedback_instanced,
    PROVIDER_GL_ARB_transpose_matrix,
    PROVIDER_GL_ARB_uniform_buffer_object,
    PROVIDER_GL_ARB_vertex_array_object,
    PROVIDER_GL_ARB_vertex_attrib_64bit,
    PROVIDER_GL_ARB_vertex_attrib_binding,
    PROVIDER_GL_ARB_vertex_blend,
    PROVIDER_GL_ARB_vertex_buffer_object,
    PROVIDER_GL_ARB_vertex_program,
    PROVIDER_GL_ARB_vertex_shader,
    PROVIDER_GL_ARB_vertex_type_2_10_10_10_rev,
    PROVIDER_GL_ARB_viewport_array,
    PROVIDER_GL_ARB_window_pos,
    PROVIDER_GL_ATI_draw_buffers,
    PROVIDER_GL_ATI_element_array,
    PROVIDER_GL_ATI_envmap_bumpmap,
    PROVIDER_GL_ATI_fragment_shader,
    PROVIDER_GL_ATI_map_object_buffer,
    PROVIDER_GL_ATI_pn_triangles,
    PROVIDER_GL_ATI_separate_stencil,
    PROVIDER_GL_ATI_vertex_array_object,
    PROVIDER_GL_ATI_vertex_attrib_array_object,
    PROVIDER_GL_ATI_vertex_streams,
    PROVIDER_GL_EXT_EGL_image_storage,
    PROVIDER_GL_EXT_base_instance,
    PROVIDER_GL_EXT_bindable_uniform,
    PROVIDER_GL_EXT_blend_color,
    PROVIDER_GL_EXT_blend_equation_separate,
    PROVIDER_GL_EXT_blend_func_extended,
    PROVIDER_GL_EXT_blend_func_separate,
    PROVIDER_GL_EXT_blend_minmax,
    PROVIDER_GL_EXT_buffer_storage,
    PROVIDER_GL_EXT_clear_texture,
    PROVIDER_GL_EXT_clip_control,
    PROVIDER_GL_EXT_color_subtable,
    PROVIDER_GL_EXT_compiled_vertex_array,
    PROVIDER_GL_EXT_convolution,
    PROVIDER_GL_EXT_coordinate_frame,
    PROVIDER_GL_EXT_copy_image,
    PROVIDER_GL_EXT_copy_texture,
    PROVIDER_GL_EXT_cull_vertex,
    PROVIDER_GL_EXT_debug_label,
    PROVIDER_GL_EXT_debug_marker,
    PROVIDER_GL_EXT_depth_bounds_test,
    PROVIDER_GL_EXT_direct_state_access,
    PROVIDER_GL_EXT_discard_framebuffer,
    PROVIDER_GL_EXT_disjoint_timer_query,
    PROVIDER_GL_EXT_draw_buffers,
    PROVIDER_GL_EXT_draw_buffers2,
    PROVIDER_GL_EXT_draw_buffers_indexed,
    PROVIDER_GL_EXT_draw_elements_base_vertex,
    PROVIDER_GL_EXT_draw_instanced,
    PROVIDER_GL_EXT_draw_range_elements,
    PROVIDER_GL_EXT_draw_transform_feedback,
    PROVIDER_GL_EXT_external_buffer,
    PROVIDER_GL_EXT_fog_coord,
    PROVIDER_GL_EXT_framebuffer_blit,
    PROVIDER_GL_EXT_framebuffer_multisample,
    PROVIDER_GL_EXT_framebuffer_object,
    PROVIDER_GL_EXT_geometry_shader,
    PROVIDER_GL_EXT_geometry_shader4,
    PROVIDER_GL_EXT_gpu_program_parameters,
    PROVIDER_GL_EXT_gpu_shader4,
    PROVIDER_GL_EXT_histogram,
    PROVIDER_GL_EXT_index_func,
    PROVIDER_GL_EXT_index_material,
    PROVIDER_GL_EXT_instanced_arrays,
    PROVIDER_GL_EXT_light_texture,
    PROVIDER_GL_EXT_map_buffer_range,
    PROVIDER_GL_EXT_memory_object,
    PROVIDER_GL_EXT_memory_object_fd,
    PROVIDER_GL_EXT_memory_object_win32,
    PROVIDER_GL_EXT_multi_draw_arrays,
    PROVIDER_GL_EXT_multi_draw_indirect,
    PROVIDER_GL_EXT_multisample,
    PROVIDER_GL_EXT_multisampled_render_to_texture,
    PROVIDER_GL_EXT_multiview_draw_buffers,
    PROVIDER_GL_EXT_occlusion_query_boolean,
    PROVIDER_GL_EXT_paletted_texture,
    PROVIDER_GL_EXT_pixel_transform,
    PROVIDER_GL_EXT_point_parameters,
    PROVIDER_GL_EXT_polygon_offset,
    PROVIDER_GL_EXT_polygon_offset_clamp,
    PROVIDER_GL_EXT_primitive_bounding_box,
    PROVIDER_GL_EXT_provoking_vertex,
    PROVIDER_GL_EXT_raster_multisample,
    PROVIDER_GL_EXT_robustness,
    PROVIDER_GL_EXT_secondary_color,
    PROVIDER_GL_EXT_semaphore,
    PROVIDER_GL_EXT_semaphore_fd,
    PROVIDER_GL_EXT_semaphore_win32,
    PROVIDER_GL_EXT_separate_shader_objects,
    PROVIDER_GL_EXT_shader_framebuffer_fetch_non_coherent,
    PROVIDER_GL_EXT_shader_image_load_store,
    PROVIDER_GL_EXT_shader_pixel_local_storage2,
    PROVIDER_GL_EXT_sparse_texture,
    PROVIDER_GL_EXT_stencil_clear_tag,
    PROVIDER_GL_EXT_stencil_two_side,
    PROVIDER_GL_EXT_subtexture,
    PROVIDER_GL_EXT_tessellation_shader,
    PROVIDER_GL_EXT_texture3D,
    PROVIDER_GL_EXT_texture_array,
    PROVIDER_GL_EXT_texture_border_clamp,
    PROVIDER_GL_EXT_texture_buffer,
    PROVIDER_GL_EXT_texture_buffer_object,
    PROVIDER_GL_EXT_texture_integer,
    PROVIDER_GL_EXT_texture_object,
    PROVIDER_GL_EXT_texture_perturb_normal,
    PROVIDER_GL_EXT_texture_storage,
    PROVIDER_GL_EXT_texture_view,
    PROVIDER_GL_EXT_timer_query,
    PROVIDER_GL_EXT_transform_feedback,
    PROVIDER_GL_EXT_vertex_array,
    PROVIDER_GL_EXT_vertex_attrib_64bit,
    PROVIDER_GL_EXT_vertex_shader,
    PROVIDER_GL_EXT_vertex_weighting,
    PROVIDER_GL_EXT_win32_keyed_mutex,
    PROVIDER_GL_EXT_window_rectangles,
    PROVIDER_GL_EXT_x11_sync_object,
    PROVIDER_GL_GREMEDY_frame_terminator,
    PROVIDER_GL_GREMEDY_string_marker,
    PROVIDER_GL_HP_image_transform,
    PROVIDER_GL_IBM_multimode_draw_arrays,
    PROVIDER_GL_IBM_static_data,
    PROVIDER_GL_IBM_vertex_array_lists,
    PROVIDER_GL_IMG_bindless_texture,
    PROVIDER_GL_IMG_framebuffer_downsample,
    PROVIDER_GL_IMG_multisampled_render_to_texture,
    PROVIDER_GL_IMG_user_clip_plane,
    PROVIDER_GL_INGR_blend_func_separate,
    PROVIDER_GL_INTEL_framebuffer_CMAA,
    PROVIDER_GL_INTEL_map_texture,
    PROVIDER_GL_INTEL_parallel_arrays,
    PROVIDER_GL_INTEL_performance_query,
    PROVIDER_GL_KHR_blend_equation_advanced,
    PROVIDER_GL_KHR_debug,
    PROVIDER_GL_KHR_parallel_shader_compile,
    PROVIDER_GL_KHR_robustness,
    PROVIDER_GL_MESA_framebuffer_flip_y,
    PROVIDER_GL_MESA_resize_buffers,
    PROVIDER_GL_MESA_window_pos,
    PROVIDER_GL_NVX_conditional_render,
    PROVIDER_GL_NVX_gpu_multicast2,
    PROVIDER_GL_NVX_linked_gpu_multicast,
    PROVIDER_GL_NVX_progress_fence,
    PROVIDER_GL_NV_alpha_to_coverage_dither_control,
    PROVIDER_GL_NV_bindless_multi_draw_indirect,
    PROVIDER_GL_NV_bindless_multi_draw_indirect_count,
    PROVIDER_GL_NV_bindless_texture,
    PROVIDER_GL_NV_blend_equation_advanced,
    PROVIDER_GL_NV_clip_space_w_scaling,
    PROVIDER_GL_NV_command_list,
    PROVIDER_GL_NV_conditional_render,
    PROVIDER_GL_NV_conservative_raster,
    PROVIDER_GL_NV_conservative_raster_dilate,
    PROVIDER_GL_NV_conservative_raster_pre_snap_triangles,
    PROVIDER_GL_NV_copy_buffer,
    PROVIDER_GL_NV_copy_image,
    PROVIDER_GL_NV_coverage_sample,
    PROVIDER_GL_NV_depth_buffer_float,
    PROVIDER_GL_NV_draw_buffers,
    PROVIDER_GL_NV_draw_instanced,
    PROVIDER_GL_NV_draw_texture,
    PROVIDER_GL_NV_draw_vulkan_image,
    PROVIDER_GL_NV_evaluators,
    PROVIDER_GL_NV_explicit_multisample,
    PROVIDER_GL_NV_fence,
    PROVIDER_GL_NV_fragment_coverage_to_color,
    PROVIDER_GL_NV_fragment_program,
    PROVIDER_GL_NV_framebuffer_blit,
    PROVIDER_GL_NV_framebuffer_mixed_samples,
    PROVIDER_GL_NV_framebuffer_multisample,
    PROVIDER_GL_NV_framebuffer_multisample_coverage,
    PROVIDER_GL_NV_geometry_program4,
    PROVIDER_GL_NV_gpu_multicast,
    PROVIDER_GL_NV_gpu_program4,
    PROVIDER_GL_NV_gpu_program5,
    PROVIDER_GL_NV_gpu_shader5,
    PROVIDER_GL_NV_half_float,
    PROVIDER_GL_NV_instanced_arrays,
    PROVIDER_GL_NV_internalformat_sample_query,
    PROVIDER_GL_NV_memory_attachment,
    PROVIDER_GL_NV_mesh_shader,
    PROVIDER_GL_NV_non_square_matrices,
    PROVIDER_GL_NV_occlusion_query,
    PROVIDER_GL_NV_parameter_buffer_object,
    PROVIDER_GL_NV_path_rendering,
    PROVIDER_GL_NV_pixel_data_range,
    PROVIDER_GL_NV_point_sprite,
    PROVIDER_GL_NV_polygon_mode,
    PROVIDER_GL_NV_present_video,
    PROVIDER_GL_NV_primitive_restart,
    PROVIDER_GL_NV_query_resource,
    PROVIDER_GL_NV_query_resource_tag,
    PROVIDER_GL_NV_read_buffer,
    PROVIDER_GL_NV_register_combiners,
    PROVIDER_GL_NV_register_combiners2,
    PROVIDER_GL_NV_sample_locations,
    PROVIDER_GL_NV_scissor_exclusive,
    PROVIDER_GL_NV_shader_buffer_load,
    PROVIDER_GL_NV_shading_rate_image,
    PROVIDER_GL_NV_texture_barrier,
    PROVIDER_GL_NV_texture_multisample,
    PROVIDER_GL_NV_transform_feedback,
    PROVIDER_GL_NV_transform_feedback2,
    PROVIDER_GL_NV_vdpau_interop,
    PROVIDER_GL_NV_vdpau_interop2,
    PROVIDER_GL_NV_vertex_array_range,
    PROVIDER_GL_NV_vertex_attrib_integer_64bit,
    PROVIDER_GL_NV_vertex_buffer_unified_memory,
    PROVIDER_GL_NV_vertex_program,
    PROVIDER_GL_NV_vertex_program4,
    PROVIDER_GL_NV_video_capture,
    PROVIDER_GL_NV_viewport_array,
    PROVIDER_GL_NV_viewport_swizzle,
    PROVIDER_GL_OES_EGL_image,
    PROVIDER_GL_OES_blend_equation_separate,
    PROVIDER_GL_OES_blend_func_separate,
    PROVIDER_GL_OES_blend_subtract,
    PROVIDER_GL_OES_byte_coordinates,
    PROVIDER_GL_OES_copy_image,
    PROVIDER_GL_OES_draw_buffers_indexed,
    PROVIDER_GL_OES_draw_elements_base_vertex,
    PROVIDER_GL_OES_draw_texture,
    PROVIDER_GL_OES_fixed_point,
    PROVIDER_GL_OES_framebuffer_object,
    PROVIDER_GL_OES_geometry_shader,
    PROVIDER_GL_OES_get_program_binary,
    PROVIDER_GL_OES_mapbuffer,
    PROVIDER_GL_OES_matrix_palette,
    PROVIDER_GL_OES_point_size_array,
    PROVIDER_GL_OES_primitive_bounding_box,
    PROVIDER_GL_OES_query_matrix,
    PROVIDER_GL_OES_sample_shading,
    PROVIDER_GL_OES_single_precision,
    PROVIDER_GL_OES_tessellation_shader,
    PROVIDER_GL_OES_texture_3D,
    PROVIDER_GL_OES_texture_border_clamp,
    PROVIDER_GL_OES_texture_buffer,
    PROVIDER_GL_OES_texture_cube_map,
    PROVIDER_GL_OES_texture_storage_multisample_2d_array,
    PROVIDER_GL_OES_texture_view,
    PROVIDER_GL_OES_vertex_array_object,
    PROVIDER_GL_OES_viewport_array,
    PROVIDER_GL_OVR_multiview,
    PROVIDER_GL_OVR_multiview_multisampled_render_to_texture,
    PROVIDER_GL_PGI_misc_hints,
    PROVIDER_GL_QCOM_alpha_test,
    PROVIDER_GL_QCOM_driver_control,
    PROVIDER_GL_QCOM_extended_get,
    PROVIDER_GL_QCOM_extended_get2,
    PROVIDER_GL_QCOM_framebuffer_foveated,
    PROVIDER_GL_QCOM_shader_framebuffer_fetch_noncoherent,
    PROVIDER_GL_QCOM_texture_foveated,
    PROVIDER_GL_QCOM_tiled_rendering,
    PROVIDER_GL_SGIS_detail_texture,
    PROVIDER_GL_SGIS_fog_function,
    PROVIDER_GL_SGIS_multisample,
    PROVIDER_GL_SGIS_pixel_texture,
    PROVIDER_GL_SGIS_point_parameters,
    PROVIDER_GL_SGIS_sharpen_texture,
    PROVIDER_GL_SGIS_texture4D,
    PROVIDER_GL_SGIS_texture_color_mask,
    PROVIDER_GL_SGIS_texture_filter4,
    PROVIDER_GL_SGIX_async,
    PROVIDER_GL_SGIX_flush_raster,
    PROVIDER_GL_SGIX_fragment_lighting,
    PROVIDER_GL_SGIX_framezoom,
    PROVIDER_GL_SGIX_igloo_interface,
    PROVIDER_GL_SGIX_instruments,
    PROVIDER_GL_SGIX_list_priority,
    PROVIDER_GL_SGIX_pixel_texture,
    PROVIDER_GL_SGIX_polynomial_ffd,
    PROVIDER_GL_SGIX_reference_plane,
    PROVIDER_GL_SGIX_sprite,
    PROVIDER_GL_SGIX_tag_sample_buffer,
    PROVIDER_GL_SGI_color_table,
    PROVIDER_GL_SUNX_constant_data,
    PROVIDER_GL_SUN_global_alpha,
    PROVIDER_GL_SUN_mesh_array,
    PROVIDER_GL_SUN_triangle_list,
    PROVIDER_GL_SUN_vertex,
    PROVIDER_OpenGL_ES_1_0,
    PROVIDER_OpenGL_ES_2_0,
    PROVIDER_OpenGL_ES_3_0,
    PROVIDER_OpenGL_ES_3_1,
    PROVIDER_OpenGL_ES_3_2,
    PROVIDER_always_present,
} PACKED;
ENDPACKED

static const char *enum_string =
    "Desktop OpenGL 1.0\0"
    "Desktop OpenGL 1.1\0"
    "Desktop OpenGL 1.2\0"
    "Desktop OpenGL 1.3\0"
    "Desktop OpenGL 1.4\0"
    "Desktop OpenGL 1.5\0"
    "Desktop OpenGL 2.0\0"
    "Desktop OpenGL 2.1\0"
    "Desktop OpenGL 3.0\0"
    "Desktop OpenGL 3.1\0"
    "Desktop OpenGL 3.2\0"
    "Desktop OpenGL 3.3\0"
    "Desktop OpenGL 4.0\0"
    "Desktop OpenGL 4.1\0"
    "Desktop OpenGL 4.2\0"
    "Desktop OpenGL 4.3\0"
    "Desktop OpenGL 4.4\0"
    "Desktop OpenGL 4.5\0"
    "Desktop OpenGL 4.6\0"
    "GL_3DFX_tbuffer\0"
    "GL_AMD_debug_output\0"
    "GL_AMD_draw_buffers_blend\0"
    "GL_AMD_framebuffer_multisample_advanced\0"
    "GL_AMD_framebuffer_sample_positions\0"
    "GL_AMD_gpu_shader_int64\0"
    "GL_AMD_interleaved_elements\0"
    "GL_AMD_multi_draw_indirect\0"
    "GL_AMD_name_gen_delete\0"
    "GL_AMD_occlusion_query_event\0"
    "GL_AMD_performance_monitor\0"
    "GL_AMD_sample_positions\0"
    "GL_AMD_sparse_texture\0"
    "GL_AMD_stencil_operation_extended\0"
    "GL_AMD_vertex_shader_tessellator\0"
    "GL_ANGLE_framebuffer_blit\0"
    "GL_ANGLE_framebuffer_multisample\0"
    "GL_ANGLE_instanced_arrays\0"
    "GL_ANGLE_translated_shader_source\0"
    "GL_APPLE_copy_texture_levels\0"
    "GL_APPLE_element_array\0"
    "GL_APPLE_fence\0"
    "GL_APPLE_flush_buffer_range\0"
    "GL_APPLE_framebuffer_multisample\0"
    "GL_APPLE_object_purgeable\0"
    "GL_APPLE_sync\0"
    "GL_APPLE_texture_range\0"
    "GL_APPLE_vertex_array_object\0"
    "GL_APPLE_vertex_array_range\0"
    "GL_APPLE_vertex_program_evaluators\0"
    "GL_ARB_ES2_compatibility\0"
    "GL_ARB_ES3_1_compatibility\0"
    "GL_ARB_ES3_2_compatibility\0"
    "GL_ARB_base_instance\0"
    "GL_ARB_bindless_texture\0"
    "GL_ARB_blend_func_extended\0"
    "GL_ARB_buffer_storage\0"
    "GL_ARB_cl_event\0"
    "GL_ARB_clear_buffer_object\0"
    "GL_ARB_clear_texture\0"
    "GL_ARB_clip_control\0"
    "GL_ARB_color_buffer_float\0"
    "GL_ARB_compute_shader\0"
    "GL_ARB_compute_variable_group_size\0"
    "GL_ARB_copy_buffer\0"
    "GL_ARB_copy_image\0"
    "GL_ARB_debug_output\0"
    "GL_ARB_direct_state_access\0"
    "GL_ARB_draw_buffers\0"
    "GL_ARB_draw_buffers_blend\0"
    "GL_ARB_draw_elements_base_vertex\0"
    "GL_ARB_draw_indirect\0"
    "GL_ARB_draw_instanced\0"
    "GL_ARB_fragment_program\0"
    "GL_ARB_framebuffer_no_attachments\0"
    "GL_ARB_framebuffer_object\0"
    "GL_ARB_geometry_shader4\0"
    "GL_ARB_get_program_binary\0"
    "GL_ARB_get_texture_sub_image\0"
    "GL_ARB_gl_spirv\0"
    "GL_ARB_gpu_shader_fp64\0"
    "GL_ARB_gpu_shader_int64\0"
    "GL_ARB_imaging\0"
    "GL_ARB_indirect_parameters\0"
    "GL_ARB_instanced_arrays\0"
    "GL_ARB_internalformat_query\0"
    "GL_ARB_internalformat_query2\0"
    "GL_ARB_invalidate_subdata\0"
    "GL_ARB_map_buffer_range\0"
    "GL_ARB_matrix_palette\0"
    "GL_ARB_multi_bind\0"
    "GL_ARB_multi_draw_indirect\0"
    "GL_ARB_multisample\0"
    "GL_ARB_multitexture\0"
    "GL_ARB_occlusion_query\0"
    "GL_ARB_parallel_shader_compile\0"
    "GL_ARB_point_parameters\0"
    "GL_ARB_polygon_offset_clamp\0"
    "GL_ARB_program_interface_query\0"
    "GL_ARB_provoking_vertex\0"
    "GL_ARB_robustness\0"
    "GL_ARB_sample_locations\0"
    "GL_ARB_sample_shading\0"
    "GL_ARB_sampler_objects\0"
    "GL_ARB_separate_shader_objects\0"
    "GL_ARB_shader_atomic_counters\0"
    "GL_ARB_shader_image_load_store\0"
    "GL_ARB_shader_objects\0"
    "GL_ARB_shader_storage_buffer_object\0"
    "GL_ARB_shader_subroutine\0"
    "GL_ARB_shading_language_include\0"
    "GL_ARB_sparse_buffer\0"
    "GL_ARB_sparse_texture\0"
    "GL_ARB_sync\0"
    "GL_ARB_tessellation_shader\0"
    "GL_ARB_texture_barrier\0"
    "GL_ARB_texture_buffer_object\0"
    "GL_ARB_texture_buffer_range\0"
    "GL_ARB_texture_compression\0"
    "GL_ARB_texture_multisample\0"
    "GL_ARB_texture_storage\0"
    "GL_ARB_texture_storage_multisample\0"
    "GL_ARB_texture_view\0"
    "GL_ARB_timer_query\0"
    "GL_ARB_transform_feedback2\0"
    "GL_ARB_transform_feedback3\0"
    "GL_ARB_transform_feedback_instanced\0"
    "GL_ARB_transpose_matrix\0"
    "GL_ARB_uniform_buffer_object\0"
    "GL_ARB_vertex_array_object\0"
    "GL_ARB_vertex_attrib_64bit\0"
    "GL_ARB_vertex_attrib_binding\0"
    "GL_ARB_vertex_blend\0"
    "GL_ARB_vertex_buffer_object\0"
    "GL_ARB_vertex_program\0"
    "GL_ARB_vertex_shader\0"
    "GL_ARB_vertex_type_2_10_10_10_rev\0"
    "GL_ARB_viewport_array\0"
    "GL_ARB_window_pos\0"
    "GL_ATI_draw_buffers\0"
    "GL_ATI_element_array\0"
    "GL_ATI_envmap_bumpmap\0"
    "GL_ATI_fragment_shader\0"
    "GL_ATI_map_object_buffer\0"
    "GL_ATI_pn_triangles\0"
    "GL_ATI_separate_stencil\0"
    "GL_ATI_vertex_array_object\0"
    "GL_ATI_vertex_attrib_array_object\0"
    "GL_ATI_vertex_streams\0"
    "GL_EXT_EGL_image_storage\0"
    "GL_EXT_base_instance\0"
    "GL_EXT_bindable_uniform\0"
    "GL_EXT_blend_color\0"
    "GL_EXT_blend_equation_separate\0"
    "GL_EXT_blend_func_extended\0"
    "GL_EXT_blend_func_separate\0"
    "GL_EXT_blend_minmax\0"
    "GL_EXT_buffer_storage\0"
    "GL_EXT_clear_texture\0"
    "GL_EXT_clip_control\0"
    "GL_EXT_color_subtable\0"
    "GL_EXT_compiled_vertex_array\0"
    "GL_EXT_convolution\0"
    "GL_EXT_coordinate_frame\0"
    "GL_EXT_copy_image\0"
    "GL_EXT_copy_texture\0"
    "GL_EXT_cull_vertex\0"
    "GL_EXT_debug_label\0"
    "GL_EXT_debug_marker\0"
    "GL_EXT_depth_bounds_test\0"
    "GL_EXT_direct_state_access\0"
    "GL_EXT_discard_framebuffer\0"
    "GL_EXT_disjoint_timer_query\0"
    "GL_EXT_draw_buffers\0"
    "GL_EXT_draw_buffers2\0"
    "GL_EXT_draw_buffers_indexed\0"
    "GL_EXT_draw_elements_base_vertex\0"
    "GL_EXT_draw_instanced\0"
    "GL_EXT_draw_range_elements\0"
    "GL_EXT_draw_transform_feedback\0"
    "GL_EXT_external_buffer\0"
    "GL_EXT_fog_coord\0"
    "GL_EXT_framebuffer_blit\0"
    "GL_EXT_framebuffer_multisample\0"
    "GL_EXT_framebuffer_object\0"
    "GL_EXT_geometry_shader\0"
    "GL_EXT_geometry_shader4\0"
    "GL_EXT_gpu_program_parameters\0"
    "GL_EXT_gpu_shader4\0"
    "GL_EXT_histogram\0"
    "GL_EXT_index_func\0"
    "GL_EXT_index_material\0"
    "GL_EXT_instanced_arrays\0"
    "GL_EXT_light_texture\0"
    "GL_EXT_map_buffer_range\0"
    "GL_EXT_memory_object\0"
    "GL_EXT_memory_object_fd\0"
    "GL_EXT_memory_object_win32\0"
    "GL_EXT_multi_draw_arrays\0"
    "GL_EXT_multi_draw_indirect\0"
    "GL_EXT_multisample\0"
    "GL_EXT_multisampled_render_to_texture\0"
    "GL_EXT_multiview_draw_buffers\0"
    "GL_EXT_occlusion_query_boolean\0"
    "GL_EXT_paletted_texture\0"
    "GL_EXT_pixel_transform\0"
    "GL_EXT_point_parameters\0"
    "GL_EXT_polygon_offset\0"
    "GL_EXT_polygon_offset_clamp\0"
    "GL_EXT_primitive_bounding_box\0"
    "GL_EXT_provoking_vertex\0"
    "GL_EXT_raster_multisample\0"
    "GL_EXT_robustness\0"
    "GL_EXT_secondary_color\0"
    "GL_EXT_semaphore\0"
    "GL_EXT_semaphore_fd\0"
    "GL_EXT_semaphore_win32\0"
    "GL_EXT_separate_shader_objects\0"
    "GL_EXT_shader_framebuffer_fetch_non_coherent\0"
    "GL_EXT_shader_image_load_store\0"
    "GL_EXT_shader_pixel_local_storage2\0"
    "GL_EXT_sparse_texture\0"
    "GL_EXT_stencil_clear_tag\0"
    "GL_EXT_stencil_two_side\0"
    "GL_EXT_subtexture\0"
    "GL_EXT_tessellation_shader\0"
    "GL_EXT_texture3D\0"
    "GL_EXT_texture_array\0"
    "GL_EXT_texture_border_clamp\0"
    "GL_EXT_texture_buffer\0"
    "GL_EXT_texture_buffer_object\0"
    "GL_EXT_texture_integer\0"
    "GL_EXT_texture_object\0"
    "GL_EXT_texture_perturb_normal\0"
    "GL_EXT_texture_storage\0"
    "GL_EXT_texture_view\0"
    "GL_EXT_timer_query\0"
    "GL_EXT_transform_feedback\0"
    "GL_EXT_vertex_array\0"
    "GL_EXT_vertex_attrib_64bit\0"
    "GL_EXT_vertex_shader\0"
    "GL_EXT_vertex_weighting\0"
    "GL_EXT_win32_keyed_mutex\0"
    "GL_EXT_window_rectangles\0"
    "GL_EXT_x11_sync_object\0"
    "GL_GREMEDY_frame_terminator\0"
    "GL_GREMEDY_string_marker\0"
    "GL_HP_image_transform\0"
    "GL_IBM_multimode_draw_arrays\0"
    "GL_IBM_static_data\0"
    "GL_IBM_vertex_array_lists\0"
    "GL_IMG_bindless_texture\0"
    "GL_IMG_framebuffer_downsample\0"
    "GL_IMG_multisampled_render_to_texture\0"
    "GL_IMG_user_clip_plane\0"
    "GL_INGR_blend_func_separate\0"
    "GL_INTEL_framebuffer_CMAA\0"
    "GL_INTEL_map_texture\0"
    "GL_INTEL_parallel_arrays\0"
    "GL_INTEL_performance_query\0"
    "GL_KHR_blend_equation_advanced\0"
    "GL_KHR_debug\0"
    "GL_KHR_parallel_shader_compile\0"
    "GL_KHR_robustness\0"
    "GL_MESA_framebuffer_flip_y\0"
    "GL_MESA_resize_buffers\0"
    "GL_MESA_window_pos\0"
    "GL_NVX_conditional_render\0"
    "GL_NVX_gpu_multicast2\0"
    "GL_NVX_linked_gpu_multicast\0"
    "GL_NVX_progress_fence\0"
    "GL_NV_alpha_to_coverage_dither_control\0"
    "GL_NV_bindless_multi_draw_indirect\0"
    "GL_NV_bindless_multi_draw_indirect_count\0"
    "GL_NV_bindless_texture\0"
    "GL_NV_blend_equation_advanced\0"
    "GL_NV_clip_space_w_scaling\0"
    "GL_NV_command_list\0"
    "GL_NV_conditional_render\0"
    "GL_NV_conservative_raster\0"
    "GL_NV_conservative_raster_dilate\0"
    "GL_NV_conservative_raster_pre_snap_triangles\0"
    "GL_NV_copy_buffer\0"
    "GL_NV_copy_image\0"
    "GL_NV_coverage_sample\0"
    "GL_NV_depth_buffer_float\0"
    "GL_NV_draw_buffers\0"
    "GL_NV_draw_instanced\0"
    "GL_NV_draw_texture\0"
    "GL_NV_draw_vulkan_image\0"
    "GL_NV_evaluators\0"
    "GL_NV_explicit_multisample\0"
    "GL_NV_fence\0"
    "GL_NV_fragment_coverage_to_color\0"
    "GL_NV_fragment_program\0"
    "GL_NV_framebuffer_blit\0"
    "GL_NV_framebuffer_mixed_samples\0"
    "GL_NV_framebuffer_multisample\0"
    "GL_NV_framebuffer_multisample_coverage\0"
    "GL_NV_geometry_program4\0"
    "GL_NV_gpu_multicast\0"
    "GL_NV_gpu_program4\0"
    "GL_NV_gpu_program5\0"
    "GL_NV_gpu_shader5\0"
    "GL_NV_half_float\0"
    "GL_NV_instanced_arrays\0"
    "GL_NV_internalformat_sample_query\0"
    "GL_NV_memory_attachment\0"
    "GL_NV_mesh_shader\0"
    "GL_NV_non_square_matrices\0"
    "GL_NV_occlusion_query\0"
    "GL_NV_parameter_buffer_object\0"
    "GL_NV_path_rendering\0"
    "GL_NV_pixel_data_range\0"
    "GL_NV_point_sprite\0"
    "GL_NV_polygon_mode\0"
    "GL_NV_present_video\0"
    "GL_NV_primitive_restart\0"
    "GL_NV_query_resource\0"
    "GL_NV_query_resource_tag\0"
    "GL_NV_read_buffer\0"
    "GL_NV_register_combiners\0"
    "GL_NV_register_combiners2\0"
    "GL_NV_sample_locations\0"
    "GL_NV_scissor_exclusive\0"
    "GL_NV_shader_buffer_load\0"
    "GL_NV_shading_rate_image\0"
    "GL_NV_texture_barrier\0"
    "GL_NV_texture_multisample\0"
    "GL_NV_transform_feedback\0"
    "GL_NV_transform_feedback2\0"
    "GL_NV_vdpau_interop\0"
    "GL_NV_vdpau_interop2\0"
    "GL_NV_vertex_array_range\0"
    "GL_NV_vertex_attrib_integer_64bit\0"
    "GL_NV_vertex_buffer_unified_memory\0"
    "GL_NV_vertex_program\0"
    "GL_NV_vertex_program4\0"
    "GL_NV_video_capture\0"
    "GL_NV_viewport_array\0"
    "GL_NV_viewport_swizzle\0"
    "GL_OES_EGL_image\0"
    "GL_OES_blend_equation_separate\0"
    "GL_OES_blend_func_separate\0"
    "GL_OES_blend_subtract\0"
    "GL_OES_byte_coordinates\0"
    "GL_OES_copy_image\0"
    "GL_OES_draw_buffers_indexed\0"
    "GL_OES_draw_elements_base_vertex\0"
    "GL_OES_draw_texture\0"
    "GL_OES_fixed_point\0"
    "GL_OES_framebuffer_object\0"
    "GL_OES_geometry_shader\0"
    "GL_OES_get_program_binary\0"
    "GL_OES_mapbuffer\0"
    "GL_OES_matrix_palette\0"
    "GL_OES_point_size_array\0"
    "GL_OES_primitive_bounding_box\0"
    "GL_OES_query_matrix\0"
    "GL_OES_sample_shading\0"
    "GL_OES_single_precision\0"
    "GL_OES_tessellation_shader\0"
    "GL_OES_texture_3D\0"
    "GL_OES_texture_border_clamp\0"
    "GL_OES_texture_buffer\0"
    "GL_OES_texture_cube_map\0"
    "GL_OES_texture_storage_multisample_2d_array\0"
    "GL_OES_texture_view\0"
    "GL_OES_vertex_array_object\0"
    "GL_OES_viewport_array\0"
    "GL_OVR_multiview\0"
    "GL_OVR_multiview_multisampled_render_to_texture\0"
    "GL_PGI_misc_hints\0"
    "GL_QCOM_alpha_test\0"
    "GL_QCOM_driver_control\0"
    "GL_QCOM_extended_get\0"
    "GL_QCOM_extended_get2\0"
    "GL_QCOM_framebuffer_foveated\0"
    "GL_QCOM_shader_framebuffer_fetch_noncoherent\0"
    "GL_QCOM_texture_foveated\0"
    "GL_QCOM_tiled_rendering\0"
    "GL_SGIS_detail_texture\0"
    "GL_SGIS_fog_function\0"
    "GL_SGIS_multisample\0"
    "GL_SGIS_pixel_texture\0"
    "GL_SGIS_point_parameters\0"
    "GL_SGIS_sharpen_texture\0"
    "GL_SGIS_texture4D\0"
    "GL_SGIS_texture_color_mask\0"
    "GL_SGIS_texture_filter4\0"
    "GL_SGIX_async\0"
    "GL_SGIX_flush_raster\0"
    "GL_SGIX_fragment_lighting\0"
    "GL_SGIX_framezoom\0"
    "GL_SGIX_igloo_interface\0"
    "GL_SGIX_instruments\0"
    "GL_SGIX_list_priority\0"
    "GL_SGIX_pixel_texture\0"
    "GL_SGIX_polynomial_ffd\0"
    "GL_SGIX_reference_plane\0"
    "GL_SGIX_sprite\0"
    "GL_SGIX_tag_sample_buffer\0"
    "GL_SGI_color_table\0"
    "GL_SUNX_constant_data\0"
    "GL_SUN_global_alpha\0"
    "GL_SUN_mesh_array\0"
    "GL_SUN_triangle_list\0"
    "GL_SUN_vertex\0"
    "OpenGL ES 1.0\0"
    "OpenGL ES 2.0\0"
    "OpenGL ES 3.0\0"
    "OpenGL ES 3.1\0"
    "OpenGL ES 3.2\0"
    "always present\0"
     ;

static const uint16_t enum_string_offsets[] = {
    -1, /* gl_provider_terminator, unused */
    0, /* Desktop OpenGL 1.0 */
    19, /* Desktop OpenGL 1.1 */
    38, /* Desktop OpenGL 1.2 */
    57, /* Desktop OpenGL 1.3 */
    76, /* Desktop OpenGL 1.4 */
    95, /* Desktop OpenGL 1.5 */
    114, /* Desktop OpenGL 2.0 */
    133, /* Desktop OpenGL 2.1 */
    152, /* Desktop OpenGL 3.0 */
    171, /* Desktop OpenGL 3.1 */
    190, /* Desktop OpenGL 3.2 */
    209, /* Desktop OpenGL 3.3 */
    228, /* Desktop OpenGL 4.0 */
    247, /* Desktop OpenGL 4.1 */
    266, /* Desktop OpenGL 4.2 */
    285, /* Desktop OpenGL 4.3 */
    304, /* Desktop OpenGL 4.4 */
    323, /* Desktop OpenGL 4.5 */
    342, /* Desktop OpenGL 4.6 */
    361, /* GL_3DFX_tbuffer */
    377, /* GL_AMD_debug_output */
    397, /* GL_AMD_draw_buffers_blend */
    423, /* GL_AMD_framebuffer_multisample_advanced */
    463, /* GL_AMD_framebuffer_sample_positions */
    499, /* GL_AMD_gpu_shader_int64 */
    523, /* GL_AMD_interleaved_elements */
    551, /* GL_AMD_multi_draw_indirect */
    578, /* GL_AMD_name_gen_delete */
    601, /* GL_AMD_occlusion_query_event */
    630, /* GL_AMD_performance_monitor */
    657, /* GL_AMD_sample_positions */
    681, /* GL_AMD_sparse_texture */
    703, /* GL_AMD_stencil_operation_extended */
    737, /* GL_AMD_vertex_shader_tessellator */
    770, /* GL_ANGLE_framebuffer_blit */
    796, /* GL_ANGLE_framebuffer_multisample */
    829, /* GL_ANGLE_instanced_arrays */
    855, /* GL_ANGLE_translated_shader_source */
    889, /* GL_APPLE_copy_texture_levels */
    918, /* GL_APPLE_element_array */
    941, /* GL_APPLE_fence */
    956, /* GL_APPLE_flush_buffer_range */
    984, /* GL_APPLE_framebuffer_multisample */
    1017, /* GL_APPLE_object_purgeable */
    1043, /* GL_APPLE_sync */
    1057, /* GL_APPLE_texture_range */
    1080, /* GL_APPLE_vertex_array_object */
    1109, /* GL_APPLE_vertex_array_range */
    1137, /* GL_APPLE_vertex_program_evaluators */
    1172, /* GL_ARB_ES2_compatibility */
    1197, /* GL_ARB_ES3_1_compatibility */
    1224, /* GL_ARB_ES3_2_compatibility */
    1251, /* GL_ARB_base_instance */
    1272, /* GL_ARB_bindless_texture */
    1296, /* GL_ARB_blend_func_extended */
    1323, /* GL_ARB_buffer_storage */
    1345, /* GL_ARB_cl_event */
    1361, /* GL_ARB_clear_buffer_object */
    1388, /* GL_ARB_clear_texture */
    1409, /* GL_ARB_clip_control */
    1429, /* GL_ARB_color_buffer_float */
    1455, /* GL_ARB_compute_shader */
    1477, /* GL_ARB_compute_variable_group_size */
    1512, /* GL_ARB_copy_buffer */
    1531, /* GL_ARB_copy_image */
    1549, /* GL_ARB_debug_output */
    1569, /* GL_ARB_direct_state_access */
    1596, /* GL_ARB_draw_buffers */
    1616, /* GL_ARB_draw_buffers_blend */
    1642, /* GL_ARB_draw_elements_base_vertex */
    1675, /* GL_ARB_draw_indirect */
    1696, /* GL_ARB_draw_instanced */
    1718, /* GL_ARB_fragment_program */
    1742, /* GL_ARB_framebuffer_no_attachments */
    1776, /* GL_ARB_framebuffer_object */
    1802, /* GL_ARB_geometry_shader4 */
    1826, /* GL_ARB_get_program_binary */
    1852, /* GL_ARB_get_texture_sub_image */
    1881, /* GL_ARB_gl_spirv */
    1897, /* GL_ARB_gpu_shader_fp64 */
    1920, /* GL_ARB_gpu_shader_int64 */
    1944, /* GL_ARB_imaging */
    1959, /* GL_ARB_indirect_parameters */
    1986, /* GL_ARB_instanced_arrays */
    2010, /* GL_ARB_internalformat_query */
    2038, /* GL_ARB_internalformat_query2 */
    2067, /* GL_ARB_invalidate_subdata */
    2093, /* GL_ARB_map_buffer_range */
    2117, /* GL_ARB_matrix_palette */
    2139, /* GL_ARB_multi_bind */
    2157, /* GL_ARB_multi_draw_indirect */
    2184, /* GL_ARB_multisample */
    2203, /* GL_ARB_multitexture */
    2223, /* GL_ARB_occlusion_query */
    2246, /* GL_ARB_parallel_shader_compile */
    2277, /* GL_ARB_point_parameters */
    2301, /* GL_ARB_polygon_offset_clamp */
    2329, /* GL_ARB_program_interface_query */
    2360, /* GL_ARB_provoking_vertex */
    2384, /* GL_ARB_robustness */
    2402, /* GL_ARB_sample_locations */
    2426, /* GL_ARB_sample_shading */
    2448, /* GL_ARB_sampler_objects */
    2471, /* GL_ARB_separate_shader_objects */
    2502, /* GL_ARB_shader_atomic_counters */
    2532, /* GL_ARB_shader_image_load_store */
    2563, /* GL_ARB_shader_objects */
    2585, /* GL_ARB_shader_storage_buffer_object */
    2621, /* GL_ARB_shader_subroutine */
    2646, /* GL_ARB_shading_language_include */
    2678, /* GL_ARB_sparse_buffer */
    2699, /* GL_ARB_sparse_texture */
    2721, /* GL_ARB_sync */
    2733, /* GL_ARB_tessellation_shader */
    2760, /* GL_ARB_texture_barrier */
    2783, /* GL_ARB_texture_buffer_object */
    2812, /* GL_ARB_texture_buffer_range */
    2840, /* GL_ARB_texture_compression */
    2867, /* GL_ARB_texture_multisample */
    2894, /* GL_ARB_texture_storage */
    2917, /* GL_ARB_texture_storage_multisample */
    2952, /* GL_ARB_texture_view */
    2972, /* GL_ARB_timer_query */
    2991, /* GL_ARB_transform_feedback2 */
    3018, /* GL_ARB_transform_feedback3 */
    3045, /* GL_ARB_transform_feedback_instanced */
    3081, /* GL_ARB_transpose_matrix */
    3105, /* GL_ARB_uniform_buffer_object */
    3134, /* GL_ARB_vertex_array_object */
    3161, /* GL_ARB_vertex_attrib_64bit */
    3188, /* GL_ARB_vertex_attrib_binding */
    3217, /* GL_ARB_vertex_blend */
    3237, /* GL_ARB_vertex_buffer_object */
    3265, /* GL_ARB_vertex_program */
    3287, /* GL_ARB_vertex_shader */
    3308, /* GL_ARB_vertex_type_2_10_10_10_rev */
    3342, /* GL_ARB_viewport_array */
    3364, /* GL_ARB_window_pos */
    3382, /* GL_ATI_draw_buffers */
    3402, /* GL_ATI_element_array */
    3423, /* GL_ATI_envmap_bumpmap */
    3445, /* GL_ATI_fragment_shader */
    3468, /* GL_ATI_map_object_buffer */
    3493, /* GL_ATI_pn_triangles */
    3513, /* GL_ATI_separate_stencil */
    3537, /* GL_ATI_vertex_array_object */
    3564, /* GL_ATI_vertex_attrib_array_object */
    3598, /* GL_ATI_vertex_streams */
    3620, /* GL_EXT_EGL_image_storage */
    3645, /* GL_EXT_base_instance */
    3666, /* GL_EXT_bindable_uniform */
    3690, /* GL_EXT_blend_color */
    3709, /* GL_EXT_blend_equation_separate */
    3740, /* GL_EXT_blend_func_extended */
    3767, /* GL_EXT_blend_func_separate */
    3794, /* GL_EXT_blend_minmax */
    3814, /* GL_EXT_buffer_storage */
    3836, /* GL_EXT_clear_texture */
    3857, /* GL_EXT_clip_control */
    3877, /* GL_EXT_color_subtable */
    3899, /* GL_EXT_compiled_vertex_array */
    3928, /* GL_EXT_convolution */
    3947, /* GL_EXT_coordinate_frame */
    3971, /* GL_EXT_copy_image */
    3989, /* GL_EXT_copy_texture */
    4009, /* GL_EXT_cull_vertex */
    4028, /* GL_EXT_debug_label */
    4047, /* GL_EXT_debug_marker */
    4067, /* GL_EXT_depth_bounds_test */
    4092, /* GL_EXT_direct_state_access */
    4119, /* GL_EXT_discard_framebuffer */
    4146, /* GL_EXT_disjoint_timer_query */
    4174, /* GL_EXT_draw_buffers */
    4194, /* GL_EXT_draw_buffers2 */
    4215, /* GL_EXT_draw_buffers_indexed */
    4243, /* GL_EXT_draw_elements_base_vertex */
    4276, /* GL_EXT_draw_instanced */
    4298, /* GL_EXT_draw_range_elements */
    4325, /* GL_EXT_draw_transform_feedback */
    4356, /* GL_EXT_external_buffer */
    4379, /* GL_EXT_fog_coord */
    4396, /* GL_EXT_framebuffer_blit */
    4420, /* GL_EXT_framebuffer_multisample */
    4451, /* GL_EXT_framebuffer_object */
    4477, /* GL_EXT_geometry_shader */
    4500, /* GL_EXT_geometry_shader4 */
    4524, /* GL_EXT_gpu_program_parameters */
    4554, /* GL_EXT_gpu_shader4 */
    4573, /* GL_EXT_histogram */
    4590, /* GL_EXT_index_func */
    4608, /* GL_EXT_index_material */
    4630, /* GL_EXT_instanced_arrays */
    4654, /* GL_EXT_light_texture */
    4675, /* GL_EXT_map_buffer_range */
    4699, /* GL_EXT_memory_object */
    4720, /* GL_EXT_memory_object_fd */
    4744, /* GL_EXT_memory_object_win32 */
    4771, /* GL_EXT_multi_draw_arrays */
    4796, /* GL_EXT_multi_draw_indirect */
    4823, /* GL_EXT_multisample */
    4842, /* GL_EXT_multisampled_render_to_texture */
    4880, /* GL_EXT_multiview_draw_buffers */
    4910, /* GL_EXT_occlusion_query_boolean */
    4941, /* GL_EXT_paletted_texture */
    4965, /* GL_EXT_pixel_transform */
    4988, /* GL_EXT_point_parameters */
    5012, /* GL_EXT_polygon_offset */
    5034, /* GL_EXT_polygon_offset_clamp */
    5062, /* GL_EXT_primitive_bounding_box */
    5092, /* GL_EXT_provoking_vertex */
    5116, /* GL_EXT_raster_multisample */
    5142, /* GL_EXT_robustness */
    5160, /* GL_EXT_secondary_color */
    5183, /* GL_EXT_semaphore */
    5200, /* GL_EXT_semaphore_fd */
    5220, /* GL_EXT_semaphore_win32 */
    5243, /* GL_EXT_separate_shader_objects */
    5274, /* GL_EXT_shader_framebuffer_fetch_non_coherent */
    5319, /* GL_EXT_shader_image_load_store */
    5350, /* GL_EXT_shader_pixel_local_storage2 */
    5385, /* GL_EXT_sparse_texture */
    5407, /* GL_EXT_stencil_clear_tag */
    5432, /* GL_EXT_stencil_two_side */
    5456, /* GL_EXT_subtexture */
    5474, /* GL_EXT_tessellation_shader */
    5501, /* GL_EXT_texture3D */
    5518, /* GL_EXT_texture_array */
    5539, /* GL_EXT_texture_border_clamp */
    5567, /* GL_EXT_texture_buffer */
    5589, /* GL_EXT_texture_buffer_object */
    5618, /* GL_EXT_texture_integer */
    5641, /* GL_EXT_texture_object */
    5663, /* GL_EXT_texture_perturb_normal */
    5693, /* GL_EXT_texture_storage */
    5716, /* GL_EXT_texture_view */
    5736, /* GL_EXT_timer_query */
    5755, /* GL_EXT_transform_feedback */
    5781, /* GL_EXT_vertex_array */
    5801, /* GL_EXT_vertex_attrib_64bit */
    5828, /* GL_EXT_vertex_shader */
    5849, /* GL_EXT_vertex_weighting */
    5873, /* GL_EXT_win32_keyed_mutex */
    5898, /* GL_EXT_window_rectangles */
    5923, /* GL_EXT_x11_sync_object */
    5946, /* GL_GREMEDY_frame_terminator */
    5974, /* GL_GREMEDY_string_marker */
    5999, /* GL_HP_image_transform */
    6021, /* GL_IBM_multimode_draw_arrays */
    6050, /* GL_IBM_static_data */
    6069, /* GL_IBM_vertex_array_lists */
    6095, /* GL_IMG_bindless_texture */
    6119, /* GL_IMG_framebuffer_downsample */
    6149, /* GL_IMG_multisampled_render_to_texture */
    6187, /* GL_IMG_user_clip_plane */
    6210, /* GL_INGR_blend_func_separate */
    6238, /* GL_INTEL_framebuffer_CMAA */
    6264, /* GL_INTEL_map_texture */
    6285, /* GL_INTEL_parallel_arrays */
    6310, /* GL_INTEL_performance_query */
    6337, /* GL_KHR_blend_equation_advanced */
    6368, /* GL_KHR_debug */
    6381, /* GL_KHR_parallel_shader_compile */
    6412, /* GL_KHR_robustness */
    6430, /* GL_MESA_framebuffer_flip_y */
    6457, /* GL_MESA_resize_buffers */
    6480, /* GL_MESA_window_pos */
    6499, /* GL_NVX_conditional_render */
    6525, /* GL_NVX_gpu_multicast2 */
    6547, /* GL_NVX_linked_gpu_multicast */
    6575, /* GL_NVX_progress_fence */
    6597, /* GL_NV_alpha_to_coverage_dither_control */
    6636, /* GL_NV_bindless_multi_draw_indirect */
    6671, /* GL_NV_bindless_multi_draw_indirect_count */
    6712, /* GL_NV_bindless_texture */
    6735, /* GL_NV_blend_equation_advanced */
    6765, /* GL_NV_clip_space_w_scaling */
    6792, /* GL_NV_command_list */
    6811, /* GL_NV_conditional_render */
    6836, /* GL_NV_conservative_raster */
    6862, /* GL_NV_conservative_raster_dilate */
    6895, /* GL_NV_conservative_raster_pre_snap_triangles */
    6940, /* GL_NV_copy_buffer */
    6958, /* GL_NV_copy_image */
    6975, /* GL_NV_coverage_sample */
    6997, /* GL_NV_depth_buffer_float */
    7022, /* GL_NV_draw_buffers */
    7041, /* GL_NV_draw_instanced */
    7062, /* GL_NV_draw_texture */
    7081, /* GL_NV_draw_vulkan_image */
    7105, /* GL_NV_evaluators */
    7122, /* GL_NV_explicit_multisample */
    7149, /* GL_NV_fence */
    7161, /* GL_NV_fragment_coverage_to_color */
    7194, /* GL_NV_fragment_program */
    7217, /* GL_NV_framebuffer_blit */
    7240, /* GL_NV_framebuffer_mixed_samples */
    7272, /* GL_NV_framebuffer_multisample */
    7302, /* GL_NV_framebuffer_multisample_coverage */
    7341, /* GL_NV_geometry_program4 */
    7365, /* GL_NV_gpu_multicast */
    7385, /* GL_NV_gpu_program4 */
    7404, /* GL_NV_gpu_program5 */
    7423, /* GL_NV_gpu_shader5 */
    7441, /* GL_NV_half_float */
    7458, /* GL_NV_instanced_arrays */
    7481, /* GL_NV_internalformat_sample_query */
    7515, /* GL_NV_memory_attachment */
    7539, /* GL_NV_mesh_shader */
    7557, /* GL_NV_non_square_matrices */
    7583, /* GL_NV_occlusion_query */
    7605, /* GL_NV_parameter_buffer_object */
    7635, /* GL_NV_path_rendering */
    7656, /* GL_NV_pixel_data_range */
    7679, /* GL_NV_point_sprite */
    7698, /* GL_NV_polygon_mode */
    7717, /* GL_NV_present_video */
    7737, /* GL_NV_primitive_restart */
    7761, /* GL_NV_query_resource */
    7782, /* GL_NV_query_resource_tag */
    7807, /* GL_NV_read_buffer */
    7825, /* GL_NV_register_combiners */
    7850, /* GL_NV_register_combiners2 */
    7876, /* GL_NV_sample_locations */
    7899, /* GL_NV_scissor_exclusive */
    7923, /* GL_NV_shader_buffer_load */
    7948, /* GL_NV_shading_rate_image */
    7973, /* GL_NV_texture_barrier */
    7995, /* GL_NV_texture_multisample */
    8021, /* GL_NV_transform_feedback */
    8046, /* GL_NV_transform_feedback2 */
    8072, /* GL_NV_vdpau_interop */
    8092, /* GL_NV_vdpau_interop2 */
    8113, /* GL_NV_vertex_array_range */
    8138, /* GL_NV_vertex_attrib_integer_64bit */
    8172, /* GL_NV_vertex_buffer_unified_memory */
    8207, /* GL_NV_vertex_program */
    8228, /* GL_NV_vertex_program4 */
    8250, /* GL_NV_video_capture */
    8270, /* GL_NV_viewport_array */
    8291, /* GL_NV_viewport_swizzle */
    8314, /* GL_OES_EGL_image */
    8331, /* GL_OES_blend_equation_separate */
    8362, /* GL_OES_blend_func_separate */
    8389, /* GL_OES_blend_subtract */
    8411, /* GL_OES_byte_coordinates */
    8435, /* GL_OES_copy_image */
    8453, /* GL_OES_draw_buffers_indexed */
    8481, /* GL_OES_draw_elements_base_vertex */
    8514, /* GL_OES_draw_texture */
    8534, /* GL_OES_fixed_point */
    8553, /* GL_OES_framebuffer_object */
    8579, /* GL_OES_geometry_shader */
    8602, /* GL_OES_get_program_binary */
    8628, /* GL_OES_mapbuffer */
    8645, /* GL_OES_matrix_palette */
    8667, /* GL_OES_point_size_array */
    8691, /* GL_OES_primitive_bounding_box */
    8721, /* GL_OES_query_matrix */
    8741, /* GL_OES_sample_shading */
    8763, /* GL_OES_single_precision */
    8787, /* GL_OES_tessellation_shader */
    8814, /* GL_OES_texture_3D */
    8832, /* GL_OES_texture_border_clamp */
    8860, /* GL_OES_texture_buffer */
    8882, /* GL_OES_texture_cube_map */
    8906, /* GL_OES_texture_storage_multisample_2d_array */
    8950, /* GL_OES_texture_view */
    8970, /* GL_OES_vertex_array_object */
    8997, /* GL_OES_viewport_array */
    9019, /* GL_OVR_multiview */
    9036, /* GL_OVR_multiview_multisampled_render_to_texture */
    9084, /* GL_PGI_misc_hints */
    9102, /* GL_QCOM_alpha_test */
    9121, /* GL_QCOM_driver_control */
    9144, /* GL_QCOM_extended_get */
    9165, /* GL_QCOM_extended_get2 */
    9187, /* GL_QCOM_framebuffer_foveated */
    9216, /* GL_QCOM_shader_framebuffer_fetch_noncoherent */
    9261, /* GL_QCOM_texture_foveated */
    9286, /* GL_QCOM_tiled_rendering */
    9310, /* GL_SGIS_detail_texture */
    9333, /* GL_SGIS_fog_function */
    9354, /* GL_SGIS_multisample */
    9374, /* GL_SGIS_pixel_texture */
    9396, /* GL_SGIS_point_parameters */
    9421, /* GL_SGIS_sharpen_texture */
    9445, /* GL_SGIS_texture4D */
    9463, /* GL_SGIS_texture_color_mask */
    9490, /* GL_SGIS_texture_filter4 */
    9514, /* GL_SGIX_async */
    9528, /* GL_SGIX_flush_raster */
    9549, /* GL_SGIX_fragment_lighting */
    9575, /* GL_SGIX_framezoom */
    9593, /* GL_SGIX_igloo_interface */
    9617, /* GL_SGIX_instruments */
    9637, /* GL_SGIX_list_priority */
    9659, /* GL_SGIX_pixel_texture */
    9681, /* GL_SGIX_polynomial_ffd */
    9704, /* GL_SGIX_reference_plane */
    9728, /* GL_SGIX_sprite */
    9743, /* GL_SGIX_tag_sample_buffer */
    9769, /* GL_SGI_color_table */
    9788, /* GL_SUNX_constant_data */
    9810, /* GL_SUN_global_alpha */
    9830, /* GL_SUN_mesh_array */
    9848, /* GL_SUN_triangle_list */
    9869, /* GL_SUN_vertex */
    9883, /* OpenGL ES 1.0 */
    9897, /* OpenGL ES 2.0 */
    9911, /* OpenGL ES 3.0 */
    9925, /* OpenGL ES 3.1 */
    9939, /* OpenGL ES 3.2 */
    9953, /* always present */
};

static const char entrypoint_strings[] = {
   'g',
   'l',
   'A',
   'c',
   'c',
   'u',
   'm',
   0, // glAccum
   'g',
   'l',
   'A',
   'c',
   'c',
   'u',
   'm',
   'x',
   'O',
   'E',
   'S',
   0, // glAccumxOES
   'g',
   'l',
   'A',
   'c',
   'q',
   'u',
   'i',
   'r',
   'e',
   'K',
   'e',
   'y',
   'e',
   'd',
   'M',
   'u',
   't',
   'e',
   'x',
   'W',
   'i',
   'n',
   '3',
   '2',
   'E',
   'X',
   'T',
   0, // glAcquireKeyedMutexWin32EXT
   'g',
   'l',
   'A',
   'c',
   't',
   'i',
   'v',
   'e',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'E',
   'X',
   'T',
   0, // glActiveProgramEXT
   'g',
   'l',
   'A',
   'c',
   't',
   'i',
   'v',
   'e',
   'S',
   'h',
   'a',
   'd',
   'e',
   'r',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   0, // glActiveShaderProgram
   'g',
   'l',
   'A',
   'c',
   't',
   'i',
   'v',
   'e',
   'S',
   'h',
   'a',
   'd',
   'e',
   'r',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'E',
   'X',
   'T',
   0, // glActiveShaderProgramEXT
   'g',
   'l',
   'A',
   'c',
   't',
   'i',
   'v',
   'e',
   'S',
   't',
   'e',
   'n',
   'c',
   'i',
   'l',
   'F',
   'a',
   'c',
   'e',
   'E',
   'X',
   'T',
   0, // glActiveStencilFaceEXT
   'g',
   'l',
   'A',
   'c',
   't',
   'i',
   'v',
   'e',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   0, // glActiveTexture
   'g',
   'l',
   'A',
   'c',
   't',
   'i',
   'v',
   'e',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'A',
   'R',
   'B',
   0, // glActiveTextureARB
   'g',
   'l',
   'A',
   'c',
   't',
   'i',
   'v',
   'e',
   'V',
   'a',
   'r',
   'y',
   'i',
   'n',
   'g',
   'N',
   'V',
   0, // glActiveVaryingNV
   'g',
   'l',
   'A',
   'l',
   'p',
   'h',
   'a',
   'F',
   'r',
   'a',
   'g',
   'm',
   'e',
   'n',
   't',
   'O',
   'p',
   '1',
   'A',
   'T',
   'I',
   0, // glAlphaFragmentOp1ATI
   'g',
   'l',
   'A',
   'l',
   'p',
   'h',
   'a',
   'F',
   'r',
   'a',
   'g',
   'm',
   'e',
   'n',
   't',
   'O',
   'p',
   '2',
   'A',
   'T',
   'I',
   0, // glAlphaFragmentOp2ATI
   'g',
   'l',
   'A',
   'l',
   'p',
   'h',
   'a',
   'F',
   'r',
   'a',
   'g',
   'm',
   'e',
   'n',
   't',
   'O',
   'p',
   '3',
   'A',
   'T',
   'I',
   0, // glAlphaFragmentOp3ATI
   'g',
   'l',
   'A',
   'l',
   'p',
   'h',
   'a',
   'F',
   'u',
   'n',
   'c',
   0, // glAlphaFunc
   'g',
   'l',
   'A',
   'l',
   'p',
   'h',
   'a',
   'F',
   'u',
   'n',
   'c',
   'Q',
   'C',
   'O',
   'M',
   0, // glAlphaFuncQCOM
   'g',
   'l',
   'A',
   'l',
   'p',
   'h',
   'a',
   'F',
   'u',
   'n',
   'c',
   'x',
   0, // glAlphaFuncx
   'g',
   'l',
   'A',
   'l',
   'p',
   'h',
   'a',
   'F',
   'u',
   'n',
   'c',
   'x',
   'O',
   'E',
   'S',
   0, // glAlphaFuncxOES
   'g',
   'l',
   'A',
   'l',
   'p',
   'h',
   'a',
   'T',
   'o',
   'C',
   'o',
   'v',
   'e',
   'r',
   'a',
   'g',
   'e',
   'D',
   'i',
   't',
   'h',
   'e',
   'r',
   'C',
   'o',
   'n',
   't',
   'r',
   'o',
   'l',
   'N',
   'V',
   0, // glAlphaToCoverageDitherControlNV
   'g',
   'l',
   'A',
   'p',
   'p',
   'l',
   'y',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'A',
   't',
   't',
   'a',
   'c',
   'h',
   'm',
   'e',
   'n',
   't',
   'C',
   'M',
   'A',
   'A',
   'I',
   'N',
   'T',
   'E',
   'L',
   0, // glApplyFramebufferAttachmentCMAAINTEL
   'g',
   'l',
   'A',
   'p',
   'p',
   'l',
   'y',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'E',
   'X',
   'T',
   0, // glApplyTextureEXT
   'g',
   'l',
   'A',
   'r',
   'e',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   's',
   'R',
   'e',
   's',
   'i',
   'd',
   'e',
   'n',
   't',
   'N',
   'V',
   0, // glAreProgramsResidentNV
   'g',
   'l',
   'A',
   'r',
   'e',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   's',
   'R',
   'e',
   's',
   'i',
   'd',
   'e',
   'n',
   't',
   0, // glAreTexturesResident
   'g',
   'l',
   'A',
   'r',
   'e',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   's',
   'R',
   'e',
   's',
   'i',
   'd',
   'e',
   'n',
   't',
   'E',
   'X',
   'T',
   0, // glAreTexturesResidentEXT
   'g',
   'l',
   'A',
   'r',
   'r',
   'a',
   'y',
   'E',
   'l',
   'e',
   'm',
   'e',
   'n',
   't',
   0, // glArrayElement
   'g',
   'l',
   'A',
   'r',
   'r',
   'a',
   'y',
   'E',
   'l',
   'e',
   'm',
   'e',
   'n',
   't',
   'E',
   'X',
   'T',
   0, // glArrayElementEXT
   'g',
   'l',
   'A',
   'r',
   'r',
   'a',
   'y',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'A',
   'T',
   'I',
   0, // glArrayObjectATI
   'g',
   'l',
   'A',
   's',
   'y',
   'n',
   'c',
   'C',
   'o',
   'p',
   'y',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   'u',
   'b',
   'D',
   'a',
   't',
   'a',
   'N',
   'V',
   'X',
   0, // glAsyncCopyBufferSubDataNVX
   'g',
   'l',
   'A',
   's',
   'y',
   'n',
   'c',
   'C',
   'o',
   'p',
   'y',
   'I',
   'm',
   'a',
   'g',
   'e',
   'S',
   'u',
   'b',
   'D',
   'a',
   't',
   'a',
   'N',
   'V',
   'X',
   0, // glAsyncCopyImageSubDataNVX
   'g',
   'l',
   'A',
   's',
   'y',
   'n',
   'c',
   'M',
   'a',
   'r',
   'k',
   'e',
   'r',
   'S',
   'G',
   'I',
   'X',
   0, // glAsyncMarkerSGIX
   'g',
   'l',
   'A',
   't',
   't',
   'a',
   'c',
   'h',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'A',
   'R',
   'B',
   0, // glAttachObjectARB
   'g',
   'l',
   'A',
   't',
   't',
   'a',
   'c',
   'h',
   'S',
   'h',
   'a',
   'd',
   'e',
   'r',
   0, // glAttachShader
   'g',
   'l',
   'B',
   'e',
   'g',
   'i',
   'n',
   0, // glBegin
   'g',
   'l',
   'B',
   'e',
   'g',
   'i',
   'n',
   'C',
   'o',
   'n',
   'd',
   'i',
   't',
   'i',
   'o',
   'n',
   'a',
   'l',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   0, // glBeginConditionalRender
   'g',
   'l',
   'B',
   'e',
   'g',
   'i',
   'n',
   'C',
   'o',
   'n',
   'd',
   'i',
   't',
   'i',
   'o',
   'n',
   'a',
   'l',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'N',
   'V',
   0, // glBeginConditionalRenderNV
   'g',
   'l',
   'B',
   'e',
   'g',
   'i',
   'n',
   'C',
   'o',
   'n',
   'd',
   'i',
   't',
   'i',
   'o',
   'n',
   'a',
   'l',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'N',
   'V',
   'X',
   0, // glBeginConditionalRenderNVX
   'g',
   'l',
   'B',
   'e',
   'g',
   'i',
   'n',
   'F',
   'r',
   'a',
   'g',
   'm',
   'e',
   'n',
   't',
   'S',
   'h',
   'a',
   'd',
   'e',
   'r',
   'A',
   'T',
   'I',
   0, // glBeginFragmentShaderATI
   'g',
   'l',
   'B',
   'e',
   'g',
   'i',
   'n',
   'O',
   'c',
   'c',
   'l',
   'u',
   's',
   'i',
   'o',
   'n',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'N',
   'V',
   0, // glBeginOcclusionQueryNV
   'g',
   'l',
   'B',
   'e',
   'g',
   'i',
   'n',
   'P',
   'e',
   'r',
   'f',
   'M',
   'o',
   'n',
   'i',
   't',
   'o',
   'r',
   'A',
   'M',
   'D',
   0, // glBeginPerfMonitorAMD
   'g',
   'l',
   'B',
   'e',
   'g',
   'i',
   'n',
   'P',
   'e',
   'r',
   'f',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'I',
   'N',
   'T',
   'E',
   'L',
   0, // glBeginPerfQueryINTEL
   'g',
   'l',
   'B',
   'e',
   'g',
   'i',
   'n',
   'Q',
   'u',
   'e',
   'r',
   'y',
   0, // glBeginQuery
   'g',
   'l',
   'B',
   'e',
   'g',
   'i',
   'n',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'A',
   'R',
   'B',
   0, // glBeginQueryARB
   'g',
   'l',
   'B',
   'e',
   'g',
   'i',
   'n',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'E',
   'X',
   'T',
   0, // glBeginQueryEXT
   'g',
   'l',
   'B',
   'e',
   'g',
   'i',
   'n',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'I',
   'n',
   'd',
   'e',
   'x',
   'e',
   'd',
   0, // glBeginQueryIndexed
   'g',
   'l',
   'B',
   'e',
   'g',
   'i',
   'n',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'F',
   'e',
   'e',
   'd',
   'b',
   'a',
   'c',
   'k',
   0, // glBeginTransformFeedback
   'g',
   'l',
   'B',
   'e',
   'g',
   'i',
   'n',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'F',
   'e',
   'e',
   'd',
   'b',
   'a',
   'c',
   'k',
   'E',
   'X',
   'T',
   0, // glBeginTransformFeedbackEXT
   'g',
   'l',
   'B',
   'e',
   'g',
   'i',
   'n',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'F',
   'e',
   'e',
   'd',
   'b',
   'a',
   'c',
   'k',
   'N',
   'V',
   0, // glBeginTransformFeedbackNV
   'g',
   'l',
   'B',
   'e',
   'g',
   'i',
   'n',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'S',
   'h',
   'a',
   'd',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glBeginVertexShaderEXT
   'g',
   'l',
   'B',
   'e',
   'g',
   'i',
   'n',
   'V',
   'i',
   'd',
   'e',
   'o',
   'C',
   'a',
   'p',
   't',
   'u',
   'r',
   'e',
   'N',
   'V',
   0, // glBeginVideoCaptureNV
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'L',
   'o',
   'c',
   'a',
   't',
   'i',
   'o',
   'n',
   0, // glBindAttribLocation
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'L',
   'o',
   'c',
   'a',
   't',
   'i',
   'o',
   'n',
   'A',
   'R',
   'B',
   0, // glBindAttribLocationARB
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   0, // glBindBuffer
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'A',
   'R',
   'B',
   0, // glBindBufferARB
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'B',
   'a',
   's',
   'e',
   0, // glBindBufferBase
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'B',
   'a',
   's',
   'e',
   'E',
   'X',
   'T',
   0, // glBindBufferBaseEXT
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'B',
   'a',
   's',
   'e',
   'N',
   'V',
   0, // glBindBufferBaseNV
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'O',
   'f',
   'f',
   's',
   'e',
   't',
   'E',
   'X',
   'T',
   0, // glBindBufferOffsetEXT
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'O',
   'f',
   'f',
   's',
   'e',
   't',
   'N',
   'V',
   0, // glBindBufferOffsetNV
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'R',
   'a',
   'n',
   'g',
   'e',
   0, // glBindBufferRange
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'R',
   'a',
   'n',
   'g',
   'e',
   'E',
   'X',
   'T',
   0, // glBindBufferRangeEXT
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'R',
   'a',
   'n',
   'g',
   'e',
   'N',
   'V',
   0, // glBindBufferRangeNV
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   's',
   'B',
   'a',
   's',
   'e',
   0, // glBindBuffersBase
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   's',
   'R',
   'a',
   'n',
   'g',
   'e',
   0, // glBindBuffersRange
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'F',
   'r',
   'a',
   'g',
   'D',
   'a',
   't',
   'a',
   'L',
   'o',
   'c',
   'a',
   't',
   'i',
   'o',
   'n',
   0, // glBindFragDataLocation
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'F',
   'r',
   'a',
   'g',
   'D',
   'a',
   't',
   'a',
   'L',
   'o',
   'c',
   'a',
   't',
   'i',
   'o',
   'n',
   'E',
   'X',
   'T',
   0, // glBindFragDataLocationEXT
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'F',
   'r',
   'a',
   'g',
   'D',
   'a',
   't',
   'a',
   'L',
   'o',
   'c',
   'a',
   't',
   'i',
   'o',
   'n',
   'I',
   'n',
   'd',
   'e',
   'x',
   'e',
   'd',
   0, // glBindFragDataLocationIndexed
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'F',
   'r',
   'a',
   'g',
   'D',
   'a',
   't',
   'a',
   'L',
   'o',
   'c',
   'a',
   't',
   'i',
   'o',
   'n',
   'I',
   'n',
   'd',
   'e',
   'x',
   'e',
   'd',
   'E',
   'X',
   'T',
   0, // glBindFragDataLocationIndexedEXT
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'F',
   'r',
   'a',
   'g',
   'm',
   'e',
   'n',
   't',
   'S',
   'h',
   'a',
   'd',
   'e',
   'r',
   'A',
   'T',
   'I',
   0, // glBindFragmentShaderATI
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   0, // glBindFramebuffer
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glBindFramebufferEXT
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'O',
   'E',
   'S',
   0, // glBindFramebufferOES
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'I',
   'm',
   'a',
   'g',
   'e',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   0, // glBindImageTexture
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'I',
   'm',
   'a',
   'g',
   'e',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'E',
   'X',
   'T',
   0, // glBindImageTextureEXT
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'I',
   'm',
   'a',
   'g',
   'e',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   's',
   0, // glBindImageTextures
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'L',
   'i',
   'g',
   'h',
   't',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glBindLightParameterEXT
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'M',
   'a',
   't',
   'e',
   'r',
   'i',
   'a',
   'l',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glBindMaterialParameterEXT
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'E',
   'X',
   'T',
   0, // glBindMultiTextureEXT
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glBindParameterEXT
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'A',
   'R',
   'B',
   0, // glBindProgramARB
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'N',
   'V',
   0, // glBindProgramNV
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'P',
   'i',
   'p',
   'e',
   'l',
   'i',
   'n',
   'e',
   0, // glBindProgramPipeline
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'P',
   'i',
   'p',
   'e',
   'l',
   'i',
   'n',
   'e',
   'E',
   'X',
   'T',
   0, // glBindProgramPipelineEXT
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   0, // glBindRenderbuffer
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glBindRenderbufferEXT
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'O',
   'E',
   'S',
   0, // glBindRenderbufferOES
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'r',
   0, // glBindSampler
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'r',
   's',
   0, // glBindSamplers
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'S',
   'h',
   'a',
   'd',
   'i',
   'n',
   'g',
   'R',
   'a',
   't',
   'e',
   'I',
   'm',
   'a',
   'g',
   'e',
   'N',
   'V',
   0, // glBindShadingRateImageNV
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'T',
   'e',
   'x',
   'G',
   'e',
   'n',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glBindTexGenParameterEXT
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   0, // glBindTexture
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'E',
   'X',
   'T',
   0, // glBindTextureEXT
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'U',
   'n',
   'i',
   't',
   0, // glBindTextureUnit
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'U',
   'n',
   'i',
   't',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glBindTextureUnitParameterEXT
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   's',
   0, // glBindTextures
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'F',
   'e',
   'e',
   'd',
   'b',
   'a',
   'c',
   'k',
   0, // glBindTransformFeedback
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'F',
   'e',
   'e',
   'd',
   'b',
   'a',
   'c',
   'k',
   'N',
   'V',
   0, // glBindTransformFeedbackNV
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   0, // glBindVertexArray
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'A',
   'P',
   'P',
   'L',
   'E',
   0, // glBindVertexArrayAPPLE
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'O',
   'E',
   'S',
   0, // glBindVertexArrayOES
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   0, // glBindVertexBuffer
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   's',
   0, // glBindVertexBuffers
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'S',
   'h',
   'a',
   'd',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glBindVertexShaderEXT
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'V',
   'i',
   'd',
   'e',
   'o',
   'C',
   'a',
   'p',
   't',
   'u',
   'r',
   'e',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'N',
   'V',
   0, // glBindVideoCaptureStreamBufferNV
   'g',
   'l',
   'B',
   'i',
   'n',
   'd',
   'V',
   'i',
   'd',
   'e',
   'o',
   'C',
   'a',
   'p',
   't',
   'u',
   'r',
   'e',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'N',
   'V',
   0, // glBindVideoCaptureStreamTextureNV
   'g',
   'l',
   'B',
   'i',
   'n',
   'o',
   'r',
   'm',
   'a',
   'l',
   '3',
   'b',
   'E',
   'X',
   'T',
   0, // glBinormal3bEXT
   'g',
   'l',
   'B',
   'i',
   'n',
   'o',
   'r',
   'm',
   'a',
   'l',
   '3',
   'b',
   'v',
   'E',
   'X',
   'T',
   0, // glBinormal3bvEXT
   'g',
   'l',
   'B',
   'i',
   'n',
   'o',
   'r',
   'm',
   'a',
   'l',
   '3',
   'd',
   'E',
   'X',
   'T',
   0, // glBinormal3dEXT
   'g',
   'l',
   'B',
   'i',
   'n',
   'o',
   'r',
   'm',
   'a',
   'l',
   '3',
   'd',
   'v',
   'E',
   'X',
   'T',
   0, // glBinormal3dvEXT
   'g',
   'l',
   'B',
   'i',
   'n',
   'o',
   'r',
   'm',
   'a',
   'l',
   '3',
   'f',
   'E',
   'X',
   'T',
   0, // glBinormal3fEXT
   'g',
   'l',
   'B',
   'i',
   'n',
   'o',
   'r',
   'm',
   'a',
   'l',
   '3',
   'f',
   'v',
   'E',
   'X',
   'T',
   0, // glBinormal3fvEXT
   'g',
   'l',
   'B',
   'i',
   'n',
   'o',
   'r',
   'm',
   'a',
   'l',
   '3',
   'i',
   'E',
   'X',
   'T',
   0, // glBinormal3iEXT
   'g',
   'l',
   'B',
   'i',
   'n',
   'o',
   'r',
   'm',
   'a',
   'l',
   '3',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glBinormal3ivEXT
   'g',
   'l',
   'B',
   'i',
   'n',
   'o',
   'r',
   'm',
   'a',
   'l',
   '3',
   's',
   'E',
   'X',
   'T',
   0, // glBinormal3sEXT
   'g',
   'l',
   'B',
   'i',
   'n',
   'o',
   'r',
   'm',
   'a',
   'l',
   '3',
   's',
   'v',
   'E',
   'X',
   'T',
   0, // glBinormal3svEXT
   'g',
   'l',
   'B',
   'i',
   'n',
   'o',
   'r',
   'm',
   'a',
   'l',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glBinormalPointerEXT
   'g',
   'l',
   'B',
   'i',
   't',
   'm',
   'a',
   'p',
   0, // glBitmap
   'g',
   'l',
   'B',
   'i',
   't',
   'm',
   'a',
   'p',
   'x',
   'O',
   'E',
   'S',
   0, // glBitmapxOES
   'g',
   'l',
   'B',
   'l',
   'e',
   'n',
   'd',
   'B',
   'a',
   'r',
   'r',
   'i',
   'e',
   'r',
   0, // glBlendBarrier
   'g',
   'l',
   'B',
   'l',
   'e',
   'n',
   'd',
   'B',
   'a',
   'r',
   'r',
   'i',
   'e',
   'r',
   'K',
   'H',
   'R',
   0, // glBlendBarrierKHR
   'g',
   'l',
   'B',
   'l',
   'e',
   'n',
   'd',
   'B',
   'a',
   'r',
   'r',
   'i',
   'e',
   'r',
   'N',
   'V',
   0, // glBlendBarrierNV
   'g',
   'l',
   'B',
   'l',
   'e',
   'n',
   'd',
   'C',
   'o',
   'l',
   'o',
   'r',
   0, // glBlendColor
   'g',
   'l',
   'B',
   'l',
   'e',
   'n',
   'd',
   'C',
   'o',
   'l',
   'o',
   'r',
   'E',
   'X',
   'T',
   0, // glBlendColorEXT
   'g',
   'l',
   'B',
   'l',
   'e',
   'n',
   'd',
   'C',
   'o',
   'l',
   'o',
   'r',
   'x',
   'O',
   'E',
   'S',
   0, // glBlendColorxOES
   'g',
   'l',
   'B',
   'l',
   'e',
   'n',
   'd',
   'E',
   'q',
   'u',
   'a',
   't',
   'i',
   'o',
   'n',
   0, // glBlendEquation
   'g',
   'l',
   'B',
   'l',
   'e',
   'n',
   'd',
   'E',
   'q',
   'u',
   'a',
   't',
   'i',
   'o',
   'n',
   'E',
   'X',
   'T',
   0, // glBlendEquationEXT
   'g',
   'l',
   'B',
   'l',
   'e',
   'n',
   'd',
   'E',
   'q',
   'u',
   'a',
   't',
   'i',
   'o',
   'n',
   'I',
   'n',
   'd',
   'e',
   'x',
   'e',
   'd',
   'A',
   'M',
   'D',
   0, // glBlendEquationIndexedAMD
   'g',
   'l',
   'B',
   'l',
   'e',
   'n',
   'd',
   'E',
   'q',
   'u',
   'a',
   't',
   'i',
   'o',
   'n',
   'O',
   'E',
   'S',
   0, // glBlendEquationOES
   'g',
   'l',
   'B',
   'l',
   'e',
   'n',
   'd',
   'E',
   'q',
   'u',
   'a',
   't',
   'i',
   'o',
   'n',
   'S',
   'e',
   'p',
   'a',
   'r',
   'a',
   't',
   'e',
   0, // glBlendEquationSeparate
   'g',
   'l',
   'B',
   'l',
   'e',
   'n',
   'd',
   'E',
   'q',
   'u',
   'a',
   't',
   'i',
   'o',
   'n',
   'S',
   'e',
   'p',
   'a',
   'r',
   'a',
   't',
   'e',
   'E',
   'X',
   'T',
   0, // glBlendEquationSeparateEXT
   'g',
   'l',
   'B',
   'l',
   'e',
   'n',
   'd',
   'E',
   'q',
   'u',
   'a',
   't',
   'i',
   'o',
   'n',
   'S',
   'e',
   'p',
   'a',
   'r',
   'a',
   't',
   'e',
   'I',
   'n',
   'd',
   'e',
   'x',
   'e',
   'd',
   'A',
   'M',
   'D',
   0, // glBlendEquationSeparateIndexedAMD
   'g',
   'l',
   'B',
   'l',
   'e',
   'n',
   'd',
   'E',
   'q',
   'u',
   'a',
   't',
   'i',
   'o',
   'n',
   'S',
   'e',
   'p',
   'a',
   'r',
   'a',
   't',
   'e',
   'O',
   'E',
   'S',
   0, // glBlendEquationSeparateOES
   'g',
   'l',
   'B',
   'l',
   'e',
   'n',
   'd',
   'E',
   'q',
   'u',
   'a',
   't',
   'i',
   'o',
   'n',
   'S',
   'e',
   'p',
   'a',
   'r',
   'a',
   't',
   'e',
   'i',
   0, // glBlendEquationSeparatei
   'g',
   'l',
   'B',
   'l',
   'e',
   'n',
   'd',
   'E',
   'q',
   'u',
   'a',
   't',
   'i',
   'o',
   'n',
   'S',
   'e',
   'p',
   'a',
   'r',
   'a',
   't',
   'e',
   'i',
   'A',
   'R',
   'B',
   0, // glBlendEquationSeparateiARB
   'g',
   'l',
   'B',
   'l',
   'e',
   'n',
   'd',
   'E',
   'q',
   'u',
   'a',
   't',
   'i',
   'o',
   'n',
   'S',
   'e',
   'p',
   'a',
   'r',
   'a',
   't',
   'e',
   'i',
   'E',
   'X',
   'T',
   0, // glBlendEquationSeparateiEXT
   'g',
   'l',
   'B',
   'l',
   'e',
   'n',
   'd',
   'E',
   'q',
   'u',
   'a',
   't',
   'i',
   'o',
   'n',
   'S',
   'e',
   'p',
   'a',
   'r',
   'a',
   't',
   'e',
   'i',
   'O',
   'E',
   'S',
   0, // glBlendEquationSeparateiOES
   'g',
   'l',
   'B',
   'l',
   'e',
   'n',
   'd',
   'E',
   'q',
   'u',
   'a',
   't',
   'i',
   'o',
   'n',
   'i',
   0, // glBlendEquationi
   'g',
   'l',
   'B',
   'l',
   'e',
   'n',
   'd',
   'E',
   'q',
   'u',
   'a',
   't',
   'i',
   'o',
   'n',
   'i',
   'A',
   'R',
   'B',
   0, // glBlendEquationiARB
   'g',
   'l',
   'B',
   'l',
   'e',
   'n',
   'd',
   'E',
   'q',
   'u',
   'a',
   't',
   'i',
   'o',
   'n',
   'i',
   'E',
   'X',
   'T',
   0, // glBlendEquationiEXT
   'g',
   'l',
   'B',
   'l',
   'e',
   'n',
   'd',
   'E',
   'q',
   'u',
   'a',
   't',
   'i',
   'o',
   'n',
   'i',
   'O',
   'E',
   'S',
   0, // glBlendEquationiOES
   'g',
   'l',
   'B',
   'l',
   'e',
   'n',
   'd',
   'F',
   'u',
   'n',
   'c',
   0, // glBlendFunc
   'g',
   'l',
   'B',
   'l',
   'e',
   'n',
   'd',
   'F',
   'u',
   'n',
   'c',
   'I',
   'n',
   'd',
   'e',
   'x',
   'e',
   'd',
   'A',
   'M',
   'D',
   0, // glBlendFuncIndexedAMD
   'g',
   'l',
   'B',
   'l',
   'e',
   'n',
   'd',
   'F',
   'u',
   'n',
   'c',
   'S',
   'e',
   'p',
   'a',
   'r',
   'a',
   't',
   'e',
   0, // glBlendFuncSeparate
   'g',
   'l',
   'B',
   'l',
   'e',
   'n',
   'd',
   'F',
   'u',
   'n',
   'c',
   'S',
   'e',
   'p',
   'a',
   'r',
   'a',
   't',
   'e',
   'E',
   'X',
   'T',
   0, // glBlendFuncSeparateEXT
   'g',
   'l',
   'B',
   'l',
   'e',
   'n',
   'd',
   'F',
   'u',
   'n',
   'c',
   'S',
   'e',
   'p',
   'a',
   'r',
   'a',
   't',
   'e',
   'I',
   'N',
   'G',
   'R',
   0, // glBlendFuncSeparateINGR
   'g',
   'l',
   'B',
   'l',
   'e',
   'n',
   'd',
   'F',
   'u',
   'n',
   'c',
   'S',
   'e',
   'p',
   'a',
   'r',
   'a',
   't',
   'e',
   'I',
   'n',
   'd',
   'e',
   'x',
   'e',
   'd',
   'A',
   'M',
   'D',
   0, // glBlendFuncSeparateIndexedAMD
   'g',
   'l',
   'B',
   'l',
   'e',
   'n',
   'd',
   'F',
   'u',
   'n',
   'c',
   'S',
   'e',
   'p',
   'a',
   'r',
   'a',
   't',
   'e',
   'O',
   'E',
   'S',
   0, // glBlendFuncSeparateOES
   'g',
   'l',
   'B',
   'l',
   'e',
   'n',
   'd',
   'F',
   'u',
   'n',
   'c',
   'S',
   'e',
   'p',
   'a',
   'r',
   'a',
   't',
   'e',
   'i',
   0, // glBlendFuncSeparatei
   'g',
   'l',
   'B',
   'l',
   'e',
   'n',
   'd',
   'F',
   'u',
   'n',
   'c',
   'S',
   'e',
   'p',
   'a',
   'r',
   'a',
   't',
   'e',
   'i',
   'A',
   'R',
   'B',
   0, // glBlendFuncSeparateiARB
   'g',
   'l',
   'B',
   'l',
   'e',
   'n',
   'd',
   'F',
   'u',
   'n',
   'c',
   'S',
   'e',
   'p',
   'a',
   'r',
   'a',
   't',
   'e',
   'i',
   'E',
   'X',
   'T',
   0, // glBlendFuncSeparateiEXT
   'g',
   'l',
   'B',
   'l',
   'e',
   'n',
   'd',
   'F',
   'u',
   'n',
   'c',
   'S',
   'e',
   'p',
   'a',
   'r',
   'a',
   't',
   'e',
   'i',
   'O',
   'E',
   'S',
   0, // glBlendFuncSeparateiOES
   'g',
   'l',
   'B',
   'l',
   'e',
   'n',
   'd',
   'F',
   'u',
   'n',
   'c',
   'i',
   0, // glBlendFunci
   'g',
   'l',
   'B',
   'l',
   'e',
   'n',
   'd',
   'F',
   'u',
   'n',
   'c',
   'i',
   'A',
   'R',
   'B',
   0, // glBlendFunciARB
   'g',
   'l',
   'B',
   'l',
   'e',
   'n',
   'd',
   'F',
   'u',
   'n',
   'c',
   'i',
   'E',
   'X',
   'T',
   0, // glBlendFunciEXT
   'g',
   'l',
   'B',
   'l',
   'e',
   'n',
   'd',
   'F',
   'u',
   'n',
   'c',
   'i',
   'O',
   'E',
   'S',
   0, // glBlendFunciOES
   'g',
   'l',
   'B',
   'l',
   'e',
   'n',
   'd',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'N',
   'V',
   0, // glBlendParameteriNV
   'g',
   'l',
   'B',
   'l',
   'i',
   't',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   0, // glBlitFramebuffer
   'g',
   'l',
   'B',
   'l',
   'i',
   't',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'A',
   'N',
   'G',
   'L',
   'E',
   0, // glBlitFramebufferANGLE
   'g',
   'l',
   'B',
   'l',
   'i',
   't',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glBlitFramebufferEXT
   'g',
   'l',
   'B',
   'l',
   'i',
   't',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'N',
   'V',
   0, // glBlitFramebufferNV
   'g',
   'l',
   'B',
   'l',
   'i',
   't',
   'N',
   'a',
   'm',
   'e',
   'd',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   0, // glBlitNamedFramebuffer
   'g',
   'l',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'A',
   'd',
   'd',
   'r',
   'e',
   's',
   's',
   'R',
   'a',
   'n',
   'g',
   'e',
   'N',
   'V',
   0, // glBufferAddressRangeNV
   'g',
   'l',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'A',
   't',
   't',
   'a',
   'c',
   'h',
   'M',
   'e',
   'm',
   'o',
   'r',
   'y',
   'N',
   'V',
   0, // glBufferAttachMemoryNV
   'g',
   'l',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'D',
   'a',
   't',
   'a',
   0, // glBufferData
   'g',
   'l',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'D',
   'a',
   't',
   'a',
   'A',
   'R',
   'B',
   0, // glBufferDataARB
   'g',
   'l',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'P',
   'a',
   'g',
   'e',
   'C',
   'o',
   'm',
   'm',
   'i',
   't',
   'm',
   'e',
   'n',
   't',
   'A',
   'R',
   'B',
   0, // glBufferPageCommitmentARB
   'g',
   'l',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'A',
   'P',
   'P',
   'L',
   'E',
   0, // glBufferParameteriAPPLE
   'g',
   'l',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   0, // glBufferStorage
   'g',
   'l',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   'E',
   'X',
   'T',
   0, // glBufferStorageEXT
   'g',
   'l',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   'E',
   'x',
   't',
   'e',
   'r',
   'n',
   'a',
   'l',
   'E',
   'X',
   'T',
   0, // glBufferStorageExternalEXT
   'g',
   'l',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   'M',
   'e',
   'm',
   'E',
   'X',
   'T',
   0, // glBufferStorageMemEXT
   'g',
   'l',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   'u',
   'b',
   'D',
   'a',
   't',
   'a',
   0, // glBufferSubData
   'g',
   'l',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   'u',
   'b',
   'D',
   'a',
   't',
   'a',
   'A',
   'R',
   'B',
   0, // glBufferSubDataARB
   'g',
   'l',
   'C',
   'a',
   'l',
   'l',
   'C',
   'o',
   'm',
   'm',
   'a',
   'n',
   'd',
   'L',
   'i',
   's',
   't',
   'N',
   'V',
   0, // glCallCommandListNV
   'g',
   'l',
   'C',
   'a',
   'l',
   'l',
   'L',
   'i',
   's',
   't',
   0, // glCallList
   'g',
   'l',
   'C',
   'a',
   'l',
   'l',
   'L',
   'i',
   's',
   't',
   's',
   0, // glCallLists
   'g',
   'l',
   'C',
   'h',
   'e',
   'c',
   'k',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   't',
   'a',
   't',
   'u',
   's',
   0, // glCheckFramebufferStatus
   'g',
   'l',
   'C',
   'h',
   'e',
   'c',
   'k',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   't',
   'a',
   't',
   'u',
   's',
   'E',
   'X',
   'T',
   0, // glCheckFramebufferStatusEXT
   'g',
   'l',
   'C',
   'h',
   'e',
   'c',
   'k',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   't',
   'a',
   't',
   'u',
   's',
   'O',
   'E',
   'S',
   0, // glCheckFramebufferStatusOES
   'g',
   'l',
   'C',
   'h',
   'e',
   'c',
   'k',
   'N',
   'a',
   'm',
   'e',
   'd',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   't',
   'a',
   't',
   'u',
   's',
   0, // glCheckNamedFramebufferStatus
   'g',
   'l',
   'C',
   'h',
   'e',
   'c',
   'k',
   'N',
   'a',
   'm',
   'e',
   'd',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   't',
   'a',
   't',
   'u',
   's',
   'E',
   'X',
   'T',
   0, // glCheckNamedFramebufferStatusEXT
   'g',
   'l',
   'C',
   'l',
   'a',
   'm',
   'p',
   'C',
   'o',
   'l',
   'o',
   'r',
   0, // glClampColor
   'g',
   'l',
   'C',
   'l',
   'a',
   'm',
   'p',
   'C',
   'o',
   'l',
   'o',
   'r',
   'A',
   'R',
   'B',
   0, // glClampColorARB
   'g',
   'l',
   'C',
   'l',
   'e',
   'a',
   'r',
   0, // glClear
   'g',
   'l',
   'C',
   'l',
   'e',
   'a',
   'r',
   'A',
   'c',
   'c',
   'u',
   'm',
   0, // glClearAccum
   'g',
   'l',
   'C',
   'l',
   'e',
   'a',
   'r',
   'A',
   'c',
   'c',
   'u',
   'm',
   'x',
   'O',
   'E',
   'S',
   0, // glClearAccumxOES
   'g',
   'l',
   'C',
   'l',
   'e',
   'a',
   'r',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'D',
   'a',
   't',
   'a',
   0, // glClearBufferData
   'g',
   'l',
   'C',
   'l',
   'e',
   'a',
   'r',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   'u',
   'b',
   'D',
   'a',
   't',
   'a',
   0, // glClearBufferSubData
   'g',
   'l',
   'C',
   'l',
   'e',
   'a',
   'r',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'f',
   'i',
   0, // glClearBufferfi
   'g',
   'l',
   'C',
   'l',
   'e',
   'a',
   'r',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'f',
   'v',
   0, // glClearBufferfv
   'g',
   'l',
   'C',
   'l',
   'e',
   'a',
   'r',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'i',
   'v',
   0, // glClearBufferiv
   'g',
   'l',
   'C',
   'l',
   'e',
   'a',
   'r',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'u',
   'i',
   'v',
   0, // glClearBufferuiv
   'g',
   'l',
   'C',
   'l',
   'e',
   'a',
   'r',
   'C',
   'o',
   'l',
   'o',
   'r',
   0, // glClearColor
   'g',
   'l',
   'C',
   'l',
   'e',
   'a',
   'r',
   'C',
   'o',
   'l',
   'o',
   'r',
   'I',
   'i',
   'E',
   'X',
   'T',
   0, // glClearColorIiEXT
   'g',
   'l',
   'C',
   'l',
   'e',
   'a',
   'r',
   'C',
   'o',
   'l',
   'o',
   'r',
   'I',
   'u',
   'i',
   'E',
   'X',
   'T',
   0, // glClearColorIuiEXT
   'g',
   'l',
   'C',
   'l',
   'e',
   'a',
   'r',
   'C',
   'o',
   'l',
   'o',
   'r',
   'x',
   0, // glClearColorx
   'g',
   'l',
   'C',
   'l',
   'e',
   'a',
   'r',
   'C',
   'o',
   'l',
   'o',
   'r',
   'x',
   'O',
   'E',
   'S',
   0, // glClearColorxOES
   'g',
   'l',
   'C',
   'l',
   'e',
   'a',
   'r',
   'D',
   'e',
   'p',
   't',
   'h',
   0, // glClearDepth
   'g',
   'l',
   'C',
   'l',
   'e',
   'a',
   'r',
   'D',
   'e',
   'p',
   't',
   'h',
   'd',
   'N',
   'V',
   0, // glClearDepthdNV
   'g',
   'l',
   'C',
   'l',
   'e',
   'a',
   'r',
   'D',
   'e',
   'p',
   't',
   'h',
   'f',
   0, // glClearDepthf
   'g',
   'l',
   'C',
   'l',
   'e',
   'a',
   'r',
   'D',
   'e',
   'p',
   't',
   'h',
   'f',
   'O',
   'E',
   'S',
   0, // glClearDepthfOES
   'g',
   'l',
   'C',
   'l',
   'e',
   'a',
   'r',
   'D',
   'e',
   'p',
   't',
   'h',
   'x',
   0, // glClearDepthx
   'g',
   'l',
   'C',
   'l',
   'e',
   'a',
   'r',
   'D',
   'e',
   'p',
   't',
   'h',
   'x',
   'O',
   'E',
   'S',
   0, // glClearDepthxOES
   'g',
   'l',
   'C',
   'l',
   'e',
   'a',
   'r',
   'I',
   'n',
   'd',
   'e',
   'x',
   0, // glClearIndex
   'g',
   'l',
   'C',
   'l',
   'e',
   'a',
   'r',
   'N',
   'a',
   'm',
   'e',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'D',
   'a',
   't',
   'a',
   0, // glClearNamedBufferData
   'g',
   'l',
   'C',
   'l',
   'e',
   'a',
   'r',
   'N',
   'a',
   'm',
   'e',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'D',
   'a',
   't',
   'a',
   'E',
   'X',
   'T',
   0, // glClearNamedBufferDataEXT
   'g',
   'l',
   'C',
   'l',
   'e',
   'a',
   'r',
   'N',
   'a',
   'm',
   'e',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   'u',
   'b',
   'D',
   'a',
   't',
   'a',
   0, // glClearNamedBufferSubData
   'g',
   'l',
   'C',
   'l',
   'e',
   'a',
   'r',
   'N',
   'a',
   'm',
   'e',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   'u',
   'b',
   'D',
   'a',
   't',
   'a',
   'E',
   'X',
   'T',
   0, // glClearNamedBufferSubDataEXT
   'g',
   'l',
   'C',
   'l',
   'e',
   'a',
   'r',
   'N',
   'a',
   'm',
   'e',
   'd',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'f',
   'i',
   0, // glClearNamedFramebufferfi
   'g',
   'l',
   'C',
   'l',
   'e',
   'a',
   'r',
   'N',
   'a',
   'm',
   'e',
   'd',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'f',
   'v',
   0, // glClearNamedFramebufferfv
   'g',
   'l',
   'C',
   'l',
   'e',
   'a',
   'r',
   'N',
   'a',
   'm',
   'e',
   'd',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'i',
   'v',
   0, // glClearNamedFramebufferiv
   'g',
   'l',
   'C',
   'l',
   'e',
   'a',
   'r',
   'N',
   'a',
   'm',
   'e',
   'd',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'u',
   'i',
   'v',
   0, // glClearNamedFramebufferuiv
   'g',
   'l',
   'C',
   'l',
   'e',
   'a',
   'r',
   'P',
   'i',
   'x',
   'e',
   'l',
   'L',
   'o',
   'c',
   'a',
   'l',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   'u',
   'i',
   'E',
   'X',
   'T',
   0, // glClearPixelLocalStorageuiEXT
   'g',
   'l',
   'C',
   'l',
   'e',
   'a',
   'r',
   'S',
   't',
   'e',
   'n',
   'c',
   'i',
   'l',
   0, // glClearStencil
   'g',
   'l',
   'C',
   'l',
   'e',
   'a',
   'r',
   'T',
   'e',
   'x',
   'I',
   'm',
   'a',
   'g',
   'e',
   0, // glClearTexImage
   'g',
   'l',
   'C',
   'l',
   'e',
   'a',
   'r',
   'T',
   'e',
   'x',
   'I',
   'm',
   'a',
   'g',
   'e',
   'E',
   'X',
   'T',
   0, // glClearTexImageEXT
   'g',
   'l',
   'C',
   'l',
   'e',
   'a',
   'r',
   'T',
   'e',
   'x',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   0, // glClearTexSubImage
   'g',
   'l',
   'C',
   'l',
   'e',
   'a',
   'r',
   'T',
   'e',
   'x',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   'E',
   'X',
   'T',
   0, // glClearTexSubImageEXT
   'g',
   'l',
   'C',
   'l',
   'i',
   'e',
   'n',
   't',
   'A',
   'c',
   't',
   'i',
   'v',
   'e',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   0, // glClientActiveTexture
   'g',
   'l',
   'C',
   'l',
   'i',
   'e',
   'n',
   't',
   'A',
   'c',
   't',
   'i',
   'v',
   'e',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'A',
   'R',
   'B',
   0, // glClientActiveTextureARB
   'g',
   'l',
   'C',
   'l',
   'i',
   'e',
   'n',
   't',
   'A',
   'c',
   't',
   'i',
   'v',
   'e',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   'A',
   'T',
   'I',
   0, // glClientActiveVertexStreamATI
   'g',
   'l',
   'C',
   'l',
   'i',
   'e',
   'n',
   't',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'D',
   'e',
   'f',
   'a',
   'u',
   'l',
   't',
   'E',
   'X',
   'T',
   0, // glClientAttribDefaultEXT
   'g',
   'l',
   'C',
   'l',
   'i',
   'e',
   'n',
   't',
   'W',
   'a',
   'i',
   't',
   'S',
   'e',
   'm',
   'a',
   'p',
   'h',
   'o',
   'r',
   'e',
   'u',
   'i',
   '6',
   '4',
   'N',
   'V',
   'X',
   0, // glClientWaitSemaphoreui64NVX
   'g',
   'l',
   'C',
   'l',
   'i',
   'e',
   'n',
   't',
   'W',
   'a',
   'i',
   't',
   'S',
   'y',
   'n',
   'c',
   0, // glClientWaitSync
   'g',
   'l',
   'C',
   'l',
   'i',
   'e',
   'n',
   't',
   'W',
   'a',
   'i',
   't',
   'S',
   'y',
   'n',
   'c',
   'A',
   'P',
   'P',
   'L',
   'E',
   0, // glClientWaitSyncAPPLE
   'g',
   'l',
   'C',
   'l',
   'i',
   'p',
   'C',
   'o',
   'n',
   't',
   'r',
   'o',
   'l',
   0, // glClipControl
   'g',
   'l',
   'C',
   'l',
   'i',
   'p',
   'C',
   'o',
   'n',
   't',
   'r',
   'o',
   'l',
   'E',
   'X',
   'T',
   0, // glClipControlEXT
   'g',
   'l',
   'C',
   'l',
   'i',
   'p',
   'P',
   'l',
   'a',
   'n',
   'e',
   0, // glClipPlane
   'g',
   'l',
   'C',
   'l',
   'i',
   'p',
   'P',
   'l',
   'a',
   'n',
   'e',
   'f',
   0, // glClipPlanef
   'g',
   'l',
   'C',
   'l',
   'i',
   'p',
   'P',
   'l',
   'a',
   'n',
   'e',
   'f',
   'I',
   'M',
   'G',
   0, // glClipPlanefIMG
   'g',
   'l',
   'C',
   'l',
   'i',
   'p',
   'P',
   'l',
   'a',
   'n',
   'e',
   'f',
   'O',
   'E',
   'S',
   0, // glClipPlanefOES
   'g',
   'l',
   'C',
   'l',
   'i',
   'p',
   'P',
   'l',
   'a',
   'n',
   'e',
   'x',
   0, // glClipPlanex
   'g',
   'l',
   'C',
   'l',
   'i',
   'p',
   'P',
   'l',
   'a',
   'n',
   'e',
   'x',
   'I',
   'M',
   'G',
   0, // glClipPlanexIMG
   'g',
   'l',
   'C',
   'l',
   'i',
   'p',
   'P',
   'l',
   'a',
   'n',
   'e',
   'x',
   'O',
   'E',
   'S',
   0, // glClipPlanexOES
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'b',
   0, // glColor3b
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'b',
   'v',
   0, // glColor3bv
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'd',
   0, // glColor3d
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'd',
   'v',
   0, // glColor3dv
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'f',
   0, // glColor3f
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'f',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '3',
   'f',
   'S',
   'U',
   'N',
   0, // glColor3fVertex3fSUN
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'f',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '3',
   'f',
   'v',
   'S',
   'U',
   'N',
   0, // glColor3fVertex3fvSUN
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'f',
   'v',
   0, // glColor3fv
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'h',
   'N',
   'V',
   0, // glColor3hNV
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'h',
   'v',
   'N',
   'V',
   0, // glColor3hvNV
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'i',
   0, // glColor3i
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'i',
   'v',
   0, // glColor3iv
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   's',
   0, // glColor3s
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   's',
   'v',
   0, // glColor3sv
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'u',
   'b',
   0, // glColor3ub
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'u',
   'b',
   'v',
   0, // glColor3ubv
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'u',
   'i',
   0, // glColor3ui
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'u',
   'i',
   'v',
   0, // glColor3uiv
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'u',
   's',
   0, // glColor3us
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'u',
   's',
   'v',
   0, // glColor3usv
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'x',
   'O',
   'E',
   'S',
   0, // glColor3xOES
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'x',
   'v',
   'O',
   'E',
   'S',
   0, // glColor3xvOES
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   '4',
   'b',
   0, // glColor4b
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   '4',
   'b',
   'v',
   0, // glColor4bv
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   '4',
   'd',
   0, // glColor4d
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   '4',
   'd',
   'v',
   0, // glColor4dv
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   '4',
   'f',
   0, // glColor4f
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   '4',
   'f',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   '3',
   'f',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '3',
   'f',
   'S',
   'U',
   'N',
   0, // glColor4fNormal3fVertex3fSUN
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   '4',
   'f',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   '3',
   'f',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '3',
   'f',
   'v',
   'S',
   'U',
   'N',
   0, // glColor4fNormal3fVertex3fvSUN
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   '4',
   'f',
   'v',
   0, // glColor4fv
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   '4',
   'h',
   'N',
   'V',
   0, // glColor4hNV
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   '4',
   'h',
   'v',
   'N',
   'V',
   0, // glColor4hvNV
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   '4',
   'i',
   0, // glColor4i
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   '4',
   'i',
   'v',
   0, // glColor4iv
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   '4',
   's',
   0, // glColor4s
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   '4',
   's',
   'v',
   0, // glColor4sv
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   '4',
   'u',
   'b',
   0, // glColor4ub
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   '4',
   'u',
   'b',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '2',
   'f',
   'S',
   'U',
   'N',
   0, // glColor4ubVertex2fSUN
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   '4',
   'u',
   'b',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '2',
   'f',
   'v',
   'S',
   'U',
   'N',
   0, // glColor4ubVertex2fvSUN
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   '4',
   'u',
   'b',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '3',
   'f',
   'S',
   'U',
   'N',
   0, // glColor4ubVertex3fSUN
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   '4',
   'u',
   'b',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '3',
   'f',
   'v',
   'S',
   'U',
   'N',
   0, // glColor4ubVertex3fvSUN
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   '4',
   'u',
   'b',
   'v',
   0, // glColor4ubv
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   '4',
   'u',
   'i',
   0, // glColor4ui
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   '4',
   'u',
   'i',
   'v',
   0, // glColor4uiv
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   '4',
   'u',
   's',
   0, // glColor4us
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   '4',
   'u',
   's',
   'v',
   0, // glColor4usv
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   '4',
   'x',
   0, // glColor4x
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   '4',
   'x',
   'O',
   'E',
   'S',
   0, // glColor4xOES
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   '4',
   'x',
   'v',
   'O',
   'E',
   'S',
   0, // glColor4xvOES
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   'F',
   'o',
   'r',
   'm',
   'a',
   't',
   'N',
   'V',
   0, // glColorFormatNV
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   'F',
   'r',
   'a',
   'g',
   'm',
   'e',
   'n',
   't',
   'O',
   'p',
   '1',
   'A',
   'T',
   'I',
   0, // glColorFragmentOp1ATI
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   'F',
   'r',
   'a',
   'g',
   'm',
   'e',
   'n',
   't',
   'O',
   'p',
   '2',
   'A',
   'T',
   'I',
   0, // glColorFragmentOp2ATI
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   'F',
   'r',
   'a',
   'g',
   'm',
   'e',
   'n',
   't',
   'O',
   'p',
   '3',
   'A',
   'T',
   'I',
   0, // glColorFragmentOp3ATI
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   'M',
   'a',
   's',
   'k',
   0, // glColorMask
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   'M',
   'a',
   's',
   'k',
   'I',
   'n',
   'd',
   'e',
   'x',
   'e',
   'd',
   'E',
   'X',
   'T',
   0, // glColorMaskIndexedEXT
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   'M',
   'a',
   's',
   'k',
   'i',
   0, // glColorMaski
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   'M',
   'a',
   's',
   'k',
   'i',
   'E',
   'X',
   'T',
   0, // glColorMaskiEXT
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   'M',
   'a',
   's',
   'k',
   'i',
   'O',
   'E',
   'S',
   0, // glColorMaskiOES
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   'M',
   'a',
   't',
   'e',
   'r',
   'i',
   'a',
   'l',
   0, // glColorMaterial
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   'P',
   '3',
   'u',
   'i',
   0, // glColorP3ui
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   'P',
   '3',
   'u',
   'i',
   'v',
   0, // glColorP3uiv
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   'P',
   '4',
   'u',
   'i',
   0, // glColorP4ui
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   'P',
   '4',
   'u',
   'i',
   'v',
   0, // glColorP4uiv
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   0, // glColorPointer
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glColorPointerEXT
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'L',
   'i',
   's',
   't',
   'I',
   'B',
   'M',
   0, // glColorPointerListIBM
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'v',
   'I',
   'N',
   'T',
   'E',
   'L',
   0, // glColorPointervINTEL
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   'S',
   'u',
   'b',
   'T',
   'a',
   'b',
   'l',
   'e',
   0, // glColorSubTable
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   'S',
   'u',
   'b',
   'T',
   'a',
   'b',
   'l',
   'e',
   'E',
   'X',
   'T',
   0, // glColorSubTableEXT
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   'T',
   'a',
   'b',
   'l',
   'e',
   0, // glColorTable
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   'T',
   'a',
   'b',
   'l',
   'e',
   'E',
   'X',
   'T',
   0, // glColorTableEXT
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   'T',
   'a',
   'b',
   'l',
   'e',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   0, // glColorTableParameterfv
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   'T',
   'a',
   'b',
   'l',
   'e',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   'S',
   'G',
   'I',
   0, // glColorTableParameterfvSGI
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   'T',
   'a',
   'b',
   'l',
   'e',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   0, // glColorTableParameteriv
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   'T',
   'a',
   'b',
   'l',
   'e',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'S',
   'G',
   'I',
   0, // glColorTableParameterivSGI
   'g',
   'l',
   'C',
   'o',
   'l',
   'o',
   'r',
   'T',
   'a',
   'b',
   'l',
   'e',
   'S',
   'G',
   'I',
   0, // glColorTableSGI
   'g',
   'l',
   'C',
   'o',
   'm',
   'b',
   'i',
   'n',
   'e',
   'r',
   'I',
   'n',
   'p',
   'u',
   't',
   'N',
   'V',
   0, // glCombinerInputNV
   'g',
   'l',
   'C',
   'o',
   'm',
   'b',
   'i',
   'n',
   'e',
   'r',
   'O',
   'u',
   't',
   'p',
   'u',
   't',
   'N',
   'V',
   0, // glCombinerOutputNV
   'g',
   'l',
   'C',
   'o',
   'm',
   'b',
   'i',
   'n',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'N',
   'V',
   0, // glCombinerParameterfNV
   'g',
   'l',
   'C',
   'o',
   'm',
   'b',
   'i',
   'n',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   'N',
   'V',
   0, // glCombinerParameterfvNV
   'g',
   'l',
   'C',
   'o',
   'm',
   'b',
   'i',
   'n',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'N',
   'V',
   0, // glCombinerParameteriNV
   'g',
   'l',
   'C',
   'o',
   'm',
   'b',
   'i',
   'n',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'N',
   'V',
   0, // glCombinerParameterivNV
   'g',
   'l',
   'C',
   'o',
   'm',
   'b',
   'i',
   'n',
   'e',
   'r',
   'S',
   't',
   'a',
   'g',
   'e',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   'N',
   'V',
   0, // glCombinerStageParameterfvNV
   'g',
   'l',
   'C',
   'o',
   'm',
   'm',
   'a',
   'n',
   'd',
   'L',
   'i',
   's',
   't',
   'S',
   'e',
   'g',
   'm',
   'e',
   'n',
   't',
   's',
   'N',
   'V',
   0, // glCommandListSegmentsNV
   'g',
   'l',
   'C',
   'o',
   'm',
   'p',
   'i',
   'l',
   'e',
   'C',
   'o',
   'm',
   'm',
   'a',
   'n',
   'd',
   'L',
   'i',
   's',
   't',
   'N',
   'V',
   0, // glCompileCommandListNV
   'g',
   'l',
   'C',
   'o',
   'm',
   'p',
   'i',
   'l',
   'e',
   'S',
   'h',
   'a',
   'd',
   'e',
   'r',
   0, // glCompileShader
   'g',
   'l',
   'C',
   'o',
   'm',
   'p',
   'i',
   'l',
   'e',
   'S',
   'h',
   'a',
   'd',
   'e',
   'r',
   'A',
   'R',
   'B',
   0, // glCompileShaderARB
   'g',
   'l',
   'C',
   'o',
   'm',
   'p',
   'i',
   'l',
   'e',
   'S',
   'h',
   'a',
   'd',
   'e',
   'r',
   'I',
   'n',
   'c',
   'l',
   'u',
   'd',
   'e',
   'A',
   'R',
   'B',
   0, // glCompileShaderIncludeARB
   'g',
   'l',
   'C',
   'o',
   'm',
   'p',
   'r',
   'e',
   's',
   's',
   'e',
   'd',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'I',
   'm',
   'a',
   'g',
   'e',
   '1',
   'D',
   'E',
   'X',
   'T',
   0, // glCompressedMultiTexImage1DEXT
   'g',
   'l',
   'C',
   'o',
   'm',
   'p',
   'r',
   'e',
   's',
   's',
   'e',
   'd',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'I',
   'm',
   'a',
   'g',
   'e',
   '2',
   'D',
   'E',
   'X',
   'T',
   0, // glCompressedMultiTexImage2DEXT
   'g',
   'l',
   'C',
   'o',
   'm',
   'p',
   'r',
   'e',
   's',
   's',
   'e',
   'd',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'I',
   'm',
   'a',
   'g',
   'e',
   '3',
   'D',
   'E',
   'X',
   'T',
   0, // glCompressedMultiTexImage3DEXT
   'g',
   'l',
   'C',
   'o',
   'm',
   'p',
   'r',
   'e',
   's',
   's',
   'e',
   'd',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   '1',
   'D',
   'E',
   'X',
   'T',
   0, // glCompressedMultiTexSubImage1DEXT
   'g',
   'l',
   'C',
   'o',
   'm',
   'p',
   'r',
   'e',
   's',
   's',
   'e',
   'd',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   '2',
   'D',
   'E',
   'X',
   'T',
   0, // glCompressedMultiTexSubImage2DEXT
   'g',
   'l',
   'C',
   'o',
   'm',
   'p',
   'r',
   'e',
   's',
   's',
   'e',
   'd',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   '3',
   'D',
   'E',
   'X',
   'T',
   0, // glCompressedMultiTexSubImage3DEXT
   'g',
   'l',
   'C',
   'o',
   'm',
   'p',
   'r',
   'e',
   's',
   's',
   'e',
   'd',
   'T',
   'e',
   'x',
   'I',
   'm',
   'a',
   'g',
   'e',
   '1',
   'D',
   0, // glCompressedTexImage1D
   'g',
   'l',
   'C',
   'o',
   'm',
   'p',
   'r',
   'e',
   's',
   's',
   'e',
   'd',
   'T',
   'e',
   'x',
   'I',
   'm',
   'a',
   'g',
   'e',
   '1',
   'D',
   'A',
   'R',
   'B',
   0, // glCompressedTexImage1DARB
   'g',
   'l',
   'C',
   'o',
   'm',
   'p',
   'r',
   'e',
   's',
   's',
   'e',
   'd',
   'T',
   'e',
   'x',
   'I',
   'm',
   'a',
   'g',
   'e',
   '2',
   'D',
   0, // glCompressedTexImage2D
   'g',
   'l',
   'C',
   'o',
   'm',
   'p',
   'r',
   'e',
   's',
   's',
   'e',
   'd',
   'T',
   'e',
   'x',
   'I',
   'm',
   'a',
   'g',
   'e',
   '2',
   'D',
   'A',
   'R',
   'B',
   0, // glCompressedTexImage2DARB
   'g',
   'l',
   'C',
   'o',
   'm',
   'p',
   'r',
   'e',
   's',
   's',
   'e',
   'd',
   'T',
   'e',
   'x',
   'I',
   'm',
   'a',
   'g',
   'e',
   '3',
   'D',
   0, // glCompressedTexImage3D
   'g',
   'l',
   'C',
   'o',
   'm',
   'p',
   'r',
   'e',
   's',
   's',
   'e',
   'd',
   'T',
   'e',
   'x',
   'I',
   'm',
   'a',
   'g',
   'e',
   '3',
   'D',
   'A',
   'R',
   'B',
   0, // glCompressedTexImage3DARB
   'g',
   'l',
   'C',
   'o',
   'm',
   'p',
   'r',
   'e',
   's',
   's',
   'e',
   'd',
   'T',
   'e',
   'x',
   'I',
   'm',
   'a',
   'g',
   'e',
   '3',
   'D',
   'O',
   'E',
   'S',
   0, // glCompressedTexImage3DOES
   'g',
   'l',
   'C',
   'o',
   'm',
   'p',
   'r',
   'e',
   's',
   's',
   'e',
   'd',
   'T',
   'e',
   'x',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   '1',
   'D',
   0, // glCompressedTexSubImage1D
   'g',
   'l',
   'C',
   'o',
   'm',
   'p',
   'r',
   'e',
   's',
   's',
   'e',
   'd',
   'T',
   'e',
   'x',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   '1',
   'D',
   'A',
   'R',
   'B',
   0, // glCompressedTexSubImage1DARB
   'g',
   'l',
   'C',
   'o',
   'm',
   'p',
   'r',
   'e',
   's',
   's',
   'e',
   'd',
   'T',
   'e',
   'x',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   '2',
   'D',
   0, // glCompressedTexSubImage2D
   'g',
   'l',
   'C',
   'o',
   'm',
   'p',
   'r',
   'e',
   's',
   's',
   'e',
   'd',
   'T',
   'e',
   'x',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   '2',
   'D',
   'A',
   'R',
   'B',
   0, // glCompressedTexSubImage2DARB
   'g',
   'l',
   'C',
   'o',
   'm',
   'p',
   'r',
   'e',
   's',
   's',
   'e',
   'd',
   'T',
   'e',
   'x',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   '3',
   'D',
   0, // glCompressedTexSubImage3D
   'g',
   'l',
   'C',
   'o',
   'm',
   'p',
   'r',
   'e',
   's',
   's',
   'e',
   'd',
   'T',
   'e',
   'x',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   '3',
   'D',
   'A',
   'R',
   'B',
   0, // glCompressedTexSubImage3DARB
   'g',
   'l',
   'C',
   'o',
   'm',
   'p',
   'r',
   'e',
   's',
   's',
   'e',
   'd',
   'T',
   'e',
   'x',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   '3',
   'D',
   'O',
   'E',
   'S',
   0, // glCompressedTexSubImage3DOES
   'g',
   'l',
   'C',
   'o',
   'm',
   'p',
   'r',
   'e',
   's',
   's',
   'e',
   'd',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'I',
   'm',
   'a',
   'g',
   'e',
   '1',
   'D',
   'E',
   'X',
   'T',
   0, // glCompressedTextureImage1DEXT
   'g',
   'l',
   'C',
   'o',
   'm',
   'p',
   'r',
   'e',
   's',
   's',
   'e',
   'd',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'I',
   'm',
   'a',
   'g',
   'e',
   '2',
   'D',
   'E',
   'X',
   'T',
   0, // glCompressedTextureImage2DEXT
   'g',
   'l',
   'C',
   'o',
   'm',
   'p',
   'r',
   'e',
   's',
   's',
   'e',
   'd',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'I',
   'm',
   'a',
   'g',
   'e',
   '3',
   'D',
   'E',
   'X',
   'T',
   0, // glCompressedTextureImage3DEXT
   'g',
   'l',
   'C',
   'o',
   'm',
   'p',
   'r',
   'e',
   's',
   's',
   'e',
   'd',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   '1',
   'D',
   0, // glCompressedTextureSubImage1D
   'g',
   'l',
   'C',
   'o',
   'm',
   'p',
   'r',
   'e',
   's',
   's',
   'e',
   'd',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   '1',
   'D',
   'E',
   'X',
   'T',
   0, // glCompressedTextureSubImage1DEXT
   'g',
   'l',
   'C',
   'o',
   'm',
   'p',
   'r',
   'e',
   's',
   's',
   'e',
   'd',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   '2',
   'D',
   0, // glCompressedTextureSubImage2D
   'g',
   'l',
   'C',
   'o',
   'm',
   'p',
   'r',
   'e',
   's',
   's',
   'e',
   'd',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   '2',
   'D',
   'E',
   'X',
   'T',
   0, // glCompressedTextureSubImage2DEXT
   'g',
   'l',
   'C',
   'o',
   'm',
   'p',
   'r',
   'e',
   's',
   's',
   'e',
   'd',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   '3',
   'D',
   0, // glCompressedTextureSubImage3D
   'g',
   'l',
   'C',
   'o',
   'm',
   'p',
   'r',
   'e',
   's',
   's',
   'e',
   'd',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   '3',
   'D',
   'E',
   'X',
   'T',
   0, // glCompressedTextureSubImage3DEXT
   'g',
   'l',
   'C',
   'o',
   'n',
   's',
   'e',
   'r',
   'v',
   'a',
   't',
   'i',
   'v',
   'e',
   'R',
   'a',
   's',
   't',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'N',
   'V',
   0, // glConservativeRasterParameterfNV
   'g',
   'l',
   'C',
   'o',
   'n',
   's',
   'e',
   'r',
   'v',
   'a',
   't',
   'i',
   'v',
   'e',
   'R',
   'a',
   's',
   't',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'N',
   'V',
   0, // glConservativeRasterParameteriNV
   'g',
   'l',
   'C',
   'o',
   'n',
   'v',
   'o',
   'l',
   'u',
   't',
   'i',
   'o',
   'n',
   'F',
   'i',
   'l',
   't',
   'e',
   'r',
   '1',
   'D',
   0, // glConvolutionFilter1D
   'g',
   'l',
   'C',
   'o',
   'n',
   'v',
   'o',
   'l',
   'u',
   't',
   'i',
   'o',
   'n',
   'F',
   'i',
   'l',
   't',
   'e',
   'r',
   '1',
   'D',
   'E',
   'X',
   'T',
   0, // glConvolutionFilter1DEXT
   'g',
   'l',
   'C',
   'o',
   'n',
   'v',
   'o',
   'l',
   'u',
   't',
   'i',
   'o',
   'n',
   'F',
   'i',
   'l',
   't',
   'e',
   'r',
   '2',
   'D',
   0, // glConvolutionFilter2D
   'g',
   'l',
   'C',
   'o',
   'n',
   'v',
   'o',
   'l',
   'u',
   't',
   'i',
   'o',
   'n',
   'F',
   'i',
   'l',
   't',
   'e',
   'r',
   '2',
   'D',
   'E',
   'X',
   'T',
   0, // glConvolutionFilter2DEXT
   'g',
   'l',
   'C',
   'o',
   'n',
   'v',
   'o',
   'l',
   'u',
   't',
   'i',
   'o',
   'n',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   0, // glConvolutionParameterf
   'g',
   'l',
   'C',
   'o',
   'n',
   'v',
   'o',
   'l',
   'u',
   't',
   'i',
   'o',
   'n',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'E',
   'X',
   'T',
   0, // glConvolutionParameterfEXT
   'g',
   'l',
   'C',
   'o',
   'n',
   'v',
   'o',
   'l',
   'u',
   't',
   'i',
   'o',
   'n',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   0, // glConvolutionParameterfv
   'g',
   'l',
   'C',
   'o',
   'n',
   'v',
   'o',
   'l',
   'u',
   't',
   'i',
   'o',
   'n',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   'E',
   'X',
   'T',
   0, // glConvolutionParameterfvEXT
   'g',
   'l',
   'C',
   'o',
   'n',
   'v',
   'o',
   'l',
   'u',
   't',
   'i',
   'o',
   'n',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   0, // glConvolutionParameteri
   'g',
   'l',
   'C',
   'o',
   'n',
   'v',
   'o',
   'l',
   'u',
   't',
   'i',
   'o',
   'n',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'E',
   'X',
   'T',
   0, // glConvolutionParameteriEXT
   'g',
   'l',
   'C',
   'o',
   'n',
   'v',
   'o',
   'l',
   'u',
   't',
   'i',
   'o',
   'n',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   0, // glConvolutionParameteriv
   'g',
   'l',
   'C',
   'o',
   'n',
   'v',
   'o',
   'l',
   'u',
   't',
   'i',
   'o',
   'n',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glConvolutionParameterivEXT
   'g',
   'l',
   'C',
   'o',
   'n',
   'v',
   'o',
   'l',
   'u',
   't',
   'i',
   'o',
   'n',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'x',
   'O',
   'E',
   'S',
   0, // glConvolutionParameterxOES
   'g',
   'l',
   'C',
   'o',
   'n',
   'v',
   'o',
   'l',
   'u',
   't',
   'i',
   'o',
   'n',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'x',
   'v',
   'O',
   'E',
   'S',
   0, // glConvolutionParameterxvOES
   'g',
   'l',
   'C',
   'o',
   'p',
   'y',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   'u',
   'b',
   'D',
   'a',
   't',
   'a',
   0, // glCopyBufferSubData
   'g',
   'l',
   'C',
   'o',
   'p',
   'y',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   'u',
   'b',
   'D',
   'a',
   't',
   'a',
   'N',
   'V',
   0, // glCopyBufferSubDataNV
   'g',
   'l',
   'C',
   'o',
   'p',
   'y',
   'C',
   'o',
   'l',
   'o',
   'r',
   'S',
   'u',
   'b',
   'T',
   'a',
   'b',
   'l',
   'e',
   0, // glCopyColorSubTable
   'g',
   'l',
   'C',
   'o',
   'p',
   'y',
   'C',
   'o',
   'l',
   'o',
   'r',
   'S',
   'u',
   'b',
   'T',
   'a',
   'b',
   'l',
   'e',
   'E',
   'X',
   'T',
   0, // glCopyColorSubTableEXT
   'g',
   'l',
   'C',
   'o',
   'p',
   'y',
   'C',
   'o',
   'l',
   'o',
   'r',
   'T',
   'a',
   'b',
   'l',
   'e',
   0, // glCopyColorTable
   'g',
   'l',
   'C',
   'o',
   'p',
   'y',
   'C',
   'o',
   'l',
   'o',
   'r',
   'T',
   'a',
   'b',
   'l',
   'e',
   'S',
   'G',
   'I',
   0, // glCopyColorTableSGI
   'g',
   'l',
   'C',
   'o',
   'p',
   'y',
   'C',
   'o',
   'n',
   'v',
   'o',
   'l',
   'u',
   't',
   'i',
   'o',
   'n',
   'F',
   'i',
   'l',
   't',
   'e',
   'r',
   '1',
   'D',
   0, // glCopyConvolutionFilter1D
   'g',
   'l',
   'C',
   'o',
   'p',
   'y',
   'C',
   'o',
   'n',
   'v',
   'o',
   'l',
   'u',
   't',
   'i',
   'o',
   'n',
   'F',
   'i',
   'l',
   't',
   'e',
   'r',
   '1',
   'D',
   'E',
   'X',
   'T',
   0, // glCopyConvolutionFilter1DEXT
   'g',
   'l',
   'C',
   'o',
   'p',
   'y',
   'C',
   'o',
   'n',
   'v',
   'o',
   'l',
   'u',
   't',
   'i',
   'o',
   'n',
   'F',
   'i',
   'l',
   't',
   'e',
   'r',
   '2',
   'D',
   0, // glCopyConvolutionFilter2D
   'g',
   'l',
   'C',
   'o',
   'p',
   'y',
   'C',
   'o',
   'n',
   'v',
   'o',
   'l',
   'u',
   't',
   'i',
   'o',
   'n',
   'F',
   'i',
   'l',
   't',
   'e',
   'r',
   '2',
   'D',
   'E',
   'X',
   'T',
   0, // glCopyConvolutionFilter2DEXT
   'g',
   'l',
   'C',
   'o',
   'p',
   'y',
   'I',
   'm',
   'a',
   'g',
   'e',
   'S',
   'u',
   'b',
   'D',
   'a',
   't',
   'a',
   0, // glCopyImageSubData
   'g',
   'l',
   'C',
   'o',
   'p',
   'y',
   'I',
   'm',
   'a',
   'g',
   'e',
   'S',
   'u',
   'b',
   'D',
   'a',
   't',
   'a',
   'E',
   'X',
   'T',
   0, // glCopyImageSubDataEXT
   'g',
   'l',
   'C',
   'o',
   'p',
   'y',
   'I',
   'm',
   'a',
   'g',
   'e',
   'S',
   'u',
   'b',
   'D',
   'a',
   't',
   'a',
   'N',
   'V',
   0, // glCopyImageSubDataNV
   'g',
   'l',
   'C',
   'o',
   'p',
   'y',
   'I',
   'm',
   'a',
   'g',
   'e',
   'S',
   'u',
   'b',
   'D',
   'a',
   't',
   'a',
   'O',
   'E',
   'S',
   0, // glCopyImageSubDataOES
   'g',
   'l',
   'C',
   'o',
   'p',
   'y',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'I',
   'm',
   'a',
   'g',
   'e',
   '1',
   'D',
   'E',
   'X',
   'T',
   0, // glCopyMultiTexImage1DEXT
   'g',
   'l',
   'C',
   'o',
   'p',
   'y',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'I',
   'm',
   'a',
   'g',
   'e',
   '2',
   'D',
   'E',
   'X',
   'T',
   0, // glCopyMultiTexImage2DEXT
   'g',
   'l',
   'C',
   'o',
   'p',
   'y',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   '1',
   'D',
   'E',
   'X',
   'T',
   0, // glCopyMultiTexSubImage1DEXT
   'g',
   'l',
   'C',
   'o',
   'p',
   'y',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   '2',
   'D',
   'E',
   'X',
   'T',
   0, // glCopyMultiTexSubImage2DEXT
   'g',
   'l',
   'C',
   'o',
   'p',
   'y',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   '3',
   'D',
   'E',
   'X',
   'T',
   0, // glCopyMultiTexSubImage3DEXT
   'g',
   'l',
   'C',
   'o',
   'p',
   'y',
   'N',
   'a',
   'm',
   'e',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   'u',
   'b',
   'D',
   'a',
   't',
   'a',
   0, // glCopyNamedBufferSubData
   'g',
   'l',
   'C',
   'o',
   'p',
   'y',
   'P',
   'a',
   't',
   'h',
   'N',
   'V',
   0, // glCopyPathNV
   'g',
   'l',
   'C',
   'o',
   'p',
   'y',
   'P',
   'i',
   'x',
   'e',
   'l',
   's',
   0, // glCopyPixels
   'g',
   'l',
   'C',
   'o',
   'p',
   'y',
   'T',
   'e',
   'x',
   'I',
   'm',
   'a',
   'g',
   'e',
   '1',
   'D',
   0, // glCopyTexImage1D
   'g',
   'l',
   'C',
   'o',
   'p',
   'y',
   'T',
   'e',
   'x',
   'I',
   'm',
   'a',
   'g',
   'e',
   '1',
   'D',
   'E',
   'X',
   'T',
   0, // glCopyTexImage1DEXT
   'g',
   'l',
   'C',
   'o',
   'p',
   'y',
   'T',
   'e',
   'x',
   'I',
   'm',
   'a',
   'g',
   'e',
   '2',
   'D',
   0, // glCopyTexImage2D
   'g',
   'l',
   'C',
   'o',
   'p',
   'y',
   'T',
   'e',
   'x',
   'I',
   'm',
   'a',
   'g',
   'e',
   '2',
   'D',
   'E',
   'X',
   'T',
   0, // glCopyTexImage2DEXT
   'g',
   'l',
   'C',
   'o',
   'p',
   'y',
   'T',
   'e',
   'x',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   '1',
   'D',
   0, // glCopyTexSubImage1D
   'g',
   'l',
   'C',
   'o',
   'p',
   'y',
   'T',
   'e',
   'x',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   '1',
   'D',
   'E',
   'X',
   'T',
   0, // glCopyTexSubImage1DEXT
   'g',
   'l',
   'C',
   'o',
   'p',
   'y',
   'T',
   'e',
   'x',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   '2',
   'D',
   0, // glCopyTexSubImage2D
   'g',
   'l',
   'C',
   'o',
   'p',
   'y',
   'T',
   'e',
   'x',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   '2',
   'D',
   'E',
   'X',
   'T',
   0, // glCopyTexSubImage2DEXT
   'g',
   'l',
   'C',
   'o',
   'p',
   'y',
   'T',
   'e',
   'x',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   '3',
   'D',
   0, // glCopyTexSubImage3D
   'g',
   'l',
   'C',
   'o',
   'p',
   'y',
   'T',
   'e',
   'x',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   '3',
   'D',
   'E',
   'X',
   'T',
   0, // glCopyTexSubImage3DEXT
   'g',
   'l',
   'C',
   'o',
   'p',
   'y',
   'T',
   'e',
   'x',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   '3',
   'D',
   'O',
   'E',
   'S',
   0, // glCopyTexSubImage3DOES
   'g',
   'l',
   'C',
   'o',
   'p',
   'y',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'I',
   'm',
   'a',
   'g',
   'e',
   '1',
   'D',
   'E',
   'X',
   'T',
   0, // glCopyTextureImage1DEXT
   'g',
   'l',
   'C',
   'o',
   'p',
   'y',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'I',
   'm',
   'a',
   'g',
   'e',
   '2',
   'D',
   'E',
   'X',
   'T',
   0, // glCopyTextureImage2DEXT
   'g',
   'l',
   'C',
   'o',
   'p',
   'y',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'L',
   'e',
   'v',
   'e',
   'l',
   's',
   'A',
   'P',
   'P',
   'L',
   'E',
   0, // glCopyTextureLevelsAPPLE
   'g',
   'l',
   'C',
   'o',
   'p',
   'y',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   '1',
   'D',
   0, // glCopyTextureSubImage1D
   'g',
   'l',
   'C',
   'o',
   'p',
   'y',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   '1',
   'D',
   'E',
   'X',
   'T',
   0, // glCopyTextureSubImage1DEXT
   'g',
   'l',
   'C',
   'o',
   'p',
   'y',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   '2',
   'D',
   0, // glCopyTextureSubImage2D
   'g',
   'l',
   'C',
   'o',
   'p',
   'y',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   '2',
   'D',
   'E',
   'X',
   'T',
   0, // glCopyTextureSubImage2DEXT
   'g',
   'l',
   'C',
   'o',
   'p',
   'y',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   '3',
   'D',
   0, // glCopyTextureSubImage3D
   'g',
   'l',
   'C',
   'o',
   'p',
   'y',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   '3',
   'D',
   'E',
   'X',
   'T',
   0, // glCopyTextureSubImage3DEXT
   'g',
   'l',
   'C',
   'o',
   'v',
   'e',
   'r',
   'F',
   'i',
   'l',
   'l',
   'P',
   'a',
   't',
   'h',
   'I',
   'n',
   's',
   't',
   'a',
   'n',
   'c',
   'e',
   'd',
   'N',
   'V',
   0, // glCoverFillPathInstancedNV
   'g',
   'l',
   'C',
   'o',
   'v',
   'e',
   'r',
   'F',
   'i',
   'l',
   'l',
   'P',
   'a',
   't',
   'h',
   'N',
   'V',
   0, // glCoverFillPathNV
   'g',
   'l',
   'C',
   'o',
   'v',
   'e',
   'r',
   'S',
   't',
   'r',
   'o',
   'k',
   'e',
   'P',
   'a',
   't',
   'h',
   'I',
   'n',
   's',
   't',
   'a',
   'n',
   'c',
   'e',
   'd',
   'N',
   'V',
   0, // glCoverStrokePathInstancedNV
   'g',
   'l',
   'C',
   'o',
   'v',
   'e',
   'r',
   'S',
   't',
   'r',
   'o',
   'k',
   'e',
   'P',
   'a',
   't',
   'h',
   'N',
   'V',
   0, // glCoverStrokePathNV
   'g',
   'l',
   'C',
   'o',
   'v',
   'e',
   'r',
   'a',
   'g',
   'e',
   'M',
   'a',
   's',
   'k',
   'N',
   'V',
   0, // glCoverageMaskNV
   'g',
   'l',
   'C',
   'o',
   'v',
   'e',
   'r',
   'a',
   'g',
   'e',
   'M',
   'o',
   'd',
   'u',
   'l',
   'a',
   't',
   'i',
   'o',
   'n',
   'N',
   'V',
   0, // glCoverageModulationNV
   'g',
   'l',
   'C',
   'o',
   'v',
   'e',
   'r',
   'a',
   'g',
   'e',
   'M',
   'o',
   'd',
   'u',
   'l',
   'a',
   't',
   'i',
   'o',
   'n',
   'T',
   'a',
   'b',
   'l',
   'e',
   'N',
   'V',
   0, // glCoverageModulationTableNV
   'g',
   'l',
   'C',
   'o',
   'v',
   'e',
   'r',
   'a',
   'g',
   'e',
   'O',
   'p',
   'e',
   'r',
   'a',
   't',
   'i',
   'o',
   'n',
   'N',
   'V',
   0, // glCoverageOperationNV
   'g',
   'l',
   'C',
   'r',
   'e',
   'a',
   't',
   'e',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   's',
   0, // glCreateBuffers
   'g',
   'l',
   'C',
   'r',
   'e',
   'a',
   't',
   'e',
   'C',
   'o',
   'm',
   'm',
   'a',
   'n',
   'd',
   'L',
   'i',
   's',
   't',
   's',
   'N',
   'V',
   0, // glCreateCommandListsNV
   'g',
   'l',
   'C',
   'r',
   'e',
   'a',
   't',
   'e',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   's',
   0, // glCreateFramebuffers
   'g',
   'l',
   'C',
   'r',
   'e',
   'a',
   't',
   'e',
   'M',
   'e',
   'm',
   'o',
   'r',
   'y',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   's',
   'E',
   'X',
   'T',
   0, // glCreateMemoryObjectsEXT
   'g',
   'l',
   'C',
   'r',
   'e',
   'a',
   't',
   'e',
   'P',
   'e',
   'r',
   'f',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'I',
   'N',
   'T',
   'E',
   'L',
   0, // glCreatePerfQueryINTEL
   'g',
   'l',
   'C',
   'r',
   'e',
   'a',
   't',
   'e',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   0, // glCreateProgram
   'g',
   'l',
   'C',
   'r',
   'e',
   'a',
   't',
   'e',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'A',
   'R',
   'B',
   0, // glCreateProgramObjectARB
   'g',
   'l',
   'C',
   'r',
   'e',
   'a',
   't',
   'e',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'P',
   'i',
   'p',
   'e',
   'l',
   'i',
   'n',
   'e',
   's',
   0, // glCreateProgramPipelines
   'g',
   'l',
   'C',
   'r',
   'e',
   'a',
   't',
   'e',
   'P',
   'r',
   'o',
   'g',
   'r',
   'e',
   's',
   's',
   'F',
   'e',
   'n',
   'c',
   'e',
   'N',
   'V',
   'X',
   0, // glCreateProgressFenceNVX
   'g',
   'l',
   'C',
   'r',
   'e',
   'a',
   't',
   'e',
   'Q',
   'u',
   'e',
   'r',
   'i',
   'e',
   's',
   0, // glCreateQueries
   'g',
   'l',
   'C',
   'r',
   'e',
   'a',
   't',
   'e',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   's',
   0, // glCreateRenderbuffers
   'g',
   'l',
   'C',
   'r',
   'e',
   'a',
   't',
   'e',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'r',
   's',
   0, // glCreateSamplers
   'g',
   'l',
   'C',
   'r',
   'e',
   'a',
   't',
   'e',
   'S',
   'h',
   'a',
   'd',
   'e',
   'r',
   0, // glCreateShader
   'g',
   'l',
   'C',
   'r',
   'e',
   'a',
   't',
   'e',
   'S',
   'h',
   'a',
   'd',
   'e',
   'r',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'A',
   'R',
   'B',
   0, // glCreateShaderObjectARB
   'g',
   'l',
   'C',
   'r',
   'e',
   'a',
   't',
   'e',
   'S',
   'h',
   'a',
   'd',
   'e',
   'r',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'E',
   'X',
   'T',
   0, // glCreateShaderProgramEXT
   'g',
   'l',
   'C',
   'r',
   'e',
   'a',
   't',
   'e',
   'S',
   'h',
   'a',
   'd',
   'e',
   'r',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'v',
   0, // glCreateShaderProgramv
   'g',
   'l',
   'C',
   'r',
   'e',
   'a',
   't',
   'e',
   'S',
   'h',
   'a',
   'd',
   'e',
   'r',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'v',
   'E',
   'X',
   'T',
   0, // glCreateShaderProgramvEXT
   'g',
   'l',
   'C',
   'r',
   'e',
   'a',
   't',
   'e',
   'S',
   't',
   'a',
   't',
   'e',
   's',
   'N',
   'V',
   0, // glCreateStatesNV
   'g',
   'l',
   'C',
   'r',
   'e',
   'a',
   't',
   'e',
   'S',
   'y',
   'n',
   'c',
   'F',
   'r',
   'o',
   'm',
   'C',
   'L',
   'e',
   'v',
   'e',
   'n',
   't',
   'A',
   'R',
   'B',
   0, // glCreateSyncFromCLeventARB
   'g',
   'l',
   'C',
   'r',
   'e',
   'a',
   't',
   'e',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   's',
   0, // glCreateTextures
   'g',
   'l',
   'C',
   'r',
   'e',
   'a',
   't',
   'e',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'F',
   'e',
   'e',
   'd',
   'b',
   'a',
   'c',
   'k',
   's',
   0, // glCreateTransformFeedbacks
   'g',
   'l',
   'C',
   'r',
   'e',
   'a',
   't',
   'e',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   's',
   0, // glCreateVertexArrays
   'g',
   'l',
   'C',
   'u',
   'l',
   'l',
   'F',
   'a',
   'c',
   'e',
   0, // glCullFace
   'g',
   'l',
   'C',
   'u',
   'l',
   'l',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'd',
   'v',
   'E',
   'X',
   'T',
   0, // glCullParameterdvEXT
   'g',
   'l',
   'C',
   'u',
   'l',
   'l',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   'E',
   'X',
   'T',
   0, // glCullParameterfvEXT
   'g',
   'l',
   'C',
   'u',
   'r',
   'r',
   'e',
   'n',
   't',
   'P',
   'a',
   'l',
   'e',
   't',
   't',
   'e',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'A',
   'R',
   'B',
   0, // glCurrentPaletteMatrixARB
   'g',
   'l',
   'C',
   'u',
   'r',
   'r',
   'e',
   'n',
   't',
   'P',
   'a',
   'l',
   'e',
   't',
   't',
   'e',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'O',
   'E',
   'S',
   0, // glCurrentPaletteMatrixOES
   'g',
   'l',
   'D',
   'e',
   'b',
   'u',
   'g',
   'M',
   'e',
   's',
   's',
   'a',
   'g',
   'e',
   'C',
   'a',
   'l',
   'l',
   'b',
   'a',
   'c',
   'k',
   0, // glDebugMessageCallback
   'g',
   'l',
   'D',
   'e',
   'b',
   'u',
   'g',
   'M',
   'e',
   's',
   's',
   'a',
   'g',
   'e',
   'C',
   'a',
   'l',
   'l',
   'b',
   'a',
   'c',
   'k',
   'A',
   'M',
   'D',
   0, // glDebugMessageCallbackAMD
   'g',
   'l',
   'D',
   'e',
   'b',
   'u',
   'g',
   'M',
   'e',
   's',
   's',
   'a',
   'g',
   'e',
   'C',
   'a',
   'l',
   'l',
   'b',
   'a',
   'c',
   'k',
   'A',
   'R',
   'B',
   0, // glDebugMessageCallbackARB
   'g',
   'l',
   'D',
   'e',
   'b',
   'u',
   'g',
   'M',
   'e',
   's',
   's',
   'a',
   'g',
   'e',
   'C',
   'a',
   'l',
   'l',
   'b',
   'a',
   'c',
   'k',
   'K',
   'H',
   'R',
   0, // glDebugMessageCallbackKHR
   'g',
   'l',
   'D',
   'e',
   'b',
   'u',
   'g',
   'M',
   'e',
   's',
   's',
   'a',
   'g',
   'e',
   'C',
   'o',
   'n',
   't',
   'r',
   'o',
   'l',
   0, // glDebugMessageControl
   'g',
   'l',
   'D',
   'e',
   'b',
   'u',
   'g',
   'M',
   'e',
   's',
   's',
   'a',
   'g',
   'e',
   'C',
   'o',
   'n',
   't',
   'r',
   'o',
   'l',
   'A',
   'R',
   'B',
   0, // glDebugMessageControlARB
   'g',
   'l',
   'D',
   'e',
   'b',
   'u',
   'g',
   'M',
   'e',
   's',
   's',
   'a',
   'g',
   'e',
   'C',
   'o',
   'n',
   't',
   'r',
   'o',
   'l',
   'K',
   'H',
   'R',
   0, // glDebugMessageControlKHR
   'g',
   'l',
   'D',
   'e',
   'b',
   'u',
   'g',
   'M',
   'e',
   's',
   's',
   'a',
   'g',
   'e',
   'E',
   'n',
   'a',
   'b',
   'l',
   'e',
   'A',
   'M',
   'D',
   0, // glDebugMessageEnableAMD
   'g',
   'l',
   'D',
   'e',
   'b',
   'u',
   'g',
   'M',
   'e',
   's',
   's',
   'a',
   'g',
   'e',
   'I',
   'n',
   's',
   'e',
   'r',
   't',
   0, // glDebugMessageInsert
   'g',
   'l',
   'D',
   'e',
   'b',
   'u',
   'g',
   'M',
   'e',
   's',
   's',
   'a',
   'g',
   'e',
   'I',
   'n',
   's',
   'e',
   'r',
   't',
   'A',
   'M',
   'D',
   0, // glDebugMessageInsertAMD
   'g',
   'l',
   'D',
   'e',
   'b',
   'u',
   'g',
   'M',
   'e',
   's',
   's',
   'a',
   'g',
   'e',
   'I',
   'n',
   's',
   'e',
   'r',
   't',
   'A',
   'R',
   'B',
   0, // glDebugMessageInsertARB
   'g',
   'l',
   'D',
   'e',
   'b',
   'u',
   'g',
   'M',
   'e',
   's',
   's',
   'a',
   'g',
   'e',
   'I',
   'n',
   's',
   'e',
   'r',
   't',
   'K',
   'H',
   'R',
   0, // glDebugMessageInsertKHR
   'g',
   'l',
   'D',
   'e',
   'f',
   'o',
   'r',
   'm',
   'S',
   'G',
   'I',
   'X',
   0, // glDeformSGIX
   'g',
   'l',
   'D',
   'e',
   'f',
   'o',
   'r',
   'm',
   'a',
   't',
   'i',
   'o',
   'n',
   'M',
   'a',
   'p',
   '3',
   'd',
   'S',
   'G',
   'I',
   'X',
   0, // glDeformationMap3dSGIX
   'g',
   'l',
   'D',
   'e',
   'f',
   'o',
   'r',
   'm',
   'a',
   't',
   'i',
   'o',
   'n',
   'M',
   'a',
   'p',
   '3',
   'f',
   'S',
   'G',
   'I',
   'X',
   0, // glDeformationMap3fSGIX
   'g',
   'l',
   'D',
   'e',
   'l',
   'e',
   't',
   'e',
   'A',
   's',
   'y',
   'n',
   'c',
   'M',
   'a',
   'r',
   'k',
   'e',
   'r',
   's',
   'S',
   'G',
   'I',
   'X',
   0, // glDeleteAsyncMarkersSGIX
   'g',
   'l',
   'D',
   'e',
   'l',
   'e',
   't',
   'e',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   's',
   0, // glDeleteBuffers
   'g',
   'l',
   'D',
   'e',
   'l',
   'e',
   't',
   'e',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   's',
   'A',
   'R',
   'B',
   0, // glDeleteBuffersARB
   'g',
   'l',
   'D',
   'e',
   'l',
   'e',
   't',
   'e',
   'C',
   'o',
   'm',
   'm',
   'a',
   'n',
   'd',
   'L',
   'i',
   's',
   't',
   's',
   'N',
   'V',
   0, // glDeleteCommandListsNV
   'g',
   'l',
   'D',
   'e',
   'l',
   'e',
   't',
   'e',
   'F',
   'e',
   'n',
   'c',
   'e',
   's',
   'A',
   'P',
   'P',
   'L',
   'E',
   0, // glDeleteFencesAPPLE
   'g',
   'l',
   'D',
   'e',
   'l',
   'e',
   't',
   'e',
   'F',
   'e',
   'n',
   'c',
   'e',
   's',
   'N',
   'V',
   0, // glDeleteFencesNV
   'g',
   'l',
   'D',
   'e',
   'l',
   'e',
   't',
   'e',
   'F',
   'r',
   'a',
   'g',
   'm',
   'e',
   'n',
   't',
   'S',
   'h',
   'a',
   'd',
   'e',
   'r',
   'A',
   'T',
   'I',
   0, // glDeleteFragmentShaderATI
   'g',
   'l',
   'D',
   'e',
   'l',
   'e',
   't',
   'e',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   's',
   0, // glDeleteFramebuffers
   'g',
   'l',
   'D',
   'e',
   'l',
   'e',
   't',
   'e',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   's',
   'E',
   'X',
   'T',
   0, // glDeleteFramebuffersEXT
   'g',
   'l',
   'D',
   'e',
   'l',
   'e',
   't',
   'e',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   's',
   'O',
   'E',
   'S',
   0, // glDeleteFramebuffersOES
   'g',
   'l',
   'D',
   'e',
   'l',
   'e',
   't',
   'e',
   'L',
   'i',
   's',
   't',
   's',
   0, // glDeleteLists
   'g',
   'l',
   'D',
   'e',
   'l',
   'e',
   't',
   'e',
   'M',
   'e',
   'm',
   'o',
   'r',
   'y',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   's',
   'E',
   'X',
   'T',
   0, // glDeleteMemoryObjectsEXT
   'g',
   'l',
   'D',
   'e',
   'l',
   'e',
   't',
   'e',
   'N',
   'a',
   'm',
   'e',
   'd',
   'S',
   't',
   'r',
   'i',
   'n',
   'g',
   'A',
   'R',
   'B',
   0, // glDeleteNamedStringARB
   'g',
   'l',
   'D',
   'e',
   'l',
   'e',
   't',
   'e',
   'N',
   'a',
   'm',
   'e',
   's',
   'A',
   'M',
   'D',
   0, // glDeleteNamesAMD
   'g',
   'l',
   'D',
   'e',
   'l',
   'e',
   't',
   'e',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'A',
   'R',
   'B',
   0, // glDeleteObjectARB
   'g',
   'l',
   'D',
   'e',
   'l',
   'e',
   't',
   'e',
   'O',
   'c',
   'c',
   'l',
   'u',
   's',
   'i',
   'o',
   'n',
   'Q',
   'u',
   'e',
   'r',
   'i',
   'e',
   's',
   'N',
   'V',
   0, // glDeleteOcclusionQueriesNV
   'g',
   'l',
   'D',
   'e',
   'l',
   'e',
   't',
   'e',
   'P',
   'a',
   't',
   'h',
   's',
   'N',
   'V',
   0, // glDeletePathsNV
   'g',
   'l',
   'D',
   'e',
   'l',
   'e',
   't',
   'e',
   'P',
   'e',
   'r',
   'f',
   'M',
   'o',
   'n',
   'i',
   't',
   'o',
   'r',
   's',
   'A',
   'M',
   'D',
   0, // glDeletePerfMonitorsAMD
   'g',
   'l',
   'D',
   'e',
   'l',
   'e',
   't',
   'e',
   'P',
   'e',
   'r',
   'f',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'I',
   'N',
   'T',
   'E',
   'L',
   0, // glDeletePerfQueryINTEL
   'g',
   'l',
   'D',
   'e',
   'l',
   'e',
   't',
   'e',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   0, // glDeleteProgram
   'g',
   'l',
   'D',
   'e',
   'l',
   'e',
   't',
   'e',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'P',
   'i',
   'p',
   'e',
   'l',
   'i',
   'n',
   'e',
   's',
   0, // glDeleteProgramPipelines
   'g',
   'l',
   'D',
   'e',
   'l',
   'e',
   't',
   'e',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'P',
   'i',
   'p',
   'e',
   'l',
   'i',
   'n',
   'e',
   's',
   'E',
   'X',
   'T',
   0, // glDeleteProgramPipelinesEXT
   'g',
   'l',
   'D',
   'e',
   'l',
   'e',
   't',
   'e',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   's',
   'A',
   'R',
   'B',
   0, // glDeleteProgramsARB
   'g',
   'l',
   'D',
   'e',
   'l',
   'e',
   't',
   'e',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   's',
   'N',
   'V',
   0, // glDeleteProgramsNV
   'g',
   'l',
   'D',
   'e',
   'l',
   'e',
   't',
   'e',
   'Q',
   'u',
   'e',
   'r',
   'i',
   'e',
   's',
   0, // glDeleteQueries
   'g',
   'l',
   'D',
   'e',
   'l',
   'e',
   't',
   'e',
   'Q',
   'u',
   'e',
   'r',
   'i',
   'e',
   's',
   'A',
   'R',
   'B',
   0, // glDeleteQueriesARB
   'g',
   'l',
   'D',
   'e',
   'l',
   'e',
   't',
   'e',
   'Q',
   'u',
   'e',
   'r',
   'i',
   'e',
   's',
   'E',
   'X',
   'T',
   0, // glDeleteQueriesEXT
   'g',
   'l',
   'D',
   'e',
   'l',
   'e',
   't',
   'e',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'R',
   'e',
   's',
   'o',
   'u',
   'r',
   'c',
   'e',
   'T',
   'a',
   'g',
   'N',
   'V',
   0, // glDeleteQueryResourceTagNV
   'g',
   'l',
   'D',
   'e',
   'l',
   'e',
   't',
   'e',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   's',
   0, // glDeleteRenderbuffers
   'g',
   'l',
   'D',
   'e',
   'l',
   'e',
   't',
   'e',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   's',
   'E',
   'X',
   'T',
   0, // glDeleteRenderbuffersEXT
   'g',
   'l',
   'D',
   'e',
   'l',
   'e',
   't',
   'e',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   's',
   'O',
   'E',
   'S',
   0, // glDeleteRenderbuffersOES
   'g',
   'l',
   'D',
   'e',
   'l',
   'e',
   't',
   'e',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'r',
   's',
   0, // glDeleteSamplers
   'g',
   'l',
   'D',
   'e',
   'l',
   'e',
   't',
   'e',
   'S',
   'e',
   'm',
   'a',
   'p',
   'h',
   'o',
   'r',
   'e',
   's',
   'E',
   'X',
   'T',
   0, // glDeleteSemaphoresEXT
   'g',
   'l',
   'D',
   'e',
   'l',
   'e',
   't',
   'e',
   'S',
   'h',
   'a',
   'd',
   'e',
   'r',
   0, // glDeleteShader
   'g',
   'l',
   'D',
   'e',
   'l',
   'e',
   't',
   'e',
   'S',
   't',
   'a',
   't',
   'e',
   's',
   'N',
   'V',
   0, // glDeleteStatesNV
   'g',
   'l',
   'D',
   'e',
   'l',
   'e',
   't',
   'e',
   'S',
   'y',
   'n',
   'c',
   0, // glDeleteSync
   'g',
   'l',
   'D',
   'e',
   'l',
   'e',
   't',
   'e',
   'S',
   'y',
   'n',
   'c',
   'A',
   'P',
   'P',
   'L',
   'E',
   0, // glDeleteSyncAPPLE
   'g',
   'l',
   'D',
   'e',
   'l',
   'e',
   't',
   'e',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   's',
   0, // glDeleteTextures
   'g',
   'l',
   'D',
   'e',
   'l',
   'e',
   't',
   'e',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   's',
   'E',
   'X',
   'T',
   0, // glDeleteTexturesEXT
   'g',
   'l',
   'D',
   'e',
   'l',
   'e',
   't',
   'e',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'F',
   'e',
   'e',
   'd',
   'b',
   'a',
   'c',
   'k',
   's',
   0, // glDeleteTransformFeedbacks
   'g',
   'l',
   'D',
   'e',
   'l',
   'e',
   't',
   'e',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'F',
   'e',
   'e',
   'd',
   'b',
   'a',
   'c',
   'k',
   's',
   'N',
   'V',
   0, // glDeleteTransformFeedbacksNV
   'g',
   'l',
   'D',
   'e',
   'l',
   'e',
   't',
   'e',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   's',
   0, // glDeleteVertexArrays
   'g',
   'l',
   'D',
   'e',
   'l',
   'e',
   't',
   'e',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   's',
   'A',
   'P',
   'P',
   'L',
   'E',
   0, // glDeleteVertexArraysAPPLE
   'g',
   'l',
   'D',
   'e',
   'l',
   'e',
   't',
   'e',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   's',
   'O',
   'E',
   'S',
   0, // glDeleteVertexArraysOES
   'g',
   'l',
   'D',
   'e',
   'l',
   'e',
   't',
   'e',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'S',
   'h',
   'a',
   'd',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glDeleteVertexShaderEXT
   'g',
   'l',
   'D',
   'e',
   'p',
   't',
   'h',
   'B',
   'o',
   'u',
   'n',
   'd',
   's',
   'E',
   'X',
   'T',
   0, // glDepthBoundsEXT
   'g',
   'l',
   'D',
   'e',
   'p',
   't',
   'h',
   'B',
   'o',
   'u',
   'n',
   'd',
   's',
   'd',
   'N',
   'V',
   0, // glDepthBoundsdNV
   'g',
   'l',
   'D',
   'e',
   'p',
   't',
   'h',
   'F',
   'u',
   'n',
   'c',
   0, // glDepthFunc
   'g',
   'l',
   'D',
   'e',
   'p',
   't',
   'h',
   'M',
   'a',
   's',
   'k',
   0, // glDepthMask
   'g',
   'l',
   'D',
   'e',
   'p',
   't',
   'h',
   'R',
   'a',
   'n',
   'g',
   'e',
   0, // glDepthRange
   'g',
   'l',
   'D',
   'e',
   'p',
   't',
   'h',
   'R',
   'a',
   'n',
   'g',
   'e',
   'A',
   'r',
   'r',
   'a',
   'y',
   'f',
   'v',
   'N',
   'V',
   0, // glDepthRangeArrayfvNV
   'g',
   'l',
   'D',
   'e',
   'p',
   't',
   'h',
   'R',
   'a',
   'n',
   'g',
   'e',
   'A',
   'r',
   'r',
   'a',
   'y',
   'f',
   'v',
   'O',
   'E',
   'S',
   0, // glDepthRangeArrayfvOES
   'g',
   'l',
   'D',
   'e',
   'p',
   't',
   'h',
   'R',
   'a',
   'n',
   'g',
   'e',
   'A',
   'r',
   'r',
   'a',
   'y',
   'v',
   0, // glDepthRangeArrayv
   'g',
   'l',
   'D',
   'e',
   'p',
   't',
   'h',
   'R',
   'a',
   'n',
   'g',
   'e',
   'I',
   'n',
   'd',
   'e',
   'x',
   'e',
   'd',
   0, // glDepthRangeIndexed
   'g',
   'l',
   'D',
   'e',
   'p',
   't',
   'h',
   'R',
   'a',
   'n',
   'g',
   'e',
   'I',
   'n',
   'd',
   'e',
   'x',
   'e',
   'd',
   'f',
   'N',
   'V',
   0, // glDepthRangeIndexedfNV
   'g',
   'l',
   'D',
   'e',
   'p',
   't',
   'h',
   'R',
   'a',
   'n',
   'g',
   'e',
   'I',
   'n',
   'd',
   'e',
   'x',
   'e',
   'd',
   'f',
   'O',
   'E',
   'S',
   0, // glDepthRangeIndexedfOES
   'g',
   'l',
   'D',
   'e',
   'p',
   't',
   'h',
   'R',
   'a',
   'n',
   'g',
   'e',
   'd',
   'N',
   'V',
   0, // glDepthRangedNV
   'g',
   'l',
   'D',
   'e',
   'p',
   't',
   'h',
   'R',
   'a',
   'n',
   'g',
   'e',
   'f',
   0, // glDepthRangef
   'g',
   'l',
   'D',
   'e',
   'p',
   't',
   'h',
   'R',
   'a',
   'n',
   'g',
   'e',
   'f',
   'O',
   'E',
   'S',
   0, // glDepthRangefOES
   'g',
   'l',
   'D',
   'e',
   'p',
   't',
   'h',
   'R',
   'a',
   'n',
   'g',
   'e',
   'x',
   0, // glDepthRangex
   'g',
   'l',
   'D',
   'e',
   'p',
   't',
   'h',
   'R',
   'a',
   'n',
   'g',
   'e',
   'x',
   'O',
   'E',
   'S',
   0, // glDepthRangexOES
   'g',
   'l',
   'D',
   'e',
   't',
   'a',
   'c',
   'h',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'A',
   'R',
   'B',
   0, // glDetachObjectARB
   'g',
   'l',
   'D',
   'e',
   't',
   'a',
   'c',
   'h',
   'S',
   'h',
   'a',
   'd',
   'e',
   'r',
   0, // glDetachShader
   'g',
   'l',
   'D',
   'e',
   't',
   'a',
   'i',
   'l',
   'T',
   'e',
   'x',
   'F',
   'u',
   'n',
   'c',
   'S',
   'G',
   'I',
   'S',
   0, // glDetailTexFuncSGIS
   'g',
   'l',
   'D',
   'i',
   's',
   'a',
   'b',
   'l',
   'e',
   0, // glDisable
   'g',
   'l',
   'D',
   'i',
   's',
   'a',
   'b',
   'l',
   'e',
   'C',
   'l',
   'i',
   'e',
   'n',
   't',
   'S',
   't',
   'a',
   't',
   'e',
   0, // glDisableClientState
   'g',
   'l',
   'D',
   'i',
   's',
   'a',
   'b',
   'l',
   'e',
   'C',
   'l',
   'i',
   'e',
   'n',
   't',
   'S',
   't',
   'a',
   't',
   'e',
   'I',
   'n',
   'd',
   'e',
   'x',
   'e',
   'd',
   'E',
   'X',
   'T',
   0, // glDisableClientStateIndexedEXT
   'g',
   'l',
   'D',
   'i',
   's',
   'a',
   'b',
   'l',
   'e',
   'C',
   'l',
   'i',
   'e',
   'n',
   't',
   'S',
   't',
   'a',
   't',
   'e',
   'i',
   'E',
   'X',
   'T',
   0, // glDisableClientStateiEXT
   'g',
   'l',
   'D',
   'i',
   's',
   'a',
   'b',
   'l',
   'e',
   'D',
   'r',
   'i',
   'v',
   'e',
   'r',
   'C',
   'o',
   'n',
   't',
   'r',
   'o',
   'l',
   'Q',
   'C',
   'O',
   'M',
   0, // glDisableDriverControlQCOM
   'g',
   'l',
   'D',
   'i',
   's',
   'a',
   'b',
   'l',
   'e',
   'I',
   'n',
   'd',
   'e',
   'x',
   'e',
   'd',
   'E',
   'X',
   'T',
   0, // glDisableIndexedEXT
   'g',
   'l',
   'D',
   'i',
   's',
   'a',
   'b',
   'l',
   'e',
   'V',
   'a',
   'r',
   'i',
   'a',
   'n',
   't',
   'C',
   'l',
   'i',
   'e',
   'n',
   't',
   'S',
   't',
   'a',
   't',
   'e',
   'E',
   'X',
   'T',
   0, // glDisableVariantClientStateEXT
   'g',
   'l',
   'D',
   'i',
   's',
   'a',
   'b',
   'l',
   'e',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   0, // glDisableVertexArrayAttrib
   'g',
   'l',
   'D',
   'i',
   's',
   'a',
   'b',
   'l',
   'e',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'E',
   'X',
   'T',
   0, // glDisableVertexArrayAttribEXT
   'g',
   'l',
   'D',
   'i',
   's',
   'a',
   'b',
   'l',
   'e',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'E',
   'X',
   'T',
   0, // glDisableVertexArrayEXT
   'g',
   'l',
   'D',
   'i',
   's',
   'a',
   'b',
   'l',
   'e',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'A',
   'P',
   'P',
   'L',
   'E',
   0, // glDisableVertexAttribAPPLE
   'g',
   'l',
   'D',
   'i',
   's',
   'a',
   'b',
   'l',
   'e',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'A',
   'r',
   'r',
   'a',
   'y',
   0, // glDisableVertexAttribArray
   'g',
   'l',
   'D',
   'i',
   's',
   'a',
   'b',
   'l',
   'e',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'A',
   'r',
   'r',
   'a',
   'y',
   'A',
   'R',
   'B',
   0, // glDisableVertexAttribArrayARB
   'g',
   'l',
   'D',
   'i',
   's',
   'a',
   'b',
   'l',
   'e',
   'i',
   0, // glDisablei
   'g',
   'l',
   'D',
   'i',
   's',
   'a',
   'b',
   'l',
   'e',
   'i',
   'E',
   'X',
   'T',
   0, // glDisableiEXT
   'g',
   'l',
   'D',
   'i',
   's',
   'a',
   'b',
   'l',
   'e',
   'i',
   'N',
   'V',
   0, // glDisableiNV
   'g',
   'l',
   'D',
   'i',
   's',
   'a',
   'b',
   'l',
   'e',
   'i',
   'O',
   'E',
   'S',
   0, // glDisableiOES
   'g',
   'l',
   'D',
   'i',
   's',
   'c',
   'a',
   'r',
   'd',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glDiscardFramebufferEXT
   'g',
   'l',
   'D',
   'i',
   's',
   'p',
   'a',
   't',
   'c',
   'h',
   'C',
   'o',
   'm',
   'p',
   'u',
   't',
   'e',
   0, // glDispatchCompute
   'g',
   'l',
   'D',
   'i',
   's',
   'p',
   'a',
   't',
   'c',
   'h',
   'C',
   'o',
   'm',
   'p',
   'u',
   't',
   'e',
   'G',
   'r',
   'o',
   'u',
   'p',
   'S',
   'i',
   'z',
   'e',
   'A',
   'R',
   'B',
   0, // glDispatchComputeGroupSizeARB
   'g',
   'l',
   'D',
   'i',
   's',
   'p',
   'a',
   't',
   'c',
   'h',
   'C',
   'o',
   'm',
   'p',
   'u',
   't',
   'e',
   'I',
   'n',
   'd',
   'i',
   'r',
   'e',
   'c',
   't',
   0, // glDispatchComputeIndirect
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'A',
   'r',
   'r',
   'a',
   'y',
   's',
   0, // glDrawArrays
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'A',
   'r',
   'r',
   'a',
   'y',
   's',
   'E',
   'X',
   'T',
   0, // glDrawArraysEXT
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'A',
   'r',
   'r',
   'a',
   'y',
   's',
   'I',
   'n',
   'd',
   'i',
   'r',
   'e',
   'c',
   't',
   0, // glDrawArraysIndirect
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'A',
   'r',
   'r',
   'a',
   'y',
   's',
   'I',
   'n',
   's',
   't',
   'a',
   'n',
   'c',
   'e',
   'd',
   0, // glDrawArraysInstanced
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'A',
   'r',
   'r',
   'a',
   'y',
   's',
   'I',
   'n',
   's',
   't',
   'a',
   'n',
   'c',
   'e',
   'd',
   'A',
   'N',
   'G',
   'L',
   'E',
   0, // glDrawArraysInstancedANGLE
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'A',
   'r',
   'r',
   'a',
   'y',
   's',
   'I',
   'n',
   's',
   't',
   'a',
   'n',
   'c',
   'e',
   'd',
   'A',
   'R',
   'B',
   0, // glDrawArraysInstancedARB
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'A',
   'r',
   'r',
   'a',
   'y',
   's',
   'I',
   'n',
   's',
   't',
   'a',
   'n',
   'c',
   'e',
   'd',
   'B',
   'a',
   's',
   'e',
   'I',
   'n',
   's',
   't',
   'a',
   'n',
   'c',
   'e',
   0, // glDrawArraysInstancedBaseInstance
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'A',
   'r',
   'r',
   'a',
   'y',
   's',
   'I',
   'n',
   's',
   't',
   'a',
   'n',
   'c',
   'e',
   'd',
   'B',
   'a',
   's',
   'e',
   'I',
   'n',
   's',
   't',
   'a',
   'n',
   'c',
   'e',
   'E',
   'X',
   'T',
   0, // glDrawArraysInstancedBaseInstanceEXT
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'A',
   'r',
   'r',
   'a',
   'y',
   's',
   'I',
   'n',
   's',
   't',
   'a',
   'n',
   'c',
   'e',
   'd',
   'E',
   'X',
   'T',
   0, // glDrawArraysInstancedEXT
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'A',
   'r',
   'r',
   'a',
   'y',
   's',
   'I',
   'n',
   's',
   't',
   'a',
   'n',
   'c',
   'e',
   'd',
   'N',
   'V',
   0, // glDrawArraysInstancedNV
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   0, // glDrawBuffer
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   's',
   0, // glDrawBuffers
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   's',
   'A',
   'R',
   'B',
   0, // glDrawBuffersARB
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   's',
   'A',
   'T',
   'I',
   0, // glDrawBuffersATI
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   's',
   'E',
   'X',
   'T',
   0, // glDrawBuffersEXT
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   's',
   'I',
   'n',
   'd',
   'e',
   'x',
   'e',
   'd',
   'E',
   'X',
   'T',
   0, // glDrawBuffersIndexedEXT
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   's',
   'N',
   'V',
   0, // glDrawBuffersNV
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'C',
   'o',
   'm',
   'm',
   'a',
   'n',
   'd',
   's',
   'A',
   'd',
   'd',
   'r',
   'e',
   's',
   's',
   'N',
   'V',
   0, // glDrawCommandsAddressNV
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'C',
   'o',
   'm',
   'm',
   'a',
   'n',
   'd',
   's',
   'N',
   'V',
   0, // glDrawCommandsNV
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'C',
   'o',
   'm',
   'm',
   'a',
   'n',
   'd',
   's',
   'S',
   't',
   'a',
   't',
   'e',
   's',
   'A',
   'd',
   'd',
   'r',
   'e',
   's',
   's',
   'N',
   'V',
   0, // glDrawCommandsStatesAddressNV
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'C',
   'o',
   'm',
   'm',
   'a',
   'n',
   'd',
   's',
   'S',
   't',
   'a',
   't',
   'e',
   's',
   'N',
   'V',
   0, // glDrawCommandsStatesNV
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'E',
   'l',
   'e',
   'm',
   'e',
   'n',
   't',
   'A',
   'r',
   'r',
   'a',
   'y',
   'A',
   'P',
   'P',
   'L',
   'E',
   0, // glDrawElementArrayAPPLE
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'E',
   'l',
   'e',
   'm',
   'e',
   'n',
   't',
   'A',
   'r',
   'r',
   'a',
   'y',
   'A',
   'T',
   'I',
   0, // glDrawElementArrayATI
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'E',
   'l',
   'e',
   'm',
   'e',
   'n',
   't',
   's',
   0, // glDrawElements
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'E',
   'l',
   'e',
   'm',
   'e',
   'n',
   't',
   's',
   'B',
   'a',
   's',
   'e',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   0, // glDrawElementsBaseVertex
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'E',
   'l',
   'e',
   'm',
   'e',
   'n',
   't',
   's',
   'B',
   'a',
   's',
   'e',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'E',
   'X',
   'T',
   0, // glDrawElementsBaseVertexEXT
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'E',
   'l',
   'e',
   'm',
   'e',
   'n',
   't',
   's',
   'B',
   'a',
   's',
   'e',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'O',
   'E',
   'S',
   0, // glDrawElementsBaseVertexOES
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'E',
   'l',
   'e',
   'm',
   'e',
   'n',
   't',
   's',
   'I',
   'n',
   'd',
   'i',
   'r',
   'e',
   'c',
   't',
   0, // glDrawElementsIndirect
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'E',
   'l',
   'e',
   'm',
   'e',
   'n',
   't',
   's',
   'I',
   'n',
   's',
   't',
   'a',
   'n',
   'c',
   'e',
   'd',
   0, // glDrawElementsInstanced
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'E',
   'l',
   'e',
   'm',
   'e',
   'n',
   't',
   's',
   'I',
   'n',
   's',
   't',
   'a',
   'n',
   'c',
   'e',
   'd',
   'A',
   'N',
   'G',
   'L',
   'E',
   0, // glDrawElementsInstancedANGLE
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'E',
   'l',
   'e',
   'm',
   'e',
   'n',
   't',
   's',
   'I',
   'n',
   's',
   't',
   'a',
   'n',
   'c',
   'e',
   'd',
   'A',
   'R',
   'B',
   0, // glDrawElementsInstancedARB
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'E',
   'l',
   'e',
   'm',
   'e',
   'n',
   't',
   's',
   'I',
   'n',
   's',
   't',
   'a',
   'n',
   'c',
   'e',
   'd',
   'B',
   'a',
   's',
   'e',
   'I',
   'n',
   's',
   't',
   'a',
   'n',
   'c',
   'e',
   0, // glDrawElementsInstancedBaseInstance
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'E',
   'l',
   'e',
   'm',
   'e',
   'n',
   't',
   's',
   'I',
   'n',
   's',
   't',
   'a',
   'n',
   'c',
   'e',
   'd',
   'B',
   'a',
   's',
   'e',
   'I',
   'n',
   's',
   't',
   'a',
   'n',
   'c',
   'e',
   'E',
   'X',
   'T',
   0, // glDrawElementsInstancedBaseInstanceEXT
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'E',
   'l',
   'e',
   'm',
   'e',
   'n',
   't',
   's',
   'I',
   'n',
   's',
   't',
   'a',
   'n',
   'c',
   'e',
   'd',
   'B',
   'a',
   's',
   'e',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   0, // glDrawElementsInstancedBaseVertex
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'E',
   'l',
   'e',
   'm',
   'e',
   'n',
   't',
   's',
   'I',
   'n',
   's',
   't',
   'a',
   'n',
   'c',
   'e',
   'd',
   'B',
   'a',
   's',
   'e',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'B',
   'a',
   's',
   'e',
   'I',
   'n',
   's',
   't',
   'a',
   'n',
   'c',
   'e',
   0, // glDrawElementsInstancedBaseVertexBaseInstance
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'E',
   'l',
   'e',
   'm',
   'e',
   'n',
   't',
   's',
   'I',
   'n',
   's',
   't',
   'a',
   'n',
   'c',
   'e',
   'd',
   'B',
   'a',
   's',
   'e',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'B',
   'a',
   's',
   'e',
   'I',
   'n',
   's',
   't',
   'a',
   'n',
   'c',
   'e',
   'E',
   'X',
   'T',
   0, // glDrawElementsInstancedBaseVertexBaseInstanceEXT
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'E',
   'l',
   'e',
   'm',
   'e',
   'n',
   't',
   's',
   'I',
   'n',
   's',
   't',
   'a',
   'n',
   'c',
   'e',
   'd',
   'B',
   'a',
   's',
   'e',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'E',
   'X',
   'T',
   0, // glDrawElementsInstancedBaseVertexEXT
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'E',
   'l',
   'e',
   'm',
   'e',
   'n',
   't',
   's',
   'I',
   'n',
   's',
   't',
   'a',
   'n',
   'c',
   'e',
   'd',
   'B',
   'a',
   's',
   'e',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'O',
   'E',
   'S',
   0, // glDrawElementsInstancedBaseVertexOES
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'E',
   'l',
   'e',
   'm',
   'e',
   'n',
   't',
   's',
   'I',
   'n',
   's',
   't',
   'a',
   'n',
   'c',
   'e',
   'd',
   'E',
   'X',
   'T',
   0, // glDrawElementsInstancedEXT
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'E',
   'l',
   'e',
   'm',
   'e',
   'n',
   't',
   's',
   'I',
   'n',
   's',
   't',
   'a',
   'n',
   'c',
   'e',
   'd',
   'N',
   'V',
   0, // glDrawElementsInstancedNV
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'M',
   'e',
   's',
   'h',
   'A',
   'r',
   'r',
   'a',
   'y',
   's',
   'S',
   'U',
   'N',
   0, // glDrawMeshArraysSUN
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'M',
   'e',
   's',
   'h',
   'T',
   'a',
   's',
   'k',
   's',
   'I',
   'n',
   'd',
   'i',
   'r',
   'e',
   'c',
   't',
   'N',
   'V',
   0, // glDrawMeshTasksIndirectNV
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'M',
   'e',
   's',
   'h',
   'T',
   'a',
   's',
   'k',
   's',
   'N',
   'V',
   0, // glDrawMeshTasksNV
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'P',
   'i',
   'x',
   'e',
   'l',
   's',
   0, // glDrawPixels
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'R',
   'a',
   'n',
   'g',
   'e',
   'E',
   'l',
   'e',
   'm',
   'e',
   'n',
   't',
   'A',
   'r',
   'r',
   'a',
   'y',
   'A',
   'P',
   'P',
   'L',
   'E',
   0, // glDrawRangeElementArrayAPPLE
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'R',
   'a',
   'n',
   'g',
   'e',
   'E',
   'l',
   'e',
   'm',
   'e',
   'n',
   't',
   'A',
   'r',
   'r',
   'a',
   'y',
   'A',
   'T',
   'I',
   0, // glDrawRangeElementArrayATI
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'R',
   'a',
   'n',
   'g',
   'e',
   'E',
   'l',
   'e',
   'm',
   'e',
   'n',
   't',
   's',
   0, // glDrawRangeElements
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'R',
   'a',
   'n',
   'g',
   'e',
   'E',
   'l',
   'e',
   'm',
   'e',
   'n',
   't',
   's',
   'B',
   'a',
   's',
   'e',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   0, // glDrawRangeElementsBaseVertex
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'R',
   'a',
   'n',
   'g',
   'e',
   'E',
   'l',
   'e',
   'm',
   'e',
   'n',
   't',
   's',
   'B',
   'a',
   's',
   'e',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'E',
   'X',
   'T',
   0, // glDrawRangeElementsBaseVertexEXT
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'R',
   'a',
   'n',
   'g',
   'e',
   'E',
   'l',
   'e',
   'm',
   'e',
   'n',
   't',
   's',
   'B',
   'a',
   's',
   'e',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'O',
   'E',
   'S',
   0, // glDrawRangeElementsBaseVertexOES
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'R',
   'a',
   'n',
   'g',
   'e',
   'E',
   'l',
   'e',
   'm',
   'e',
   'n',
   't',
   's',
   'E',
   'X',
   'T',
   0, // glDrawRangeElementsEXT
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'T',
   'e',
   'x',
   'f',
   'O',
   'E',
   'S',
   0, // glDrawTexfOES
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'T',
   'e',
   'x',
   'f',
   'v',
   'O',
   'E',
   'S',
   0, // glDrawTexfvOES
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'T',
   'e',
   'x',
   'i',
   'O',
   'E',
   'S',
   0, // glDrawTexiOES
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'T',
   'e',
   'x',
   'i',
   'v',
   'O',
   'E',
   'S',
   0, // glDrawTexivOES
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'T',
   'e',
   'x',
   's',
   'O',
   'E',
   'S',
   0, // glDrawTexsOES
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'T',
   'e',
   'x',
   's',
   'v',
   'O',
   'E',
   'S',
   0, // glDrawTexsvOES
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'N',
   'V',
   0, // glDrawTextureNV
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'T',
   'e',
   'x',
   'x',
   'O',
   'E',
   'S',
   0, // glDrawTexxOES
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'T',
   'e',
   'x',
   'x',
   'v',
   'O',
   'E',
   'S',
   0, // glDrawTexxvOES
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'F',
   'e',
   'e',
   'd',
   'b',
   'a',
   'c',
   'k',
   0, // glDrawTransformFeedback
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'F',
   'e',
   'e',
   'd',
   'b',
   'a',
   'c',
   'k',
   'E',
   'X',
   'T',
   0, // glDrawTransformFeedbackEXT
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'F',
   'e',
   'e',
   'd',
   'b',
   'a',
   'c',
   'k',
   'I',
   'n',
   's',
   't',
   'a',
   'n',
   'c',
   'e',
   'd',
   0, // glDrawTransformFeedbackInstanced
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'F',
   'e',
   'e',
   'd',
   'b',
   'a',
   'c',
   'k',
   'I',
   'n',
   's',
   't',
   'a',
   'n',
   'c',
   'e',
   'd',
   'E',
   'X',
   'T',
   0, // glDrawTransformFeedbackInstancedEXT
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'F',
   'e',
   'e',
   'd',
   'b',
   'a',
   'c',
   'k',
   'N',
   'V',
   0, // glDrawTransformFeedbackNV
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'F',
   'e',
   'e',
   'd',
   'b',
   'a',
   'c',
   'k',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   0, // glDrawTransformFeedbackStream
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'F',
   'e',
   'e',
   'd',
   'b',
   'a',
   'c',
   'k',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   'I',
   'n',
   's',
   't',
   'a',
   'n',
   'c',
   'e',
   'd',
   0, // glDrawTransformFeedbackStreamInstanced
   'g',
   'l',
   'D',
   'r',
   'a',
   'w',
   'V',
   'k',
   'I',
   'm',
   'a',
   'g',
   'e',
   'N',
   'V',
   0, // glDrawVkImageNV
   'g',
   'l',
   'E',
   'G',
   'L',
   'I',
   'm',
   'a',
   'g',
   'e',
   'T',
   'a',
   'r',
   'g',
   'e',
   't',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   'O',
   'E',
   'S',
   0, // glEGLImageTargetRenderbufferStorageOES
   'g',
   'l',
   'E',
   'G',
   'L',
   'I',
   'm',
   'a',
   'g',
   'e',
   'T',
   'a',
   'r',
   'g',
   'e',
   't',
   'T',
   'e',
   'x',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   'E',
   'X',
   'T',
   0, // glEGLImageTargetTexStorageEXT
   'g',
   'l',
   'E',
   'G',
   'L',
   'I',
   'm',
   'a',
   'g',
   'e',
   'T',
   'a',
   'r',
   'g',
   'e',
   't',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   '2',
   'D',
   'O',
   'E',
   'S',
   0, // glEGLImageTargetTexture2DOES
   'g',
   'l',
   'E',
   'G',
   'L',
   'I',
   'm',
   'a',
   'g',
   'e',
   'T',
   'a',
   'r',
   'g',
   'e',
   't',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   'E',
   'X',
   'T',
   0, // glEGLImageTargetTextureStorageEXT
   'g',
   'l',
   'E',
   'd',
   'g',
   'e',
   'F',
   'l',
   'a',
   'g',
   0, // glEdgeFlag
   'g',
   'l',
   'E',
   'd',
   'g',
   'e',
   'F',
   'l',
   'a',
   'g',
   'F',
   'o',
   'r',
   'm',
   'a',
   't',
   'N',
   'V',
   0, // glEdgeFlagFormatNV
   'g',
   'l',
   'E',
   'd',
   'g',
   'e',
   'F',
   'l',
   'a',
   'g',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   0, // glEdgeFlagPointer
   'g',
   'l',
   'E',
   'd',
   'g',
   'e',
   'F',
   'l',
   'a',
   'g',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glEdgeFlagPointerEXT
   'g',
   'l',
   'E',
   'd',
   'g',
   'e',
   'F',
   'l',
   'a',
   'g',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'L',
   'i',
   's',
   't',
   'I',
   'B',
   'M',
   0, // glEdgeFlagPointerListIBM
   'g',
   'l',
   'E',
   'd',
   'g',
   'e',
   'F',
   'l',
   'a',
   'g',
   'v',
   0, // glEdgeFlagv
   'g',
   'l',
   'E',
   'l',
   'e',
   'm',
   'e',
   'n',
   't',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'A',
   'P',
   'P',
   'L',
   'E',
   0, // glElementPointerAPPLE
   'g',
   'l',
   'E',
   'l',
   'e',
   'm',
   'e',
   'n',
   't',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'A',
   'T',
   'I',
   0, // glElementPointerATI
   'g',
   'l',
   'E',
   'n',
   'a',
   'b',
   'l',
   'e',
   0, // glEnable
   'g',
   'l',
   'E',
   'n',
   'a',
   'b',
   'l',
   'e',
   'C',
   'l',
   'i',
   'e',
   'n',
   't',
   'S',
   't',
   'a',
   't',
   'e',
   0, // glEnableClientState
   'g',
   'l',
   'E',
   'n',
   'a',
   'b',
   'l',
   'e',
   'C',
   'l',
   'i',
   'e',
   'n',
   't',
   'S',
   't',
   'a',
   't',
   'e',
   'I',
   'n',
   'd',
   'e',
   'x',
   'e',
   'd',
   'E',
   'X',
   'T',
   0, // glEnableClientStateIndexedEXT
   'g',
   'l',
   'E',
   'n',
   'a',
   'b',
   'l',
   'e',
   'C',
   'l',
   'i',
   'e',
   'n',
   't',
   'S',
   't',
   'a',
   't',
   'e',
   'i',
   'E',
   'X',
   'T',
   0, // glEnableClientStateiEXT
   'g',
   'l',
   'E',
   'n',
   'a',
   'b',
   'l',
   'e',
   'D',
   'r',
   'i',
   'v',
   'e',
   'r',
   'C',
   'o',
   'n',
   't',
   'r',
   'o',
   'l',
   'Q',
   'C',
   'O',
   'M',
   0, // glEnableDriverControlQCOM
   'g',
   'l',
   'E',
   'n',
   'a',
   'b',
   'l',
   'e',
   'I',
   'n',
   'd',
   'e',
   'x',
   'e',
   'd',
   'E',
   'X',
   'T',
   0, // glEnableIndexedEXT
   'g',
   'l',
   'E',
   'n',
   'a',
   'b',
   'l',
   'e',
   'V',
   'a',
   'r',
   'i',
   'a',
   'n',
   't',
   'C',
   'l',
   'i',
   'e',
   'n',
   't',
   'S',
   't',
   'a',
   't',
   'e',
   'E',
   'X',
   'T',
   0, // glEnableVariantClientStateEXT
   'g',
   'l',
   'E',
   'n',
   'a',
   'b',
   'l',
   'e',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   0, // glEnableVertexArrayAttrib
   'g',
   'l',
   'E',
   'n',
   'a',
   'b',
   'l',
   'e',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'E',
   'X',
   'T',
   0, // glEnableVertexArrayAttribEXT
   'g',
   'l',
   'E',
   'n',
   'a',
   'b',
   'l',
   'e',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'E',
   'X',
   'T',
   0, // glEnableVertexArrayEXT
   'g',
   'l',
   'E',
   'n',
   'a',
   'b',
   'l',
   'e',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'A',
   'P',
   'P',
   'L',
   'E',
   0, // glEnableVertexAttribAPPLE
   'g',
   'l',
   'E',
   'n',
   'a',
   'b',
   'l',
   'e',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'A',
   'r',
   'r',
   'a',
   'y',
   0, // glEnableVertexAttribArray
   'g',
   'l',
   'E',
   'n',
   'a',
   'b',
   'l',
   'e',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'A',
   'r',
   'r',
   'a',
   'y',
   'A',
   'R',
   'B',
   0, // glEnableVertexAttribArrayARB
   'g',
   'l',
   'E',
   'n',
   'a',
   'b',
   'l',
   'e',
   'i',
   0, // glEnablei
   'g',
   'l',
   'E',
   'n',
   'a',
   'b',
   'l',
   'e',
   'i',
   'E',
   'X',
   'T',
   0, // glEnableiEXT
   'g',
   'l',
   'E',
   'n',
   'a',
   'b',
   'l',
   'e',
   'i',
   'N',
   'V',
   0, // glEnableiNV
   'g',
   'l',
   'E',
   'n',
   'a',
   'b',
   'l',
   'e',
   'i',
   'O',
   'E',
   'S',
   0, // glEnableiOES
   'g',
   'l',
   'E',
   'n',
   'd',
   0, // glEnd
   'g',
   'l',
   'E',
   'n',
   'd',
   'C',
   'o',
   'n',
   'd',
   'i',
   't',
   'i',
   'o',
   'n',
   'a',
   'l',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   0, // glEndConditionalRender
   'g',
   'l',
   'E',
   'n',
   'd',
   'C',
   'o',
   'n',
   'd',
   'i',
   't',
   'i',
   'o',
   'n',
   'a',
   'l',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'N',
   'V',
   0, // glEndConditionalRenderNV
   'g',
   'l',
   'E',
   'n',
   'd',
   'C',
   'o',
   'n',
   'd',
   'i',
   't',
   'i',
   'o',
   'n',
   'a',
   'l',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'N',
   'V',
   'X',
   0, // glEndConditionalRenderNVX
   'g',
   'l',
   'E',
   'n',
   'd',
   'F',
   'r',
   'a',
   'g',
   'm',
   'e',
   'n',
   't',
   'S',
   'h',
   'a',
   'd',
   'e',
   'r',
   'A',
   'T',
   'I',
   0, // glEndFragmentShaderATI
   'g',
   'l',
   'E',
   'n',
   'd',
   'L',
   'i',
   's',
   't',
   0, // glEndList
   'g',
   'l',
   'E',
   'n',
   'd',
   'O',
   'c',
   'c',
   'l',
   'u',
   's',
   'i',
   'o',
   'n',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'N',
   'V',
   0, // glEndOcclusionQueryNV
   'g',
   'l',
   'E',
   'n',
   'd',
   'P',
   'e',
   'r',
   'f',
   'M',
   'o',
   'n',
   'i',
   't',
   'o',
   'r',
   'A',
   'M',
   'D',
   0, // glEndPerfMonitorAMD
   'g',
   'l',
   'E',
   'n',
   'd',
   'P',
   'e',
   'r',
   'f',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'I',
   'N',
   'T',
   'E',
   'L',
   0, // glEndPerfQueryINTEL
   'g',
   'l',
   'E',
   'n',
   'd',
   'Q',
   'u',
   'e',
   'r',
   'y',
   0, // glEndQuery
   'g',
   'l',
   'E',
   'n',
   'd',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'A',
   'R',
   'B',
   0, // glEndQueryARB
   'g',
   'l',
   'E',
   'n',
   'd',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'E',
   'X',
   'T',
   0, // glEndQueryEXT
   'g',
   'l',
   'E',
   'n',
   'd',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'I',
   'n',
   'd',
   'e',
   'x',
   'e',
   'd',
   0, // glEndQueryIndexed
   'g',
   'l',
   'E',
   'n',
   'd',
   'T',
   'i',
   'l',
   'i',
   'n',
   'g',
   'Q',
   'C',
   'O',
   'M',
   0, // glEndTilingQCOM
   'g',
   'l',
   'E',
   'n',
   'd',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'F',
   'e',
   'e',
   'd',
   'b',
   'a',
   'c',
   'k',
   0, // glEndTransformFeedback
   'g',
   'l',
   'E',
   'n',
   'd',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'F',
   'e',
   'e',
   'd',
   'b',
   'a',
   'c',
   'k',
   'E',
   'X',
   'T',
   0, // glEndTransformFeedbackEXT
   'g',
   'l',
   'E',
   'n',
   'd',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'F',
   'e',
   'e',
   'd',
   'b',
   'a',
   'c',
   'k',
   'N',
   'V',
   0, // glEndTransformFeedbackNV
   'g',
   'l',
   'E',
   'n',
   'd',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'S',
   'h',
   'a',
   'd',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glEndVertexShaderEXT
   'g',
   'l',
   'E',
   'n',
   'd',
   'V',
   'i',
   'd',
   'e',
   'o',
   'C',
   'a',
   'p',
   't',
   'u',
   'r',
   'e',
   'N',
   'V',
   0, // glEndVideoCaptureNV
   'g',
   'l',
   'E',
   'v',
   'a',
   'l',
   'C',
   'o',
   'o',
   'r',
   'd',
   '1',
   'd',
   0, // glEvalCoord1d
   'g',
   'l',
   'E',
   'v',
   'a',
   'l',
   'C',
   'o',
   'o',
   'r',
   'd',
   '1',
   'd',
   'v',
   0, // glEvalCoord1dv
   'g',
   'l',
   'E',
   'v',
   'a',
   'l',
   'C',
   'o',
   'o',
   'r',
   'd',
   '1',
   'f',
   0, // glEvalCoord1f
   'g',
   'l',
   'E',
   'v',
   'a',
   'l',
   'C',
   'o',
   'o',
   'r',
   'd',
   '1',
   'f',
   'v',
   0, // glEvalCoord1fv
   'g',
   'l',
   'E',
   'v',
   'a',
   'l',
   'C',
   'o',
   'o',
   'r',
   'd',
   '1',
   'x',
   'O',
   'E',
   'S',
   0, // glEvalCoord1xOES
   'g',
   'l',
   'E',
   'v',
   'a',
   'l',
   'C',
   'o',
   'o',
   'r',
   'd',
   '1',
   'x',
   'v',
   'O',
   'E',
   'S',
   0, // glEvalCoord1xvOES
   'g',
   'l',
   'E',
   'v',
   'a',
   'l',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'd',
   0, // glEvalCoord2d
   'g',
   'l',
   'E',
   'v',
   'a',
   'l',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'd',
   'v',
   0, // glEvalCoord2dv
   'g',
   'l',
   'E',
   'v',
   'a',
   'l',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'f',
   0, // glEvalCoord2f
   'g',
   'l',
   'E',
   'v',
   'a',
   'l',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'f',
   'v',
   0, // glEvalCoord2fv
   'g',
   'l',
   'E',
   'v',
   'a',
   'l',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'x',
   'O',
   'E',
   'S',
   0, // glEvalCoord2xOES
   'g',
   'l',
   'E',
   'v',
   'a',
   'l',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'x',
   'v',
   'O',
   'E',
   'S',
   0, // glEvalCoord2xvOES
   'g',
   'l',
   'E',
   'v',
   'a',
   'l',
   'M',
   'a',
   'p',
   's',
   'N',
   'V',
   0, // glEvalMapsNV
   'g',
   'l',
   'E',
   'v',
   'a',
   'l',
   'M',
   'e',
   's',
   'h',
   '1',
   0, // glEvalMesh1
   'g',
   'l',
   'E',
   'v',
   'a',
   'l',
   'M',
   'e',
   's',
   'h',
   '2',
   0, // glEvalMesh2
   'g',
   'l',
   'E',
   'v',
   'a',
   'l',
   'P',
   'o',
   'i',
   'n',
   't',
   '1',
   0, // glEvalPoint1
   'g',
   'l',
   'E',
   'v',
   'a',
   'l',
   'P',
   'o',
   'i',
   'n',
   't',
   '2',
   0, // glEvalPoint2
   'g',
   'l',
   'E',
   'v',
   'a',
   'l',
   'u',
   'a',
   't',
   'e',
   'D',
   'e',
   'p',
   't',
   'h',
   'V',
   'a',
   'l',
   'u',
   'e',
   's',
   'A',
   'R',
   'B',
   0, // glEvaluateDepthValuesARB
   'g',
   'l',
   'E',
   'x',
   'e',
   'c',
   'u',
   't',
   'e',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'N',
   'V',
   0, // glExecuteProgramNV
   'g',
   'l',
   'E',
   'x',
   't',
   'G',
   'e',
   't',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'v',
   'Q',
   'C',
   'O',
   'M',
   0, // glExtGetBufferPointervQCOM
   'g',
   'l',
   'E',
   'x',
   't',
   'G',
   'e',
   't',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   's',
   'Q',
   'C',
   'O',
   'M',
   0, // glExtGetBuffersQCOM
   'g',
   'l',
   'E',
   'x',
   't',
   'G',
   'e',
   't',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   's',
   'Q',
   'C',
   'O',
   'M',
   0, // glExtGetFramebuffersQCOM
   'g',
   'l',
   'E',
   'x',
   't',
   'G',
   'e',
   't',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'B',
   'i',
   'n',
   'a',
   'r',
   'y',
   'S',
   'o',
   'u',
   'r',
   'c',
   'e',
   'Q',
   'C',
   'O',
   'M',
   0, // glExtGetProgramBinarySourceQCOM
   'g',
   'l',
   'E',
   'x',
   't',
   'G',
   'e',
   't',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   's',
   'Q',
   'C',
   'O',
   'M',
   0, // glExtGetProgramsQCOM
   'g',
   'l',
   'E',
   'x',
   't',
   'G',
   'e',
   't',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   's',
   'Q',
   'C',
   'O',
   'M',
   0, // glExtGetRenderbuffersQCOM
   'g',
   'l',
   'E',
   'x',
   't',
   'G',
   'e',
   't',
   'S',
   'h',
   'a',
   'd',
   'e',
   'r',
   's',
   'Q',
   'C',
   'O',
   'M',
   0, // glExtGetShadersQCOM
   'g',
   'l',
   'E',
   'x',
   't',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   'L',
   'e',
   'v',
   'e',
   'l',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'Q',
   'C',
   'O',
   'M',
   0, // glExtGetTexLevelParameterivQCOM
   'g',
   'l',
   'E',
   'x',
   't',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   'Q',
   'C',
   'O',
   'M',
   0, // glExtGetTexSubImageQCOM
   'g',
   'l',
   'E',
   'x',
   't',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   's',
   'Q',
   'C',
   'O',
   'M',
   0, // glExtGetTexturesQCOM
   'g',
   'l',
   'E',
   'x',
   't',
   'I',
   's',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'B',
   'i',
   'n',
   'a',
   'r',
   'y',
   'Q',
   'C',
   'O',
   'M',
   0, // glExtIsProgramBinaryQCOM
   'g',
   'l',
   'E',
   'x',
   't',
   'T',
   'e',
   'x',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'S',
   't',
   'a',
   't',
   'e',
   'O',
   'v',
   'e',
   'r',
   'r',
   'i',
   'd',
   'e',
   'i',
   'Q',
   'C',
   'O',
   'M',
   0, // glExtTexObjectStateOverrideiQCOM
   'g',
   'l',
   'E',
   'x',
   't',
   'r',
   'a',
   'c',
   't',
   'C',
   'o',
   'm',
   'p',
   'o',
   'n',
   'e',
   'n',
   't',
   'E',
   'X',
   'T',
   0, // glExtractComponentEXT
   'g',
   'l',
   'F',
   'e',
   'e',
   'd',
   'b',
   'a',
   'c',
   'k',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   0, // glFeedbackBuffer
   'g',
   'l',
   'F',
   'e',
   'e',
   'd',
   'b',
   'a',
   'c',
   'k',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'x',
   'O',
   'E',
   'S',
   0, // glFeedbackBufferxOES
   'g',
   'l',
   'F',
   'e',
   'n',
   'c',
   'e',
   'S',
   'y',
   'n',
   'c',
   0, // glFenceSync
   'g',
   'l',
   'F',
   'e',
   'n',
   'c',
   'e',
   'S',
   'y',
   'n',
   'c',
   'A',
   'P',
   'P',
   'L',
   'E',
   0, // glFenceSyncAPPLE
   'g',
   'l',
   'F',
   'i',
   'n',
   'a',
   'l',
   'C',
   'o',
   'm',
   'b',
   'i',
   'n',
   'e',
   'r',
   'I',
   'n',
   'p',
   'u',
   't',
   'N',
   'V',
   0, // glFinalCombinerInputNV
   'g',
   'l',
   'F',
   'i',
   'n',
   'i',
   's',
   'h',
   0, // glFinish
   'g',
   'l',
   'F',
   'i',
   'n',
   'i',
   's',
   'h',
   'A',
   's',
   'y',
   'n',
   'c',
   'S',
   'G',
   'I',
   'X',
   0, // glFinishAsyncSGIX
   'g',
   'l',
   'F',
   'i',
   'n',
   'i',
   's',
   'h',
   'F',
   'e',
   'n',
   'c',
   'e',
   'A',
   'P',
   'P',
   'L',
   'E',
   0, // glFinishFenceAPPLE
   'g',
   'l',
   'F',
   'i',
   'n',
   'i',
   's',
   'h',
   'F',
   'e',
   'n',
   'c',
   'e',
   'N',
   'V',
   0, // glFinishFenceNV
   'g',
   'l',
   'F',
   'i',
   'n',
   'i',
   's',
   'h',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'A',
   'P',
   'P',
   'L',
   'E',
   0, // glFinishObjectAPPLE
   'g',
   'l',
   'F',
   'i',
   'n',
   'i',
   's',
   'h',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'S',
   'U',
   'N',
   'X',
   0, // glFinishTextureSUNX
   'g',
   'l',
   'F',
   'l',
   'u',
   's',
   'h',
   0, // glFlush
   'g',
   'l',
   'F',
   'l',
   'u',
   's',
   'h',
   'M',
   'a',
   'p',
   'p',
   'e',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'R',
   'a',
   'n',
   'g',
   'e',
   0, // glFlushMappedBufferRange
   'g',
   'l',
   'F',
   'l',
   'u',
   's',
   'h',
   'M',
   'a',
   'p',
   'p',
   'e',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'R',
   'a',
   'n',
   'g',
   'e',
   'A',
   'P',
   'P',
   'L',
   'E',
   0, // glFlushMappedBufferRangeAPPLE
   'g',
   'l',
   'F',
   'l',
   'u',
   's',
   'h',
   'M',
   'a',
   'p',
   'p',
   'e',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'R',
   'a',
   'n',
   'g',
   'e',
   'E',
   'X',
   'T',
   0, // glFlushMappedBufferRangeEXT
   'g',
   'l',
   'F',
   'l',
   'u',
   's',
   'h',
   'M',
   'a',
   'p',
   'p',
   'e',
   'd',
   'N',
   'a',
   'm',
   'e',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'R',
   'a',
   'n',
   'g',
   'e',
   0, // glFlushMappedNamedBufferRange
   'g',
   'l',
   'F',
   'l',
   'u',
   's',
   'h',
   'M',
   'a',
   'p',
   'p',
   'e',
   'd',
   'N',
   'a',
   'm',
   'e',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'R',
   'a',
   'n',
   'g',
   'e',
   'E',
   'X',
   'T',
   0, // glFlushMappedNamedBufferRangeEXT
   'g',
   'l',
   'F',
   'l',
   'u',
   's',
   'h',
   'P',
   'i',
   'x',
   'e',
   'l',
   'D',
   'a',
   't',
   'a',
   'R',
   'a',
   'n',
   'g',
   'e',
   'N',
   'V',
   0, // glFlushPixelDataRangeNV
   'g',
   'l',
   'F',
   'l',
   'u',
   's',
   'h',
   'R',
   'a',
   's',
   't',
   'e',
   'r',
   'S',
   'G',
   'I',
   'X',
   0, // glFlushRasterSGIX
   'g',
   'l',
   'F',
   'l',
   'u',
   's',
   'h',
   'S',
   't',
   'a',
   't',
   'i',
   'c',
   'D',
   'a',
   't',
   'a',
   'I',
   'B',
   'M',
   0, // glFlushStaticDataIBM
   'g',
   'l',
   'F',
   'l',
   'u',
   's',
   'h',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'R',
   'a',
   'n',
   'g',
   'e',
   'A',
   'P',
   'P',
   'L',
   'E',
   0, // glFlushVertexArrayRangeAPPLE
   'g',
   'l',
   'F',
   'l',
   'u',
   's',
   'h',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'R',
   'a',
   'n',
   'g',
   'e',
   'N',
   'V',
   0, // glFlushVertexArrayRangeNV
   'g',
   'l',
   'F',
   'o',
   'g',
   'C',
   'o',
   'o',
   'r',
   'd',
   'F',
   'o',
   'r',
   'm',
   'a',
   't',
   'N',
   'V',
   0, // glFogCoordFormatNV
   'g',
   'l',
   'F',
   'o',
   'g',
   'C',
   'o',
   'o',
   'r',
   'd',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   0, // glFogCoordPointer
   'g',
   'l',
   'F',
   'o',
   'g',
   'C',
   'o',
   'o',
   'r',
   'd',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glFogCoordPointerEXT
   'g',
   'l',
   'F',
   'o',
   'g',
   'C',
   'o',
   'o',
   'r',
   'd',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'L',
   'i',
   's',
   't',
   'I',
   'B',
   'M',
   0, // glFogCoordPointerListIBM
   'g',
   'l',
   'F',
   'o',
   'g',
   'C',
   'o',
   'o',
   'r',
   'd',
   'd',
   0, // glFogCoordd
   'g',
   'l',
   'F',
   'o',
   'g',
   'C',
   'o',
   'o',
   'r',
   'd',
   'd',
   'E',
   'X',
   'T',
   0, // glFogCoorddEXT
   'g',
   'l',
   'F',
   'o',
   'g',
   'C',
   'o',
   'o',
   'r',
   'd',
   'd',
   'v',
   0, // glFogCoorddv
   'g',
   'l',
   'F',
   'o',
   'g',
   'C',
   'o',
   'o',
   'r',
   'd',
   'd',
   'v',
   'E',
   'X',
   'T',
   0, // glFogCoorddvEXT
   'g',
   'l',
   'F',
   'o',
   'g',
   'C',
   'o',
   'o',
   'r',
   'd',
   'f',
   0, // glFogCoordf
   'g',
   'l',
   'F',
   'o',
   'g',
   'C',
   'o',
   'o',
   'r',
   'd',
   'f',
   'E',
   'X',
   'T',
   0, // glFogCoordfEXT
   'g',
   'l',
   'F',
   'o',
   'g',
   'C',
   'o',
   'o',
   'r',
   'd',
   'f',
   'v',
   0, // glFogCoordfv
   'g',
   'l',
   'F',
   'o',
   'g',
   'C',
   'o',
   'o',
   'r',
   'd',
   'f',
   'v',
   'E',
   'X',
   'T',
   0, // glFogCoordfvEXT
   'g',
   'l',
   'F',
   'o',
   'g',
   'C',
   'o',
   'o',
   'r',
   'd',
   'h',
   'N',
   'V',
   0, // glFogCoordhNV
   'g',
   'l',
   'F',
   'o',
   'g',
   'C',
   'o',
   'o',
   'r',
   'd',
   'h',
   'v',
   'N',
   'V',
   0, // glFogCoordhvNV
   'g',
   'l',
   'F',
   'o',
   'g',
   'F',
   'u',
   'n',
   'c',
   'S',
   'G',
   'I',
   'S',
   0, // glFogFuncSGIS
   'g',
   'l',
   'F',
   'o',
   'g',
   'f',
   0, // glFogf
   'g',
   'l',
   'F',
   'o',
   'g',
   'f',
   'v',
   0, // glFogfv
   'g',
   'l',
   'F',
   'o',
   'g',
   'i',
   0, // glFogi
   'g',
   'l',
   'F',
   'o',
   'g',
   'i',
   'v',
   0, // glFogiv
   'g',
   'l',
   'F',
   'o',
   'g',
   'x',
   0, // glFogx
   'g',
   'l',
   'F',
   'o',
   'g',
   'x',
   'O',
   'E',
   'S',
   0, // glFogxOES
   'g',
   'l',
   'F',
   'o',
   'g',
   'x',
   'v',
   0, // glFogxv
   'g',
   'l',
   'F',
   'o',
   'g',
   'x',
   'v',
   'O',
   'E',
   'S',
   0, // glFogxvOES
   'g',
   'l',
   'F',
   'r',
   'a',
   'g',
   'm',
   'e',
   'n',
   't',
   'C',
   'o',
   'l',
   'o',
   'r',
   'M',
   'a',
   't',
   'e',
   'r',
   'i',
   'a',
   'l',
   'S',
   'G',
   'I',
   'X',
   0, // glFragmentColorMaterialSGIX
   'g',
   'l',
   'F',
   'r',
   'a',
   'g',
   'm',
   'e',
   'n',
   't',
   'C',
   'o',
   'v',
   'e',
   'r',
   'a',
   'g',
   'e',
   'C',
   'o',
   'l',
   'o',
   'r',
   'N',
   'V',
   0, // glFragmentCoverageColorNV
   'g',
   'l',
   'F',
   'r',
   'a',
   'g',
   'm',
   'e',
   'n',
   't',
   'L',
   'i',
   'g',
   'h',
   't',
   'M',
   'o',
   'd',
   'e',
   'l',
   'f',
   'S',
   'G',
   'I',
   'X',
   0, // glFragmentLightModelfSGIX
   'g',
   'l',
   'F',
   'r',
   'a',
   'g',
   'm',
   'e',
   'n',
   't',
   'L',
   'i',
   'g',
   'h',
   't',
   'M',
   'o',
   'd',
   'e',
   'l',
   'f',
   'v',
   'S',
   'G',
   'I',
   'X',
   0, // glFragmentLightModelfvSGIX
   'g',
   'l',
   'F',
   'r',
   'a',
   'g',
   'm',
   'e',
   'n',
   't',
   'L',
   'i',
   'g',
   'h',
   't',
   'M',
   'o',
   'd',
   'e',
   'l',
   'i',
   'S',
   'G',
   'I',
   'X',
   0, // glFragmentLightModeliSGIX
   'g',
   'l',
   'F',
   'r',
   'a',
   'g',
   'm',
   'e',
   'n',
   't',
   'L',
   'i',
   'g',
   'h',
   't',
   'M',
   'o',
   'd',
   'e',
   'l',
   'i',
   'v',
   'S',
   'G',
   'I',
   'X',
   0, // glFragmentLightModelivSGIX
   'g',
   'l',
   'F',
   'r',
   'a',
   'g',
   'm',
   'e',
   'n',
   't',
   'L',
   'i',
   'g',
   'h',
   't',
   'f',
   'S',
   'G',
   'I',
   'X',
   0, // glFragmentLightfSGIX
   'g',
   'l',
   'F',
   'r',
   'a',
   'g',
   'm',
   'e',
   'n',
   't',
   'L',
   'i',
   'g',
   'h',
   't',
   'f',
   'v',
   'S',
   'G',
   'I',
   'X',
   0, // glFragmentLightfvSGIX
   'g',
   'l',
   'F',
   'r',
   'a',
   'g',
   'm',
   'e',
   'n',
   't',
   'L',
   'i',
   'g',
   'h',
   't',
   'i',
   'S',
   'G',
   'I',
   'X',
   0, // glFragmentLightiSGIX
   'g',
   'l',
   'F',
   'r',
   'a',
   'g',
   'm',
   'e',
   'n',
   't',
   'L',
   'i',
   'g',
   'h',
   't',
   'i',
   'v',
   'S',
   'G',
   'I',
   'X',
   0, // glFragmentLightivSGIX
   'g',
   'l',
   'F',
   'r',
   'a',
   'g',
   'm',
   'e',
   'n',
   't',
   'M',
   'a',
   't',
   'e',
   'r',
   'i',
   'a',
   'l',
   'f',
   'S',
   'G',
   'I',
   'X',
   0, // glFragmentMaterialfSGIX
   'g',
   'l',
   'F',
   'r',
   'a',
   'g',
   'm',
   'e',
   'n',
   't',
   'M',
   'a',
   't',
   'e',
   'r',
   'i',
   'a',
   'l',
   'f',
   'v',
   'S',
   'G',
   'I',
   'X',
   0, // glFragmentMaterialfvSGIX
   'g',
   'l',
   'F',
   'r',
   'a',
   'g',
   'm',
   'e',
   'n',
   't',
   'M',
   'a',
   't',
   'e',
   'r',
   'i',
   'a',
   'l',
   'i',
   'S',
   'G',
   'I',
   'X',
   0, // glFragmentMaterialiSGIX
   'g',
   'l',
   'F',
   'r',
   'a',
   'g',
   'm',
   'e',
   'n',
   't',
   'M',
   'a',
   't',
   'e',
   'r',
   'i',
   'a',
   'l',
   'i',
   'v',
   'S',
   'G',
   'I',
   'X',
   0, // glFragmentMaterialivSGIX
   'g',
   'l',
   'F',
   'r',
   'a',
   'm',
   'e',
   'T',
   'e',
   'r',
   'm',
   'i',
   'n',
   'a',
   't',
   'o',
   'r',
   'G',
   'R',
   'E',
   'M',
   'E',
   'D',
   'Y',
   0, // glFrameTerminatorGREMEDY
   'g',
   'l',
   'F',
   'r',
   'a',
   'm',
   'e',
   'Z',
   'o',
   'o',
   'm',
   'S',
   'G',
   'I',
   'X',
   0, // glFrameZoomSGIX
   'g',
   'l',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'D',
   'r',
   'a',
   'w',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glFramebufferDrawBufferEXT
   'g',
   'l',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'D',
   'r',
   'a',
   'w',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   's',
   'E',
   'X',
   'T',
   0, // glFramebufferDrawBuffersEXT
   'g',
   'l',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'F',
   'e',
   't',
   'c',
   'h',
   'B',
   'a',
   'r',
   'r',
   'i',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glFramebufferFetchBarrierEXT
   'g',
   'l',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'F',
   'e',
   't',
   'c',
   'h',
   'B',
   'a',
   'r',
   'r',
   'i',
   'e',
   'r',
   'Q',
   'C',
   'O',
   'M',
   0, // glFramebufferFetchBarrierQCOM
   'g',
   'l',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'F',
   'o',
   'v',
   'e',
   'a',
   't',
   'i',
   'o',
   'n',
   'C',
   'o',
   'n',
   'f',
   'i',
   'g',
   'Q',
   'C',
   'O',
   'M',
   0, // glFramebufferFoveationConfigQCOM
   'g',
   'l',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'F',
   'o',
   'v',
   'e',
   'a',
   't',
   'i',
   'o',
   'n',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   's',
   'Q',
   'C',
   'O',
   'M',
   0, // glFramebufferFoveationParametersQCOM
   'g',
   'l',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   0, // glFramebufferParameteri
   'g',
   'l',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'M',
   'E',
   'S',
   'A',
   0, // glFramebufferParameteriMESA
   'g',
   'l',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'P',
   'i',
   'x',
   'e',
   'l',
   'L',
   'o',
   'c',
   'a',
   'l',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   'S',
   'i',
   'z',
   'e',
   'E',
   'X',
   'T',
   0, // glFramebufferPixelLocalStorageSizeEXT
   'g',
   'l',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'R',
   'e',
   'a',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glFramebufferReadBufferEXT
   'g',
   'l',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   0, // glFramebufferRenderbuffer
   'g',
   'l',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glFramebufferRenderbufferEXT
   'g',
   'l',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'O',
   'E',
   'S',
   0, // glFramebufferRenderbufferOES
   'g',
   'l',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'L',
   'o',
   'c',
   'a',
   't',
   'i',
   'o',
   'n',
   's',
   'f',
   'v',
   'A',
   'R',
   'B',
   0, // glFramebufferSampleLocationsfvARB
   'g',
   'l',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'L',
   'o',
   'c',
   'a',
   't',
   'i',
   'o',
   'n',
   's',
   'f',
   'v',
   'N',
   'V',
   0, // glFramebufferSampleLocationsfvNV
   'g',
   'l',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'P',
   'o',
   's',
   'i',
   't',
   'i',
   'o',
   'n',
   's',
   'f',
   'v',
   'A',
   'M',
   'D',
   0, // glFramebufferSamplePositionsfvAMD
   'g',
   'l',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   0, // glFramebufferTexture
   'g',
   'l',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   '1',
   'D',
   0, // glFramebufferTexture1D
   'g',
   'l',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   '1',
   'D',
   'E',
   'X',
   'T',
   0, // glFramebufferTexture1DEXT
   'g',
   'l',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   '2',
   'D',
   0, // glFramebufferTexture2D
   'g',
   'l',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   '2',
   'D',
   'D',
   'o',
   'w',
   'n',
   's',
   'a',
   'm',
   'p',
   'l',
   'e',
   'I',
   'M',
   'G',
   0, // glFramebufferTexture2DDownsampleIMG
   'g',
   'l',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   '2',
   'D',
   'E',
   'X',
   'T',
   0, // glFramebufferTexture2DEXT
   'g',
   'l',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   '2',
   'D',
   'M',
   'u',
   'l',
   't',
   'i',
   's',
   'a',
   'm',
   'p',
   'l',
   'e',
   'E',
   'X',
   'T',
   0, // glFramebufferTexture2DMultisampleEXT
   'g',
   'l',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   '2',
   'D',
   'M',
   'u',
   'l',
   't',
   'i',
   's',
   'a',
   'm',
   'p',
   'l',
   'e',
   'I',
   'M',
   'G',
   0, // glFramebufferTexture2DMultisampleIMG
   'g',
   'l',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   '2',
   'D',
   'O',
   'E',
   'S',
   0, // glFramebufferTexture2DOES
   'g',
   'l',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   '3',
   'D',
   0, // glFramebufferTexture3D
   'g',
   'l',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   '3',
   'D',
   'E',
   'X',
   'T',
   0, // glFramebufferTexture3DEXT
   'g',
   'l',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   '3',
   'D',
   'O',
   'E',
   'S',
   0, // glFramebufferTexture3DOES
   'g',
   'l',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'A',
   'R',
   'B',
   0, // glFramebufferTextureARB
   'g',
   'l',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'E',
   'X',
   'T',
   0, // glFramebufferTextureEXT
   'g',
   'l',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'F',
   'a',
   'c',
   'e',
   'A',
   'R',
   'B',
   0, // glFramebufferTextureFaceARB
   'g',
   'l',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'F',
   'a',
   'c',
   'e',
   'E',
   'X',
   'T',
   0, // glFramebufferTextureFaceEXT
   'g',
   'l',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'L',
   'a',
   'y',
   'e',
   'r',
   0, // glFramebufferTextureLayer
   'g',
   'l',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'L',
   'a',
   'y',
   'e',
   'r',
   'A',
   'R',
   'B',
   0, // glFramebufferTextureLayerARB
   'g',
   'l',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'L',
   'a',
   'y',
   'e',
   'r',
   'D',
   'o',
   'w',
   'n',
   's',
   'a',
   'm',
   'p',
   'l',
   'e',
   'I',
   'M',
   'G',
   0, // glFramebufferTextureLayerDownsampleIMG
   'g',
   'l',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'L',
   'a',
   'y',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glFramebufferTextureLayerEXT
   'g',
   'l',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'M',
   'u',
   'l',
   't',
   'i',
   's',
   'a',
   'm',
   'p',
   'l',
   'e',
   'M',
   'u',
   'l',
   't',
   'i',
   'v',
   'i',
   'e',
   'w',
   'O',
   'V',
   'R',
   0, // glFramebufferTextureMultisampleMultiviewOVR
   'g',
   'l',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'M',
   'u',
   'l',
   't',
   'i',
   'v',
   'i',
   'e',
   'w',
   'O',
   'V',
   'R',
   0, // glFramebufferTextureMultiviewOVR
   'g',
   'l',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'O',
   'E',
   'S',
   0, // glFramebufferTextureOES
   'g',
   'l',
   'F',
   'r',
   'e',
   'e',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'A',
   'T',
   'I',
   0, // glFreeObjectBufferATI
   'g',
   'l',
   'F',
   'r',
   'o',
   'n',
   't',
   'F',
   'a',
   'c',
   'e',
   0, // glFrontFace
   'g',
   'l',
   'F',
   'r',
   'u',
   's',
   't',
   'u',
   'm',
   0, // glFrustum
   'g',
   'l',
   'F',
   'r',
   'u',
   's',
   't',
   'u',
   'm',
   'f',
   0, // glFrustumf
   'g',
   'l',
   'F',
   'r',
   'u',
   's',
   't',
   'u',
   'm',
   'f',
   'O',
   'E',
   'S',
   0, // glFrustumfOES
   'g',
   'l',
   'F',
   'r',
   'u',
   's',
   't',
   'u',
   'm',
   'x',
   0, // glFrustumx
   'g',
   'l',
   'F',
   'r',
   'u',
   's',
   't',
   'u',
   'm',
   'x',
   'O',
   'E',
   'S',
   0, // glFrustumxOES
   'g',
   'l',
   'G',
   'e',
   'n',
   'A',
   's',
   'y',
   'n',
   'c',
   'M',
   'a',
   'r',
   'k',
   'e',
   'r',
   's',
   'S',
   'G',
   'I',
   'X',
   0, // glGenAsyncMarkersSGIX
   'g',
   'l',
   'G',
   'e',
   'n',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   's',
   0, // glGenBuffers
   'g',
   'l',
   'G',
   'e',
   'n',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   's',
   'A',
   'R',
   'B',
   0, // glGenBuffersARB
   'g',
   'l',
   'G',
   'e',
   'n',
   'F',
   'e',
   'n',
   'c',
   'e',
   's',
   'A',
   'P',
   'P',
   'L',
   'E',
   0, // glGenFencesAPPLE
   'g',
   'l',
   'G',
   'e',
   'n',
   'F',
   'e',
   'n',
   'c',
   'e',
   's',
   'N',
   'V',
   0, // glGenFencesNV
   'g',
   'l',
   'G',
   'e',
   'n',
   'F',
   'r',
   'a',
   'g',
   'm',
   'e',
   'n',
   't',
   'S',
   'h',
   'a',
   'd',
   'e',
   'r',
   's',
   'A',
   'T',
   'I',
   0, // glGenFragmentShadersATI
   'g',
   'l',
   'G',
   'e',
   'n',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   's',
   0, // glGenFramebuffers
   'g',
   'l',
   'G',
   'e',
   'n',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   's',
   'E',
   'X',
   'T',
   0, // glGenFramebuffersEXT
   'g',
   'l',
   'G',
   'e',
   'n',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   's',
   'O',
   'E',
   'S',
   0, // glGenFramebuffersOES
   'g',
   'l',
   'G',
   'e',
   'n',
   'L',
   'i',
   's',
   't',
   's',
   0, // glGenLists
   'g',
   'l',
   'G',
   'e',
   'n',
   'N',
   'a',
   'm',
   'e',
   's',
   'A',
   'M',
   'D',
   0, // glGenNamesAMD
   'g',
   'l',
   'G',
   'e',
   'n',
   'O',
   'c',
   'c',
   'l',
   'u',
   's',
   'i',
   'o',
   'n',
   'Q',
   'u',
   'e',
   'r',
   'i',
   'e',
   's',
   'N',
   'V',
   0, // glGenOcclusionQueriesNV
   'g',
   'l',
   'G',
   'e',
   'n',
   'P',
   'a',
   't',
   'h',
   's',
   'N',
   'V',
   0, // glGenPathsNV
   'g',
   'l',
   'G',
   'e',
   'n',
   'P',
   'e',
   'r',
   'f',
   'M',
   'o',
   'n',
   'i',
   't',
   'o',
   'r',
   's',
   'A',
   'M',
   'D',
   0, // glGenPerfMonitorsAMD
   'g',
   'l',
   'G',
   'e',
   'n',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'P',
   'i',
   'p',
   'e',
   'l',
   'i',
   'n',
   'e',
   's',
   0, // glGenProgramPipelines
   'g',
   'l',
   'G',
   'e',
   'n',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'P',
   'i',
   'p',
   'e',
   'l',
   'i',
   'n',
   'e',
   's',
   'E',
   'X',
   'T',
   0, // glGenProgramPipelinesEXT
   'g',
   'l',
   'G',
   'e',
   'n',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   's',
   'A',
   'R',
   'B',
   0, // glGenProgramsARB
   'g',
   'l',
   'G',
   'e',
   'n',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   's',
   'N',
   'V',
   0, // glGenProgramsNV
   'g',
   'l',
   'G',
   'e',
   'n',
   'Q',
   'u',
   'e',
   'r',
   'i',
   'e',
   's',
   0, // glGenQueries
   'g',
   'l',
   'G',
   'e',
   'n',
   'Q',
   'u',
   'e',
   'r',
   'i',
   'e',
   's',
   'A',
   'R',
   'B',
   0, // glGenQueriesARB
   'g',
   'l',
   'G',
   'e',
   'n',
   'Q',
   'u',
   'e',
   'r',
   'i',
   'e',
   's',
   'E',
   'X',
   'T',
   0, // glGenQueriesEXT
   'g',
   'l',
   'G',
   'e',
   'n',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'R',
   'e',
   's',
   'o',
   'u',
   'r',
   'c',
   'e',
   'T',
   'a',
   'g',
   'N',
   'V',
   0, // glGenQueryResourceTagNV
   'g',
   'l',
   'G',
   'e',
   'n',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   's',
   0, // glGenRenderbuffers
   'g',
   'l',
   'G',
   'e',
   'n',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   's',
   'E',
   'X',
   'T',
   0, // glGenRenderbuffersEXT
   'g',
   'l',
   'G',
   'e',
   'n',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   's',
   'O',
   'E',
   'S',
   0, // glGenRenderbuffersOES
   'g',
   'l',
   'G',
   'e',
   'n',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'r',
   's',
   0, // glGenSamplers
   'g',
   'l',
   'G',
   'e',
   'n',
   'S',
   'e',
   'm',
   'a',
   'p',
   'h',
   'o',
   'r',
   'e',
   's',
   'E',
   'X',
   'T',
   0, // glGenSemaphoresEXT
   'g',
   'l',
   'G',
   'e',
   'n',
   'S',
   'y',
   'm',
   'b',
   'o',
   'l',
   's',
   'E',
   'X',
   'T',
   0, // glGenSymbolsEXT
   'g',
   'l',
   'G',
   'e',
   'n',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   's',
   0, // glGenTextures
   'g',
   'l',
   'G',
   'e',
   'n',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   's',
   'E',
   'X',
   'T',
   0, // glGenTexturesEXT
   'g',
   'l',
   'G',
   'e',
   'n',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'F',
   'e',
   'e',
   'd',
   'b',
   'a',
   'c',
   'k',
   's',
   0, // glGenTransformFeedbacks
   'g',
   'l',
   'G',
   'e',
   'n',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'F',
   'e',
   'e',
   'd',
   'b',
   'a',
   'c',
   'k',
   's',
   'N',
   'V',
   0, // glGenTransformFeedbacksNV
   'g',
   'l',
   'G',
   'e',
   'n',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   's',
   0, // glGenVertexArrays
   'g',
   'l',
   'G',
   'e',
   'n',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   's',
   'A',
   'P',
   'P',
   'L',
   'E',
   0, // glGenVertexArraysAPPLE
   'g',
   'l',
   'G',
   'e',
   'n',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   's',
   'O',
   'E',
   'S',
   0, // glGenVertexArraysOES
   'g',
   'l',
   'G',
   'e',
   'n',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'S',
   'h',
   'a',
   'd',
   'e',
   'r',
   's',
   'E',
   'X',
   'T',
   0, // glGenVertexShadersEXT
   'g',
   'l',
   'G',
   'e',
   'n',
   'e',
   'r',
   'a',
   't',
   'e',
   'M',
   'i',
   'p',
   'm',
   'a',
   'p',
   0, // glGenerateMipmap
   'g',
   'l',
   'G',
   'e',
   'n',
   'e',
   'r',
   'a',
   't',
   'e',
   'M',
   'i',
   'p',
   'm',
   'a',
   'p',
   'E',
   'X',
   'T',
   0, // glGenerateMipmapEXT
   'g',
   'l',
   'G',
   'e',
   'n',
   'e',
   'r',
   'a',
   't',
   'e',
   'M',
   'i',
   'p',
   'm',
   'a',
   'p',
   'O',
   'E',
   'S',
   0, // glGenerateMipmapOES
   'g',
   'l',
   'G',
   'e',
   'n',
   'e',
   'r',
   'a',
   't',
   'e',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'M',
   'i',
   'p',
   'm',
   'a',
   'p',
   'E',
   'X',
   'T',
   0, // glGenerateMultiTexMipmapEXT
   'g',
   'l',
   'G',
   'e',
   'n',
   'e',
   'r',
   'a',
   't',
   'e',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'M',
   'i',
   'p',
   'm',
   'a',
   'p',
   0, // glGenerateTextureMipmap
   'g',
   'l',
   'G',
   'e',
   'n',
   'e',
   'r',
   'a',
   't',
   'e',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'M',
   'i',
   'p',
   'm',
   'a',
   'p',
   'E',
   'X',
   'T',
   0, // glGenerateTextureMipmapEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'A',
   'c',
   't',
   'i',
   'v',
   'e',
   'A',
   't',
   'o',
   'm',
   'i',
   'c',
   'C',
   'o',
   'u',
   'n',
   't',
   'e',
   'r',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'i',
   'v',
   0, // glGetActiveAtomicCounterBufferiv
   'g',
   'l',
   'G',
   'e',
   't',
   'A',
   'c',
   't',
   'i',
   'v',
   'e',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   0, // glGetActiveAttrib
   'g',
   'l',
   'G',
   'e',
   't',
   'A',
   'c',
   't',
   'i',
   'v',
   'e',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'A',
   'R',
   'B',
   0, // glGetActiveAttribARB
   'g',
   'l',
   'G',
   'e',
   't',
   'A',
   'c',
   't',
   'i',
   'v',
   'e',
   'S',
   'u',
   'b',
   'r',
   'o',
   'u',
   't',
   'i',
   'n',
   'e',
   'N',
   'a',
   'm',
   'e',
   0, // glGetActiveSubroutineName
   'g',
   'l',
   'G',
   'e',
   't',
   'A',
   'c',
   't',
   'i',
   'v',
   'e',
   'S',
   'u',
   'b',
   'r',
   'o',
   'u',
   't',
   'i',
   'n',
   'e',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'N',
   'a',
   'm',
   'e',
   0, // glGetActiveSubroutineUniformName
   'g',
   'l',
   'G',
   'e',
   't',
   'A',
   'c',
   't',
   'i',
   'v',
   'e',
   'S',
   'u',
   'b',
   'r',
   'o',
   'u',
   't',
   'i',
   'n',
   'e',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'i',
   'v',
   0, // glGetActiveSubroutineUniformiv
   'g',
   'l',
   'G',
   'e',
   't',
   'A',
   'c',
   't',
   'i',
   'v',
   'e',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   0, // glGetActiveUniform
   'g',
   'l',
   'G',
   'e',
   't',
   'A',
   'c',
   't',
   'i',
   'v',
   'e',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'A',
   'R',
   'B',
   0, // glGetActiveUniformARB
   'g',
   'l',
   'G',
   'e',
   't',
   'A',
   'c',
   't',
   'i',
   'v',
   'e',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'B',
   'l',
   'o',
   'c',
   'k',
   'N',
   'a',
   'm',
   'e',
   0, // glGetActiveUniformBlockName
   'g',
   'l',
   'G',
   'e',
   't',
   'A',
   'c',
   't',
   'i',
   'v',
   'e',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'B',
   'l',
   'o',
   'c',
   'k',
   'i',
   'v',
   0, // glGetActiveUniformBlockiv
   'g',
   'l',
   'G',
   'e',
   't',
   'A',
   'c',
   't',
   'i',
   'v',
   'e',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'N',
   'a',
   'm',
   'e',
   0, // glGetActiveUniformName
   'g',
   'l',
   'G',
   'e',
   't',
   'A',
   'c',
   't',
   'i',
   'v',
   'e',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   's',
   'i',
   'v',
   0, // glGetActiveUniformsiv
   'g',
   'l',
   'G',
   'e',
   't',
   'A',
   'c',
   't',
   'i',
   'v',
   'e',
   'V',
   'a',
   'r',
   'y',
   'i',
   'n',
   'g',
   'N',
   'V',
   0, // glGetActiveVaryingNV
   'g',
   'l',
   'G',
   'e',
   't',
   'A',
   'r',
   'r',
   'a',
   'y',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'f',
   'v',
   'A',
   'T',
   'I',
   0, // glGetArrayObjectfvATI
   'g',
   'l',
   'G',
   'e',
   't',
   'A',
   'r',
   'r',
   'a',
   'y',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'i',
   'v',
   'A',
   'T',
   'I',
   0, // glGetArrayObjectivATI
   'g',
   'l',
   'G',
   'e',
   't',
   'A',
   't',
   't',
   'a',
   'c',
   'h',
   'e',
   'd',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   's',
   'A',
   'R',
   'B',
   0, // glGetAttachedObjectsARB
   'g',
   'l',
   'G',
   'e',
   't',
   'A',
   't',
   't',
   'a',
   'c',
   'h',
   'e',
   'd',
   'S',
   'h',
   'a',
   'd',
   'e',
   'r',
   's',
   0, // glGetAttachedShaders
   'g',
   'l',
   'G',
   'e',
   't',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'L',
   'o',
   'c',
   'a',
   't',
   'i',
   'o',
   'n',
   0, // glGetAttribLocation
   'g',
   'l',
   'G',
   'e',
   't',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'L',
   'o',
   'c',
   'a',
   't',
   'i',
   'o',
   'n',
   'A',
   'R',
   'B',
   0, // glGetAttribLocationARB
   'g',
   'l',
   'G',
   'e',
   't',
   'B',
   'o',
   'o',
   'l',
   'e',
   'a',
   'n',
   'I',
   'n',
   'd',
   'e',
   'x',
   'e',
   'd',
   'v',
   'E',
   'X',
   'T',
   0, // glGetBooleanIndexedvEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'B',
   'o',
   'o',
   'l',
   'e',
   'a',
   'n',
   'i',
   '_',
   'v',
   0, // glGetBooleani_v
   'g',
   'l',
   'G',
   'e',
   't',
   'B',
   'o',
   'o',
   'l',
   'e',
   'a',
   'n',
   'v',
   0, // glGetBooleanv
   'g',
   'l',
   'G',
   'e',
   't',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   '6',
   '4',
   'v',
   0, // glGetBufferParameteri64v
   'g',
   'l',
   'G',
   'e',
   't',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   0, // glGetBufferParameteriv
   'g',
   'l',
   'G',
   'e',
   't',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'A',
   'R',
   'B',
   0, // glGetBufferParameterivARB
   'g',
   'l',
   'G',
   'e',
   't',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'u',
   'i',
   '6',
   '4',
   'v',
   'N',
   'V',
   0, // glGetBufferParameterui64vNV
   'g',
   'l',
   'G',
   'e',
   't',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'v',
   0, // glGetBufferPointerv
   'g',
   'l',
   'G',
   'e',
   't',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'v',
   'A',
   'R',
   'B',
   0, // glGetBufferPointervARB
   'g',
   'l',
   'G',
   'e',
   't',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'v',
   'O',
   'E',
   'S',
   0, // glGetBufferPointervOES
   'g',
   'l',
   'G',
   'e',
   't',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   'u',
   'b',
   'D',
   'a',
   't',
   'a',
   0, // glGetBufferSubData
   'g',
   'l',
   'G',
   'e',
   't',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   'u',
   'b',
   'D',
   'a',
   't',
   'a',
   'A',
   'R',
   'B',
   0, // glGetBufferSubDataARB
   'g',
   'l',
   'G',
   'e',
   't',
   'C',
   'l',
   'i',
   'p',
   'P',
   'l',
   'a',
   'n',
   'e',
   0, // glGetClipPlane
   'g',
   'l',
   'G',
   'e',
   't',
   'C',
   'l',
   'i',
   'p',
   'P',
   'l',
   'a',
   'n',
   'e',
   'f',
   0, // glGetClipPlanef
   'g',
   'l',
   'G',
   'e',
   't',
   'C',
   'l',
   'i',
   'p',
   'P',
   'l',
   'a',
   'n',
   'e',
   'f',
   'O',
   'E',
   'S',
   0, // glGetClipPlanefOES
   'g',
   'l',
   'G',
   'e',
   't',
   'C',
   'l',
   'i',
   'p',
   'P',
   'l',
   'a',
   'n',
   'e',
   'x',
   0, // glGetClipPlanex
   'g',
   'l',
   'G',
   'e',
   't',
   'C',
   'l',
   'i',
   'p',
   'P',
   'l',
   'a',
   'n',
   'e',
   'x',
   'O',
   'E',
   'S',
   0, // glGetClipPlanexOES
   'g',
   'l',
   'G',
   'e',
   't',
   'C',
   'o',
   'l',
   'o',
   'r',
   'T',
   'a',
   'b',
   'l',
   'e',
   0, // glGetColorTable
   'g',
   'l',
   'G',
   'e',
   't',
   'C',
   'o',
   'l',
   'o',
   'r',
   'T',
   'a',
   'b',
   'l',
   'e',
   'E',
   'X',
   'T',
   0, // glGetColorTableEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'C',
   'o',
   'l',
   'o',
   'r',
   'T',
   'a',
   'b',
   'l',
   'e',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   0, // glGetColorTableParameterfv
   'g',
   'l',
   'G',
   'e',
   't',
   'C',
   'o',
   'l',
   'o',
   'r',
   'T',
   'a',
   'b',
   'l',
   'e',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   'E',
   'X',
   'T',
   0, // glGetColorTableParameterfvEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'C',
   'o',
   'l',
   'o',
   'r',
   'T',
   'a',
   'b',
   'l',
   'e',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   'S',
   'G',
   'I',
   0, // glGetColorTableParameterfvSGI
   'g',
   'l',
   'G',
   'e',
   't',
   'C',
   'o',
   'l',
   'o',
   'r',
   'T',
   'a',
   'b',
   'l',
   'e',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   0, // glGetColorTableParameteriv
   'g',
   'l',
   'G',
   'e',
   't',
   'C',
   'o',
   'l',
   'o',
   'r',
   'T',
   'a',
   'b',
   'l',
   'e',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glGetColorTableParameterivEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'C',
   'o',
   'l',
   'o',
   'r',
   'T',
   'a',
   'b',
   'l',
   'e',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'S',
   'G',
   'I',
   0, // glGetColorTableParameterivSGI
   'g',
   'l',
   'G',
   'e',
   't',
   'C',
   'o',
   'l',
   'o',
   'r',
   'T',
   'a',
   'b',
   'l',
   'e',
   'S',
   'G',
   'I',
   0, // glGetColorTableSGI
   'g',
   'l',
   'G',
   'e',
   't',
   'C',
   'o',
   'm',
   'b',
   'i',
   'n',
   'e',
   'r',
   'I',
   'n',
   'p',
   'u',
   't',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   'N',
   'V',
   0, // glGetCombinerInputParameterfvNV
   'g',
   'l',
   'G',
   'e',
   't',
   'C',
   'o',
   'm',
   'b',
   'i',
   'n',
   'e',
   'r',
   'I',
   'n',
   'p',
   'u',
   't',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'N',
   'V',
   0, // glGetCombinerInputParameterivNV
   'g',
   'l',
   'G',
   'e',
   't',
   'C',
   'o',
   'm',
   'b',
   'i',
   'n',
   'e',
   'r',
   'O',
   'u',
   't',
   'p',
   'u',
   't',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   'N',
   'V',
   0, // glGetCombinerOutputParameterfvNV
   'g',
   'l',
   'G',
   'e',
   't',
   'C',
   'o',
   'm',
   'b',
   'i',
   'n',
   'e',
   'r',
   'O',
   'u',
   't',
   'p',
   'u',
   't',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'N',
   'V',
   0, // glGetCombinerOutputParameterivNV
   'g',
   'l',
   'G',
   'e',
   't',
   'C',
   'o',
   'm',
   'b',
   'i',
   'n',
   'e',
   'r',
   'S',
   't',
   'a',
   'g',
   'e',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   'N',
   'V',
   0, // glGetCombinerStageParameterfvNV
   'g',
   'l',
   'G',
   'e',
   't',
   'C',
   'o',
   'm',
   'm',
   'a',
   'n',
   'd',
   'H',
   'e',
   'a',
   'd',
   'e',
   'r',
   'N',
   'V',
   0, // glGetCommandHeaderNV
   'g',
   'l',
   'G',
   'e',
   't',
   'C',
   'o',
   'm',
   'p',
   'r',
   'e',
   's',
   's',
   'e',
   'd',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'I',
   'm',
   'a',
   'g',
   'e',
   'E',
   'X',
   'T',
   0, // glGetCompressedMultiTexImageEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'C',
   'o',
   'm',
   'p',
   'r',
   'e',
   's',
   's',
   'e',
   'd',
   'T',
   'e',
   'x',
   'I',
   'm',
   'a',
   'g',
   'e',
   0, // glGetCompressedTexImage
   'g',
   'l',
   'G',
   'e',
   't',
   'C',
   'o',
   'm',
   'p',
   'r',
   'e',
   's',
   's',
   'e',
   'd',
   'T',
   'e',
   'x',
   'I',
   'm',
   'a',
   'g',
   'e',
   'A',
   'R',
   'B',
   0, // glGetCompressedTexImageARB
   'g',
   'l',
   'G',
   'e',
   't',
   'C',
   'o',
   'm',
   'p',
   'r',
   'e',
   's',
   's',
   'e',
   'd',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'I',
   'm',
   'a',
   'g',
   'e',
   0, // glGetCompressedTextureImage
   'g',
   'l',
   'G',
   'e',
   't',
   'C',
   'o',
   'm',
   'p',
   'r',
   'e',
   's',
   's',
   'e',
   'd',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'I',
   'm',
   'a',
   'g',
   'e',
   'E',
   'X',
   'T',
   0, // glGetCompressedTextureImageEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'C',
   'o',
   'm',
   'p',
   'r',
   'e',
   's',
   's',
   'e',
   'd',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   0, // glGetCompressedTextureSubImage
   'g',
   'l',
   'G',
   'e',
   't',
   'C',
   'o',
   'n',
   'v',
   'o',
   'l',
   'u',
   't',
   'i',
   'o',
   'n',
   'F',
   'i',
   'l',
   't',
   'e',
   'r',
   0, // glGetConvolutionFilter
   'g',
   'l',
   'G',
   'e',
   't',
   'C',
   'o',
   'n',
   'v',
   'o',
   'l',
   'u',
   't',
   'i',
   'o',
   'n',
   'F',
   'i',
   'l',
   't',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glGetConvolutionFilterEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'C',
   'o',
   'n',
   'v',
   'o',
   'l',
   'u',
   't',
   'i',
   'o',
   'n',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   0, // glGetConvolutionParameterfv
   'g',
   'l',
   'G',
   'e',
   't',
   'C',
   'o',
   'n',
   'v',
   'o',
   'l',
   'u',
   't',
   'i',
   'o',
   'n',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   'E',
   'X',
   'T',
   0, // glGetConvolutionParameterfvEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'C',
   'o',
   'n',
   'v',
   'o',
   'l',
   'u',
   't',
   'i',
   'o',
   'n',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   0, // glGetConvolutionParameteriv
   'g',
   'l',
   'G',
   'e',
   't',
   'C',
   'o',
   'n',
   'v',
   'o',
   'l',
   'u',
   't',
   'i',
   'o',
   'n',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glGetConvolutionParameterivEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'C',
   'o',
   'n',
   'v',
   'o',
   'l',
   'u',
   't',
   'i',
   'o',
   'n',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'x',
   'v',
   'O',
   'E',
   'S',
   0, // glGetConvolutionParameterxvOES
   'g',
   'l',
   'G',
   'e',
   't',
   'C',
   'o',
   'v',
   'e',
   'r',
   'a',
   'g',
   'e',
   'M',
   'o',
   'd',
   'u',
   'l',
   'a',
   't',
   'i',
   'o',
   'n',
   'T',
   'a',
   'b',
   'l',
   'e',
   'N',
   'V',
   0, // glGetCoverageModulationTableNV
   'g',
   'l',
   'G',
   'e',
   't',
   'D',
   'e',
   'b',
   'u',
   'g',
   'M',
   'e',
   's',
   's',
   'a',
   'g',
   'e',
   'L',
   'o',
   'g',
   0, // glGetDebugMessageLog
   'g',
   'l',
   'G',
   'e',
   't',
   'D',
   'e',
   'b',
   'u',
   'g',
   'M',
   'e',
   's',
   's',
   'a',
   'g',
   'e',
   'L',
   'o',
   'g',
   'A',
   'M',
   'D',
   0, // glGetDebugMessageLogAMD
   'g',
   'l',
   'G',
   'e',
   't',
   'D',
   'e',
   'b',
   'u',
   'g',
   'M',
   'e',
   's',
   's',
   'a',
   'g',
   'e',
   'L',
   'o',
   'g',
   'A',
   'R',
   'B',
   0, // glGetDebugMessageLogARB
   'g',
   'l',
   'G',
   'e',
   't',
   'D',
   'e',
   'b',
   'u',
   'g',
   'M',
   'e',
   's',
   's',
   'a',
   'g',
   'e',
   'L',
   'o',
   'g',
   'K',
   'H',
   'R',
   0, // glGetDebugMessageLogKHR
   'g',
   'l',
   'G',
   'e',
   't',
   'D',
   'e',
   't',
   'a',
   'i',
   'l',
   'T',
   'e',
   'x',
   'F',
   'u',
   'n',
   'c',
   'S',
   'G',
   'I',
   'S',
   0, // glGetDetailTexFuncSGIS
   'g',
   'l',
   'G',
   'e',
   't',
   'D',
   'o',
   'u',
   'b',
   'l',
   'e',
   'I',
   'n',
   'd',
   'e',
   'x',
   'e',
   'd',
   'v',
   'E',
   'X',
   'T',
   0, // glGetDoubleIndexedvEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'D',
   'o',
   'u',
   'b',
   'l',
   'e',
   'i',
   '_',
   'v',
   0, // glGetDoublei_v
   'g',
   'l',
   'G',
   'e',
   't',
   'D',
   'o',
   'u',
   'b',
   'l',
   'e',
   'i',
   '_',
   'v',
   'E',
   'X',
   'T',
   0, // glGetDoublei_vEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'D',
   'o',
   'u',
   'b',
   'l',
   'e',
   'v',
   0, // glGetDoublev
   'g',
   'l',
   'G',
   'e',
   't',
   'D',
   'r',
   'i',
   'v',
   'e',
   'r',
   'C',
   'o',
   'n',
   't',
   'r',
   'o',
   'l',
   'S',
   't',
   'r',
   'i',
   'n',
   'g',
   'Q',
   'C',
   'O',
   'M',
   0, // glGetDriverControlStringQCOM
   'g',
   'l',
   'G',
   'e',
   't',
   'D',
   'r',
   'i',
   'v',
   'e',
   'r',
   'C',
   'o',
   'n',
   't',
   'r',
   'o',
   'l',
   's',
   'Q',
   'C',
   'O',
   'M',
   0, // glGetDriverControlsQCOM
   'g',
   'l',
   'G',
   'e',
   't',
   'E',
   'r',
   'r',
   'o',
   'r',
   0, // glGetError
   'g',
   'l',
   'G',
   'e',
   't',
   'F',
   'e',
   'n',
   'c',
   'e',
   'i',
   'v',
   'N',
   'V',
   0, // glGetFenceivNV
   'g',
   'l',
   'G',
   'e',
   't',
   'F',
   'i',
   'n',
   'a',
   'l',
   'C',
   'o',
   'm',
   'b',
   'i',
   'n',
   'e',
   'r',
   'I',
   'n',
   'p',
   'u',
   't',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   'N',
   'V',
   0, // glGetFinalCombinerInputParameterfvNV
   'g',
   'l',
   'G',
   'e',
   't',
   'F',
   'i',
   'n',
   'a',
   'l',
   'C',
   'o',
   'm',
   'b',
   'i',
   'n',
   'e',
   'r',
   'I',
   'n',
   'p',
   'u',
   't',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'N',
   'V',
   0, // glGetFinalCombinerInputParameterivNV
   'g',
   'l',
   'G',
   'e',
   't',
   'F',
   'i',
   'r',
   's',
   't',
   'P',
   'e',
   'r',
   'f',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'I',
   'd',
   'I',
   'N',
   'T',
   'E',
   'L',
   0, // glGetFirstPerfQueryIdINTEL
   'g',
   'l',
   'G',
   'e',
   't',
   'F',
   'i',
   'x',
   'e',
   'd',
   'v',
   0, // glGetFixedv
   'g',
   'l',
   'G',
   'e',
   't',
   'F',
   'i',
   'x',
   'e',
   'd',
   'v',
   'O',
   'E',
   'S',
   0, // glGetFixedvOES
   'g',
   'l',
   'G',
   'e',
   't',
   'F',
   'l',
   'o',
   'a',
   't',
   'I',
   'n',
   'd',
   'e',
   'x',
   'e',
   'd',
   'v',
   'E',
   'X',
   'T',
   0, // glGetFloatIndexedvEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'F',
   'l',
   'o',
   'a',
   't',
   'i',
   '_',
   'v',
   0, // glGetFloati_v
   'g',
   'l',
   'G',
   'e',
   't',
   'F',
   'l',
   'o',
   'a',
   't',
   'i',
   '_',
   'v',
   'E',
   'X',
   'T',
   0, // glGetFloati_vEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'F',
   'l',
   'o',
   'a',
   't',
   'i',
   '_',
   'v',
   'N',
   'V',
   0, // glGetFloati_vNV
   'g',
   'l',
   'G',
   'e',
   't',
   'F',
   'l',
   'o',
   'a',
   't',
   'i',
   '_',
   'v',
   'O',
   'E',
   'S',
   0, // glGetFloati_vOES
   'g',
   'l',
   'G',
   'e',
   't',
   'F',
   'l',
   'o',
   'a',
   't',
   'v',
   0, // glGetFloatv
   'g',
   'l',
   'G',
   'e',
   't',
   'F',
   'o',
   'g',
   'F',
   'u',
   'n',
   'c',
   'S',
   'G',
   'I',
   'S',
   0, // glGetFogFuncSGIS
   'g',
   'l',
   'G',
   'e',
   't',
   'F',
   'r',
   'a',
   'g',
   'D',
   'a',
   't',
   'a',
   'I',
   'n',
   'd',
   'e',
   'x',
   0, // glGetFragDataIndex
   'g',
   'l',
   'G',
   'e',
   't',
   'F',
   'r',
   'a',
   'g',
   'D',
   'a',
   't',
   'a',
   'I',
   'n',
   'd',
   'e',
   'x',
   'E',
   'X',
   'T',
   0, // glGetFragDataIndexEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'F',
   'r',
   'a',
   'g',
   'D',
   'a',
   't',
   'a',
   'L',
   'o',
   'c',
   'a',
   't',
   'i',
   'o',
   'n',
   0, // glGetFragDataLocation
   'g',
   'l',
   'G',
   'e',
   't',
   'F',
   'r',
   'a',
   'g',
   'D',
   'a',
   't',
   'a',
   'L',
   'o',
   'c',
   'a',
   't',
   'i',
   'o',
   'n',
   'E',
   'X',
   'T',
   0, // glGetFragDataLocationEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'F',
   'r',
   'a',
   'g',
   'm',
   'e',
   'n',
   't',
   'L',
   'i',
   'g',
   'h',
   't',
   'f',
   'v',
   'S',
   'G',
   'I',
   'X',
   0, // glGetFragmentLightfvSGIX
   'g',
   'l',
   'G',
   'e',
   't',
   'F',
   'r',
   'a',
   'g',
   'm',
   'e',
   'n',
   't',
   'L',
   'i',
   'g',
   'h',
   't',
   'i',
   'v',
   'S',
   'G',
   'I',
   'X',
   0, // glGetFragmentLightivSGIX
   'g',
   'l',
   'G',
   'e',
   't',
   'F',
   'r',
   'a',
   'g',
   'm',
   'e',
   'n',
   't',
   'M',
   'a',
   't',
   'e',
   'r',
   'i',
   'a',
   'l',
   'f',
   'v',
   'S',
   'G',
   'I',
   'X',
   0, // glGetFragmentMaterialfvSGIX
   'g',
   'l',
   'G',
   'e',
   't',
   'F',
   'r',
   'a',
   'g',
   'm',
   'e',
   'n',
   't',
   'M',
   'a',
   't',
   'e',
   'r',
   'i',
   'a',
   'l',
   'i',
   'v',
   'S',
   'G',
   'I',
   'X',
   0, // glGetFragmentMaterialivSGIX
   'g',
   'l',
   'G',
   'e',
   't',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'A',
   't',
   't',
   'a',
   'c',
   'h',
   'm',
   'e',
   'n',
   't',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   0, // glGetFramebufferAttachmentParameteriv
   'g',
   'l',
   'G',
   'e',
   't',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'A',
   't',
   't',
   'a',
   'c',
   'h',
   'm',
   'e',
   'n',
   't',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glGetFramebufferAttachmentParameterivEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'A',
   't',
   't',
   'a',
   'c',
   'h',
   'm',
   'e',
   'n',
   't',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'O',
   'E',
   'S',
   0, // glGetFramebufferAttachmentParameterivOES
   'g',
   'l',
   'G',
   'e',
   't',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   'A',
   'M',
   'D',
   0, // glGetFramebufferParameterfvAMD
   'g',
   'l',
   'G',
   'e',
   't',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   0, // glGetFramebufferParameteriv
   'g',
   'l',
   'G',
   'e',
   't',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glGetFramebufferParameterivEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'M',
   'E',
   'S',
   'A',
   0, // glGetFramebufferParameterivMESA
   'g',
   'l',
   'G',
   'e',
   't',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'P',
   'i',
   'x',
   'e',
   'l',
   'L',
   'o',
   'c',
   'a',
   'l',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   'S',
   'i',
   'z',
   'e',
   'E',
   'X',
   'T',
   0, // glGetFramebufferPixelLocalStorageSizeEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'G',
   'r',
   'a',
   'p',
   'h',
   'i',
   'c',
   's',
   'R',
   'e',
   's',
   'e',
   't',
   'S',
   't',
   'a',
   't',
   'u',
   's',
   0, // glGetGraphicsResetStatus
   'g',
   'l',
   'G',
   'e',
   't',
   'G',
   'r',
   'a',
   'p',
   'h',
   'i',
   'c',
   's',
   'R',
   'e',
   's',
   'e',
   't',
   'S',
   't',
   'a',
   't',
   'u',
   's',
   'A',
   'R',
   'B',
   0, // glGetGraphicsResetStatusARB
   'g',
   'l',
   'G',
   'e',
   't',
   'G',
   'r',
   'a',
   'p',
   'h',
   'i',
   'c',
   's',
   'R',
   'e',
   's',
   'e',
   't',
   'S',
   't',
   'a',
   't',
   'u',
   's',
   'E',
   'X',
   'T',
   0, // glGetGraphicsResetStatusEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'G',
   'r',
   'a',
   'p',
   'h',
   'i',
   'c',
   's',
   'R',
   'e',
   's',
   'e',
   't',
   'S',
   't',
   'a',
   't',
   'u',
   's',
   'K',
   'H',
   'R',
   0, // glGetGraphicsResetStatusKHR
   'g',
   'l',
   'G',
   'e',
   't',
   'H',
   'a',
   'n',
   'd',
   'l',
   'e',
   'A',
   'R',
   'B',
   0, // glGetHandleARB
   'g',
   'l',
   'G',
   'e',
   't',
   'H',
   'i',
   's',
   't',
   'o',
   'g',
   'r',
   'a',
   'm',
   0, // glGetHistogram
   'g',
   'l',
   'G',
   'e',
   't',
   'H',
   'i',
   's',
   't',
   'o',
   'g',
   'r',
   'a',
   'm',
   'E',
   'X',
   'T',
   0, // glGetHistogramEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'H',
   'i',
   's',
   't',
   'o',
   'g',
   'r',
   'a',
   'm',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   0, // glGetHistogramParameterfv
   'g',
   'l',
   'G',
   'e',
   't',
   'H',
   'i',
   's',
   't',
   'o',
   'g',
   'r',
   'a',
   'm',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   'E',
   'X',
   'T',
   0, // glGetHistogramParameterfvEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'H',
   'i',
   's',
   't',
   'o',
   'g',
   'r',
   'a',
   'm',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   0, // glGetHistogramParameteriv
   'g',
   'l',
   'G',
   'e',
   't',
   'H',
   'i',
   's',
   't',
   'o',
   'g',
   'r',
   'a',
   'm',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glGetHistogramParameterivEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'H',
   'i',
   's',
   't',
   'o',
   'g',
   'r',
   'a',
   'm',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'x',
   'v',
   'O',
   'E',
   'S',
   0, // glGetHistogramParameterxvOES
   'g',
   'l',
   'G',
   'e',
   't',
   'I',
   'm',
   'a',
   'g',
   'e',
   'H',
   'a',
   'n',
   'd',
   'l',
   'e',
   'A',
   'R',
   'B',
   0, // glGetImageHandleARB
   'g',
   'l',
   'G',
   'e',
   't',
   'I',
   'm',
   'a',
   'g',
   'e',
   'H',
   'a',
   'n',
   'd',
   'l',
   'e',
   'N',
   'V',
   0, // glGetImageHandleNV
   'g',
   'l',
   'G',
   'e',
   't',
   'I',
   'm',
   'a',
   'g',
   'e',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   'H',
   'P',
   0, // glGetImageTransformParameterfvHP
   'g',
   'l',
   'G',
   'e',
   't',
   'I',
   'm',
   'a',
   'g',
   'e',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'H',
   'P',
   0, // glGetImageTransformParameterivHP
   'g',
   'l',
   'G',
   'e',
   't',
   'I',
   'n',
   'f',
   'o',
   'L',
   'o',
   'g',
   'A',
   'R',
   'B',
   0, // glGetInfoLogARB
   'g',
   'l',
   'G',
   'e',
   't',
   'I',
   'n',
   's',
   't',
   'r',
   'u',
   'm',
   'e',
   'n',
   't',
   's',
   'S',
   'G',
   'I',
   'X',
   0, // glGetInstrumentsSGIX
   'g',
   'l',
   'G',
   'e',
   't',
   'I',
   'n',
   't',
   'e',
   'g',
   'e',
   'r',
   '6',
   '4',
   'i',
   '_',
   'v',
   0, // glGetInteger64i_v
   'g',
   'l',
   'G',
   'e',
   't',
   'I',
   'n',
   't',
   'e',
   'g',
   'e',
   'r',
   '6',
   '4',
   'v',
   0, // glGetInteger64v
   'g',
   'l',
   'G',
   'e',
   't',
   'I',
   'n',
   't',
   'e',
   'g',
   'e',
   'r',
   '6',
   '4',
   'v',
   'A',
   'P',
   'P',
   'L',
   'E',
   0, // glGetInteger64vAPPLE
   'g',
   'l',
   'G',
   'e',
   't',
   'I',
   'n',
   't',
   'e',
   'g',
   'e',
   'r',
   'I',
   'n',
   'd',
   'e',
   'x',
   'e',
   'd',
   'v',
   'E',
   'X',
   'T',
   0, // glGetIntegerIndexedvEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'I',
   'n',
   't',
   'e',
   'g',
   'e',
   'r',
   'i',
   '_',
   'v',
   0, // glGetIntegeri_v
   'g',
   'l',
   'G',
   'e',
   't',
   'I',
   'n',
   't',
   'e',
   'g',
   'e',
   'r',
   'i',
   '_',
   'v',
   'E',
   'X',
   'T',
   0, // glGetIntegeri_vEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'I',
   'n',
   't',
   'e',
   'g',
   'e',
   'r',
   'u',
   'i',
   '6',
   '4',
   'i',
   '_',
   'v',
   'N',
   'V',
   0, // glGetIntegerui64i_vNV
   'g',
   'l',
   'G',
   'e',
   't',
   'I',
   'n',
   't',
   'e',
   'g',
   'e',
   'r',
   'u',
   'i',
   '6',
   '4',
   'v',
   'N',
   'V',
   0, // glGetIntegerui64vNV
   'g',
   'l',
   'G',
   'e',
   't',
   'I',
   'n',
   't',
   'e',
   'g',
   'e',
   'r',
   'v',
   0, // glGetIntegerv
   'g',
   'l',
   'G',
   'e',
   't',
   'I',
   'n',
   't',
   'e',
   'r',
   'n',
   'a',
   'l',
   'f',
   'o',
   'r',
   'm',
   'a',
   't',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'i',
   'v',
   'N',
   'V',
   0, // glGetInternalformatSampleivNV
   'g',
   'l',
   'G',
   'e',
   't',
   'I',
   'n',
   't',
   'e',
   'r',
   'n',
   'a',
   'l',
   'f',
   'o',
   'r',
   'm',
   'a',
   't',
   'i',
   '6',
   '4',
   'v',
   0, // glGetInternalformati64v
   'g',
   'l',
   'G',
   'e',
   't',
   'I',
   'n',
   't',
   'e',
   'r',
   'n',
   'a',
   'l',
   'f',
   'o',
   'r',
   'm',
   'a',
   't',
   'i',
   'v',
   0, // glGetInternalformativ
   'g',
   'l',
   'G',
   'e',
   't',
   'I',
   'n',
   'v',
   'a',
   'r',
   'i',
   'a',
   'n',
   't',
   'B',
   'o',
   'o',
   'l',
   'e',
   'a',
   'n',
   'v',
   'E',
   'X',
   'T',
   0, // glGetInvariantBooleanvEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'I',
   'n',
   'v',
   'a',
   'r',
   'i',
   'a',
   'n',
   't',
   'F',
   'l',
   'o',
   'a',
   't',
   'v',
   'E',
   'X',
   'T',
   0, // glGetInvariantFloatvEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'I',
   'n',
   'v',
   'a',
   'r',
   'i',
   'a',
   'n',
   't',
   'I',
   'n',
   't',
   'e',
   'g',
   'e',
   'r',
   'v',
   'E',
   'X',
   'T',
   0, // glGetInvariantIntegervEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'L',
   'i',
   'g',
   'h',
   't',
   'f',
   'v',
   0, // glGetLightfv
   'g',
   'l',
   'G',
   'e',
   't',
   'L',
   'i',
   'g',
   'h',
   't',
   'i',
   'v',
   0, // glGetLightiv
   'g',
   'l',
   'G',
   'e',
   't',
   'L',
   'i',
   'g',
   'h',
   't',
   'x',
   'O',
   'E',
   'S',
   0, // glGetLightxOES
   'g',
   'l',
   'G',
   'e',
   't',
   'L',
   'i',
   'g',
   'h',
   't',
   'x',
   'v',
   0, // glGetLightxv
   'g',
   'l',
   'G',
   'e',
   't',
   'L',
   'i',
   'g',
   'h',
   't',
   'x',
   'v',
   'O',
   'E',
   'S',
   0, // glGetLightxvOES
   'g',
   'l',
   'G',
   'e',
   't',
   'L',
   'i',
   's',
   't',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   'S',
   'G',
   'I',
   'X',
   0, // glGetListParameterfvSGIX
   'g',
   'l',
   'G',
   'e',
   't',
   'L',
   'i',
   's',
   't',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'S',
   'G',
   'I',
   'X',
   0, // glGetListParameterivSGIX
   'g',
   'l',
   'G',
   'e',
   't',
   'L',
   'o',
   'c',
   'a',
   'l',
   'C',
   'o',
   'n',
   's',
   't',
   'a',
   'n',
   't',
   'B',
   'o',
   'o',
   'l',
   'e',
   'a',
   'n',
   'v',
   'E',
   'X',
   'T',
   0, // glGetLocalConstantBooleanvEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'L',
   'o',
   'c',
   'a',
   'l',
   'C',
   'o',
   'n',
   's',
   't',
   'a',
   'n',
   't',
   'F',
   'l',
   'o',
   'a',
   't',
   'v',
   'E',
   'X',
   'T',
   0, // glGetLocalConstantFloatvEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'L',
   'o',
   'c',
   'a',
   'l',
   'C',
   'o',
   'n',
   's',
   't',
   'a',
   'n',
   't',
   'I',
   'n',
   't',
   'e',
   'g',
   'e',
   'r',
   'v',
   'E',
   'X',
   'T',
   0, // glGetLocalConstantIntegervEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'M',
   'a',
   'p',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   'N',
   'V',
   0, // glGetMapAttribParameterfvNV
   'g',
   'l',
   'G',
   'e',
   't',
   'M',
   'a',
   'p',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'N',
   'V',
   0, // glGetMapAttribParameterivNV
   'g',
   'l',
   'G',
   'e',
   't',
   'M',
   'a',
   'p',
   'C',
   'o',
   'n',
   't',
   'r',
   'o',
   'l',
   'P',
   'o',
   'i',
   'n',
   't',
   's',
   'N',
   'V',
   0, // glGetMapControlPointsNV
   'g',
   'l',
   'G',
   'e',
   't',
   'M',
   'a',
   'p',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   'N',
   'V',
   0, // glGetMapParameterfvNV
   'g',
   'l',
   'G',
   'e',
   't',
   'M',
   'a',
   'p',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'N',
   'V',
   0, // glGetMapParameterivNV
   'g',
   'l',
   'G',
   'e',
   't',
   'M',
   'a',
   'p',
   'd',
   'v',
   0, // glGetMapdv
   'g',
   'l',
   'G',
   'e',
   't',
   'M',
   'a',
   'p',
   'f',
   'v',
   0, // glGetMapfv
   'g',
   'l',
   'G',
   'e',
   't',
   'M',
   'a',
   'p',
   'i',
   'v',
   0, // glGetMapiv
   'g',
   'l',
   'G',
   'e',
   't',
   'M',
   'a',
   'p',
   'x',
   'v',
   'O',
   'E',
   'S',
   0, // glGetMapxvOES
   'g',
   'l',
   'G',
   'e',
   't',
   'M',
   'a',
   't',
   'e',
   'r',
   'i',
   'a',
   'l',
   'f',
   'v',
   0, // glGetMaterialfv
   'g',
   'l',
   'G',
   'e',
   't',
   'M',
   'a',
   't',
   'e',
   'r',
   'i',
   'a',
   'l',
   'i',
   'v',
   0, // glGetMaterialiv
   'g',
   'l',
   'G',
   'e',
   't',
   'M',
   'a',
   't',
   'e',
   'r',
   'i',
   'a',
   'l',
   'x',
   'O',
   'E',
   'S',
   0, // glGetMaterialxOES
   'g',
   'l',
   'G',
   'e',
   't',
   'M',
   'a',
   't',
   'e',
   'r',
   'i',
   'a',
   'l',
   'x',
   'v',
   0, // glGetMaterialxv
   'g',
   'l',
   'G',
   'e',
   't',
   'M',
   'a',
   't',
   'e',
   'r',
   'i',
   'a',
   'l',
   'x',
   'v',
   'O',
   'E',
   'S',
   0, // glGetMaterialxvOES
   'g',
   'l',
   'G',
   'e',
   't',
   'M',
   'e',
   'm',
   'o',
   'r',
   'y',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'D',
   'e',
   't',
   'a',
   'c',
   'h',
   'e',
   'd',
   'R',
   'e',
   's',
   'o',
   'u',
   'r',
   'c',
   'e',
   's',
   'u',
   'i',
   'v',
   'N',
   'V',
   0, // glGetMemoryObjectDetachedResourcesuivNV
   'g',
   'l',
   'G',
   'e',
   't',
   'M',
   'e',
   'm',
   'o',
   'r',
   'y',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glGetMemoryObjectParameterivEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'M',
   'i',
   'n',
   'm',
   'a',
   'x',
   0, // glGetMinmax
   'g',
   'l',
   'G',
   'e',
   't',
   'M',
   'i',
   'n',
   'm',
   'a',
   'x',
   'E',
   'X',
   'T',
   0, // glGetMinmaxEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'M',
   'i',
   'n',
   'm',
   'a',
   'x',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   0, // glGetMinmaxParameterfv
   'g',
   'l',
   'G',
   'e',
   't',
   'M',
   'i',
   'n',
   'm',
   'a',
   'x',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   'E',
   'X',
   'T',
   0, // glGetMinmaxParameterfvEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'M',
   'i',
   'n',
   'm',
   'a',
   'x',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   0, // glGetMinmaxParameteriv
   'g',
   'l',
   'G',
   'e',
   't',
   'M',
   'i',
   'n',
   'm',
   'a',
   'x',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glGetMinmaxParameterivEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'E',
   'n',
   'v',
   'f',
   'v',
   'E',
   'X',
   'T',
   0, // glGetMultiTexEnvfvEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'E',
   'n',
   'v',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glGetMultiTexEnvivEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'G',
   'e',
   'n',
   'd',
   'v',
   'E',
   'X',
   'T',
   0, // glGetMultiTexGendvEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'G',
   'e',
   'n',
   'f',
   'v',
   'E',
   'X',
   'T',
   0, // glGetMultiTexGenfvEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'G',
   'e',
   'n',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glGetMultiTexGenivEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'I',
   'm',
   'a',
   'g',
   'e',
   'E',
   'X',
   'T',
   0, // glGetMultiTexImageEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'L',
   'e',
   'v',
   'e',
   'l',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   'E',
   'X',
   'T',
   0, // glGetMultiTexLevelParameterfvEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'L',
   'e',
   'v',
   'e',
   'l',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glGetMultiTexLevelParameterivEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glGetMultiTexParameterIivEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   'u',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glGetMultiTexParameterIuivEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   'E',
   'X',
   'T',
   0, // glGetMultiTexParameterfvEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glGetMultiTexParameterivEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'M',
   'u',
   'l',
   't',
   'i',
   's',
   'a',
   'm',
   'p',
   'l',
   'e',
   'f',
   'v',
   0, // glGetMultisamplefv
   'g',
   'l',
   'G',
   'e',
   't',
   'M',
   'u',
   'l',
   't',
   'i',
   's',
   'a',
   'm',
   'p',
   'l',
   'e',
   'f',
   'v',
   'N',
   'V',
   0, // glGetMultisamplefvNV
   'g',
   'l',
   'G',
   'e',
   't',
   'N',
   'a',
   'm',
   'e',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   '6',
   '4',
   'v',
   0, // glGetNamedBufferParameteri64v
   'g',
   'l',
   'G',
   'e',
   't',
   'N',
   'a',
   'm',
   'e',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   0, // glGetNamedBufferParameteriv
   'g',
   'l',
   'G',
   'e',
   't',
   'N',
   'a',
   'm',
   'e',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glGetNamedBufferParameterivEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'N',
   'a',
   'm',
   'e',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'u',
   'i',
   '6',
   '4',
   'v',
   'N',
   'V',
   0, // glGetNamedBufferParameterui64vNV
   'g',
   'l',
   'G',
   'e',
   't',
   'N',
   'a',
   'm',
   'e',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'v',
   0, // glGetNamedBufferPointerv
   'g',
   'l',
   'G',
   'e',
   't',
   'N',
   'a',
   'm',
   'e',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'v',
   'E',
   'X',
   'T',
   0, // glGetNamedBufferPointervEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'N',
   'a',
   'm',
   'e',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   'u',
   'b',
   'D',
   'a',
   't',
   'a',
   0, // glGetNamedBufferSubData
   'g',
   'l',
   'G',
   'e',
   't',
   'N',
   'a',
   'm',
   'e',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   'u',
   'b',
   'D',
   'a',
   't',
   'a',
   'E',
   'X',
   'T',
   0, // glGetNamedBufferSubDataEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'N',
   'a',
   'm',
   'e',
   'd',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'A',
   't',
   't',
   'a',
   'c',
   'h',
   'm',
   'e',
   'n',
   't',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   0, // glGetNamedFramebufferAttachmentParameteriv
   'g',
   'l',
   'G',
   'e',
   't',
   'N',
   'a',
   'm',
   'e',
   'd',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'A',
   't',
   't',
   'a',
   'c',
   'h',
   'm',
   'e',
   'n',
   't',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glGetNamedFramebufferAttachmentParameterivEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'N',
   'a',
   'm',
   'e',
   'd',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   'A',
   'M',
   'D',
   0, // glGetNamedFramebufferParameterfvAMD
   'g',
   'l',
   'G',
   'e',
   't',
   'N',
   'a',
   'm',
   'e',
   'd',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   0, // glGetNamedFramebufferParameteriv
   'g',
   'l',
   'G',
   'e',
   't',
   'N',
   'a',
   'm',
   'e',
   'd',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glGetNamedFramebufferParameterivEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'N',
   'a',
   'm',
   'e',
   'd',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'L',
   'o',
   'c',
   'a',
   'l',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glGetNamedProgramLocalParameterIivEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'N',
   'a',
   'm',
   'e',
   'd',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'L',
   'o',
   'c',
   'a',
   'l',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   'u',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glGetNamedProgramLocalParameterIuivEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'N',
   'a',
   'm',
   'e',
   'd',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'L',
   'o',
   'c',
   'a',
   'l',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'd',
   'v',
   'E',
   'X',
   'T',
   0, // glGetNamedProgramLocalParameterdvEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'N',
   'a',
   'm',
   'e',
   'd',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'L',
   'o',
   'c',
   'a',
   'l',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   'E',
   'X',
   'T',
   0, // glGetNamedProgramLocalParameterfvEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'N',
   'a',
   'm',
   'e',
   'd',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'S',
   't',
   'r',
   'i',
   'n',
   'g',
   'E',
   'X',
   'T',
   0, // glGetNamedProgramStringEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'N',
   'a',
   'm',
   'e',
   'd',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glGetNamedProgramivEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'N',
   'a',
   'm',
   'e',
   'd',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   0, // glGetNamedRenderbufferParameteriv
   'g',
   'l',
   'G',
   'e',
   't',
   'N',
   'a',
   'm',
   'e',
   'd',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glGetNamedRenderbufferParameterivEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'N',
   'a',
   'm',
   'e',
   'd',
   'S',
   't',
   'r',
   'i',
   'n',
   'g',
   'A',
   'R',
   'B',
   0, // glGetNamedStringARB
   'g',
   'l',
   'G',
   'e',
   't',
   'N',
   'a',
   'm',
   'e',
   'd',
   'S',
   't',
   'r',
   'i',
   'n',
   'g',
   'i',
   'v',
   'A',
   'R',
   'B',
   0, // glGetNamedStringivARB
   'g',
   'l',
   'G',
   'e',
   't',
   'N',
   'e',
   'x',
   't',
   'P',
   'e',
   'r',
   'f',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'I',
   'd',
   'I',
   'N',
   'T',
   'E',
   'L',
   0, // glGetNextPerfQueryIdINTEL
   'g',
   'l',
   'G',
   'e',
   't',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'f',
   'v',
   'A',
   'T',
   'I',
   0, // glGetObjectBufferfvATI
   'g',
   'l',
   'G',
   'e',
   't',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'i',
   'v',
   'A',
   'T',
   'I',
   0, // glGetObjectBufferivATI
   'g',
   'l',
   'G',
   'e',
   't',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'L',
   'a',
   'b',
   'e',
   'l',
   0, // glGetObjectLabel
   'g',
   'l',
   'G',
   'e',
   't',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'L',
   'a',
   'b',
   'e',
   'l',
   'E',
   'X',
   'T',
   0, // glGetObjectLabelEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'L',
   'a',
   'b',
   'e',
   'l',
   'K',
   'H',
   'R',
   0, // glGetObjectLabelKHR
   'g',
   'l',
   'G',
   'e',
   't',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   'A',
   'R',
   'B',
   0, // glGetObjectParameterfvARB
   'g',
   'l',
   'G',
   'e',
   't',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'A',
   'P',
   'P',
   'L',
   'E',
   0, // glGetObjectParameterivAPPLE
   'g',
   'l',
   'G',
   'e',
   't',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'A',
   'R',
   'B',
   0, // glGetObjectParameterivARB
   'g',
   'l',
   'G',
   'e',
   't',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'P',
   't',
   'r',
   'L',
   'a',
   'b',
   'e',
   'l',
   0, // glGetObjectPtrLabel
   'g',
   'l',
   'G',
   'e',
   't',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'P',
   't',
   'r',
   'L',
   'a',
   'b',
   'e',
   'l',
   'K',
   'H',
   'R',
   0, // glGetObjectPtrLabelKHR
   'g',
   'l',
   'G',
   'e',
   't',
   'O',
   'c',
   'c',
   'l',
   'u',
   's',
   'i',
   'o',
   'n',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'i',
   'v',
   'N',
   'V',
   0, // glGetOcclusionQueryivNV
   'g',
   'l',
   'G',
   'e',
   't',
   'O',
   'c',
   'c',
   'l',
   'u',
   's',
   'i',
   'o',
   'n',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'u',
   'i',
   'v',
   'N',
   'V',
   0, // glGetOcclusionQueryuivNV
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'a',
   't',
   'h',
   'C',
   'o',
   'l',
   'o',
   'r',
   'G',
   'e',
   'n',
   'f',
   'v',
   'N',
   'V',
   0, // glGetPathColorGenfvNV
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'a',
   't',
   'h',
   'C',
   'o',
   'l',
   'o',
   'r',
   'G',
   'e',
   'n',
   'i',
   'v',
   'N',
   'V',
   0, // glGetPathColorGenivNV
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'a',
   't',
   'h',
   'C',
   'o',
   'm',
   'm',
   'a',
   'n',
   'd',
   's',
   'N',
   'V',
   0, // glGetPathCommandsNV
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'a',
   't',
   'h',
   'C',
   'o',
   'o',
   'r',
   'd',
   's',
   'N',
   'V',
   0, // glGetPathCoordsNV
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'a',
   't',
   'h',
   'D',
   'a',
   's',
   'h',
   'A',
   'r',
   'r',
   'a',
   'y',
   'N',
   'V',
   0, // glGetPathDashArrayNV
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'a',
   't',
   'h',
   'L',
   'e',
   'n',
   'g',
   't',
   'h',
   'N',
   'V',
   0, // glGetPathLengthNV
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'a',
   't',
   'h',
   'M',
   'e',
   't',
   'r',
   'i',
   'c',
   'R',
   'a',
   'n',
   'g',
   'e',
   'N',
   'V',
   0, // glGetPathMetricRangeNV
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'a',
   't',
   'h',
   'M',
   'e',
   't',
   'r',
   'i',
   'c',
   's',
   'N',
   'V',
   0, // glGetPathMetricsNV
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'a',
   't',
   'h',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   'N',
   'V',
   0, // glGetPathParameterfvNV
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'a',
   't',
   'h',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'N',
   'V',
   0, // glGetPathParameterivNV
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'a',
   't',
   'h',
   'S',
   'p',
   'a',
   'c',
   'i',
   'n',
   'g',
   'N',
   'V',
   0, // glGetPathSpacingNV
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'a',
   't',
   'h',
   'T',
   'e',
   'x',
   'G',
   'e',
   'n',
   'f',
   'v',
   'N',
   'V',
   0, // glGetPathTexGenfvNV
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'a',
   't',
   'h',
   'T',
   'e',
   'x',
   'G',
   'e',
   'n',
   'i',
   'v',
   'N',
   'V',
   0, // glGetPathTexGenivNV
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'e',
   'r',
   'f',
   'C',
   'o',
   'u',
   'n',
   't',
   'e',
   'r',
   'I',
   'n',
   'f',
   'o',
   'I',
   'N',
   'T',
   'E',
   'L',
   0, // glGetPerfCounterInfoINTEL
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'e',
   'r',
   'f',
   'M',
   'o',
   'n',
   'i',
   't',
   'o',
   'r',
   'C',
   'o',
   'u',
   'n',
   't',
   'e',
   'r',
   'D',
   'a',
   't',
   'a',
   'A',
   'M',
   'D',
   0, // glGetPerfMonitorCounterDataAMD
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'e',
   'r',
   'f',
   'M',
   'o',
   'n',
   'i',
   't',
   'o',
   'r',
   'C',
   'o',
   'u',
   'n',
   't',
   'e',
   'r',
   'I',
   'n',
   'f',
   'o',
   'A',
   'M',
   'D',
   0, // glGetPerfMonitorCounterInfoAMD
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'e',
   'r',
   'f',
   'M',
   'o',
   'n',
   'i',
   't',
   'o',
   'r',
   'C',
   'o',
   'u',
   'n',
   't',
   'e',
   'r',
   'S',
   't',
   'r',
   'i',
   'n',
   'g',
   'A',
   'M',
   'D',
   0, // glGetPerfMonitorCounterStringAMD
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'e',
   'r',
   'f',
   'M',
   'o',
   'n',
   'i',
   't',
   'o',
   'r',
   'C',
   'o',
   'u',
   'n',
   't',
   'e',
   'r',
   's',
   'A',
   'M',
   'D',
   0, // glGetPerfMonitorCountersAMD
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'e',
   'r',
   'f',
   'M',
   'o',
   'n',
   'i',
   't',
   'o',
   'r',
   'G',
   'r',
   'o',
   'u',
   'p',
   'S',
   't',
   'r',
   'i',
   'n',
   'g',
   'A',
   'M',
   'D',
   0, // glGetPerfMonitorGroupStringAMD
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'e',
   'r',
   'f',
   'M',
   'o',
   'n',
   'i',
   't',
   'o',
   'r',
   'G',
   'r',
   'o',
   'u',
   'p',
   's',
   'A',
   'M',
   'D',
   0, // glGetPerfMonitorGroupsAMD
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'e',
   'r',
   'f',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'D',
   'a',
   't',
   'a',
   'I',
   'N',
   'T',
   'E',
   'L',
   0, // glGetPerfQueryDataINTEL
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'e',
   'r',
   'f',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'I',
   'd',
   'B',
   'y',
   'N',
   'a',
   'm',
   'e',
   'I',
   'N',
   'T',
   'E',
   'L',
   0, // glGetPerfQueryIdByNameINTEL
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'e',
   'r',
   'f',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'I',
   'n',
   'f',
   'o',
   'I',
   'N',
   'T',
   'E',
   'L',
   0, // glGetPerfQueryInfoINTEL
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'i',
   'x',
   'e',
   'l',
   'M',
   'a',
   'p',
   'f',
   'v',
   0, // glGetPixelMapfv
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'i',
   'x',
   'e',
   'l',
   'M',
   'a',
   'p',
   'u',
   'i',
   'v',
   0, // glGetPixelMapuiv
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'i',
   'x',
   'e',
   'l',
   'M',
   'a',
   'p',
   'u',
   's',
   'v',
   0, // glGetPixelMapusv
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'i',
   'x',
   'e',
   'l',
   'M',
   'a',
   'p',
   'x',
   'v',
   0, // glGetPixelMapxv
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'i',
   'x',
   'e',
   'l',
   'T',
   'e',
   'x',
   'G',
   'e',
   'n',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   'S',
   'G',
   'I',
   'S',
   0, // glGetPixelTexGenParameterfvSGIS
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'i',
   'x',
   'e',
   'l',
   'T',
   'e',
   'x',
   'G',
   'e',
   'n',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'S',
   'G',
   'I',
   'S',
   0, // glGetPixelTexGenParameterivSGIS
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'i',
   'x',
   'e',
   'l',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   'E',
   'X',
   'T',
   0, // glGetPixelTransformParameterfvEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'i',
   'x',
   'e',
   'l',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glGetPixelTransformParameterivEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'I',
   'n',
   'd',
   'e',
   'x',
   'e',
   'd',
   'v',
   'E',
   'X',
   'T',
   0, // glGetPointerIndexedvEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'i',
   '_',
   'v',
   'E',
   'X',
   'T',
   0, // glGetPointeri_vEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'v',
   0, // glGetPointerv
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'v',
   'E',
   'X',
   'T',
   0, // glGetPointervEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'v',
   'K',
   'H',
   'R',
   0, // glGetPointervKHR
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'o',
   'l',
   'y',
   'g',
   'o',
   'n',
   'S',
   't',
   'i',
   'p',
   'p',
   'l',
   'e',
   0, // glGetPolygonStipple
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'B',
   'i',
   'n',
   'a',
   'r',
   'y',
   0, // glGetProgramBinary
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'B',
   'i',
   'n',
   'a',
   'r',
   'y',
   'O',
   'E',
   'S',
   0, // glGetProgramBinaryOES
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'E',
   'n',
   'v',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   'i',
   'v',
   'N',
   'V',
   0, // glGetProgramEnvParameterIivNV
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'E',
   'n',
   'v',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   'u',
   'i',
   'v',
   'N',
   'V',
   0, // glGetProgramEnvParameterIuivNV
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'E',
   'n',
   'v',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'd',
   'v',
   'A',
   'R',
   'B',
   0, // glGetProgramEnvParameterdvARB
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'E',
   'n',
   'v',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   'A',
   'R',
   'B',
   0, // glGetProgramEnvParameterfvARB
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'I',
   'n',
   'f',
   'o',
   'L',
   'o',
   'g',
   0, // glGetProgramInfoLog
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'I',
   'n',
   't',
   'e',
   'r',
   'f',
   'a',
   'c',
   'e',
   'i',
   'v',
   0, // glGetProgramInterfaceiv
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'L',
   'o',
   'c',
   'a',
   'l',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   'i',
   'v',
   'N',
   'V',
   0, // glGetProgramLocalParameterIivNV
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'L',
   'o',
   'c',
   'a',
   'l',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   'u',
   'i',
   'v',
   'N',
   'V',
   0, // glGetProgramLocalParameterIuivNV
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'L',
   'o',
   'c',
   'a',
   'l',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'd',
   'v',
   'A',
   'R',
   'B',
   0, // glGetProgramLocalParameterdvARB
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'L',
   'o',
   'c',
   'a',
   'l',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   'A',
   'R',
   'B',
   0, // glGetProgramLocalParameterfvARB
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'N',
   'a',
   'm',
   'e',
   'd',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'd',
   'v',
   'N',
   'V',
   0, // glGetProgramNamedParameterdvNV
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'N',
   'a',
   'm',
   'e',
   'd',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   'N',
   'V',
   0, // glGetProgramNamedParameterfvNV
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'd',
   'v',
   'N',
   'V',
   0, // glGetProgramParameterdvNV
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   'N',
   'V',
   0, // glGetProgramParameterfvNV
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'P',
   'i',
   'p',
   'e',
   'l',
   'i',
   'n',
   'e',
   'I',
   'n',
   'f',
   'o',
   'L',
   'o',
   'g',
   0, // glGetProgramPipelineInfoLog
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'P',
   'i',
   'p',
   'e',
   'l',
   'i',
   'n',
   'e',
   'I',
   'n',
   'f',
   'o',
   'L',
   'o',
   'g',
   'E',
   'X',
   'T',
   0, // glGetProgramPipelineInfoLogEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'P',
   'i',
   'p',
   'e',
   'l',
   'i',
   'n',
   'e',
   'i',
   'v',
   0, // glGetProgramPipelineiv
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'P',
   'i',
   'p',
   'e',
   'l',
   'i',
   'n',
   'e',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glGetProgramPipelineivEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'R',
   'e',
   's',
   'o',
   'u',
   'r',
   'c',
   'e',
   'I',
   'n',
   'd',
   'e',
   'x',
   0, // glGetProgramResourceIndex
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'R',
   'e',
   's',
   'o',
   'u',
   'r',
   'c',
   'e',
   'L',
   'o',
   'c',
   'a',
   't',
   'i',
   'o',
   'n',
   0, // glGetProgramResourceLocation
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'R',
   'e',
   's',
   'o',
   'u',
   'r',
   'c',
   'e',
   'L',
   'o',
   'c',
   'a',
   't',
   'i',
   'o',
   'n',
   'I',
   'n',
   'd',
   'e',
   'x',
   0, // glGetProgramResourceLocationIndex
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'R',
   'e',
   's',
   'o',
   'u',
   'r',
   'c',
   'e',
   'L',
   'o',
   'c',
   'a',
   't',
   'i',
   'o',
   'n',
   'I',
   'n',
   'd',
   'e',
   'x',
   'E',
   'X',
   'T',
   0, // glGetProgramResourceLocationIndexEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'R',
   'e',
   's',
   'o',
   'u',
   'r',
   'c',
   'e',
   'N',
   'a',
   'm',
   'e',
   0, // glGetProgramResourceName
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'R',
   'e',
   's',
   'o',
   'u',
   'r',
   'c',
   'e',
   'f',
   'v',
   'N',
   'V',
   0, // glGetProgramResourcefvNV
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'R',
   'e',
   's',
   'o',
   'u',
   'r',
   'c',
   'e',
   'i',
   'v',
   0, // glGetProgramResourceiv
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'S',
   't',
   'a',
   'g',
   'e',
   'i',
   'v',
   0, // glGetProgramStageiv
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'S',
   't',
   'r',
   'i',
   'n',
   'g',
   'A',
   'R',
   'B',
   0, // glGetProgramStringARB
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'S',
   't',
   'r',
   'i',
   'n',
   'g',
   'N',
   'V',
   0, // glGetProgramStringNV
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'S',
   'u',
   'b',
   'r',
   'o',
   'u',
   't',
   'i',
   'n',
   'e',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'u',
   'i',
   'v',
   'N',
   'V',
   0, // glGetProgramSubroutineParameteruivNV
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'i',
   'v',
   0, // glGetProgramiv
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'i',
   'v',
   'A',
   'R',
   'B',
   0, // glGetProgramivARB
   'g',
   'l',
   'G',
   'e',
   't',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'i',
   'v',
   'N',
   'V',
   0, // glGetProgramivNV
   'g',
   'l',
   'G',
   'e',
   't',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'i',
   '6',
   '4',
   'v',
   0, // glGetQueryBufferObjecti64v
   'g',
   'l',
   'G',
   'e',
   't',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'i',
   'v',
   0, // glGetQueryBufferObjectiv
   'g',
   'l',
   'G',
   'e',
   't',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'u',
   'i',
   '6',
   '4',
   'v',
   0, // glGetQueryBufferObjectui64v
   'g',
   'l',
   'G',
   'e',
   't',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'u',
   'i',
   'v',
   0, // glGetQueryBufferObjectuiv
   'g',
   'l',
   'G',
   'e',
   't',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'I',
   'n',
   'd',
   'e',
   'x',
   'e',
   'd',
   'i',
   'v',
   0, // glGetQueryIndexediv
   'g',
   'l',
   'G',
   'e',
   't',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'i',
   '6',
   '4',
   'v',
   0, // glGetQueryObjecti64v
   'g',
   'l',
   'G',
   'e',
   't',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'i',
   '6',
   '4',
   'v',
   'E',
   'X',
   'T',
   0, // glGetQueryObjecti64vEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'i',
   'v',
   0, // glGetQueryObjectiv
   'g',
   'l',
   'G',
   'e',
   't',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'i',
   'v',
   'A',
   'R',
   'B',
   0, // glGetQueryObjectivARB
   'g',
   'l',
   'G',
   'e',
   't',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glGetQueryObjectivEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'u',
   'i',
   '6',
   '4',
   'v',
   0, // glGetQueryObjectui64v
   'g',
   'l',
   'G',
   'e',
   't',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'u',
   'i',
   '6',
   '4',
   'v',
   'E',
   'X',
   'T',
   0, // glGetQueryObjectui64vEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'u',
   'i',
   'v',
   0, // glGetQueryObjectuiv
   'g',
   'l',
   'G',
   'e',
   't',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'u',
   'i',
   'v',
   'A',
   'R',
   'B',
   0, // glGetQueryObjectuivARB
   'g',
   'l',
   'G',
   'e',
   't',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'u',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glGetQueryObjectuivEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'i',
   'v',
   0, // glGetQueryiv
   'g',
   'l',
   'G',
   'e',
   't',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'i',
   'v',
   'A',
   'R',
   'B',
   0, // glGetQueryivARB
   'g',
   'l',
   'G',
   'e',
   't',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glGetQueryivEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   0, // glGetRenderbufferParameteriv
   'g',
   'l',
   'G',
   'e',
   't',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glGetRenderbufferParameterivEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'O',
   'E',
   'S',
   0, // glGetRenderbufferParameterivOES
   'g',
   'l',
   'G',
   'e',
   't',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   'i',
   'v',
   0, // glGetSamplerParameterIiv
   'g',
   'l',
   'G',
   'e',
   't',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glGetSamplerParameterIivEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   'i',
   'v',
   'O',
   'E',
   'S',
   0, // glGetSamplerParameterIivOES
   'g',
   'l',
   'G',
   'e',
   't',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   'u',
   'i',
   'v',
   0, // glGetSamplerParameterIuiv
   'g',
   'l',
   'G',
   'e',
   't',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   'u',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glGetSamplerParameterIuivEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   'u',
   'i',
   'v',
   'O',
   'E',
   'S',
   0, // glGetSamplerParameterIuivOES
   'g',
   'l',
   'G',
   'e',
   't',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   0, // glGetSamplerParameterfv
   'g',
   'l',
   'G',
   'e',
   't',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   0, // glGetSamplerParameteriv
   'g',
   'l',
   'G',
   'e',
   't',
   'S',
   'e',
   'm',
   'a',
   'p',
   'h',
   'o',
   'r',
   'e',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'u',
   'i',
   '6',
   '4',
   'v',
   'E',
   'X',
   'T',
   0, // glGetSemaphoreParameterui64vEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'S',
   'e',
   'p',
   'a',
   'r',
   'a',
   'b',
   'l',
   'e',
   'F',
   'i',
   'l',
   't',
   'e',
   'r',
   0, // glGetSeparableFilter
   'g',
   'l',
   'G',
   'e',
   't',
   'S',
   'e',
   'p',
   'a',
   'r',
   'a',
   'b',
   'l',
   'e',
   'F',
   'i',
   'l',
   't',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glGetSeparableFilterEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'S',
   'h',
   'a',
   'd',
   'e',
   'r',
   'I',
   'n',
   'f',
   'o',
   'L',
   'o',
   'g',
   0, // glGetShaderInfoLog
   'g',
   'l',
   'G',
   'e',
   't',
   'S',
   'h',
   'a',
   'd',
   'e',
   'r',
   'P',
   'r',
   'e',
   'c',
   'i',
   's',
   'i',
   'o',
   'n',
   'F',
   'o',
   'r',
   'm',
   'a',
   't',
   0, // glGetShaderPrecisionFormat
   'g',
   'l',
   'G',
   'e',
   't',
   'S',
   'h',
   'a',
   'd',
   'e',
   'r',
   'S',
   'o',
   'u',
   'r',
   'c',
   'e',
   0, // glGetShaderSource
   'g',
   'l',
   'G',
   'e',
   't',
   'S',
   'h',
   'a',
   'd',
   'e',
   'r',
   'S',
   'o',
   'u',
   'r',
   'c',
   'e',
   'A',
   'R',
   'B',
   0, // glGetShaderSourceARB
   'g',
   'l',
   'G',
   'e',
   't',
   'S',
   'h',
   'a',
   'd',
   'e',
   'r',
   'i',
   'v',
   0, // glGetShaderiv
   'g',
   'l',
   'G',
   'e',
   't',
   'S',
   'h',
   'a',
   'd',
   'i',
   'n',
   'g',
   'R',
   'a',
   't',
   'e',
   'I',
   'm',
   'a',
   'g',
   'e',
   'P',
   'a',
   'l',
   'e',
   't',
   't',
   'e',
   'N',
   'V',
   0, // glGetShadingRateImagePaletteNV
   'g',
   'l',
   'G',
   'e',
   't',
   'S',
   'h',
   'a',
   'd',
   'i',
   'n',
   'g',
   'R',
   'a',
   't',
   'e',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'L',
   'o',
   'c',
   'a',
   't',
   'i',
   'o',
   'n',
   'i',
   'v',
   'N',
   'V',
   0, // glGetShadingRateSampleLocationivNV
   'g',
   'l',
   'G',
   'e',
   't',
   'S',
   'h',
   'a',
   'r',
   'p',
   'e',
   'n',
   'T',
   'e',
   'x',
   'F',
   'u',
   'n',
   'c',
   'S',
   'G',
   'I',
   'S',
   0, // glGetSharpenTexFuncSGIS
   'g',
   'l',
   'G',
   'e',
   't',
   'S',
   't',
   'a',
   'g',
   'e',
   'I',
   'n',
   'd',
   'e',
   'x',
   'N',
   'V',
   0, // glGetStageIndexNV
   'g',
   'l',
   'G',
   'e',
   't',
   'S',
   't',
   'r',
   'i',
   'n',
   'g',
   0, // glGetString
   'g',
   'l',
   'G',
   'e',
   't',
   'S',
   't',
   'r',
   'i',
   'n',
   'g',
   'i',
   0, // glGetStringi
   'g',
   'l',
   'G',
   'e',
   't',
   'S',
   'u',
   'b',
   'r',
   'o',
   'u',
   't',
   'i',
   'n',
   'e',
   'I',
   'n',
   'd',
   'e',
   'x',
   0, // glGetSubroutineIndex
   'g',
   'l',
   'G',
   'e',
   't',
   'S',
   'u',
   'b',
   'r',
   'o',
   'u',
   't',
   'i',
   'n',
   'e',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'L',
   'o',
   'c',
   'a',
   't',
   'i',
   'o',
   'n',
   0, // glGetSubroutineUniformLocation
   'g',
   'l',
   'G',
   'e',
   't',
   'S',
   'y',
   'n',
   'c',
   'i',
   'v',
   0, // glGetSynciv
   'g',
   'l',
   'G',
   'e',
   't',
   'S',
   'y',
   'n',
   'c',
   'i',
   'v',
   'A',
   'P',
   'P',
   'L',
   'E',
   0, // glGetSyncivAPPLE
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   'B',
   'u',
   'm',
   'p',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   'A',
   'T',
   'I',
   0, // glGetTexBumpParameterfvATI
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   'B',
   'u',
   'm',
   'p',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'A',
   'T',
   'I',
   0, // glGetTexBumpParameterivATI
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   'E',
   'n',
   'v',
   'f',
   'v',
   0, // glGetTexEnvfv
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   'E',
   'n',
   'v',
   'i',
   'v',
   0, // glGetTexEnviv
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   'E',
   'n',
   'v',
   'x',
   'v',
   0, // glGetTexEnvxv
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   'E',
   'n',
   'v',
   'x',
   'v',
   'O',
   'E',
   'S',
   0, // glGetTexEnvxvOES
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   'F',
   'i',
   'l',
   't',
   'e',
   'r',
   'F',
   'u',
   'n',
   'c',
   'S',
   'G',
   'I',
   'S',
   0, // glGetTexFilterFuncSGIS
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   'G',
   'e',
   'n',
   'd',
   'v',
   0, // glGetTexGendv
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   'G',
   'e',
   'n',
   'f',
   'v',
   0, // glGetTexGenfv
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   'G',
   'e',
   'n',
   'f',
   'v',
   'O',
   'E',
   'S',
   0, // glGetTexGenfvOES
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   'G',
   'e',
   'n',
   'i',
   'v',
   0, // glGetTexGeniv
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   'G',
   'e',
   'n',
   'i',
   'v',
   'O',
   'E',
   'S',
   0, // glGetTexGenivOES
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   'G',
   'e',
   'n',
   'x',
   'v',
   'O',
   'E',
   'S',
   0, // glGetTexGenxvOES
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   'I',
   'm',
   'a',
   'g',
   'e',
   0, // glGetTexImage
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   'L',
   'e',
   'v',
   'e',
   'l',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   0, // glGetTexLevelParameterfv
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   'L',
   'e',
   'v',
   'e',
   'l',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   0, // glGetTexLevelParameteriv
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   'L',
   'e',
   'v',
   'e',
   'l',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'x',
   'v',
   'O',
   'E',
   'S',
   0, // glGetTexLevelParameterxvOES
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   'i',
   'v',
   0, // glGetTexParameterIiv
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glGetTexParameterIivEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   'i',
   'v',
   'O',
   'E',
   'S',
   0, // glGetTexParameterIivOES
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   'u',
   'i',
   'v',
   0, // glGetTexParameterIuiv
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   'u',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glGetTexParameterIuivEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   'u',
   'i',
   'v',
   'O',
   'E',
   'S',
   0, // glGetTexParameterIuivOES
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'v',
   'A',
   'P',
   'P',
   'L',
   'E',
   0, // glGetTexParameterPointervAPPLE
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   0, // glGetTexParameterfv
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   0, // glGetTexParameteriv
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'x',
   'v',
   0, // glGetTexParameterxv
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'x',
   'v',
   'O',
   'E',
   'S',
   0, // glGetTexParameterxvOES
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'H',
   'a',
   'n',
   'd',
   'l',
   'e',
   'A',
   'R',
   'B',
   0, // glGetTextureHandleARB
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'H',
   'a',
   'n',
   'd',
   'l',
   'e',
   'I',
   'M',
   'G',
   0, // glGetTextureHandleIMG
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'H',
   'a',
   'n',
   'd',
   'l',
   'e',
   'N',
   'V',
   0, // glGetTextureHandleNV
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'I',
   'm',
   'a',
   'g',
   'e',
   0, // glGetTextureImage
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'I',
   'm',
   'a',
   'g',
   'e',
   'E',
   'X',
   'T',
   0, // glGetTextureImageEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'L',
   'e',
   'v',
   'e',
   'l',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   0, // glGetTextureLevelParameterfv
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'L',
   'e',
   'v',
   'e',
   'l',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   'E',
   'X',
   'T',
   0, // glGetTextureLevelParameterfvEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'L',
   'e',
   'v',
   'e',
   'l',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   0, // glGetTextureLevelParameteriv
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'L',
   'e',
   'v',
   'e',
   'l',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glGetTextureLevelParameterivEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   'i',
   'v',
   0, // glGetTextureParameterIiv
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glGetTextureParameterIivEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   'u',
   'i',
   'v',
   0, // glGetTextureParameterIuiv
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   'u',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glGetTextureParameterIuivEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   0, // glGetTextureParameterfv
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   'E',
   'X',
   'T',
   0, // glGetTextureParameterfvEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   0, // glGetTextureParameteriv
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glGetTextureParameterivEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'r',
   'H',
   'a',
   'n',
   'd',
   'l',
   'e',
   'A',
   'R',
   'B',
   0, // glGetTextureSamplerHandleARB
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'r',
   'H',
   'a',
   'n',
   'd',
   'l',
   'e',
   'I',
   'M',
   'G',
   0, // glGetTextureSamplerHandleIMG
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'r',
   'H',
   'a',
   'n',
   'd',
   'l',
   'e',
   'N',
   'V',
   0, // glGetTextureSamplerHandleNV
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   0, // glGetTextureSubImage
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'r',
   'a',
   'c',
   'k',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'i',
   'v',
   'N',
   'V',
   0, // glGetTrackMatrixivNV
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'F',
   'e',
   'e',
   'd',
   'b',
   'a',
   'c',
   'k',
   'V',
   'a',
   'r',
   'y',
   'i',
   'n',
   'g',
   0, // glGetTransformFeedbackVarying
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'F',
   'e',
   'e',
   'd',
   'b',
   'a',
   'c',
   'k',
   'V',
   'a',
   'r',
   'y',
   'i',
   'n',
   'g',
   'E',
   'X',
   'T',
   0, // glGetTransformFeedbackVaryingEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'F',
   'e',
   'e',
   'd',
   'b',
   'a',
   'c',
   'k',
   'V',
   'a',
   'r',
   'y',
   'i',
   'n',
   'g',
   'N',
   'V',
   0, // glGetTransformFeedbackVaryingNV
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'F',
   'e',
   'e',
   'd',
   'b',
   'a',
   'c',
   'k',
   'i',
   '6',
   '4',
   '_',
   'v',
   0, // glGetTransformFeedbacki64_v
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'F',
   'e',
   'e',
   'd',
   'b',
   'a',
   'c',
   'k',
   'i',
   '_',
   'v',
   0, // glGetTransformFeedbacki_v
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'F',
   'e',
   'e',
   'd',
   'b',
   'a',
   'c',
   'k',
   'i',
   'v',
   0, // glGetTransformFeedbackiv
   'g',
   'l',
   'G',
   'e',
   't',
   'T',
   'r',
   'a',
   'n',
   's',
   'l',
   'a',
   't',
   'e',
   'd',
   'S',
   'h',
   'a',
   'd',
   'e',
   'r',
   'S',
   'o',
   'u',
   'r',
   'c',
   'e',
   'A',
   'N',
   'G',
   'L',
   'E',
   0, // glGetTranslatedShaderSourceANGLE
   'g',
   'l',
   'G',
   'e',
   't',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'B',
   'l',
   'o',
   'c',
   'k',
   'I',
   'n',
   'd',
   'e',
   'x',
   0, // glGetUniformBlockIndex
   'g',
   'l',
   'G',
   'e',
   't',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   'i',
   'z',
   'e',
   'E',
   'X',
   'T',
   0, // glGetUniformBufferSizeEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'I',
   'n',
   'd',
   'i',
   'c',
   'e',
   's',
   0, // glGetUniformIndices
   'g',
   'l',
   'G',
   'e',
   't',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'L',
   'o',
   'c',
   'a',
   't',
   'i',
   'o',
   'n',
   0, // glGetUniformLocation
   'g',
   'l',
   'G',
   'e',
   't',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'L',
   'o',
   'c',
   'a',
   't',
   'i',
   'o',
   'n',
   'A',
   'R',
   'B',
   0, // glGetUniformLocationARB
   'g',
   'l',
   'G',
   'e',
   't',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'O',
   'f',
   'f',
   's',
   'e',
   't',
   'E',
   'X',
   'T',
   0, // glGetUniformOffsetEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'S',
   'u',
   'b',
   'r',
   'o',
   'u',
   't',
   'i',
   'n',
   'e',
   'u',
   'i',
   'v',
   0, // glGetUniformSubroutineuiv
   'g',
   'l',
   'G',
   'e',
   't',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'd',
   'v',
   0, // glGetUniformdv
   'g',
   'l',
   'G',
   'e',
   't',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'f',
   'v',
   0, // glGetUniformfv
   'g',
   'l',
   'G',
   'e',
   't',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'f',
   'v',
   'A',
   'R',
   'B',
   0, // glGetUniformfvARB
   'g',
   'l',
   'G',
   'e',
   't',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'i',
   '6',
   '4',
   'v',
   'A',
   'R',
   'B',
   0, // glGetUniformi64vARB
   'g',
   'l',
   'G',
   'e',
   't',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'i',
   '6',
   '4',
   'v',
   'N',
   'V',
   0, // glGetUniformi64vNV
   'g',
   'l',
   'G',
   'e',
   't',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'i',
   'v',
   0, // glGetUniformiv
   'g',
   'l',
   'G',
   'e',
   't',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'i',
   'v',
   'A',
   'R',
   'B',
   0, // glGetUniformivARB
   'g',
   'l',
   'G',
   'e',
   't',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'u',
   'i',
   '6',
   '4',
   'v',
   'A',
   'R',
   'B',
   0, // glGetUniformui64vARB
   'g',
   'l',
   'G',
   'e',
   't',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'u',
   'i',
   '6',
   '4',
   'v',
   'N',
   'V',
   0, // glGetUniformui64vNV
   'g',
   'l',
   'G',
   'e',
   't',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'u',
   'i',
   'v',
   0, // glGetUniformuiv
   'g',
   'l',
   'G',
   'e',
   't',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'u',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glGetUniformuivEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'U',
   'n',
   's',
   'i',
   'g',
   'n',
   'e',
   'd',
   'B',
   'y',
   't',
   'e',
   'i',
   '_',
   'v',
   'E',
   'X',
   'T',
   0, // glGetUnsignedBytei_vEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'U',
   'n',
   's',
   'i',
   'g',
   'n',
   'e',
   'd',
   'B',
   'y',
   't',
   'e',
   'v',
   'E',
   'X',
   'T',
   0, // glGetUnsignedBytevEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'V',
   'a',
   'r',
   'i',
   'a',
   'n',
   't',
   'A',
   'r',
   'r',
   'a',
   'y',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'f',
   'v',
   'A',
   'T',
   'I',
   0, // glGetVariantArrayObjectfvATI
   'g',
   'l',
   'G',
   'e',
   't',
   'V',
   'a',
   'r',
   'i',
   'a',
   'n',
   't',
   'A',
   'r',
   'r',
   'a',
   'y',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'i',
   'v',
   'A',
   'T',
   'I',
   0, // glGetVariantArrayObjectivATI
   'g',
   'l',
   'G',
   'e',
   't',
   'V',
   'a',
   'r',
   'i',
   'a',
   'n',
   't',
   'B',
   'o',
   'o',
   'l',
   'e',
   'a',
   'n',
   'v',
   'E',
   'X',
   'T',
   0, // glGetVariantBooleanvEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'V',
   'a',
   'r',
   'i',
   'a',
   'n',
   't',
   'F',
   'l',
   'o',
   'a',
   't',
   'v',
   'E',
   'X',
   'T',
   0, // glGetVariantFloatvEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'V',
   'a',
   'r',
   'i',
   'a',
   'n',
   't',
   'I',
   'n',
   't',
   'e',
   'g',
   'e',
   'r',
   'v',
   'E',
   'X',
   'T',
   0, // glGetVariantIntegervEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'V',
   'a',
   'r',
   'i',
   'a',
   'n',
   't',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'v',
   'E',
   'X',
   'T',
   0, // glGetVariantPointervEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'V',
   'a',
   'r',
   'y',
   'i',
   'n',
   'g',
   'L',
   'o',
   'c',
   'a',
   't',
   'i',
   'o',
   'n',
   'N',
   'V',
   0, // glGetVaryingLocationNV
   'g',
   'l',
   'G',
   'e',
   't',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'I',
   'n',
   'd',
   'e',
   'x',
   'e',
   'd',
   '6',
   '4',
   'i',
   'v',
   0, // glGetVertexArrayIndexed64iv
   'g',
   'l',
   'G',
   'e',
   't',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'I',
   'n',
   'd',
   'e',
   'x',
   'e',
   'd',
   'i',
   'v',
   0, // glGetVertexArrayIndexediv
   'g',
   'l',
   'G',
   'e',
   't',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'I',
   'n',
   't',
   'e',
   'g',
   'e',
   'r',
   'i',
   '_',
   'v',
   'E',
   'X',
   'T',
   0, // glGetVertexArrayIntegeri_vEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'I',
   'n',
   't',
   'e',
   'g',
   'e',
   'r',
   'v',
   'E',
   'X',
   'T',
   0, // glGetVertexArrayIntegervEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'i',
   '_',
   'v',
   'E',
   'X',
   'T',
   0, // glGetVertexArrayPointeri_vEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'v',
   'E',
   'X',
   'T',
   0, // glGetVertexArrayPointervEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'i',
   'v',
   0, // glGetVertexArrayiv
   'g',
   'l',
   'G',
   'e',
   't',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'A',
   'r',
   'r',
   'a',
   'y',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'f',
   'v',
   'A',
   'T',
   'I',
   0, // glGetVertexAttribArrayObjectfvATI
   'g',
   'l',
   'G',
   'e',
   't',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'A',
   'r',
   'r',
   'a',
   'y',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'i',
   'v',
   'A',
   'T',
   'I',
   0, // glGetVertexAttribArrayObjectivATI
   'g',
   'l',
   'G',
   'e',
   't',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   'i',
   'v',
   0, // glGetVertexAttribIiv
   'g',
   'l',
   'G',
   'e',
   't',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glGetVertexAttribIivEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   'u',
   'i',
   'v',
   0, // glGetVertexAttribIuiv
   'g',
   'l',
   'G',
   'e',
   't',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   'u',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glGetVertexAttribIuivEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'L',
   'd',
   'v',
   0, // glGetVertexAttribLdv
   'g',
   'l',
   'G',
   'e',
   't',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'L',
   'd',
   'v',
   'E',
   'X',
   'T',
   0, // glGetVertexAttribLdvEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'L',
   'i',
   '6',
   '4',
   'v',
   'N',
   'V',
   0, // glGetVertexAttribLi64vNV
   'g',
   'l',
   'G',
   'e',
   't',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'L',
   'u',
   'i',
   '6',
   '4',
   'v',
   'A',
   'R',
   'B',
   0, // glGetVertexAttribLui64vARB
   'g',
   'l',
   'G',
   'e',
   't',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'L',
   'u',
   'i',
   '6',
   '4',
   'v',
   'N',
   'V',
   0, // glGetVertexAttribLui64vNV
   'g',
   'l',
   'G',
   'e',
   't',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'v',
   0, // glGetVertexAttribPointerv
   'g',
   'l',
   'G',
   'e',
   't',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'v',
   'A',
   'R',
   'B',
   0, // glGetVertexAttribPointervARB
   'g',
   'l',
   'G',
   'e',
   't',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'v',
   'N',
   'V',
   0, // glGetVertexAttribPointervNV
   'g',
   'l',
   'G',
   'e',
   't',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'd',
   'v',
   0, // glGetVertexAttribdv
   'g',
   'l',
   'G',
   'e',
   't',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'd',
   'v',
   'A',
   'R',
   'B',
   0, // glGetVertexAttribdvARB
   'g',
   'l',
   'G',
   'e',
   't',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'd',
   'v',
   'N',
   'V',
   0, // glGetVertexAttribdvNV
   'g',
   'l',
   'G',
   'e',
   't',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'f',
   'v',
   0, // glGetVertexAttribfv
   'g',
   'l',
   'G',
   'e',
   't',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'f',
   'v',
   'A',
   'R',
   'B',
   0, // glGetVertexAttribfvARB
   'g',
   'l',
   'G',
   'e',
   't',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'f',
   'v',
   'N',
   'V',
   0, // glGetVertexAttribfvNV
   'g',
   'l',
   'G',
   'e',
   't',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'i',
   'v',
   0, // glGetVertexAttribiv
   'g',
   'l',
   'G',
   'e',
   't',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'i',
   'v',
   'A',
   'R',
   'B',
   0, // glGetVertexAttribivARB
   'g',
   'l',
   'G',
   'e',
   't',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'i',
   'v',
   'N',
   'V',
   0, // glGetVertexAttribivNV
   'g',
   'l',
   'G',
   'e',
   't',
   'V',
   'i',
   'd',
   'e',
   'o',
   'C',
   'a',
   'p',
   't',
   'u',
   'r',
   'e',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   'd',
   'v',
   'N',
   'V',
   0, // glGetVideoCaptureStreamdvNV
   'g',
   'l',
   'G',
   'e',
   't',
   'V',
   'i',
   'd',
   'e',
   'o',
   'C',
   'a',
   'p',
   't',
   'u',
   'r',
   'e',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   'f',
   'v',
   'N',
   'V',
   0, // glGetVideoCaptureStreamfvNV
   'g',
   'l',
   'G',
   'e',
   't',
   'V',
   'i',
   'd',
   'e',
   'o',
   'C',
   'a',
   'p',
   't',
   'u',
   'r',
   'e',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   'i',
   'v',
   'N',
   'V',
   0, // glGetVideoCaptureStreamivNV
   'g',
   'l',
   'G',
   'e',
   't',
   'V',
   'i',
   'd',
   'e',
   'o',
   'C',
   'a',
   'p',
   't',
   'u',
   'r',
   'e',
   'i',
   'v',
   'N',
   'V',
   0, // glGetVideoCaptureivNV
   'g',
   'l',
   'G',
   'e',
   't',
   'V',
   'i',
   'd',
   'e',
   'o',
   'i',
   '6',
   '4',
   'v',
   'N',
   'V',
   0, // glGetVideoi64vNV
   'g',
   'l',
   'G',
   'e',
   't',
   'V',
   'i',
   'd',
   'e',
   'o',
   'i',
   'v',
   'N',
   'V',
   0, // glGetVideoivNV
   'g',
   'l',
   'G',
   'e',
   't',
   'V',
   'i',
   'd',
   'e',
   'o',
   'u',
   'i',
   '6',
   '4',
   'v',
   'N',
   'V',
   0, // glGetVideoui64vNV
   'g',
   'l',
   'G',
   'e',
   't',
   'V',
   'i',
   'd',
   'e',
   'o',
   'u',
   'i',
   'v',
   'N',
   'V',
   0, // glGetVideouivNV
   'g',
   'l',
   'G',
   'e',
   't',
   'V',
   'k',
   'P',
   'r',
   'o',
   'c',
   'A',
   'd',
   'd',
   'r',
   'N',
   'V',
   0, // glGetVkProcAddrNV
   'g',
   'l',
   'G',
   'e',
   't',
   'n',
   'C',
   'o',
   'l',
   'o',
   'r',
   'T',
   'a',
   'b',
   'l',
   'e',
   0, // glGetnColorTable
   'g',
   'l',
   'G',
   'e',
   't',
   'n',
   'C',
   'o',
   'l',
   'o',
   'r',
   'T',
   'a',
   'b',
   'l',
   'e',
   'A',
   'R',
   'B',
   0, // glGetnColorTableARB
   'g',
   'l',
   'G',
   'e',
   't',
   'n',
   'C',
   'o',
   'm',
   'p',
   'r',
   'e',
   's',
   's',
   'e',
   'd',
   'T',
   'e',
   'x',
   'I',
   'm',
   'a',
   'g',
   'e',
   0, // glGetnCompressedTexImage
   'g',
   'l',
   'G',
   'e',
   't',
   'n',
   'C',
   'o',
   'm',
   'p',
   'r',
   'e',
   's',
   's',
   'e',
   'd',
   'T',
   'e',
   'x',
   'I',
   'm',
   'a',
   'g',
   'e',
   'A',
   'R',
   'B',
   0, // glGetnCompressedTexImageARB
   'g',
   'l',
   'G',
   'e',
   't',
   'n',
   'C',
   'o',
   'n',
   'v',
   'o',
   'l',
   'u',
   't',
   'i',
   'o',
   'n',
   'F',
   'i',
   'l',
   't',
   'e',
   'r',
   0, // glGetnConvolutionFilter
   'g',
   'l',
   'G',
   'e',
   't',
   'n',
   'C',
   'o',
   'n',
   'v',
   'o',
   'l',
   'u',
   't',
   'i',
   'o',
   'n',
   'F',
   'i',
   'l',
   't',
   'e',
   'r',
   'A',
   'R',
   'B',
   0, // glGetnConvolutionFilterARB
   'g',
   'l',
   'G',
   'e',
   't',
   'n',
   'H',
   'i',
   's',
   't',
   'o',
   'g',
   'r',
   'a',
   'm',
   0, // glGetnHistogram
   'g',
   'l',
   'G',
   'e',
   't',
   'n',
   'H',
   'i',
   's',
   't',
   'o',
   'g',
   'r',
   'a',
   'm',
   'A',
   'R',
   'B',
   0, // glGetnHistogramARB
   'g',
   'l',
   'G',
   'e',
   't',
   'n',
   'M',
   'a',
   'p',
   'd',
   'v',
   0, // glGetnMapdv
   'g',
   'l',
   'G',
   'e',
   't',
   'n',
   'M',
   'a',
   'p',
   'd',
   'v',
   'A',
   'R',
   'B',
   0, // glGetnMapdvARB
   'g',
   'l',
   'G',
   'e',
   't',
   'n',
   'M',
   'a',
   'p',
   'f',
   'v',
   0, // glGetnMapfv
   'g',
   'l',
   'G',
   'e',
   't',
   'n',
   'M',
   'a',
   'p',
   'f',
   'v',
   'A',
   'R',
   'B',
   0, // glGetnMapfvARB
   'g',
   'l',
   'G',
   'e',
   't',
   'n',
   'M',
   'a',
   'p',
   'i',
   'v',
   0, // glGetnMapiv
   'g',
   'l',
   'G',
   'e',
   't',
   'n',
   'M',
   'a',
   'p',
   'i',
   'v',
   'A',
   'R',
   'B',
   0, // glGetnMapivARB
   'g',
   'l',
   'G',
   'e',
   't',
   'n',
   'M',
   'i',
   'n',
   'm',
   'a',
   'x',
   0, // glGetnMinmax
   'g',
   'l',
   'G',
   'e',
   't',
   'n',
   'M',
   'i',
   'n',
   'm',
   'a',
   'x',
   'A',
   'R',
   'B',
   0, // glGetnMinmaxARB
   'g',
   'l',
   'G',
   'e',
   't',
   'n',
   'P',
   'i',
   'x',
   'e',
   'l',
   'M',
   'a',
   'p',
   'f',
   'v',
   0, // glGetnPixelMapfv
   'g',
   'l',
   'G',
   'e',
   't',
   'n',
   'P',
   'i',
   'x',
   'e',
   'l',
   'M',
   'a',
   'p',
   'f',
   'v',
   'A',
   'R',
   'B',
   0, // glGetnPixelMapfvARB
   'g',
   'l',
   'G',
   'e',
   't',
   'n',
   'P',
   'i',
   'x',
   'e',
   'l',
   'M',
   'a',
   'p',
   'u',
   'i',
   'v',
   0, // glGetnPixelMapuiv
   'g',
   'l',
   'G',
   'e',
   't',
   'n',
   'P',
   'i',
   'x',
   'e',
   'l',
   'M',
   'a',
   'p',
   'u',
   'i',
   'v',
   'A',
   'R',
   'B',
   0, // glGetnPixelMapuivARB
   'g',
   'l',
   'G',
   'e',
   't',
   'n',
   'P',
   'i',
   'x',
   'e',
   'l',
   'M',
   'a',
   'p',
   'u',
   's',
   'v',
   0, // glGetnPixelMapusv
   'g',
   'l',
   'G',
   'e',
   't',
   'n',
   'P',
   'i',
   'x',
   'e',
   'l',
   'M',
   'a',
   'p',
   'u',
   's',
   'v',
   'A',
   'R',
   'B',
   0, // glGetnPixelMapusvARB
   'g',
   'l',
   'G',
   'e',
   't',
   'n',
   'P',
   'o',
   'l',
   'y',
   'g',
   'o',
   'n',
   'S',
   't',
   'i',
   'p',
   'p',
   'l',
   'e',
   0, // glGetnPolygonStipple
   'g',
   'l',
   'G',
   'e',
   't',
   'n',
   'P',
   'o',
   'l',
   'y',
   'g',
   'o',
   'n',
   'S',
   't',
   'i',
   'p',
   'p',
   'l',
   'e',
   'A',
   'R',
   'B',
   0, // glGetnPolygonStippleARB
   'g',
   'l',
   'G',
   'e',
   't',
   'n',
   'S',
   'e',
   'p',
   'a',
   'r',
   'a',
   'b',
   'l',
   'e',
   'F',
   'i',
   'l',
   't',
   'e',
   'r',
   0, // glGetnSeparableFilter
   'g',
   'l',
   'G',
   'e',
   't',
   'n',
   'S',
   'e',
   'p',
   'a',
   'r',
   'a',
   'b',
   'l',
   'e',
   'F',
   'i',
   'l',
   't',
   'e',
   'r',
   'A',
   'R',
   'B',
   0, // glGetnSeparableFilterARB
   'g',
   'l',
   'G',
   'e',
   't',
   'n',
   'T',
   'e',
   'x',
   'I',
   'm',
   'a',
   'g',
   'e',
   0, // glGetnTexImage
   'g',
   'l',
   'G',
   'e',
   't',
   'n',
   'T',
   'e',
   'x',
   'I',
   'm',
   'a',
   'g',
   'e',
   'A',
   'R',
   'B',
   0, // glGetnTexImageARB
   'g',
   'l',
   'G',
   'e',
   't',
   'n',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'd',
   'v',
   0, // glGetnUniformdv
   'g',
   'l',
   'G',
   'e',
   't',
   'n',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'd',
   'v',
   'A',
   'R',
   'B',
   0, // glGetnUniformdvARB
   'g',
   'l',
   'G',
   'e',
   't',
   'n',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'f',
   'v',
   0, // glGetnUniformfv
   'g',
   'l',
   'G',
   'e',
   't',
   'n',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'f',
   'v',
   'A',
   'R',
   'B',
   0, // glGetnUniformfvARB
   'g',
   'l',
   'G',
   'e',
   't',
   'n',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'f',
   'v',
   'E',
   'X',
   'T',
   0, // glGetnUniformfvEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'n',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'f',
   'v',
   'K',
   'H',
   'R',
   0, // glGetnUniformfvKHR
   'g',
   'l',
   'G',
   'e',
   't',
   'n',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'i',
   '6',
   '4',
   'v',
   'A',
   'R',
   'B',
   0, // glGetnUniformi64vARB
   'g',
   'l',
   'G',
   'e',
   't',
   'n',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'i',
   'v',
   0, // glGetnUniformiv
   'g',
   'l',
   'G',
   'e',
   't',
   'n',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'i',
   'v',
   'A',
   'R',
   'B',
   0, // glGetnUniformivARB
   'g',
   'l',
   'G',
   'e',
   't',
   'n',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glGetnUniformivEXT
   'g',
   'l',
   'G',
   'e',
   't',
   'n',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'i',
   'v',
   'K',
   'H',
   'R',
   0, // glGetnUniformivKHR
   'g',
   'l',
   'G',
   'e',
   't',
   'n',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'u',
   'i',
   '6',
   '4',
   'v',
   'A',
   'R',
   'B',
   0, // glGetnUniformui64vARB
   'g',
   'l',
   'G',
   'e',
   't',
   'n',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'u',
   'i',
   'v',
   0, // glGetnUniformuiv
   'g',
   'l',
   'G',
   'e',
   't',
   'n',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'u',
   'i',
   'v',
   'A',
   'R',
   'B',
   0, // glGetnUniformuivARB
   'g',
   'l',
   'G',
   'e',
   't',
   'n',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'u',
   'i',
   'v',
   'K',
   'H',
   'R',
   0, // glGetnUniformuivKHR
   'g',
   'l',
   'G',
   'l',
   'o',
   'b',
   'a',
   'l',
   'A',
   'l',
   'p',
   'h',
   'a',
   'F',
   'a',
   'c',
   't',
   'o',
   'r',
   'b',
   'S',
   'U',
   'N',
   0, // glGlobalAlphaFactorbSUN
   'g',
   'l',
   'G',
   'l',
   'o',
   'b',
   'a',
   'l',
   'A',
   'l',
   'p',
   'h',
   'a',
   'F',
   'a',
   'c',
   't',
   'o',
   'r',
   'd',
   'S',
   'U',
   'N',
   0, // glGlobalAlphaFactordSUN
   'g',
   'l',
   'G',
   'l',
   'o',
   'b',
   'a',
   'l',
   'A',
   'l',
   'p',
   'h',
   'a',
   'F',
   'a',
   'c',
   't',
   'o',
   'r',
   'f',
   'S',
   'U',
   'N',
   0, // glGlobalAlphaFactorfSUN
   'g',
   'l',
   'G',
   'l',
   'o',
   'b',
   'a',
   'l',
   'A',
   'l',
   'p',
   'h',
   'a',
   'F',
   'a',
   'c',
   't',
   'o',
   'r',
   'i',
   'S',
   'U',
   'N',
   0, // glGlobalAlphaFactoriSUN
   'g',
   'l',
   'G',
   'l',
   'o',
   'b',
   'a',
   'l',
   'A',
   'l',
   'p',
   'h',
   'a',
   'F',
   'a',
   'c',
   't',
   'o',
   'r',
   's',
   'S',
   'U',
   'N',
   0, // glGlobalAlphaFactorsSUN
   'g',
   'l',
   'G',
   'l',
   'o',
   'b',
   'a',
   'l',
   'A',
   'l',
   'p',
   'h',
   'a',
   'F',
   'a',
   'c',
   't',
   'o',
   'r',
   'u',
   'b',
   'S',
   'U',
   'N',
   0, // glGlobalAlphaFactorubSUN
   'g',
   'l',
   'G',
   'l',
   'o',
   'b',
   'a',
   'l',
   'A',
   'l',
   'p',
   'h',
   'a',
   'F',
   'a',
   'c',
   't',
   'o',
   'r',
   'u',
   'i',
   'S',
   'U',
   'N',
   0, // glGlobalAlphaFactoruiSUN
   'g',
   'l',
   'G',
   'l',
   'o',
   'b',
   'a',
   'l',
   'A',
   'l',
   'p',
   'h',
   'a',
   'F',
   'a',
   'c',
   't',
   'o',
   'r',
   'u',
   's',
   'S',
   'U',
   'N',
   0, // glGlobalAlphaFactorusSUN
   'g',
   'l',
   'H',
   'i',
   'n',
   't',
   0, // glHint
   'g',
   'l',
   'H',
   'i',
   'n',
   't',
   'P',
   'G',
   'I',
   0, // glHintPGI
   'g',
   'l',
   'H',
   'i',
   's',
   't',
   'o',
   'g',
   'r',
   'a',
   'm',
   0, // glHistogram
   'g',
   'l',
   'H',
   'i',
   's',
   't',
   'o',
   'g',
   'r',
   'a',
   'm',
   'E',
   'X',
   'T',
   0, // glHistogramEXT
   'g',
   'l',
   'I',
   'g',
   'l',
   'o',
   'o',
   'I',
   'n',
   't',
   'e',
   'r',
   'f',
   'a',
   'c',
   'e',
   'S',
   'G',
   'I',
   'X',
   0, // glIglooInterfaceSGIX
   'g',
   'l',
   'I',
   'm',
   'a',
   'g',
   'e',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'H',
   'P',
   0, // glImageTransformParameterfHP
   'g',
   'l',
   'I',
   'm',
   'a',
   'g',
   'e',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   'H',
   'P',
   0, // glImageTransformParameterfvHP
   'g',
   'l',
   'I',
   'm',
   'a',
   'g',
   'e',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'H',
   'P',
   0, // glImageTransformParameteriHP
   'g',
   'l',
   'I',
   'm',
   'a',
   'g',
   'e',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'H',
   'P',
   0, // glImageTransformParameterivHP
   'g',
   'l',
   'I',
   'm',
   'p',
   'o',
   'r',
   't',
   'M',
   'e',
   'm',
   'o',
   'r',
   'y',
   'F',
   'd',
   'E',
   'X',
   'T',
   0, // glImportMemoryFdEXT
   'g',
   'l',
   'I',
   'm',
   'p',
   'o',
   'r',
   't',
   'M',
   'e',
   'm',
   'o',
   'r',
   'y',
   'W',
   'i',
   'n',
   '3',
   '2',
   'H',
   'a',
   'n',
   'd',
   'l',
   'e',
   'E',
   'X',
   'T',
   0, // glImportMemoryWin32HandleEXT
   'g',
   'l',
   'I',
   'm',
   'p',
   'o',
   'r',
   't',
   'M',
   'e',
   'm',
   'o',
   'r',
   'y',
   'W',
   'i',
   'n',
   '3',
   '2',
   'N',
   'a',
   'm',
   'e',
   'E',
   'X',
   'T',
   0, // glImportMemoryWin32NameEXT
   'g',
   'l',
   'I',
   'm',
   'p',
   'o',
   'r',
   't',
   'S',
   'e',
   'm',
   'a',
   'p',
   'h',
   'o',
   'r',
   'e',
   'F',
   'd',
   'E',
   'X',
   'T',
   0, // glImportSemaphoreFdEXT
   'g',
   'l',
   'I',
   'm',
   'p',
   'o',
   'r',
   't',
   'S',
   'e',
   'm',
   'a',
   'p',
   'h',
   'o',
   'r',
   'e',
   'W',
   'i',
   'n',
   '3',
   '2',
   'H',
   'a',
   'n',
   'd',
   'l',
   'e',
   'E',
   'X',
   'T',
   0, // glImportSemaphoreWin32HandleEXT
   'g',
   'l',
   'I',
   'm',
   'p',
   'o',
   'r',
   't',
   'S',
   'e',
   'm',
   'a',
   'p',
   'h',
   'o',
   'r',
   'e',
   'W',
   'i',
   'n',
   '3',
   '2',
   'N',
   'a',
   'm',
   'e',
   'E',
   'X',
   'T',
   0, // glImportSemaphoreWin32NameEXT
   'g',
   'l',
   'I',
   'm',
   'p',
   'o',
   'r',
   't',
   'S',
   'y',
   'n',
   'c',
   'E',
   'X',
   'T',
   0, // glImportSyncEXT
   'g',
   'l',
   'I',
   'n',
   'd',
   'e',
   'x',
   'F',
   'o',
   'r',
   'm',
   'a',
   't',
   'N',
   'V',
   0, // glIndexFormatNV
   'g',
   'l',
   'I',
   'n',
   'd',
   'e',
   'x',
   'F',
   'u',
   'n',
   'c',
   'E',
   'X',
   'T',
   0, // glIndexFuncEXT
   'g',
   'l',
   'I',
   'n',
   'd',
   'e',
   'x',
   'M',
   'a',
   's',
   'k',
   0, // glIndexMask
   'g',
   'l',
   'I',
   'n',
   'd',
   'e',
   'x',
   'M',
   'a',
   't',
   'e',
   'r',
   'i',
   'a',
   'l',
   'E',
   'X',
   'T',
   0, // glIndexMaterialEXT
   'g',
   'l',
   'I',
   'n',
   'd',
   'e',
   'x',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   0, // glIndexPointer
   'g',
   'l',
   'I',
   'n',
   'd',
   'e',
   'x',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glIndexPointerEXT
   'g',
   'l',
   'I',
   'n',
   'd',
   'e',
   'x',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'L',
   'i',
   's',
   't',
   'I',
   'B',
   'M',
   0, // glIndexPointerListIBM
   'g',
   'l',
   'I',
   'n',
   'd',
   'e',
   'x',
   'd',
   0, // glIndexd
   'g',
   'l',
   'I',
   'n',
   'd',
   'e',
   'x',
   'd',
   'v',
   0, // glIndexdv
   'g',
   'l',
   'I',
   'n',
   'd',
   'e',
   'x',
   'f',
   0, // glIndexf
   'g',
   'l',
   'I',
   'n',
   'd',
   'e',
   'x',
   'f',
   'v',
   0, // glIndexfv
   'g',
   'l',
   'I',
   'n',
   'd',
   'e',
   'x',
   'i',
   0, // glIndexi
   'g',
   'l',
   'I',
   'n',
   'd',
   'e',
   'x',
   'i',
   'v',
   0, // glIndexiv
   'g',
   'l',
   'I',
   'n',
   'd',
   'e',
   'x',
   's',
   0, // glIndexs
   'g',
   'l',
   'I',
   'n',
   'd',
   'e',
   'x',
   's',
   'v',
   0, // glIndexsv
   'g',
   'l',
   'I',
   'n',
   'd',
   'e',
   'x',
   'u',
   'b',
   0, // glIndexub
   'g',
   'l',
   'I',
   'n',
   'd',
   'e',
   'x',
   'u',
   'b',
   'v',
   0, // glIndexubv
   'g',
   'l',
   'I',
   'n',
   'd',
   'e',
   'x',
   'x',
   'O',
   'E',
   'S',
   0, // glIndexxOES
   'g',
   'l',
   'I',
   'n',
   'd',
   'e',
   'x',
   'x',
   'v',
   'O',
   'E',
   'S',
   0, // glIndexxvOES
   'g',
   'l',
   'I',
   'n',
   'i',
   't',
   'N',
   'a',
   'm',
   'e',
   's',
   0, // glInitNames
   'g',
   'l',
   'I',
   'n',
   's',
   'e',
   'r',
   't',
   'C',
   'o',
   'm',
   'p',
   'o',
   'n',
   'e',
   'n',
   't',
   'E',
   'X',
   'T',
   0, // glInsertComponentEXT
   'g',
   'l',
   'I',
   'n',
   's',
   'e',
   'r',
   't',
   'E',
   'v',
   'e',
   'n',
   't',
   'M',
   'a',
   'r',
   'k',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glInsertEventMarkerEXT
   'g',
   'l',
   'I',
   'n',
   's',
   't',
   'r',
   'u',
   'm',
   'e',
   'n',
   't',
   's',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   'G',
   'I',
   'X',
   0, // glInstrumentsBufferSGIX
   'g',
   'l',
   'I',
   'n',
   't',
   'e',
   'r',
   'l',
   'e',
   'a',
   'v',
   'e',
   'd',
   'A',
   'r',
   'r',
   'a',
   'y',
   's',
   0, // glInterleavedArrays
   'g',
   'l',
   'I',
   'n',
   't',
   'e',
   'r',
   'p',
   'o',
   'l',
   'a',
   't',
   'e',
   'P',
   'a',
   't',
   'h',
   's',
   'N',
   'V',
   0, // glInterpolatePathsNV
   'g',
   'l',
   'I',
   'n',
   'v',
   'a',
   'l',
   'i',
   'd',
   'a',
   't',
   'e',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'D',
   'a',
   't',
   'a',
   0, // glInvalidateBufferData
   'g',
   'l',
   'I',
   'n',
   'v',
   'a',
   'l',
   'i',
   'd',
   'a',
   't',
   'e',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   'u',
   'b',
   'D',
   'a',
   't',
   'a',
   0, // glInvalidateBufferSubData
   'g',
   'l',
   'I',
   'n',
   'v',
   'a',
   'l',
   'i',
   'd',
   'a',
   't',
   'e',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   0, // glInvalidateFramebuffer
   'g',
   'l',
   'I',
   'n',
   'v',
   'a',
   'l',
   'i',
   'd',
   'a',
   't',
   'e',
   'N',
   'a',
   'm',
   'e',
   'd',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'D',
   'a',
   't',
   'a',
   0, // glInvalidateNamedFramebufferData
   'g',
   'l',
   'I',
   'n',
   'v',
   'a',
   'l',
   'i',
   'd',
   'a',
   't',
   'e',
   'N',
   'a',
   'm',
   'e',
   'd',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   'u',
   'b',
   'D',
   'a',
   't',
   'a',
   0, // glInvalidateNamedFramebufferSubData
   'g',
   'l',
   'I',
   'n',
   'v',
   'a',
   'l',
   'i',
   'd',
   'a',
   't',
   'e',
   'S',
   'u',
   'b',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   0, // glInvalidateSubFramebuffer
   'g',
   'l',
   'I',
   'n',
   'v',
   'a',
   'l',
   'i',
   'd',
   'a',
   't',
   'e',
   'T',
   'e',
   'x',
   'I',
   'm',
   'a',
   'g',
   'e',
   0, // glInvalidateTexImage
   'g',
   'l',
   'I',
   'n',
   'v',
   'a',
   'l',
   'i',
   'd',
   'a',
   't',
   'e',
   'T',
   'e',
   'x',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   0, // glInvalidateTexSubImage
   'g',
   'l',
   'I',
   's',
   'A',
   's',
   'y',
   'n',
   'c',
   'M',
   'a',
   'r',
   'k',
   'e',
   'r',
   'S',
   'G',
   'I',
   'X',
   0, // glIsAsyncMarkerSGIX
   'g',
   'l',
   'I',
   's',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   0, // glIsBuffer
   'g',
   'l',
   'I',
   's',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'A',
   'R',
   'B',
   0, // glIsBufferARB
   'g',
   'l',
   'I',
   's',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'R',
   'e',
   's',
   'i',
   'd',
   'e',
   'n',
   't',
   'N',
   'V',
   0, // glIsBufferResidentNV
   'g',
   'l',
   'I',
   's',
   'C',
   'o',
   'm',
   'm',
   'a',
   'n',
   'd',
   'L',
   'i',
   's',
   't',
   'N',
   'V',
   0, // glIsCommandListNV
   'g',
   'l',
   'I',
   's',
   'E',
   'n',
   'a',
   'b',
   'l',
   'e',
   'd',
   0, // glIsEnabled
   'g',
   'l',
   'I',
   's',
   'E',
   'n',
   'a',
   'b',
   'l',
   'e',
   'd',
   'I',
   'n',
   'd',
   'e',
   'x',
   'e',
   'd',
   'E',
   'X',
   'T',
   0, // glIsEnabledIndexedEXT
   'g',
   'l',
   'I',
   's',
   'E',
   'n',
   'a',
   'b',
   'l',
   'e',
   'd',
   'i',
   0, // glIsEnabledi
   'g',
   'l',
   'I',
   's',
   'E',
   'n',
   'a',
   'b',
   'l',
   'e',
   'd',
   'i',
   'E',
   'X',
   'T',
   0, // glIsEnablediEXT
   'g',
   'l',
   'I',
   's',
   'E',
   'n',
   'a',
   'b',
   'l',
   'e',
   'd',
   'i',
   'N',
   'V',
   0, // glIsEnablediNV
   'g',
   'l',
   'I',
   's',
   'E',
   'n',
   'a',
   'b',
   'l',
   'e',
   'd',
   'i',
   'O',
   'E',
   'S',
   0, // glIsEnablediOES
   'g',
   'l',
   'I',
   's',
   'F',
   'e',
   'n',
   'c',
   'e',
   'A',
   'P',
   'P',
   'L',
   'E',
   0, // glIsFenceAPPLE
   'g',
   'l',
   'I',
   's',
   'F',
   'e',
   'n',
   'c',
   'e',
   'N',
   'V',
   0, // glIsFenceNV
   'g',
   'l',
   'I',
   's',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   0, // glIsFramebuffer
   'g',
   'l',
   'I',
   's',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glIsFramebufferEXT
   'g',
   'l',
   'I',
   's',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'O',
   'E',
   'S',
   0, // glIsFramebufferOES
   'g',
   'l',
   'I',
   's',
   'I',
   'm',
   'a',
   'g',
   'e',
   'H',
   'a',
   'n',
   'd',
   'l',
   'e',
   'R',
   'e',
   's',
   'i',
   'd',
   'e',
   'n',
   't',
   'A',
   'R',
   'B',
   0, // glIsImageHandleResidentARB
   'g',
   'l',
   'I',
   's',
   'I',
   'm',
   'a',
   'g',
   'e',
   'H',
   'a',
   'n',
   'd',
   'l',
   'e',
   'R',
   'e',
   's',
   'i',
   'd',
   'e',
   'n',
   't',
   'N',
   'V',
   0, // glIsImageHandleResidentNV
   'g',
   'l',
   'I',
   's',
   'L',
   'i',
   's',
   't',
   0, // glIsList
   'g',
   'l',
   'I',
   's',
   'M',
   'e',
   'm',
   'o',
   'r',
   'y',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'E',
   'X',
   'T',
   0, // glIsMemoryObjectEXT
   'g',
   'l',
   'I',
   's',
   'N',
   'a',
   'm',
   'e',
   'A',
   'M',
   'D',
   0, // glIsNameAMD
   'g',
   'l',
   'I',
   's',
   'N',
   'a',
   'm',
   'e',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'R',
   'e',
   's',
   'i',
   'd',
   'e',
   'n',
   't',
   'N',
   'V',
   0, // glIsNamedBufferResidentNV
   'g',
   'l',
   'I',
   's',
   'N',
   'a',
   'm',
   'e',
   'd',
   'S',
   't',
   'r',
   'i',
   'n',
   'g',
   'A',
   'R',
   'B',
   0, // glIsNamedStringARB
   'g',
   'l',
   'I',
   's',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'A',
   'T',
   'I',
   0, // glIsObjectBufferATI
   'g',
   'l',
   'I',
   's',
   'O',
   'c',
   'c',
   'l',
   'u',
   's',
   'i',
   'o',
   'n',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'N',
   'V',
   0, // glIsOcclusionQueryNV
   'g',
   'l',
   'I',
   's',
   'P',
   'a',
   't',
   'h',
   'N',
   'V',
   0, // glIsPathNV
   'g',
   'l',
   'I',
   's',
   'P',
   'o',
   'i',
   'n',
   't',
   'I',
   'n',
   'F',
   'i',
   'l',
   'l',
   'P',
   'a',
   't',
   'h',
   'N',
   'V',
   0, // glIsPointInFillPathNV
   'g',
   'l',
   'I',
   's',
   'P',
   'o',
   'i',
   'n',
   't',
   'I',
   'n',
   'S',
   't',
   'r',
   'o',
   'k',
   'e',
   'P',
   'a',
   't',
   'h',
   'N',
   'V',
   0, // glIsPointInStrokePathNV
   'g',
   'l',
   'I',
   's',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   0, // glIsProgram
   'g',
   'l',
   'I',
   's',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'A',
   'R',
   'B',
   0, // glIsProgramARB
   'g',
   'l',
   'I',
   's',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'N',
   'V',
   0, // glIsProgramNV
   'g',
   'l',
   'I',
   's',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'P',
   'i',
   'p',
   'e',
   'l',
   'i',
   'n',
   'e',
   0, // glIsProgramPipeline
   'g',
   'l',
   'I',
   's',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'P',
   'i',
   'p',
   'e',
   'l',
   'i',
   'n',
   'e',
   'E',
   'X',
   'T',
   0, // glIsProgramPipelineEXT
   'g',
   'l',
   'I',
   's',
   'Q',
   'u',
   'e',
   'r',
   'y',
   0, // glIsQuery
   'g',
   'l',
   'I',
   's',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'A',
   'R',
   'B',
   0, // glIsQueryARB
   'g',
   'l',
   'I',
   's',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'E',
   'X',
   'T',
   0, // glIsQueryEXT
   'g',
   'l',
   'I',
   's',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   0, // glIsRenderbuffer
   'g',
   'l',
   'I',
   's',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glIsRenderbufferEXT
   'g',
   'l',
   'I',
   's',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'O',
   'E',
   'S',
   0, // glIsRenderbufferOES
   'g',
   'l',
   'I',
   's',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'r',
   0, // glIsSampler
   'g',
   'l',
   'I',
   's',
   'S',
   'e',
   'm',
   'a',
   'p',
   'h',
   'o',
   'r',
   'e',
   'E',
   'X',
   'T',
   0, // glIsSemaphoreEXT
   'g',
   'l',
   'I',
   's',
   'S',
   'h',
   'a',
   'd',
   'e',
   'r',
   0, // glIsShader
   'g',
   'l',
   'I',
   's',
   'S',
   't',
   'a',
   't',
   'e',
   'N',
   'V',
   0, // glIsStateNV
   'g',
   'l',
   'I',
   's',
   'S',
   'y',
   'n',
   'c',
   0, // glIsSync
   'g',
   'l',
   'I',
   's',
   'S',
   'y',
   'n',
   'c',
   'A',
   'P',
   'P',
   'L',
   'E',
   0, // glIsSyncAPPLE
   'g',
   'l',
   'I',
   's',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   0, // glIsTexture
   'g',
   'l',
   'I',
   's',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'E',
   'X',
   'T',
   0, // glIsTextureEXT
   'g',
   'l',
   'I',
   's',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'H',
   'a',
   'n',
   'd',
   'l',
   'e',
   'R',
   'e',
   's',
   'i',
   'd',
   'e',
   'n',
   't',
   'A',
   'R',
   'B',
   0, // glIsTextureHandleResidentARB
   'g',
   'l',
   'I',
   's',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'H',
   'a',
   'n',
   'd',
   'l',
   'e',
   'R',
   'e',
   's',
   'i',
   'd',
   'e',
   'n',
   't',
   'N',
   'V',
   0, // glIsTextureHandleResidentNV
   'g',
   'l',
   'I',
   's',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'F',
   'e',
   'e',
   'd',
   'b',
   'a',
   'c',
   'k',
   0, // glIsTransformFeedback
   'g',
   'l',
   'I',
   's',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'F',
   'e',
   'e',
   'd',
   'b',
   'a',
   'c',
   'k',
   'N',
   'V',
   0, // glIsTransformFeedbackNV
   'g',
   'l',
   'I',
   's',
   'V',
   'a',
   'r',
   'i',
   'a',
   'n',
   't',
   'E',
   'n',
   'a',
   'b',
   'l',
   'e',
   'd',
   'E',
   'X',
   'T',
   0, // glIsVariantEnabledEXT
   'g',
   'l',
   'I',
   's',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   0, // glIsVertexArray
   'g',
   'l',
   'I',
   's',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'A',
   'P',
   'P',
   'L',
   'E',
   0, // glIsVertexArrayAPPLE
   'g',
   'l',
   'I',
   's',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'O',
   'E',
   'S',
   0, // glIsVertexArrayOES
   'g',
   'l',
   'I',
   's',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'E',
   'n',
   'a',
   'b',
   'l',
   'e',
   'd',
   'A',
   'P',
   'P',
   'L',
   'E',
   0, // glIsVertexAttribEnabledAPPLE
   'g',
   'l',
   'L',
   'G',
   'P',
   'U',
   'C',
   'o',
   'p',
   'y',
   'I',
   'm',
   'a',
   'g',
   'e',
   'S',
   'u',
   'b',
   'D',
   'a',
   't',
   'a',
   'N',
   'V',
   'X',
   0, // glLGPUCopyImageSubDataNVX
   'g',
   'l',
   'L',
   'G',
   'P',
   'U',
   'I',
   'n',
   't',
   'e',
   'r',
   'l',
   'o',
   'c',
   'k',
   'N',
   'V',
   'X',
   0, // glLGPUInterlockNVX
   'g',
   'l',
   'L',
   'G',
   'P',
   'U',
   'N',
   'a',
   'm',
   'e',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   'u',
   'b',
   'D',
   'a',
   't',
   'a',
   'N',
   'V',
   'X',
   0, // glLGPUNamedBufferSubDataNVX
   'g',
   'l',
   'L',
   'a',
   'b',
   'e',
   'l',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'E',
   'X',
   'T',
   0, // glLabelObjectEXT
   'g',
   'l',
   'L',
   'i',
   'g',
   'h',
   't',
   'E',
   'n',
   'v',
   'i',
   'S',
   'G',
   'I',
   'X',
   0, // glLightEnviSGIX
   'g',
   'l',
   'L',
   'i',
   'g',
   'h',
   't',
   'M',
   'o',
   'd',
   'e',
   'l',
   'f',
   0, // glLightModelf
   'g',
   'l',
   'L',
   'i',
   'g',
   'h',
   't',
   'M',
   'o',
   'd',
   'e',
   'l',
   'f',
   'v',
   0, // glLightModelfv
   'g',
   'l',
   'L',
   'i',
   'g',
   'h',
   't',
   'M',
   'o',
   'd',
   'e',
   'l',
   'i',
   0, // glLightModeli
   'g',
   'l',
   'L',
   'i',
   'g',
   'h',
   't',
   'M',
   'o',
   'd',
   'e',
   'l',
   'i',
   'v',
   0, // glLightModeliv
   'g',
   'l',
   'L',
   'i',
   'g',
   'h',
   't',
   'M',
   'o',
   'd',
   'e',
   'l',
   'x',
   0, // glLightModelx
   'g',
   'l',
   'L',
   'i',
   'g',
   'h',
   't',
   'M',
   'o',
   'd',
   'e',
   'l',
   'x',
   'O',
   'E',
   'S',
   0, // glLightModelxOES
   'g',
   'l',
   'L',
   'i',
   'g',
   'h',
   't',
   'M',
   'o',
   'd',
   'e',
   'l',
   'x',
   'v',
   0, // glLightModelxv
   'g',
   'l',
   'L',
   'i',
   'g',
   'h',
   't',
   'M',
   'o',
   'd',
   'e',
   'l',
   'x',
   'v',
   'O',
   'E',
   'S',
   0, // glLightModelxvOES
   'g',
   'l',
   'L',
   'i',
   'g',
   'h',
   't',
   'f',
   0, // glLightf
   'g',
   'l',
   'L',
   'i',
   'g',
   'h',
   't',
   'f',
   'v',
   0, // glLightfv
   'g',
   'l',
   'L',
   'i',
   'g',
   'h',
   't',
   'i',
   0, // glLighti
   'g',
   'l',
   'L',
   'i',
   'g',
   'h',
   't',
   'i',
   'v',
   0, // glLightiv
   'g',
   'l',
   'L',
   'i',
   'g',
   'h',
   't',
   'x',
   0, // glLightx
   'g',
   'l',
   'L',
   'i',
   'g',
   'h',
   't',
   'x',
   'O',
   'E',
   'S',
   0, // glLightxOES
   'g',
   'l',
   'L',
   'i',
   'g',
   'h',
   't',
   'x',
   'v',
   0, // glLightxv
   'g',
   'l',
   'L',
   'i',
   'g',
   'h',
   't',
   'x',
   'v',
   'O',
   'E',
   'S',
   0, // glLightxvOES
   'g',
   'l',
   'L',
   'i',
   'n',
   'e',
   'S',
   't',
   'i',
   'p',
   'p',
   'l',
   'e',
   0, // glLineStipple
   'g',
   'l',
   'L',
   'i',
   'n',
   'e',
   'W',
   'i',
   'd',
   't',
   'h',
   0, // glLineWidth
   'g',
   'l',
   'L',
   'i',
   'n',
   'e',
   'W',
   'i',
   'd',
   't',
   'h',
   'x',
   0, // glLineWidthx
   'g',
   'l',
   'L',
   'i',
   'n',
   'e',
   'W',
   'i',
   'd',
   't',
   'h',
   'x',
   'O',
   'E',
   'S',
   0, // glLineWidthxOES
   'g',
   'l',
   'L',
   'i',
   'n',
   'k',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   0, // glLinkProgram
   'g',
   'l',
   'L',
   'i',
   'n',
   'k',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'A',
   'R',
   'B',
   0, // glLinkProgramARB
   'g',
   'l',
   'L',
   'i',
   's',
   't',
   'B',
   'a',
   's',
   'e',
   0, // glListBase
   'g',
   'l',
   'L',
   'i',
   's',
   't',
   'D',
   'r',
   'a',
   'w',
   'C',
   'o',
   'm',
   'm',
   'a',
   'n',
   'd',
   's',
   'S',
   't',
   'a',
   't',
   'e',
   's',
   'C',
   'l',
   'i',
   'e',
   'n',
   't',
   'N',
   'V',
   0, // glListDrawCommandsStatesClientNV
   'g',
   'l',
   'L',
   'i',
   's',
   't',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'S',
   'G',
   'I',
   'X',
   0, // glListParameterfSGIX
   'g',
   'l',
   'L',
   'i',
   's',
   't',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   'S',
   'G',
   'I',
   'X',
   0, // glListParameterfvSGIX
   'g',
   'l',
   'L',
   'i',
   's',
   't',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'S',
   'G',
   'I',
   'X',
   0, // glListParameteriSGIX
   'g',
   'l',
   'L',
   'i',
   's',
   't',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'S',
   'G',
   'I',
   'X',
   0, // glListParameterivSGIX
   'g',
   'l',
   'L',
   'o',
   'a',
   'd',
   'I',
   'd',
   'e',
   'n',
   't',
   'i',
   't',
   'y',
   0, // glLoadIdentity
   'g',
   'l',
   'L',
   'o',
   'a',
   'd',
   'I',
   'd',
   'e',
   'n',
   't',
   'i',
   't',
   'y',
   'D',
   'e',
   'f',
   'o',
   'r',
   'm',
   'a',
   't',
   'i',
   'o',
   'n',
   'M',
   'a',
   'p',
   'S',
   'G',
   'I',
   'X',
   0, // glLoadIdentityDeformationMapSGIX
   'g',
   'l',
   'L',
   'o',
   'a',
   'd',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'd',
   0, // glLoadMatrixd
   'g',
   'l',
   'L',
   'o',
   'a',
   'd',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'f',
   0, // glLoadMatrixf
   'g',
   'l',
   'L',
   'o',
   'a',
   'd',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'x',
   0, // glLoadMatrixx
   'g',
   'l',
   'L',
   'o',
   'a',
   'd',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'x',
   'O',
   'E',
   'S',
   0, // glLoadMatrixxOES
   'g',
   'l',
   'L',
   'o',
   'a',
   'd',
   'N',
   'a',
   'm',
   'e',
   0, // glLoadName
   'g',
   'l',
   'L',
   'o',
   'a',
   'd',
   'P',
   'a',
   'l',
   'e',
   't',
   't',
   'e',
   'F',
   'r',
   'o',
   'm',
   'M',
   'o',
   'd',
   'e',
   'l',
   'V',
   'i',
   'e',
   'w',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'O',
   'E',
   'S',
   0, // glLoadPaletteFromModelViewMatrixOES
   'g',
   'l',
   'L',
   'o',
   'a',
   'd',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'N',
   'V',
   0, // glLoadProgramNV
   'g',
   'l',
   'L',
   'o',
   'a',
   'd',
   'T',
   'r',
   'a',
   'n',
   's',
   'p',
   'o',
   's',
   'e',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'd',
   0, // glLoadTransposeMatrixd
   'g',
   'l',
   'L',
   'o',
   'a',
   'd',
   'T',
   'r',
   'a',
   'n',
   's',
   'p',
   'o',
   's',
   'e',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'd',
   'A',
   'R',
   'B',
   0, // glLoadTransposeMatrixdARB
   'g',
   'l',
   'L',
   'o',
   'a',
   'd',
   'T',
   'r',
   'a',
   'n',
   's',
   'p',
   'o',
   's',
   'e',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'f',
   0, // glLoadTransposeMatrixf
   'g',
   'l',
   'L',
   'o',
   'a',
   'd',
   'T',
   'r',
   'a',
   'n',
   's',
   'p',
   'o',
   's',
   'e',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'f',
   'A',
   'R',
   'B',
   0, // glLoadTransposeMatrixfARB
   'g',
   'l',
   'L',
   'o',
   'a',
   'd',
   'T',
   'r',
   'a',
   'n',
   's',
   'p',
   'o',
   's',
   'e',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'x',
   'O',
   'E',
   'S',
   0, // glLoadTransposeMatrixxOES
   'g',
   'l',
   'L',
   'o',
   'c',
   'k',
   'A',
   'r',
   'r',
   'a',
   'y',
   's',
   'E',
   'X',
   'T',
   0, // glLockArraysEXT
   'g',
   'l',
   'L',
   'o',
   'g',
   'i',
   'c',
   'O',
   'p',
   0, // glLogicOp
   'g',
   'l',
   'M',
   'a',
   'k',
   'e',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'N',
   'o',
   'n',
   'R',
   'e',
   's',
   'i',
   'd',
   'e',
   'n',
   't',
   'N',
   'V',
   0, // glMakeBufferNonResidentNV
   'g',
   'l',
   'M',
   'a',
   'k',
   'e',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'R',
   'e',
   's',
   'i',
   'd',
   'e',
   'n',
   't',
   'N',
   'V',
   0, // glMakeBufferResidentNV
   'g',
   'l',
   'M',
   'a',
   'k',
   'e',
   'I',
   'm',
   'a',
   'g',
   'e',
   'H',
   'a',
   'n',
   'd',
   'l',
   'e',
   'N',
   'o',
   'n',
   'R',
   'e',
   's',
   'i',
   'd',
   'e',
   'n',
   't',
   'A',
   'R',
   'B',
   0, // glMakeImageHandleNonResidentARB
   'g',
   'l',
   'M',
   'a',
   'k',
   'e',
   'I',
   'm',
   'a',
   'g',
   'e',
   'H',
   'a',
   'n',
   'd',
   'l',
   'e',
   'N',
   'o',
   'n',
   'R',
   'e',
   's',
   'i',
   'd',
   'e',
   'n',
   't',
   'N',
   'V',
   0, // glMakeImageHandleNonResidentNV
   'g',
   'l',
   'M',
   'a',
   'k',
   'e',
   'I',
   'm',
   'a',
   'g',
   'e',
   'H',
   'a',
   'n',
   'd',
   'l',
   'e',
   'R',
   'e',
   's',
   'i',
   'd',
   'e',
   'n',
   't',
   'A',
   'R',
   'B',
   0, // glMakeImageHandleResidentARB
   'g',
   'l',
   'M',
   'a',
   'k',
   'e',
   'I',
   'm',
   'a',
   'g',
   'e',
   'H',
   'a',
   'n',
   'd',
   'l',
   'e',
   'R',
   'e',
   's',
   'i',
   'd',
   'e',
   'n',
   't',
   'N',
   'V',
   0, // glMakeImageHandleResidentNV
   'g',
   'l',
   'M',
   'a',
   'k',
   'e',
   'N',
   'a',
   'm',
   'e',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'N',
   'o',
   'n',
   'R',
   'e',
   's',
   'i',
   'd',
   'e',
   'n',
   't',
   'N',
   'V',
   0, // glMakeNamedBufferNonResidentNV
   'g',
   'l',
   'M',
   'a',
   'k',
   'e',
   'N',
   'a',
   'm',
   'e',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'R',
   'e',
   's',
   'i',
   'd',
   'e',
   'n',
   't',
   'N',
   'V',
   0, // glMakeNamedBufferResidentNV
   'g',
   'l',
   'M',
   'a',
   'k',
   'e',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'H',
   'a',
   'n',
   'd',
   'l',
   'e',
   'N',
   'o',
   'n',
   'R',
   'e',
   's',
   'i',
   'd',
   'e',
   'n',
   't',
   'A',
   'R',
   'B',
   0, // glMakeTextureHandleNonResidentARB
   'g',
   'l',
   'M',
   'a',
   'k',
   'e',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'H',
   'a',
   'n',
   'd',
   'l',
   'e',
   'N',
   'o',
   'n',
   'R',
   'e',
   's',
   'i',
   'd',
   'e',
   'n',
   't',
   'N',
   'V',
   0, // glMakeTextureHandleNonResidentNV
   'g',
   'l',
   'M',
   'a',
   'k',
   'e',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'H',
   'a',
   'n',
   'd',
   'l',
   'e',
   'R',
   'e',
   's',
   'i',
   'd',
   'e',
   'n',
   't',
   'A',
   'R',
   'B',
   0, // glMakeTextureHandleResidentARB
   'g',
   'l',
   'M',
   'a',
   'k',
   'e',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'H',
   'a',
   'n',
   'd',
   'l',
   'e',
   'R',
   'e',
   's',
   'i',
   'd',
   'e',
   'n',
   't',
   'N',
   'V',
   0, // glMakeTextureHandleResidentNV
   'g',
   'l',
   'M',
   'a',
   'p',
   '1',
   'd',
   0, // glMap1d
   'g',
   'l',
   'M',
   'a',
   'p',
   '1',
   'f',
   0, // glMap1f
   'g',
   'l',
   'M',
   'a',
   'p',
   '1',
   'x',
   'O',
   'E',
   'S',
   0, // glMap1xOES
   'g',
   'l',
   'M',
   'a',
   'p',
   '2',
   'd',
   0, // glMap2d
   'g',
   'l',
   'M',
   'a',
   'p',
   '2',
   'f',
   0, // glMap2f
   'g',
   'l',
   'M',
   'a',
   'p',
   '2',
   'x',
   'O',
   'E',
   'S',
   0, // glMap2xOES
   'g',
   'l',
   'M',
   'a',
   'p',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   0, // glMapBuffer
   'g',
   'l',
   'M',
   'a',
   'p',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'A',
   'R',
   'B',
   0, // glMapBufferARB
   'g',
   'l',
   'M',
   'a',
   'p',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'O',
   'E',
   'S',
   0, // glMapBufferOES
   'g',
   'l',
   'M',
   'a',
   'p',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'R',
   'a',
   'n',
   'g',
   'e',
   0, // glMapBufferRange
   'g',
   'l',
   'M',
   'a',
   'p',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'R',
   'a',
   'n',
   'g',
   'e',
   'E',
   'X',
   'T',
   0, // glMapBufferRangeEXT
   'g',
   'l',
   'M',
   'a',
   'p',
   'C',
   'o',
   'n',
   't',
   'r',
   'o',
   'l',
   'P',
   'o',
   'i',
   'n',
   't',
   's',
   'N',
   'V',
   0, // glMapControlPointsNV
   'g',
   'l',
   'M',
   'a',
   'p',
   'G',
   'r',
   'i',
   'd',
   '1',
   'd',
   0, // glMapGrid1d
   'g',
   'l',
   'M',
   'a',
   'p',
   'G',
   'r',
   'i',
   'd',
   '1',
   'f',
   0, // glMapGrid1f
   'g',
   'l',
   'M',
   'a',
   'p',
   'G',
   'r',
   'i',
   'd',
   '1',
   'x',
   'O',
   'E',
   'S',
   0, // glMapGrid1xOES
   'g',
   'l',
   'M',
   'a',
   'p',
   'G',
   'r',
   'i',
   'd',
   '2',
   'd',
   0, // glMapGrid2d
   'g',
   'l',
   'M',
   'a',
   'p',
   'G',
   'r',
   'i',
   'd',
   '2',
   'f',
   0, // glMapGrid2f
   'g',
   'l',
   'M',
   'a',
   'p',
   'G',
   'r',
   'i',
   'd',
   '2',
   'x',
   'O',
   'E',
   'S',
   0, // glMapGrid2xOES
   'g',
   'l',
   'M',
   'a',
   'p',
   'N',
   'a',
   'm',
   'e',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   0, // glMapNamedBuffer
   'g',
   'l',
   'M',
   'a',
   'p',
   'N',
   'a',
   'm',
   'e',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glMapNamedBufferEXT
   'g',
   'l',
   'M',
   'a',
   'p',
   'N',
   'a',
   'm',
   'e',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'R',
   'a',
   'n',
   'g',
   'e',
   0, // glMapNamedBufferRange
   'g',
   'l',
   'M',
   'a',
   'p',
   'N',
   'a',
   'm',
   'e',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'R',
   'a',
   'n',
   'g',
   'e',
   'E',
   'X',
   'T',
   0, // glMapNamedBufferRangeEXT
   'g',
   'l',
   'M',
   'a',
   'p',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'A',
   'T',
   'I',
   0, // glMapObjectBufferATI
   'g',
   'l',
   'M',
   'a',
   'p',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   'N',
   'V',
   0, // glMapParameterfvNV
   'g',
   'l',
   'M',
   'a',
   'p',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'N',
   'V',
   0, // glMapParameterivNV
   'g',
   'l',
   'M',
   'a',
   'p',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   '2',
   'D',
   'I',
   'N',
   'T',
   'E',
   'L',
   0, // glMapTexture2DINTEL
   'g',
   'l',
   'M',
   'a',
   'p',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '1',
   'd',
   'A',
   'P',
   'P',
   'L',
   'E',
   0, // glMapVertexAttrib1dAPPLE
   'g',
   'l',
   'M',
   'a',
   'p',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '1',
   'f',
   'A',
   'P',
   'P',
   'L',
   'E',
   0, // glMapVertexAttrib1fAPPLE
   'g',
   'l',
   'M',
   'a',
   'p',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '2',
   'd',
   'A',
   'P',
   'P',
   'L',
   'E',
   0, // glMapVertexAttrib2dAPPLE
   'g',
   'l',
   'M',
   'a',
   'p',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '2',
   'f',
   'A',
   'P',
   'P',
   'L',
   'E',
   0, // glMapVertexAttrib2fAPPLE
   'g',
   'l',
   'M',
   'a',
   't',
   'e',
   'r',
   'i',
   'a',
   'l',
   'f',
   0, // glMaterialf
   'g',
   'l',
   'M',
   'a',
   't',
   'e',
   'r',
   'i',
   'a',
   'l',
   'f',
   'v',
   0, // glMaterialfv
   'g',
   'l',
   'M',
   'a',
   't',
   'e',
   'r',
   'i',
   'a',
   'l',
   'i',
   0, // glMateriali
   'g',
   'l',
   'M',
   'a',
   't',
   'e',
   'r',
   'i',
   'a',
   'l',
   'i',
   'v',
   0, // glMaterialiv
   'g',
   'l',
   'M',
   'a',
   't',
   'e',
   'r',
   'i',
   'a',
   'l',
   'x',
   0, // glMaterialx
   'g',
   'l',
   'M',
   'a',
   't',
   'e',
   'r',
   'i',
   'a',
   'l',
   'x',
   'O',
   'E',
   'S',
   0, // glMaterialxOES
   'g',
   'l',
   'M',
   'a',
   't',
   'e',
   'r',
   'i',
   'a',
   'l',
   'x',
   'v',
   0, // glMaterialxv
   'g',
   'l',
   'M',
   'a',
   't',
   'e',
   'r',
   'i',
   'a',
   'l',
   'x',
   'v',
   'O',
   'E',
   'S',
   0, // glMaterialxvOES
   'g',
   'l',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'F',
   'r',
   'u',
   's',
   't',
   'u',
   'm',
   'E',
   'X',
   'T',
   0, // glMatrixFrustumEXT
   'g',
   'l',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'I',
   'n',
   'd',
   'e',
   'x',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'A',
   'R',
   'B',
   0, // glMatrixIndexPointerARB
   'g',
   'l',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'I',
   'n',
   'd',
   'e',
   'x',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'O',
   'E',
   'S',
   0, // glMatrixIndexPointerOES
   'g',
   'l',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'I',
   'n',
   'd',
   'e',
   'x',
   'u',
   'b',
   'v',
   'A',
   'R',
   'B',
   0, // glMatrixIndexubvARB
   'g',
   'l',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'I',
   'n',
   'd',
   'e',
   'x',
   'u',
   'i',
   'v',
   'A',
   'R',
   'B',
   0, // glMatrixIndexuivARB
   'g',
   'l',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'I',
   'n',
   'd',
   'e',
   'x',
   'u',
   's',
   'v',
   'A',
   'R',
   'B',
   0, // glMatrixIndexusvARB
   'g',
   'l',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'L',
   'o',
   'a',
   'd',
   '3',
   'x',
   '2',
   'f',
   'N',
   'V',
   0, // glMatrixLoad3x2fNV
   'g',
   'l',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'L',
   'o',
   'a',
   'd',
   '3',
   'x',
   '3',
   'f',
   'N',
   'V',
   0, // glMatrixLoad3x3fNV
   'g',
   'l',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'L',
   'o',
   'a',
   'd',
   'I',
   'd',
   'e',
   'n',
   't',
   'i',
   't',
   'y',
   'E',
   'X',
   'T',
   0, // glMatrixLoadIdentityEXT
   'g',
   'l',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'L',
   'o',
   'a',
   'd',
   'T',
   'r',
   'a',
   'n',
   's',
   'p',
   'o',
   's',
   'e',
   '3',
   'x',
   '3',
   'f',
   'N',
   'V',
   0, // glMatrixLoadTranspose3x3fNV
   'g',
   'l',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'L',
   'o',
   'a',
   'd',
   'T',
   'r',
   'a',
   'n',
   's',
   'p',
   'o',
   's',
   'e',
   'd',
   'E',
   'X',
   'T',
   0, // glMatrixLoadTransposedEXT
   'g',
   'l',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'L',
   'o',
   'a',
   'd',
   'T',
   'r',
   'a',
   'n',
   's',
   'p',
   'o',
   's',
   'e',
   'f',
   'E',
   'X',
   'T',
   0, // glMatrixLoadTransposefEXT
   'g',
   'l',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'L',
   'o',
   'a',
   'd',
   'd',
   'E',
   'X',
   'T',
   0, // glMatrixLoaddEXT
   'g',
   'l',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'L',
   'o',
   'a',
   'd',
   'f',
   'E',
   'X',
   'T',
   0, // glMatrixLoadfEXT
   'g',
   'l',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'M',
   'o',
   'd',
   'e',
   0, // glMatrixMode
   'g',
   'l',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'M',
   'u',
   'l',
   't',
   '3',
   'x',
   '2',
   'f',
   'N',
   'V',
   0, // glMatrixMult3x2fNV
   'g',
   'l',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'M',
   'u',
   'l',
   't',
   '3',
   'x',
   '3',
   'f',
   'N',
   'V',
   0, // glMatrixMult3x3fNV
   'g',
   'l',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'M',
   'u',
   'l',
   't',
   'T',
   'r',
   'a',
   'n',
   's',
   'p',
   'o',
   's',
   'e',
   '3',
   'x',
   '3',
   'f',
   'N',
   'V',
   0, // glMatrixMultTranspose3x3fNV
   'g',
   'l',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'M',
   'u',
   'l',
   't',
   'T',
   'r',
   'a',
   'n',
   's',
   'p',
   'o',
   's',
   'e',
   'd',
   'E',
   'X',
   'T',
   0, // glMatrixMultTransposedEXT
   'g',
   'l',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'M',
   'u',
   'l',
   't',
   'T',
   'r',
   'a',
   'n',
   's',
   'p',
   'o',
   's',
   'e',
   'f',
   'E',
   'X',
   'T',
   0, // glMatrixMultTransposefEXT
   'g',
   'l',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'M',
   'u',
   'l',
   't',
   'd',
   'E',
   'X',
   'T',
   0, // glMatrixMultdEXT
   'g',
   'l',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'M',
   'u',
   'l',
   't',
   'f',
   'E',
   'X',
   'T',
   0, // glMatrixMultfEXT
   'g',
   'l',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'O',
   'r',
   't',
   'h',
   'o',
   'E',
   'X',
   'T',
   0, // glMatrixOrthoEXT
   'g',
   'l',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'P',
   'o',
   'p',
   'E',
   'X',
   'T',
   0, // glMatrixPopEXT
   'g',
   'l',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'P',
   'u',
   's',
   'h',
   'E',
   'X',
   'T',
   0, // glMatrixPushEXT
   'g',
   'l',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'R',
   'o',
   't',
   'a',
   't',
   'e',
   'd',
   'E',
   'X',
   'T',
   0, // glMatrixRotatedEXT
   'g',
   'l',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'R',
   'o',
   't',
   'a',
   't',
   'e',
   'f',
   'E',
   'X',
   'T',
   0, // glMatrixRotatefEXT
   'g',
   'l',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'S',
   'c',
   'a',
   'l',
   'e',
   'd',
   'E',
   'X',
   'T',
   0, // glMatrixScaledEXT
   'g',
   'l',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'S',
   'c',
   'a',
   'l',
   'e',
   'f',
   'E',
   'X',
   'T',
   0, // glMatrixScalefEXT
   'g',
   'l',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'T',
   'r',
   'a',
   'n',
   's',
   'l',
   'a',
   't',
   'e',
   'd',
   'E',
   'X',
   'T',
   0, // glMatrixTranslatedEXT
   'g',
   'l',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'T',
   'r',
   'a',
   'n',
   's',
   'l',
   'a',
   't',
   'e',
   'f',
   'E',
   'X',
   'T',
   0, // glMatrixTranslatefEXT
   'g',
   'l',
   'M',
   'a',
   'x',
   'S',
   'h',
   'a',
   'd',
   'e',
   'r',
   'C',
   'o',
   'm',
   'p',
   'i',
   'l',
   'e',
   'r',
   'T',
   'h',
   'r',
   'e',
   'a',
   'd',
   's',
   'A',
   'R',
   'B',
   0, // glMaxShaderCompilerThreadsARB
   'g',
   'l',
   'M',
   'a',
   'x',
   'S',
   'h',
   'a',
   'd',
   'e',
   'r',
   'C',
   'o',
   'm',
   'p',
   'i',
   'l',
   'e',
   'r',
   'T',
   'h',
   'r',
   'e',
   'a',
   'd',
   's',
   'K',
   'H',
   'R',
   0, // glMaxShaderCompilerThreadsKHR
   'g',
   'l',
   'M',
   'e',
   'm',
   'o',
   'r',
   'y',
   'B',
   'a',
   'r',
   'r',
   'i',
   'e',
   'r',
   0, // glMemoryBarrier
   'g',
   'l',
   'M',
   'e',
   'm',
   'o',
   'r',
   'y',
   'B',
   'a',
   'r',
   'r',
   'i',
   'e',
   'r',
   'B',
   'y',
   'R',
   'e',
   'g',
   'i',
   'o',
   'n',
   0, // glMemoryBarrierByRegion
   'g',
   'l',
   'M',
   'e',
   'm',
   'o',
   'r',
   'y',
   'B',
   'a',
   'r',
   'r',
   'i',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glMemoryBarrierEXT
   'g',
   'l',
   'M',
   'e',
   'm',
   'o',
   'r',
   'y',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glMemoryObjectParameterivEXT
   'g',
   'l',
   'M',
   'i',
   'n',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'S',
   'h',
   'a',
   'd',
   'i',
   'n',
   'g',
   0, // glMinSampleShading
   'g',
   'l',
   'M',
   'i',
   'n',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'S',
   'h',
   'a',
   'd',
   'i',
   'n',
   'g',
   'A',
   'R',
   'B',
   0, // glMinSampleShadingARB
   'g',
   'l',
   'M',
   'i',
   'n',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'S',
   'h',
   'a',
   'd',
   'i',
   'n',
   'g',
   'O',
   'E',
   'S',
   0, // glMinSampleShadingOES
   'g',
   'l',
   'M',
   'i',
   'n',
   'm',
   'a',
   'x',
   0, // glMinmax
   'g',
   'l',
   'M',
   'i',
   'n',
   'm',
   'a',
   'x',
   'E',
   'X',
   'T',
   0, // glMinmaxEXT
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'd',
   0, // glMultMatrixd
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'f',
   0, // glMultMatrixf
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'x',
   0, // glMultMatrixx
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'x',
   'O',
   'E',
   'S',
   0, // glMultMatrixxOES
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'T',
   'r',
   'a',
   'n',
   's',
   'p',
   'o',
   's',
   'e',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'd',
   0, // glMultTransposeMatrixd
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'T',
   'r',
   'a',
   'n',
   's',
   'p',
   'o',
   's',
   'e',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'd',
   'A',
   'R',
   'B',
   0, // glMultTransposeMatrixdARB
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'T',
   'r',
   'a',
   'n',
   's',
   'p',
   'o',
   's',
   'e',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'f',
   0, // glMultTransposeMatrixf
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'T',
   'r',
   'a',
   'n',
   's',
   'p',
   'o',
   's',
   'e',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'f',
   'A',
   'R',
   'B',
   0, // glMultTransposeMatrixfARB
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'T',
   'r',
   'a',
   'n',
   's',
   'p',
   'o',
   's',
   'e',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'x',
   'O',
   'E',
   'S',
   0, // glMultTransposeMatrixxOES
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'D',
   'r',
   'a',
   'w',
   'A',
   'r',
   'r',
   'a',
   'y',
   's',
   0, // glMultiDrawArrays
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'D',
   'r',
   'a',
   'w',
   'A',
   'r',
   'r',
   'a',
   'y',
   's',
   'E',
   'X',
   'T',
   0, // glMultiDrawArraysEXT
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'D',
   'r',
   'a',
   'w',
   'A',
   'r',
   'r',
   'a',
   'y',
   's',
   'I',
   'n',
   'd',
   'i',
   'r',
   'e',
   'c',
   't',
   0, // glMultiDrawArraysIndirect
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'D',
   'r',
   'a',
   'w',
   'A',
   'r',
   'r',
   'a',
   'y',
   's',
   'I',
   'n',
   'd',
   'i',
   'r',
   'e',
   'c',
   't',
   'A',
   'M',
   'D',
   0, // glMultiDrawArraysIndirectAMD
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'D',
   'r',
   'a',
   'w',
   'A',
   'r',
   'r',
   'a',
   'y',
   's',
   'I',
   'n',
   'd',
   'i',
   'r',
   'e',
   'c',
   't',
   'B',
   'i',
   'n',
   'd',
   'l',
   'e',
   's',
   's',
   'C',
   'o',
   'u',
   'n',
   't',
   'N',
   'V',
   0, // glMultiDrawArraysIndirectBindlessCountNV
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'D',
   'r',
   'a',
   'w',
   'A',
   'r',
   'r',
   'a',
   'y',
   's',
   'I',
   'n',
   'd',
   'i',
   'r',
   'e',
   'c',
   't',
   'B',
   'i',
   'n',
   'd',
   'l',
   'e',
   's',
   's',
   'N',
   'V',
   0, // glMultiDrawArraysIndirectBindlessNV
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'D',
   'r',
   'a',
   'w',
   'A',
   'r',
   'r',
   'a',
   'y',
   's',
   'I',
   'n',
   'd',
   'i',
   'r',
   'e',
   'c',
   't',
   'C',
   'o',
   'u',
   'n',
   't',
   0, // glMultiDrawArraysIndirectCount
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'D',
   'r',
   'a',
   'w',
   'A',
   'r',
   'r',
   'a',
   'y',
   's',
   'I',
   'n',
   'd',
   'i',
   'r',
   'e',
   'c',
   't',
   'C',
   'o',
   'u',
   'n',
   't',
   'A',
   'R',
   'B',
   0, // glMultiDrawArraysIndirectCountARB
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'D',
   'r',
   'a',
   'w',
   'A',
   'r',
   'r',
   'a',
   'y',
   's',
   'I',
   'n',
   'd',
   'i',
   'r',
   'e',
   'c',
   't',
   'E',
   'X',
   'T',
   0, // glMultiDrawArraysIndirectEXT
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'D',
   'r',
   'a',
   'w',
   'E',
   'l',
   'e',
   'm',
   'e',
   'n',
   't',
   'A',
   'r',
   'r',
   'a',
   'y',
   'A',
   'P',
   'P',
   'L',
   'E',
   0, // glMultiDrawElementArrayAPPLE
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'D',
   'r',
   'a',
   'w',
   'E',
   'l',
   'e',
   'm',
   'e',
   'n',
   't',
   's',
   0, // glMultiDrawElements
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'D',
   'r',
   'a',
   'w',
   'E',
   'l',
   'e',
   'm',
   'e',
   'n',
   't',
   's',
   'B',
   'a',
   's',
   'e',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   0, // glMultiDrawElementsBaseVertex
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'D',
   'r',
   'a',
   'w',
   'E',
   'l',
   'e',
   'm',
   'e',
   'n',
   't',
   's',
   'B',
   'a',
   's',
   'e',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'E',
   'X',
   'T',
   0, // glMultiDrawElementsBaseVertexEXT
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'D',
   'r',
   'a',
   'w',
   'E',
   'l',
   'e',
   'm',
   'e',
   'n',
   't',
   's',
   'E',
   'X',
   'T',
   0, // glMultiDrawElementsEXT
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'D',
   'r',
   'a',
   'w',
   'E',
   'l',
   'e',
   'm',
   'e',
   'n',
   't',
   's',
   'I',
   'n',
   'd',
   'i',
   'r',
   'e',
   'c',
   't',
   0, // glMultiDrawElementsIndirect
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'D',
   'r',
   'a',
   'w',
   'E',
   'l',
   'e',
   'm',
   'e',
   'n',
   't',
   's',
   'I',
   'n',
   'd',
   'i',
   'r',
   'e',
   'c',
   't',
   'A',
   'M',
   'D',
   0, // glMultiDrawElementsIndirectAMD
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'D',
   'r',
   'a',
   'w',
   'E',
   'l',
   'e',
   'm',
   'e',
   'n',
   't',
   's',
   'I',
   'n',
   'd',
   'i',
   'r',
   'e',
   'c',
   't',
   'B',
   'i',
   'n',
   'd',
   'l',
   'e',
   's',
   's',
   'C',
   'o',
   'u',
   'n',
   't',
   'N',
   'V',
   0, // glMultiDrawElementsIndirectBindlessCountNV
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'D',
   'r',
   'a',
   'w',
   'E',
   'l',
   'e',
   'm',
   'e',
   'n',
   't',
   's',
   'I',
   'n',
   'd',
   'i',
   'r',
   'e',
   'c',
   't',
   'B',
   'i',
   'n',
   'd',
   'l',
   'e',
   's',
   's',
   'N',
   'V',
   0, // glMultiDrawElementsIndirectBindlessNV
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'D',
   'r',
   'a',
   'w',
   'E',
   'l',
   'e',
   'm',
   'e',
   'n',
   't',
   's',
   'I',
   'n',
   'd',
   'i',
   'r',
   'e',
   'c',
   't',
   'C',
   'o',
   'u',
   'n',
   't',
   0, // glMultiDrawElementsIndirectCount
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'D',
   'r',
   'a',
   'w',
   'E',
   'l',
   'e',
   'm',
   'e',
   'n',
   't',
   's',
   'I',
   'n',
   'd',
   'i',
   'r',
   'e',
   'c',
   't',
   'C',
   'o',
   'u',
   'n',
   't',
   'A',
   'R',
   'B',
   0, // glMultiDrawElementsIndirectCountARB
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'D',
   'r',
   'a',
   'w',
   'E',
   'l',
   'e',
   'm',
   'e',
   'n',
   't',
   's',
   'I',
   'n',
   'd',
   'i',
   'r',
   'e',
   'c',
   't',
   'E',
   'X',
   'T',
   0, // glMultiDrawElementsIndirectEXT
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'D',
   'r',
   'a',
   'w',
   'M',
   'e',
   's',
   'h',
   'T',
   'a',
   's',
   'k',
   's',
   'I',
   'n',
   'd',
   'i',
   'r',
   'e',
   'c',
   't',
   'C',
   'o',
   'u',
   'n',
   't',
   'N',
   'V',
   0, // glMultiDrawMeshTasksIndirectCountNV
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'D',
   'r',
   'a',
   'w',
   'M',
   'e',
   's',
   'h',
   'T',
   'a',
   's',
   'k',
   's',
   'I',
   'n',
   'd',
   'i',
   'r',
   'e',
   'c',
   't',
   'N',
   'V',
   0, // glMultiDrawMeshTasksIndirectNV
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'D',
   'r',
   'a',
   'w',
   'R',
   'a',
   'n',
   'g',
   'e',
   'E',
   'l',
   'e',
   'm',
   'e',
   'n',
   't',
   'A',
   'r',
   'r',
   'a',
   'y',
   'A',
   'P',
   'P',
   'L',
   'E',
   0, // glMultiDrawRangeElementArrayAPPLE
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'M',
   'o',
   'd',
   'e',
   'D',
   'r',
   'a',
   'w',
   'A',
   'r',
   'r',
   'a',
   'y',
   's',
   'I',
   'B',
   'M',
   0, // glMultiModeDrawArraysIBM
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'M',
   'o',
   'd',
   'e',
   'D',
   'r',
   'a',
   'w',
   'E',
   'l',
   'e',
   'm',
   'e',
   'n',
   't',
   's',
   'I',
   'B',
   'M',
   0, // glMultiModeDrawElementsIBM
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glMultiTexBufferEXT
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '1',
   'b',
   'O',
   'E',
   'S',
   0, // glMultiTexCoord1bOES
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '1',
   'b',
   'v',
   'O',
   'E',
   'S',
   0, // glMultiTexCoord1bvOES
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '1',
   'd',
   0, // glMultiTexCoord1d
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '1',
   'd',
   'A',
   'R',
   'B',
   0, // glMultiTexCoord1dARB
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '1',
   'd',
   'v',
   0, // glMultiTexCoord1dv
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '1',
   'd',
   'v',
   'A',
   'R',
   'B',
   0, // glMultiTexCoord1dvARB
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '1',
   'f',
   0, // glMultiTexCoord1f
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '1',
   'f',
   'A',
   'R',
   'B',
   0, // glMultiTexCoord1fARB
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '1',
   'f',
   'v',
   0, // glMultiTexCoord1fv
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '1',
   'f',
   'v',
   'A',
   'R',
   'B',
   0, // glMultiTexCoord1fvARB
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '1',
   'h',
   'N',
   'V',
   0, // glMultiTexCoord1hNV
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '1',
   'h',
   'v',
   'N',
   'V',
   0, // glMultiTexCoord1hvNV
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '1',
   'i',
   0, // glMultiTexCoord1i
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '1',
   'i',
   'A',
   'R',
   'B',
   0, // glMultiTexCoord1iARB
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '1',
   'i',
   'v',
   0, // glMultiTexCoord1iv
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '1',
   'i',
   'v',
   'A',
   'R',
   'B',
   0, // glMultiTexCoord1ivARB
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '1',
   's',
   0, // glMultiTexCoord1s
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '1',
   's',
   'A',
   'R',
   'B',
   0, // glMultiTexCoord1sARB
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '1',
   's',
   'v',
   0, // glMultiTexCoord1sv
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '1',
   's',
   'v',
   'A',
   'R',
   'B',
   0, // glMultiTexCoord1svARB
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '1',
   'x',
   'O',
   'E',
   'S',
   0, // glMultiTexCoord1xOES
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '1',
   'x',
   'v',
   'O',
   'E',
   'S',
   0, // glMultiTexCoord1xvOES
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'b',
   'O',
   'E',
   'S',
   0, // glMultiTexCoord2bOES
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'b',
   'v',
   'O',
   'E',
   'S',
   0, // glMultiTexCoord2bvOES
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'd',
   0, // glMultiTexCoord2d
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'd',
   'A',
   'R',
   'B',
   0, // glMultiTexCoord2dARB
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'd',
   'v',
   0, // glMultiTexCoord2dv
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'd',
   'v',
   'A',
   'R',
   'B',
   0, // glMultiTexCoord2dvARB
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'f',
   0, // glMultiTexCoord2f
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'f',
   'A',
   'R',
   'B',
   0, // glMultiTexCoord2fARB
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'f',
   'v',
   0, // glMultiTexCoord2fv
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'f',
   'v',
   'A',
   'R',
   'B',
   0, // glMultiTexCoord2fvARB
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'h',
   'N',
   'V',
   0, // glMultiTexCoord2hNV
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'h',
   'v',
   'N',
   'V',
   0, // glMultiTexCoord2hvNV
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'i',
   0, // glMultiTexCoord2i
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'i',
   'A',
   'R',
   'B',
   0, // glMultiTexCoord2iARB
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'i',
   'v',
   0, // glMultiTexCoord2iv
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'i',
   'v',
   'A',
   'R',
   'B',
   0, // glMultiTexCoord2ivARB
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   's',
   0, // glMultiTexCoord2s
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   's',
   'A',
   'R',
   'B',
   0, // glMultiTexCoord2sARB
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   's',
   'v',
   0, // glMultiTexCoord2sv
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   's',
   'v',
   'A',
   'R',
   'B',
   0, // glMultiTexCoord2svARB
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'x',
   'O',
   'E',
   'S',
   0, // glMultiTexCoord2xOES
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'x',
   'v',
   'O',
   'E',
   'S',
   0, // glMultiTexCoord2xvOES
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '3',
   'b',
   'O',
   'E',
   'S',
   0, // glMultiTexCoord3bOES
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '3',
   'b',
   'v',
   'O',
   'E',
   'S',
   0, // glMultiTexCoord3bvOES
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '3',
   'd',
   0, // glMultiTexCoord3d
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '3',
   'd',
   'A',
   'R',
   'B',
   0, // glMultiTexCoord3dARB
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '3',
   'd',
   'v',
   0, // glMultiTexCoord3dv
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '3',
   'd',
   'v',
   'A',
   'R',
   'B',
   0, // glMultiTexCoord3dvARB
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '3',
   'f',
   0, // glMultiTexCoord3f
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '3',
   'f',
   'A',
   'R',
   'B',
   0, // glMultiTexCoord3fARB
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '3',
   'f',
   'v',
   0, // glMultiTexCoord3fv
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '3',
   'f',
   'v',
   'A',
   'R',
   'B',
   0, // glMultiTexCoord3fvARB
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '3',
   'h',
   'N',
   'V',
   0, // glMultiTexCoord3hNV
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '3',
   'h',
   'v',
   'N',
   'V',
   0, // glMultiTexCoord3hvNV
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '3',
   'i',
   0, // glMultiTexCoord3i
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '3',
   'i',
   'A',
   'R',
   'B',
   0, // glMultiTexCoord3iARB
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '3',
   'i',
   'v',
   0, // glMultiTexCoord3iv
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '3',
   'i',
   'v',
   'A',
   'R',
   'B',
   0, // glMultiTexCoord3ivARB
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '3',
   's',
   0, // glMultiTexCoord3s
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '3',
   's',
   'A',
   'R',
   'B',
   0, // glMultiTexCoord3sARB
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '3',
   's',
   'v',
   0, // glMultiTexCoord3sv
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '3',
   's',
   'v',
   'A',
   'R',
   'B',
   0, // glMultiTexCoord3svARB
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '3',
   'x',
   'O',
   'E',
   'S',
   0, // glMultiTexCoord3xOES
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '3',
   'x',
   'v',
   'O',
   'E',
   'S',
   0, // glMultiTexCoord3xvOES
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '4',
   'b',
   'O',
   'E',
   'S',
   0, // glMultiTexCoord4bOES
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '4',
   'b',
   'v',
   'O',
   'E',
   'S',
   0, // glMultiTexCoord4bvOES
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '4',
   'd',
   0, // glMultiTexCoord4d
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '4',
   'd',
   'A',
   'R',
   'B',
   0, // glMultiTexCoord4dARB
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '4',
   'd',
   'v',
   0, // glMultiTexCoord4dv
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '4',
   'd',
   'v',
   'A',
   'R',
   'B',
   0, // glMultiTexCoord4dvARB
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '4',
   'f',
   0, // glMultiTexCoord4f
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '4',
   'f',
   'A',
   'R',
   'B',
   0, // glMultiTexCoord4fARB
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '4',
   'f',
   'v',
   0, // glMultiTexCoord4fv
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '4',
   'f',
   'v',
   'A',
   'R',
   'B',
   0, // glMultiTexCoord4fvARB
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '4',
   'h',
   'N',
   'V',
   0, // glMultiTexCoord4hNV
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '4',
   'h',
   'v',
   'N',
   'V',
   0, // glMultiTexCoord4hvNV
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '4',
   'i',
   0, // glMultiTexCoord4i
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '4',
   'i',
   'A',
   'R',
   'B',
   0, // glMultiTexCoord4iARB
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '4',
   'i',
   'v',
   0, // glMultiTexCoord4iv
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '4',
   'i',
   'v',
   'A',
   'R',
   'B',
   0, // glMultiTexCoord4ivARB
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '4',
   's',
   0, // glMultiTexCoord4s
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '4',
   's',
   'A',
   'R',
   'B',
   0, // glMultiTexCoord4sARB
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '4',
   's',
   'v',
   0, // glMultiTexCoord4sv
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '4',
   's',
   'v',
   'A',
   'R',
   'B',
   0, // glMultiTexCoord4svARB
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '4',
   'x',
   0, // glMultiTexCoord4x
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '4',
   'x',
   'O',
   'E',
   'S',
   0, // glMultiTexCoord4xOES
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '4',
   'x',
   'v',
   'O',
   'E',
   'S',
   0, // glMultiTexCoord4xvOES
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   'P',
   '1',
   'u',
   'i',
   0, // glMultiTexCoordP1ui
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   'P',
   '1',
   'u',
   'i',
   'v',
   0, // glMultiTexCoordP1uiv
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   'P',
   '2',
   'u',
   'i',
   0, // glMultiTexCoordP2ui
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   'P',
   '2',
   'u',
   'i',
   'v',
   0, // glMultiTexCoordP2uiv
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   'P',
   '3',
   'u',
   'i',
   0, // glMultiTexCoordP3ui
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   'P',
   '3',
   'u',
   'i',
   'v',
   0, // glMultiTexCoordP3uiv
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   'P',
   '4',
   'u',
   'i',
   0, // glMultiTexCoordP4ui
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   'P',
   '4',
   'u',
   'i',
   'v',
   0, // glMultiTexCoordP4uiv
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glMultiTexCoordPointerEXT
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'E',
   'n',
   'v',
   'f',
   'E',
   'X',
   'T',
   0, // glMultiTexEnvfEXT
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'E',
   'n',
   'v',
   'f',
   'v',
   'E',
   'X',
   'T',
   0, // glMultiTexEnvfvEXT
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'E',
   'n',
   'v',
   'i',
   'E',
   'X',
   'T',
   0, // glMultiTexEnviEXT
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'E',
   'n',
   'v',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glMultiTexEnvivEXT
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'G',
   'e',
   'n',
   'd',
   'E',
   'X',
   'T',
   0, // glMultiTexGendEXT
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'G',
   'e',
   'n',
   'd',
   'v',
   'E',
   'X',
   'T',
   0, // glMultiTexGendvEXT
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'G',
   'e',
   'n',
   'f',
   'E',
   'X',
   'T',
   0, // glMultiTexGenfEXT
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'G',
   'e',
   'n',
   'f',
   'v',
   'E',
   'X',
   'T',
   0, // glMultiTexGenfvEXT
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'G',
   'e',
   'n',
   'i',
   'E',
   'X',
   'T',
   0, // glMultiTexGeniEXT
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'G',
   'e',
   'n',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glMultiTexGenivEXT
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'I',
   'm',
   'a',
   'g',
   'e',
   '1',
   'D',
   'E',
   'X',
   'T',
   0, // glMultiTexImage1DEXT
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'I',
   'm',
   'a',
   'g',
   'e',
   '2',
   'D',
   'E',
   'X',
   'T',
   0, // glMultiTexImage2DEXT
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'I',
   'm',
   'a',
   'g',
   'e',
   '3',
   'D',
   'E',
   'X',
   'T',
   0, // glMultiTexImage3DEXT
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glMultiTexParameterIivEXT
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   'u',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glMultiTexParameterIuivEXT
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'E',
   'X',
   'T',
   0, // glMultiTexParameterfEXT
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   'E',
   'X',
   'T',
   0, // glMultiTexParameterfvEXT
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'E',
   'X',
   'T',
   0, // glMultiTexParameteriEXT
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glMultiTexParameterivEXT
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glMultiTexRenderbufferEXT
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   '1',
   'D',
   'E',
   'X',
   'T',
   0, // glMultiTexSubImage1DEXT
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   '2',
   'D',
   'E',
   'X',
   'T',
   0, // glMultiTexSubImage2DEXT
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   '3',
   'D',
   'E',
   'X',
   'T',
   0, // glMultiTexSubImage3DEXT
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'c',
   'a',
   's',
   't',
   'B',
   'a',
   'r',
   'r',
   'i',
   'e',
   'r',
   'N',
   'V',
   0, // glMulticastBarrierNV
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'c',
   'a',
   's',
   't',
   'B',
   'l',
   'i',
   't',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'N',
   'V',
   0, // glMulticastBlitFramebufferNV
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'c',
   'a',
   's',
   't',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   'u',
   'b',
   'D',
   'a',
   't',
   'a',
   'N',
   'V',
   0, // glMulticastBufferSubDataNV
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'c',
   'a',
   's',
   't',
   'C',
   'o',
   'p',
   'y',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   'u',
   'b',
   'D',
   'a',
   't',
   'a',
   'N',
   'V',
   0, // glMulticastCopyBufferSubDataNV
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'c',
   'a',
   's',
   't',
   'C',
   'o',
   'p',
   'y',
   'I',
   'm',
   'a',
   'g',
   'e',
   'S',
   'u',
   'b',
   'D',
   'a',
   't',
   'a',
   'N',
   'V',
   0, // glMulticastCopyImageSubDataNV
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'c',
   'a',
   's',
   't',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'L',
   'o',
   'c',
   'a',
   't',
   'i',
   'o',
   'n',
   's',
   'f',
   'v',
   'N',
   'V',
   0, // glMulticastFramebufferSampleLocationsfvNV
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'c',
   'a',
   's',
   't',
   'G',
   'e',
   't',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'i',
   '6',
   '4',
   'v',
   'N',
   'V',
   0, // glMulticastGetQueryObjecti64vNV
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'c',
   'a',
   's',
   't',
   'G',
   'e',
   't',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'i',
   'v',
   'N',
   'V',
   0, // glMulticastGetQueryObjectivNV
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'c',
   'a',
   's',
   't',
   'G',
   'e',
   't',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'u',
   'i',
   '6',
   '4',
   'v',
   'N',
   'V',
   0, // glMulticastGetQueryObjectui64vNV
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'c',
   'a',
   's',
   't',
   'G',
   'e',
   't',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'u',
   'i',
   'v',
   'N',
   'V',
   0, // glMulticastGetQueryObjectuivNV
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'c',
   'a',
   's',
   't',
   'S',
   'c',
   'i',
   's',
   's',
   'o',
   'r',
   'A',
   'r',
   'r',
   'a',
   'y',
   'v',
   'N',
   'V',
   'X',
   0, // glMulticastScissorArrayvNVX
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'c',
   'a',
   's',
   't',
   'V',
   'i',
   'e',
   'w',
   'p',
   'o',
   'r',
   't',
   'A',
   'r',
   'r',
   'a',
   'y',
   'v',
   'N',
   'V',
   'X',
   0, // glMulticastViewportArrayvNVX
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'c',
   'a',
   's',
   't',
   'V',
   'i',
   'e',
   'w',
   'p',
   'o',
   'r',
   't',
   'P',
   'o',
   's',
   'i',
   't',
   'i',
   'o',
   'n',
   'W',
   'S',
   'c',
   'a',
   'l',
   'e',
   'N',
   'V',
   'X',
   0, // glMulticastViewportPositionWScaleNVX
   'g',
   'l',
   'M',
   'u',
   'l',
   't',
   'i',
   'c',
   'a',
   's',
   't',
   'W',
   'a',
   'i',
   't',
   'S',
   'y',
   'n',
   'c',
   'N',
   'V',
   0, // glMulticastWaitSyncNV
   'g',
   'l',
   'N',
   'a',
   'm',
   'e',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'A',
   't',
   't',
   'a',
   'c',
   'h',
   'M',
   'e',
   'm',
   'o',
   'r',
   'y',
   'N',
   'V',
   0, // glNamedBufferAttachMemoryNV
   'g',
   'l',
   'N',
   'a',
   'm',
   'e',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'D',
   'a',
   't',
   'a',
   0, // glNamedBufferData
   'g',
   'l',
   'N',
   'a',
   'm',
   'e',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'D',
   'a',
   't',
   'a',
   'E',
   'X',
   'T',
   0, // glNamedBufferDataEXT
   'g',
   'l',
   'N',
   'a',
   'm',
   'e',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'P',
   'a',
   'g',
   'e',
   'C',
   'o',
   'm',
   'm',
   'i',
   't',
   'm',
   'e',
   'n',
   't',
   'A',
   'R',
   'B',
   0, // glNamedBufferPageCommitmentARB
   'g',
   'l',
   'N',
   'a',
   'm',
   'e',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'P',
   'a',
   'g',
   'e',
   'C',
   'o',
   'm',
   'm',
   'i',
   't',
   'm',
   'e',
   'n',
   't',
   'E',
   'X',
   'T',
   0, // glNamedBufferPageCommitmentEXT
   'g',
   'l',
   'N',
   'a',
   'm',
   'e',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   0, // glNamedBufferStorage
   'g',
   'l',
   'N',
   'a',
   'm',
   'e',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   'E',
   'X',
   'T',
   0, // glNamedBufferStorageEXT
   'g',
   'l',
   'N',
   'a',
   'm',
   'e',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   'E',
   'x',
   't',
   'e',
   'r',
   'n',
   'a',
   'l',
   'E',
   'X',
   'T',
   0, // glNamedBufferStorageExternalEXT
   'g',
   'l',
   'N',
   'a',
   'm',
   'e',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   'M',
   'e',
   'm',
   'E',
   'X',
   'T',
   0, // glNamedBufferStorageMemEXT
   'g',
   'l',
   'N',
   'a',
   'm',
   'e',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   'u',
   'b',
   'D',
   'a',
   't',
   'a',
   0, // glNamedBufferSubData
   'g',
   'l',
   'N',
   'a',
   'm',
   'e',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   'u',
   'b',
   'D',
   'a',
   't',
   'a',
   'E',
   'X',
   'T',
   0, // glNamedBufferSubDataEXT
   'g',
   'l',
   'N',
   'a',
   'm',
   'e',
   'd',
   'C',
   'o',
   'p',
   'y',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   'u',
   'b',
   'D',
   'a',
   't',
   'a',
   'E',
   'X',
   'T',
   0, // glNamedCopyBufferSubDataEXT
   'g',
   'l',
   'N',
   'a',
   'm',
   'e',
   'd',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'D',
   'r',
   'a',
   'w',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   0, // glNamedFramebufferDrawBuffer
   'g',
   'l',
   'N',
   'a',
   'm',
   'e',
   'd',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'D',
   'r',
   'a',
   'w',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   's',
   0, // glNamedFramebufferDrawBuffers
   'g',
   'l',
   'N',
   'a',
   'm',
   'e',
   'd',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   0, // glNamedFramebufferParameteri
   'g',
   'l',
   'N',
   'a',
   'm',
   'e',
   'd',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'E',
   'X',
   'T',
   0, // glNamedFramebufferParameteriEXT
   'g',
   'l',
   'N',
   'a',
   'm',
   'e',
   'd',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'R',
   'e',
   'a',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   0, // glNamedFramebufferReadBuffer
   'g',
   'l',
   'N',
   'a',
   'm',
   'e',
   'd',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   0, // glNamedFramebufferRenderbuffer
   'g',
   'l',
   'N',
   'a',
   'm',
   'e',
   'd',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glNamedFramebufferRenderbufferEXT
   'g',
   'l',
   'N',
   'a',
   'm',
   'e',
   'd',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'L',
   'o',
   'c',
   'a',
   't',
   'i',
   'o',
   'n',
   's',
   'f',
   'v',
   'A',
   'R',
   'B',
   0, // glNamedFramebufferSampleLocationsfvARB
   'g',
   'l',
   'N',
   'a',
   'm',
   'e',
   'd',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'L',
   'o',
   'c',
   'a',
   't',
   'i',
   'o',
   'n',
   's',
   'f',
   'v',
   'N',
   'V',
   0, // glNamedFramebufferSampleLocationsfvNV
   'g',
   'l',
   'N',
   'a',
   'm',
   'e',
   'd',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'P',
   'o',
   's',
   'i',
   't',
   'i',
   'o',
   'n',
   's',
   'f',
   'v',
   'A',
   'M',
   'D',
   0, // glNamedFramebufferSamplePositionsfvAMD
   'g',
   'l',
   'N',
   'a',
   'm',
   'e',
   'd',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   0, // glNamedFramebufferTexture
   'g',
   'l',
   'N',
   'a',
   'm',
   'e',
   'd',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   '1',
   'D',
   'E',
   'X',
   'T',
   0, // glNamedFramebufferTexture1DEXT
   'g',
   'l',
   'N',
   'a',
   'm',
   'e',
   'd',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   '2',
   'D',
   'E',
   'X',
   'T',
   0, // glNamedFramebufferTexture2DEXT
   'g',
   'l',
   'N',
   'a',
   'm',
   'e',
   'd',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   '3',
   'D',
   'E',
   'X',
   'T',
   0, // glNamedFramebufferTexture3DEXT
   'g',
   'l',
   'N',
   'a',
   'm',
   'e',
   'd',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'E',
   'X',
   'T',
   0, // glNamedFramebufferTextureEXT
   'g',
   'l',
   'N',
   'a',
   'm',
   'e',
   'd',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'F',
   'a',
   'c',
   'e',
   'E',
   'X',
   'T',
   0, // glNamedFramebufferTextureFaceEXT
   'g',
   'l',
   'N',
   'a',
   'm',
   'e',
   'd',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'L',
   'a',
   'y',
   'e',
   'r',
   0, // glNamedFramebufferTextureLayer
   'g',
   'l',
   'N',
   'a',
   'm',
   'e',
   'd',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'L',
   'a',
   'y',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glNamedFramebufferTextureLayerEXT
   'g',
   'l',
   'N',
   'a',
   'm',
   'e',
   'd',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'L',
   'o',
   'c',
   'a',
   'l',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   '4',
   'd',
   'E',
   'X',
   'T',
   0, // glNamedProgramLocalParameter4dEXT
   'g',
   'l',
   'N',
   'a',
   'm',
   'e',
   'd',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'L',
   'o',
   'c',
   'a',
   'l',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   '4',
   'd',
   'v',
   'E',
   'X',
   'T',
   0, // glNamedProgramLocalParameter4dvEXT
   'g',
   'l',
   'N',
   'a',
   'm',
   'e',
   'd',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'L',
   'o',
   'c',
   'a',
   'l',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   '4',
   'f',
   'E',
   'X',
   'T',
   0, // glNamedProgramLocalParameter4fEXT
   'g',
   'l',
   'N',
   'a',
   'm',
   'e',
   'd',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'L',
   'o',
   'c',
   'a',
   'l',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   '4',
   'f',
   'v',
   'E',
   'X',
   'T',
   0, // glNamedProgramLocalParameter4fvEXT
   'g',
   'l',
   'N',
   'a',
   'm',
   'e',
   'd',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'L',
   'o',
   'c',
   'a',
   'l',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   '4',
   'i',
   'E',
   'X',
   'T',
   0, // glNamedProgramLocalParameterI4iEXT
   'g',
   'l',
   'N',
   'a',
   'm',
   'e',
   'd',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'L',
   'o',
   'c',
   'a',
   'l',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   '4',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glNamedProgramLocalParameterI4ivEXT
   'g',
   'l',
   'N',
   'a',
   'm',
   'e',
   'd',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'L',
   'o',
   'c',
   'a',
   'l',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   '4',
   'u',
   'i',
   'E',
   'X',
   'T',
   0, // glNamedProgramLocalParameterI4uiEXT
   'g',
   'l',
   'N',
   'a',
   'm',
   'e',
   'd',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'L',
   'o',
   'c',
   'a',
   'l',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   '4',
   'u',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glNamedProgramLocalParameterI4uivEXT
   'g',
   'l',
   'N',
   'a',
   'm',
   'e',
   'd',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'L',
   'o',
   'c',
   'a',
   'l',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   's',
   '4',
   'f',
   'v',
   'E',
   'X',
   'T',
   0, // glNamedProgramLocalParameters4fvEXT
   'g',
   'l',
   'N',
   'a',
   'm',
   'e',
   'd',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'L',
   'o',
   'c',
   'a',
   'l',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   's',
   'I',
   '4',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glNamedProgramLocalParametersI4ivEXT
   'g',
   'l',
   'N',
   'a',
   'm',
   'e',
   'd',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'L',
   'o',
   'c',
   'a',
   'l',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   's',
   'I',
   '4',
   'u',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glNamedProgramLocalParametersI4uivEXT
   'g',
   'l',
   'N',
   'a',
   'm',
   'e',
   'd',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'S',
   't',
   'r',
   'i',
   'n',
   'g',
   'E',
   'X',
   'T',
   0, // glNamedProgramStringEXT
   'g',
   'l',
   'N',
   'a',
   'm',
   'e',
   'd',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   0, // glNamedRenderbufferStorage
   'g',
   'l',
   'N',
   'a',
   'm',
   'e',
   'd',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   'E',
   'X',
   'T',
   0, // glNamedRenderbufferStorageEXT
   'g',
   'l',
   'N',
   'a',
   'm',
   'e',
   'd',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   'M',
   'u',
   'l',
   't',
   'i',
   's',
   'a',
   'm',
   'p',
   'l',
   'e',
   0, // glNamedRenderbufferStorageMultisample
   'g',
   'l',
   'N',
   'a',
   'm',
   'e',
   'd',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   'M',
   'u',
   'l',
   't',
   'i',
   's',
   'a',
   'm',
   'p',
   'l',
   'e',
   'A',
   'd',
   'v',
   'a',
   'n',
   'c',
   'e',
   'd',
   'A',
   'M',
   'D',
   0, // glNamedRenderbufferStorageMultisampleAdvancedAMD
   'g',
   'l',
   'N',
   'a',
   'm',
   'e',
   'd',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   'M',
   'u',
   'l',
   't',
   'i',
   's',
   'a',
   'm',
   'p',
   'l',
   'e',
   'C',
   'o',
   'v',
   'e',
   'r',
   'a',
   'g',
   'e',
   'E',
   'X',
   'T',
   0, // glNamedRenderbufferStorageMultisampleCoverageEXT
   'g',
   'l',
   'N',
   'a',
   'm',
   'e',
   'd',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   'M',
   'u',
   'l',
   't',
   'i',
   's',
   'a',
   'm',
   'p',
   'l',
   'e',
   'E',
   'X',
   'T',
   0, // glNamedRenderbufferStorageMultisampleEXT
   'g',
   'l',
   'N',
   'a',
   'm',
   'e',
   'd',
   'S',
   't',
   'r',
   'i',
   'n',
   'g',
   'A',
   'R',
   'B',
   0, // glNamedStringARB
   'g',
   'l',
   'N',
   'e',
   'w',
   'L',
   'i',
   's',
   't',
   0, // glNewList
   'g',
   'l',
   'N',
   'e',
   'w',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'A',
   'T',
   'I',
   0, // glNewObjectBufferATI
   'g',
   'l',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   '3',
   'b',
   0, // glNormal3b
   'g',
   'l',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   '3',
   'b',
   'v',
   0, // glNormal3bv
   'g',
   'l',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   '3',
   'd',
   0, // glNormal3d
   'g',
   'l',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   '3',
   'd',
   'v',
   0, // glNormal3dv
   'g',
   'l',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   '3',
   'f',
   0, // glNormal3f
   'g',
   'l',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   '3',
   'f',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '3',
   'f',
   'S',
   'U',
   'N',
   0, // glNormal3fVertex3fSUN
   'g',
   'l',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   '3',
   'f',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '3',
   'f',
   'v',
   'S',
   'U',
   'N',
   0, // glNormal3fVertex3fvSUN
   'g',
   'l',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   '3',
   'f',
   'v',
   0, // glNormal3fv
   'g',
   'l',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   '3',
   'h',
   'N',
   'V',
   0, // glNormal3hNV
   'g',
   'l',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   '3',
   'h',
   'v',
   'N',
   'V',
   0, // glNormal3hvNV
   'g',
   'l',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   '3',
   'i',
   0, // glNormal3i
   'g',
   'l',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   '3',
   'i',
   'v',
   0, // glNormal3iv
   'g',
   'l',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   '3',
   's',
   0, // glNormal3s
   'g',
   'l',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   '3',
   's',
   'v',
   0, // glNormal3sv
   'g',
   'l',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   '3',
   'x',
   0, // glNormal3x
   'g',
   'l',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   '3',
   'x',
   'O',
   'E',
   'S',
   0, // glNormal3xOES
   'g',
   'l',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   '3',
   'x',
   'v',
   'O',
   'E',
   'S',
   0, // glNormal3xvOES
   'g',
   'l',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   'F',
   'o',
   'r',
   'm',
   'a',
   't',
   'N',
   'V',
   0, // glNormalFormatNV
   'g',
   'l',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   'P',
   '3',
   'u',
   'i',
   0, // glNormalP3ui
   'g',
   'l',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   'P',
   '3',
   'u',
   'i',
   'v',
   0, // glNormalP3uiv
   'g',
   'l',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   0, // glNormalPointer
   'g',
   'l',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glNormalPointerEXT
   'g',
   'l',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'L',
   'i',
   's',
   't',
   'I',
   'B',
   'M',
   0, // glNormalPointerListIBM
   'g',
   'l',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'v',
   'I',
   'N',
   'T',
   'E',
   'L',
   0, // glNormalPointervINTEL
   'g',
   'l',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   '3',
   'b',
   'A',
   'T',
   'I',
   0, // glNormalStream3bATI
   'g',
   'l',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   '3',
   'b',
   'v',
   'A',
   'T',
   'I',
   0, // glNormalStream3bvATI
   'g',
   'l',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   '3',
   'd',
   'A',
   'T',
   'I',
   0, // glNormalStream3dATI
   'g',
   'l',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   '3',
   'd',
   'v',
   'A',
   'T',
   'I',
   0, // glNormalStream3dvATI
   'g',
   'l',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   '3',
   'f',
   'A',
   'T',
   'I',
   0, // glNormalStream3fATI
   'g',
   'l',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   '3',
   'f',
   'v',
   'A',
   'T',
   'I',
   0, // glNormalStream3fvATI
   'g',
   'l',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   '3',
   'i',
   'A',
   'T',
   'I',
   0, // glNormalStream3iATI
   'g',
   'l',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   '3',
   'i',
   'v',
   'A',
   'T',
   'I',
   0, // glNormalStream3ivATI
   'g',
   'l',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   '3',
   's',
   'A',
   'T',
   'I',
   0, // glNormalStream3sATI
   'g',
   'l',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   '3',
   's',
   'v',
   'A',
   'T',
   'I',
   0, // glNormalStream3svATI
   'g',
   'l',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'L',
   'a',
   'b',
   'e',
   'l',
   0, // glObjectLabel
   'g',
   'l',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'L',
   'a',
   'b',
   'e',
   'l',
   'K',
   'H',
   'R',
   0, // glObjectLabelKHR
   'g',
   'l',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'P',
   't',
   'r',
   'L',
   'a',
   'b',
   'e',
   'l',
   0, // glObjectPtrLabel
   'g',
   'l',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'P',
   't',
   'r',
   'L',
   'a',
   'b',
   'e',
   'l',
   'K',
   'H',
   'R',
   0, // glObjectPtrLabelKHR
   'g',
   'l',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'P',
   'u',
   'r',
   'g',
   'e',
   'a',
   'b',
   'l',
   'e',
   'A',
   'P',
   'P',
   'L',
   'E',
   0, // glObjectPurgeableAPPLE
   'g',
   'l',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'U',
   'n',
   'p',
   'u',
   'r',
   'g',
   'e',
   'a',
   'b',
   'l',
   'e',
   'A',
   'P',
   'P',
   'L',
   'E',
   0, // glObjectUnpurgeableAPPLE
   'g',
   'l',
   'O',
   'r',
   't',
   'h',
   'o',
   0, // glOrtho
   'g',
   'l',
   'O',
   'r',
   't',
   'h',
   'o',
   'f',
   0, // glOrthof
   'g',
   'l',
   'O',
   'r',
   't',
   'h',
   'o',
   'f',
   'O',
   'E',
   'S',
   0, // glOrthofOES
   'g',
   'l',
   'O',
   'r',
   't',
   'h',
   'o',
   'x',
   0, // glOrthox
   'g',
   'l',
   'O',
   'r',
   't',
   'h',
   'o',
   'x',
   'O',
   'E',
   'S',
   0, // glOrthoxOES
   'g',
   'l',
   'P',
   'N',
   'T',
   'r',
   'i',
   'a',
   'n',
   'g',
   'l',
   'e',
   's',
   'f',
   'A',
   'T',
   'I',
   0, // glPNTrianglesfATI
   'g',
   'l',
   'P',
   'N',
   'T',
   'r',
   'i',
   'a',
   'n',
   'g',
   'l',
   'e',
   's',
   'i',
   'A',
   'T',
   'I',
   0, // glPNTrianglesiATI
   'g',
   'l',
   'P',
   'a',
   's',
   's',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   'A',
   'T',
   'I',
   0, // glPassTexCoordATI
   'g',
   'l',
   'P',
   'a',
   's',
   's',
   'T',
   'h',
   'r',
   'o',
   'u',
   'g',
   'h',
   0, // glPassThrough
   'g',
   'l',
   'P',
   'a',
   's',
   's',
   'T',
   'h',
   'r',
   'o',
   'u',
   'g',
   'h',
   'x',
   'O',
   'E',
   'S',
   0, // glPassThroughxOES
   'g',
   'l',
   'P',
   'a',
   't',
   'c',
   'h',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   0, // glPatchParameterfv
   'g',
   'l',
   'P',
   'a',
   't',
   'c',
   'h',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   0, // glPatchParameteri
   'g',
   'l',
   'P',
   'a',
   't',
   'c',
   'h',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'E',
   'X',
   'T',
   0, // glPatchParameteriEXT
   'g',
   'l',
   'P',
   'a',
   't',
   'c',
   'h',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'O',
   'E',
   'S',
   0, // glPatchParameteriOES
   'g',
   'l',
   'P',
   'a',
   't',
   'h',
   'C',
   'o',
   'l',
   'o',
   'r',
   'G',
   'e',
   'n',
   'N',
   'V',
   0, // glPathColorGenNV
   'g',
   'l',
   'P',
   'a',
   't',
   'h',
   'C',
   'o',
   'm',
   'm',
   'a',
   'n',
   'd',
   's',
   'N',
   'V',
   0, // glPathCommandsNV
   'g',
   'l',
   'P',
   'a',
   't',
   'h',
   'C',
   'o',
   'o',
   'r',
   'd',
   's',
   'N',
   'V',
   0, // glPathCoordsNV
   'g',
   'l',
   'P',
   'a',
   't',
   'h',
   'C',
   'o',
   'v',
   'e',
   'r',
   'D',
   'e',
   'p',
   't',
   'h',
   'F',
   'u',
   'n',
   'c',
   'N',
   'V',
   0, // glPathCoverDepthFuncNV
   'g',
   'l',
   'P',
   'a',
   't',
   'h',
   'D',
   'a',
   's',
   'h',
   'A',
   'r',
   'r',
   'a',
   'y',
   'N',
   'V',
   0, // glPathDashArrayNV
   'g',
   'l',
   'P',
   'a',
   't',
   'h',
   'F',
   'o',
   'g',
   'G',
   'e',
   'n',
   'N',
   'V',
   0, // glPathFogGenNV
   'g',
   'l',
   'P',
   'a',
   't',
   'h',
   'G',
   'l',
   'y',
   'p',
   'h',
   'I',
   'n',
   'd',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'N',
   'V',
   0, // glPathGlyphIndexArrayNV
   'g',
   'l',
   'P',
   'a',
   't',
   'h',
   'G',
   'l',
   'y',
   'p',
   'h',
   'I',
   'n',
   'd',
   'e',
   'x',
   'R',
   'a',
   'n',
   'g',
   'e',
   'N',
   'V',
   0, // glPathGlyphIndexRangeNV
   'g',
   'l',
   'P',
   'a',
   't',
   'h',
   'G',
   'l',
   'y',
   'p',
   'h',
   'R',
   'a',
   'n',
   'g',
   'e',
   'N',
   'V',
   0, // glPathGlyphRangeNV
   'g',
   'l',
   'P',
   'a',
   't',
   'h',
   'G',
   'l',
   'y',
   'p',
   'h',
   's',
   'N',
   'V',
   0, // glPathGlyphsNV
   'g',
   'l',
   'P',
   'a',
   't',
   'h',
   'M',
   'e',
   'm',
   'o',
   'r',
   'y',
   'G',
   'l',
   'y',
   'p',
   'h',
   'I',
   'n',
   'd',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'N',
   'V',
   0, // glPathMemoryGlyphIndexArrayNV
   'g',
   'l',
   'P',
   'a',
   't',
   'h',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'N',
   'V',
   0, // glPathParameterfNV
   'g',
   'l',
   'P',
   'a',
   't',
   'h',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   'N',
   'V',
   0, // glPathParameterfvNV
   'g',
   'l',
   'P',
   'a',
   't',
   'h',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'N',
   'V',
   0, // glPathParameteriNV
   'g',
   'l',
   'P',
   'a',
   't',
   'h',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'N',
   'V',
   0, // glPathParameterivNV
   'g',
   'l',
   'P',
   'a',
   't',
   'h',
   'S',
   't',
   'e',
   'n',
   'c',
   'i',
   'l',
   'D',
   'e',
   'p',
   't',
   'h',
   'O',
   'f',
   'f',
   's',
   'e',
   't',
   'N',
   'V',
   0, // glPathStencilDepthOffsetNV
   'g',
   'l',
   'P',
   'a',
   't',
   'h',
   'S',
   't',
   'e',
   'n',
   'c',
   'i',
   'l',
   'F',
   'u',
   'n',
   'c',
   'N',
   'V',
   0, // glPathStencilFuncNV
   'g',
   'l',
   'P',
   'a',
   't',
   'h',
   'S',
   't',
   'r',
   'i',
   'n',
   'g',
   'N',
   'V',
   0, // glPathStringNV
   'g',
   'l',
   'P',
   'a',
   't',
   'h',
   'S',
   'u',
   'b',
   'C',
   'o',
   'm',
   'm',
   'a',
   'n',
   'd',
   's',
   'N',
   'V',
   0, // glPathSubCommandsNV
   'g',
   'l',
   'P',
   'a',
   't',
   'h',
   'S',
   'u',
   'b',
   'C',
   'o',
   'o',
   'r',
   'd',
   's',
   'N',
   'V',
   0, // glPathSubCoordsNV
   'g',
   'l',
   'P',
   'a',
   't',
   'h',
   'T',
   'e',
   'x',
   'G',
   'e',
   'n',
   'N',
   'V',
   0, // glPathTexGenNV
   'g',
   'l',
   'P',
   'a',
   'u',
   's',
   'e',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'F',
   'e',
   'e',
   'd',
   'b',
   'a',
   'c',
   'k',
   0, // glPauseTransformFeedback
   'g',
   'l',
   'P',
   'a',
   'u',
   's',
   'e',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'F',
   'e',
   'e',
   'd',
   'b',
   'a',
   'c',
   'k',
   'N',
   'V',
   0, // glPauseTransformFeedbackNV
   'g',
   'l',
   'P',
   'i',
   'x',
   'e',
   'l',
   'D',
   'a',
   't',
   'a',
   'R',
   'a',
   'n',
   'g',
   'e',
   'N',
   'V',
   0, // glPixelDataRangeNV
   'g',
   'l',
   'P',
   'i',
   'x',
   'e',
   'l',
   'M',
   'a',
   'p',
   'f',
   'v',
   0, // glPixelMapfv
   'g',
   'l',
   'P',
   'i',
   'x',
   'e',
   'l',
   'M',
   'a',
   'p',
   'u',
   'i',
   'v',
   0, // glPixelMapuiv
   'g',
   'l',
   'P',
   'i',
   'x',
   'e',
   'l',
   'M',
   'a',
   'p',
   'u',
   's',
   'v',
   0, // glPixelMapusv
   'g',
   'l',
   'P',
   'i',
   'x',
   'e',
   'l',
   'M',
   'a',
   'p',
   'x',
   0, // glPixelMapx
   'g',
   'l',
   'P',
   'i',
   'x',
   'e',
   'l',
   'S',
   't',
   'o',
   'r',
   'e',
   'f',
   0, // glPixelStoref
   'g',
   'l',
   'P',
   'i',
   'x',
   'e',
   'l',
   'S',
   't',
   'o',
   'r',
   'e',
   'i',
   0, // glPixelStorei
   'g',
   'l',
   'P',
   'i',
   'x',
   'e',
   'l',
   'S',
   't',
   'o',
   'r',
   'e',
   'x',
   0, // glPixelStorex
   'g',
   'l',
   'P',
   'i',
   'x',
   'e',
   'l',
   'T',
   'e',
   'x',
   'G',
   'e',
   'n',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'S',
   'G',
   'I',
   'S',
   0, // glPixelTexGenParameterfSGIS
   'g',
   'l',
   'P',
   'i',
   'x',
   'e',
   'l',
   'T',
   'e',
   'x',
   'G',
   'e',
   'n',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   'S',
   'G',
   'I',
   'S',
   0, // glPixelTexGenParameterfvSGIS
   'g',
   'l',
   'P',
   'i',
   'x',
   'e',
   'l',
   'T',
   'e',
   'x',
   'G',
   'e',
   'n',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'S',
   'G',
   'I',
   'S',
   0, // glPixelTexGenParameteriSGIS
   'g',
   'l',
   'P',
   'i',
   'x',
   'e',
   'l',
   'T',
   'e',
   'x',
   'G',
   'e',
   'n',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'S',
   'G',
   'I',
   'S',
   0, // glPixelTexGenParameterivSGIS
   'g',
   'l',
   'P',
   'i',
   'x',
   'e',
   'l',
   'T',
   'e',
   'x',
   'G',
   'e',
   'n',
   'S',
   'G',
   'I',
   'X',
   0, // glPixelTexGenSGIX
   'g',
   'l',
   'P',
   'i',
   'x',
   'e',
   'l',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'e',
   'r',
   'f',
   0, // glPixelTransferf
   'g',
   'l',
   'P',
   'i',
   'x',
   'e',
   'l',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'e',
   'r',
   'i',
   0, // glPixelTransferi
   'g',
   'l',
   'P',
   'i',
   'x',
   'e',
   'l',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'e',
   'r',
   'x',
   'O',
   'E',
   'S',
   0, // glPixelTransferxOES
   'g',
   'l',
   'P',
   'i',
   'x',
   'e',
   'l',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'E',
   'X',
   'T',
   0, // glPixelTransformParameterfEXT
   'g',
   'l',
   'P',
   'i',
   'x',
   'e',
   'l',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   'E',
   'X',
   'T',
   0, // glPixelTransformParameterfvEXT
   'g',
   'l',
   'P',
   'i',
   'x',
   'e',
   'l',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'E',
   'X',
   'T',
   0, // glPixelTransformParameteriEXT
   'g',
   'l',
   'P',
   'i',
   'x',
   'e',
   'l',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glPixelTransformParameterivEXT
   'g',
   'l',
   'P',
   'i',
   'x',
   'e',
   'l',
   'Z',
   'o',
   'o',
   'm',
   0, // glPixelZoom
   'g',
   'l',
   'P',
   'i',
   'x',
   'e',
   'l',
   'Z',
   'o',
   'o',
   'm',
   'x',
   'O',
   'E',
   'S',
   0, // glPixelZoomxOES
   'g',
   'l',
   'P',
   'o',
   'i',
   'n',
   't',
   'A',
   'l',
   'o',
   'n',
   'g',
   'P',
   'a',
   't',
   'h',
   'N',
   'V',
   0, // glPointAlongPathNV
   'g',
   'l',
   'P',
   'o',
   'i',
   'n',
   't',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   0, // glPointParameterf
   'g',
   'l',
   'P',
   'o',
   'i',
   'n',
   't',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'A',
   'R',
   'B',
   0, // glPointParameterfARB
   'g',
   'l',
   'P',
   'o',
   'i',
   'n',
   't',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'E',
   'X',
   'T',
   0, // glPointParameterfEXT
   'g',
   'l',
   'P',
   'o',
   'i',
   'n',
   't',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'S',
   'G',
   'I',
   'S',
   0, // glPointParameterfSGIS
   'g',
   'l',
   'P',
   'o',
   'i',
   'n',
   't',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   0, // glPointParameterfv
   'g',
   'l',
   'P',
   'o',
   'i',
   'n',
   't',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   'A',
   'R',
   'B',
   0, // glPointParameterfvARB
   'g',
   'l',
   'P',
   'o',
   'i',
   'n',
   't',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   'E',
   'X',
   'T',
   0, // glPointParameterfvEXT
   'g',
   'l',
   'P',
   'o',
   'i',
   'n',
   't',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   'S',
   'G',
   'I',
   'S',
   0, // glPointParameterfvSGIS
   'g',
   'l',
   'P',
   'o',
   'i',
   'n',
   't',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   0, // glPointParameteri
   'g',
   'l',
   'P',
   'o',
   'i',
   'n',
   't',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'N',
   'V',
   0, // glPointParameteriNV
   'g',
   'l',
   'P',
   'o',
   'i',
   'n',
   't',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   0, // glPointParameteriv
   'g',
   'l',
   'P',
   'o',
   'i',
   'n',
   't',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'N',
   'V',
   0, // glPointParameterivNV
   'g',
   'l',
   'P',
   'o',
   'i',
   'n',
   't',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'x',
   0, // glPointParameterx
   'g',
   'l',
   'P',
   'o',
   'i',
   'n',
   't',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'x',
   'O',
   'E',
   'S',
   0, // glPointParameterxOES
   'g',
   'l',
   'P',
   'o',
   'i',
   'n',
   't',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'x',
   'v',
   0, // glPointParameterxv
   'g',
   'l',
   'P',
   'o',
   'i',
   'n',
   't',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'x',
   'v',
   'O',
   'E',
   'S',
   0, // glPointParameterxvOES
   'g',
   'l',
   'P',
   'o',
   'i',
   'n',
   't',
   'S',
   'i',
   'z',
   'e',
   0, // glPointSize
   'g',
   'l',
   'P',
   'o',
   'i',
   'n',
   't',
   'S',
   'i',
   'z',
   'e',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'O',
   'E',
   'S',
   0, // glPointSizePointerOES
   'g',
   'l',
   'P',
   'o',
   'i',
   'n',
   't',
   'S',
   'i',
   'z',
   'e',
   'x',
   0, // glPointSizex
   'g',
   'l',
   'P',
   'o',
   'i',
   'n',
   't',
   'S',
   'i',
   'z',
   'e',
   'x',
   'O',
   'E',
   'S',
   0, // glPointSizexOES
   'g',
   'l',
   'P',
   'o',
   'l',
   'l',
   'A',
   's',
   'y',
   'n',
   'c',
   'S',
   'G',
   'I',
   'X',
   0, // glPollAsyncSGIX
   'g',
   'l',
   'P',
   'o',
   'l',
   'l',
   'I',
   'n',
   's',
   't',
   'r',
   'u',
   'm',
   'e',
   'n',
   't',
   's',
   'S',
   'G',
   'I',
   'X',
   0, // glPollInstrumentsSGIX
   'g',
   'l',
   'P',
   'o',
   'l',
   'y',
   'g',
   'o',
   'n',
   'M',
   'o',
   'd',
   'e',
   0, // glPolygonMode
   'g',
   'l',
   'P',
   'o',
   'l',
   'y',
   'g',
   'o',
   'n',
   'M',
   'o',
   'd',
   'e',
   'N',
   'V',
   0, // glPolygonModeNV
   'g',
   'l',
   'P',
   'o',
   'l',
   'y',
   'g',
   'o',
   'n',
   'O',
   'f',
   'f',
   's',
   'e',
   't',
   0, // glPolygonOffset
   'g',
   'l',
   'P',
   'o',
   'l',
   'y',
   'g',
   'o',
   'n',
   'O',
   'f',
   'f',
   's',
   'e',
   't',
   'C',
   'l',
   'a',
   'm',
   'p',
   0, // glPolygonOffsetClamp
   'g',
   'l',
   'P',
   'o',
   'l',
   'y',
   'g',
   'o',
   'n',
   'O',
   'f',
   'f',
   's',
   'e',
   't',
   'C',
   'l',
   'a',
   'm',
   'p',
   'E',
   'X',
   'T',
   0, // glPolygonOffsetClampEXT
   'g',
   'l',
   'P',
   'o',
   'l',
   'y',
   'g',
   'o',
   'n',
   'O',
   'f',
   'f',
   's',
   'e',
   't',
   'E',
   'X',
   'T',
   0, // glPolygonOffsetEXT
   'g',
   'l',
   'P',
   'o',
   'l',
   'y',
   'g',
   'o',
   'n',
   'O',
   'f',
   'f',
   's',
   'e',
   't',
   'x',
   0, // glPolygonOffsetx
   'g',
   'l',
   'P',
   'o',
   'l',
   'y',
   'g',
   'o',
   'n',
   'O',
   'f',
   'f',
   's',
   'e',
   't',
   'x',
   'O',
   'E',
   'S',
   0, // glPolygonOffsetxOES
   'g',
   'l',
   'P',
   'o',
   'l',
   'y',
   'g',
   'o',
   'n',
   'S',
   't',
   'i',
   'p',
   'p',
   'l',
   'e',
   0, // glPolygonStipple
   'g',
   'l',
   'P',
   'o',
   'p',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   0, // glPopAttrib
   'g',
   'l',
   'P',
   'o',
   'p',
   'C',
   'l',
   'i',
   'e',
   'n',
   't',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   0, // glPopClientAttrib
   'g',
   'l',
   'P',
   'o',
   'p',
   'D',
   'e',
   'b',
   'u',
   'g',
   'G',
   'r',
   'o',
   'u',
   'p',
   0, // glPopDebugGroup
   'g',
   'l',
   'P',
   'o',
   'p',
   'D',
   'e',
   'b',
   'u',
   'g',
   'G',
   'r',
   'o',
   'u',
   'p',
   'K',
   'H',
   'R',
   0, // glPopDebugGroupKHR
   'g',
   'l',
   'P',
   'o',
   'p',
   'G',
   'r',
   'o',
   'u',
   'p',
   'M',
   'a',
   'r',
   'k',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glPopGroupMarkerEXT
   'g',
   'l',
   'P',
   'o',
   'p',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   0, // glPopMatrix
   'g',
   'l',
   'P',
   'o',
   'p',
   'N',
   'a',
   'm',
   'e',
   0, // glPopName
   'g',
   'l',
   'P',
   'r',
   'e',
   's',
   'e',
   'n',
   't',
   'F',
   'r',
   'a',
   'm',
   'e',
   'D',
   'u',
   'a',
   'l',
   'F',
   'i',
   'l',
   'l',
   'N',
   'V',
   0, // glPresentFrameDualFillNV
   'g',
   'l',
   'P',
   'r',
   'e',
   's',
   'e',
   'n',
   't',
   'F',
   'r',
   'a',
   'm',
   'e',
   'K',
   'e',
   'y',
   'e',
   'd',
   'N',
   'V',
   0, // glPresentFrameKeyedNV
   'g',
   'l',
   'P',
   'r',
   'i',
   'm',
   'i',
   't',
   'i',
   'v',
   'e',
   'B',
   'o',
   'u',
   'n',
   'd',
   'i',
   'n',
   'g',
   'B',
   'o',
   'x',
   0, // glPrimitiveBoundingBox
   'g',
   'l',
   'P',
   'r',
   'i',
   'm',
   'i',
   't',
   'i',
   'v',
   'e',
   'B',
   'o',
   'u',
   'n',
   'd',
   'i',
   'n',
   'g',
   'B',
   'o',
   'x',
   'A',
   'R',
   'B',
   0, // glPrimitiveBoundingBoxARB
   'g',
   'l',
   'P',
   'r',
   'i',
   'm',
   'i',
   't',
   'i',
   'v',
   'e',
   'B',
   'o',
   'u',
   'n',
   'd',
   'i',
   'n',
   'g',
   'B',
   'o',
   'x',
   'E',
   'X',
   'T',
   0, // glPrimitiveBoundingBoxEXT
   'g',
   'l',
   'P',
   'r',
   'i',
   'm',
   'i',
   't',
   'i',
   'v',
   'e',
   'B',
   'o',
   'u',
   'n',
   'd',
   'i',
   'n',
   'g',
   'B',
   'o',
   'x',
   'O',
   'E',
   'S',
   0, // glPrimitiveBoundingBoxOES
   'g',
   'l',
   'P',
   'r',
   'i',
   'm',
   'i',
   't',
   'i',
   'v',
   'e',
   'R',
   'e',
   's',
   't',
   'a',
   'r',
   't',
   'I',
   'n',
   'd',
   'e',
   'x',
   0, // glPrimitiveRestartIndex
   'g',
   'l',
   'P',
   'r',
   'i',
   'm',
   'i',
   't',
   'i',
   'v',
   'e',
   'R',
   'e',
   's',
   't',
   'a',
   'r',
   't',
   'I',
   'n',
   'd',
   'e',
   'x',
   'N',
   'V',
   0, // glPrimitiveRestartIndexNV
   'g',
   'l',
   'P',
   'r',
   'i',
   'm',
   'i',
   't',
   'i',
   'v',
   'e',
   'R',
   'e',
   's',
   't',
   'a',
   'r',
   't',
   'N',
   'V',
   0, // glPrimitiveRestartNV
   'g',
   'l',
   'P',
   'r',
   'i',
   'o',
   'r',
   'i',
   't',
   'i',
   'z',
   'e',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   's',
   0, // glPrioritizeTextures
   'g',
   'l',
   'P',
   'r',
   'i',
   'o',
   'r',
   'i',
   't',
   'i',
   'z',
   'e',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   's',
   'E',
   'X',
   'T',
   0, // glPrioritizeTexturesEXT
   'g',
   'l',
   'P',
   'r',
   'i',
   'o',
   'r',
   'i',
   't',
   'i',
   'z',
   'e',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   's',
   'x',
   'O',
   'E',
   'S',
   0, // glPrioritizeTexturesxOES
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'B',
   'i',
   'n',
   'a',
   'r',
   'y',
   0, // glProgramBinary
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'B',
   'i',
   'n',
   'a',
   'r',
   'y',
   'O',
   'E',
   'S',
   0, // glProgramBinaryOES
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   's',
   'I',
   'i',
   'v',
   'N',
   'V',
   0, // glProgramBufferParametersIivNV
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   's',
   'I',
   'u',
   'i',
   'v',
   'N',
   'V',
   0, // glProgramBufferParametersIuivNV
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   's',
   'f',
   'v',
   'N',
   'V',
   0, // glProgramBufferParametersfvNV
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'E',
   'n',
   'v',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   '4',
   'd',
   'A',
   'R',
   'B',
   0, // glProgramEnvParameter4dARB
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'E',
   'n',
   'v',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   '4',
   'd',
   'v',
   'A',
   'R',
   'B',
   0, // glProgramEnvParameter4dvARB
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'E',
   'n',
   'v',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   '4',
   'f',
   'A',
   'R',
   'B',
   0, // glProgramEnvParameter4fARB
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'E',
   'n',
   'v',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   '4',
   'f',
   'v',
   'A',
   'R',
   'B',
   0, // glProgramEnvParameter4fvARB
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'E',
   'n',
   'v',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   '4',
   'i',
   'N',
   'V',
   0, // glProgramEnvParameterI4iNV
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'E',
   'n',
   'v',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   '4',
   'i',
   'v',
   'N',
   'V',
   0, // glProgramEnvParameterI4ivNV
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'E',
   'n',
   'v',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   '4',
   'u',
   'i',
   'N',
   'V',
   0, // glProgramEnvParameterI4uiNV
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'E',
   'n',
   'v',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   '4',
   'u',
   'i',
   'v',
   'N',
   'V',
   0, // glProgramEnvParameterI4uivNV
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'E',
   'n',
   'v',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   's',
   '4',
   'f',
   'v',
   'E',
   'X',
   'T',
   0, // glProgramEnvParameters4fvEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'E',
   'n',
   'v',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   's',
   'I',
   '4',
   'i',
   'v',
   'N',
   'V',
   0, // glProgramEnvParametersI4ivNV
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'E',
   'n',
   'v',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   's',
   'I',
   '4',
   'u',
   'i',
   'v',
   'N',
   'V',
   0, // glProgramEnvParametersI4uivNV
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'L',
   'o',
   'c',
   'a',
   'l',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   '4',
   'd',
   'A',
   'R',
   'B',
   0, // glProgramLocalParameter4dARB
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'L',
   'o',
   'c',
   'a',
   'l',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   '4',
   'd',
   'v',
   'A',
   'R',
   'B',
   0, // glProgramLocalParameter4dvARB
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'L',
   'o',
   'c',
   'a',
   'l',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   '4',
   'f',
   'A',
   'R',
   'B',
   0, // glProgramLocalParameter4fARB
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'L',
   'o',
   'c',
   'a',
   'l',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   '4',
   'f',
   'v',
   'A',
   'R',
   'B',
   0, // glProgramLocalParameter4fvARB
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'L',
   'o',
   'c',
   'a',
   'l',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   '4',
   'i',
   'N',
   'V',
   0, // glProgramLocalParameterI4iNV
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'L',
   'o',
   'c',
   'a',
   'l',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   '4',
   'i',
   'v',
   'N',
   'V',
   0, // glProgramLocalParameterI4ivNV
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'L',
   'o',
   'c',
   'a',
   'l',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   '4',
   'u',
   'i',
   'N',
   'V',
   0, // glProgramLocalParameterI4uiNV
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'L',
   'o',
   'c',
   'a',
   'l',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   '4',
   'u',
   'i',
   'v',
   'N',
   'V',
   0, // glProgramLocalParameterI4uivNV
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'L',
   'o',
   'c',
   'a',
   'l',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   's',
   '4',
   'f',
   'v',
   'E',
   'X',
   'T',
   0, // glProgramLocalParameters4fvEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'L',
   'o',
   'c',
   'a',
   'l',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   's',
   'I',
   '4',
   'i',
   'v',
   'N',
   'V',
   0, // glProgramLocalParametersI4ivNV
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'L',
   'o',
   'c',
   'a',
   'l',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   's',
   'I',
   '4',
   'u',
   'i',
   'v',
   'N',
   'V',
   0, // glProgramLocalParametersI4uivNV
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'N',
   'a',
   'm',
   'e',
   'd',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   '4',
   'd',
   'N',
   'V',
   0, // glProgramNamedParameter4dNV
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'N',
   'a',
   'm',
   'e',
   'd',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   '4',
   'd',
   'v',
   'N',
   'V',
   0, // glProgramNamedParameter4dvNV
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'N',
   'a',
   'm',
   'e',
   'd',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   '4',
   'f',
   'N',
   'V',
   0, // glProgramNamedParameter4fNV
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'N',
   'a',
   'm',
   'e',
   'd',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   '4',
   'f',
   'v',
   'N',
   'V',
   0, // glProgramNamedParameter4fvNV
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   '4',
   'd',
   'N',
   'V',
   0, // glProgramParameter4dNV
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   '4',
   'd',
   'v',
   'N',
   'V',
   0, // glProgramParameter4dvNV
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   '4',
   'f',
   'N',
   'V',
   0, // glProgramParameter4fNV
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   '4',
   'f',
   'v',
   'N',
   'V',
   0, // glProgramParameter4fvNV
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   0, // glProgramParameteri
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'A',
   'R',
   'B',
   0, // glProgramParameteriARB
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'E',
   'X',
   'T',
   0, // glProgramParameteriEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   's',
   '4',
   'd',
   'v',
   'N',
   'V',
   0, // glProgramParameters4dvNV
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   's',
   '4',
   'f',
   'v',
   'N',
   'V',
   0, // glProgramParameters4fvNV
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'P',
   'a',
   't',
   'h',
   'F',
   'r',
   'a',
   'g',
   'm',
   'e',
   'n',
   't',
   'I',
   'n',
   'p',
   'u',
   't',
   'G',
   'e',
   'n',
   'N',
   'V',
   0, // glProgramPathFragmentInputGenNV
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'S',
   't',
   'r',
   'i',
   'n',
   'g',
   'A',
   'R',
   'B',
   0, // glProgramStringARB
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'S',
   'u',
   'b',
   'r',
   'o',
   'u',
   't',
   'i',
   'n',
   'e',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   's',
   'u',
   'i',
   'v',
   'N',
   'V',
   0, // glProgramSubroutineParametersuivNV
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '1',
   'd',
   0, // glProgramUniform1d
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '1',
   'd',
   'E',
   'X',
   'T',
   0, // glProgramUniform1dEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '1',
   'd',
   'v',
   0, // glProgramUniform1dv
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '1',
   'd',
   'v',
   'E',
   'X',
   'T',
   0, // glProgramUniform1dvEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '1',
   'f',
   0, // glProgramUniform1f
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '1',
   'f',
   'E',
   'X',
   'T',
   0, // glProgramUniform1fEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '1',
   'f',
   'v',
   0, // glProgramUniform1fv
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '1',
   'f',
   'v',
   'E',
   'X',
   'T',
   0, // glProgramUniform1fvEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '1',
   'i',
   0, // glProgramUniform1i
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '1',
   'i',
   '6',
   '4',
   'A',
   'R',
   'B',
   0, // glProgramUniform1i64ARB
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '1',
   'i',
   '6',
   '4',
   'N',
   'V',
   0, // glProgramUniform1i64NV
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '1',
   'i',
   '6',
   '4',
   'v',
   'A',
   'R',
   'B',
   0, // glProgramUniform1i64vARB
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '1',
   'i',
   '6',
   '4',
   'v',
   'N',
   'V',
   0, // glProgramUniform1i64vNV
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '1',
   'i',
   'E',
   'X',
   'T',
   0, // glProgramUniform1iEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '1',
   'i',
   'v',
   0, // glProgramUniform1iv
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '1',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glProgramUniform1ivEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '1',
   'u',
   'i',
   0, // glProgramUniform1ui
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '1',
   'u',
   'i',
   '6',
   '4',
   'A',
   'R',
   'B',
   0, // glProgramUniform1ui64ARB
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '1',
   'u',
   'i',
   '6',
   '4',
   'N',
   'V',
   0, // glProgramUniform1ui64NV
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '1',
   'u',
   'i',
   '6',
   '4',
   'v',
   'A',
   'R',
   'B',
   0, // glProgramUniform1ui64vARB
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '1',
   'u',
   'i',
   '6',
   '4',
   'v',
   'N',
   'V',
   0, // glProgramUniform1ui64vNV
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '1',
   'u',
   'i',
   'E',
   'X',
   'T',
   0, // glProgramUniform1uiEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '1',
   'u',
   'i',
   'v',
   0, // glProgramUniform1uiv
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '1',
   'u',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glProgramUniform1uivEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '2',
   'd',
   0, // glProgramUniform2d
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '2',
   'd',
   'E',
   'X',
   'T',
   0, // glProgramUniform2dEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '2',
   'd',
   'v',
   0, // glProgramUniform2dv
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '2',
   'd',
   'v',
   'E',
   'X',
   'T',
   0, // glProgramUniform2dvEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '2',
   'f',
   0, // glProgramUniform2f
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '2',
   'f',
   'E',
   'X',
   'T',
   0, // glProgramUniform2fEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '2',
   'f',
   'v',
   0, // glProgramUniform2fv
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '2',
   'f',
   'v',
   'E',
   'X',
   'T',
   0, // glProgramUniform2fvEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '2',
   'i',
   0, // glProgramUniform2i
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '2',
   'i',
   '6',
   '4',
   'A',
   'R',
   'B',
   0, // glProgramUniform2i64ARB
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '2',
   'i',
   '6',
   '4',
   'N',
   'V',
   0, // glProgramUniform2i64NV
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '2',
   'i',
   '6',
   '4',
   'v',
   'A',
   'R',
   'B',
   0, // glProgramUniform2i64vARB
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '2',
   'i',
   '6',
   '4',
   'v',
   'N',
   'V',
   0, // glProgramUniform2i64vNV
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '2',
   'i',
   'E',
   'X',
   'T',
   0, // glProgramUniform2iEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '2',
   'i',
   'v',
   0, // glProgramUniform2iv
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '2',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glProgramUniform2ivEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '2',
   'u',
   'i',
   0, // glProgramUniform2ui
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '2',
   'u',
   'i',
   '6',
   '4',
   'A',
   'R',
   'B',
   0, // glProgramUniform2ui64ARB
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '2',
   'u',
   'i',
   '6',
   '4',
   'N',
   'V',
   0, // glProgramUniform2ui64NV
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '2',
   'u',
   'i',
   '6',
   '4',
   'v',
   'A',
   'R',
   'B',
   0, // glProgramUniform2ui64vARB
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '2',
   'u',
   'i',
   '6',
   '4',
   'v',
   'N',
   'V',
   0, // glProgramUniform2ui64vNV
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '2',
   'u',
   'i',
   'E',
   'X',
   'T',
   0, // glProgramUniform2uiEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '2',
   'u',
   'i',
   'v',
   0, // glProgramUniform2uiv
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '2',
   'u',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glProgramUniform2uivEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '3',
   'd',
   0, // glProgramUniform3d
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '3',
   'd',
   'E',
   'X',
   'T',
   0, // glProgramUniform3dEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '3',
   'd',
   'v',
   0, // glProgramUniform3dv
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '3',
   'd',
   'v',
   'E',
   'X',
   'T',
   0, // glProgramUniform3dvEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '3',
   'f',
   0, // glProgramUniform3f
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '3',
   'f',
   'E',
   'X',
   'T',
   0, // glProgramUniform3fEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '3',
   'f',
   'v',
   0, // glProgramUniform3fv
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '3',
   'f',
   'v',
   'E',
   'X',
   'T',
   0, // glProgramUniform3fvEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '3',
   'i',
   0, // glProgramUniform3i
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '3',
   'i',
   '6',
   '4',
   'A',
   'R',
   'B',
   0, // glProgramUniform3i64ARB
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '3',
   'i',
   '6',
   '4',
   'N',
   'V',
   0, // glProgramUniform3i64NV
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '3',
   'i',
   '6',
   '4',
   'v',
   'A',
   'R',
   'B',
   0, // glProgramUniform3i64vARB
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '3',
   'i',
   '6',
   '4',
   'v',
   'N',
   'V',
   0, // glProgramUniform3i64vNV
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '3',
   'i',
   'E',
   'X',
   'T',
   0, // glProgramUniform3iEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '3',
   'i',
   'v',
   0, // glProgramUniform3iv
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '3',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glProgramUniform3ivEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '3',
   'u',
   'i',
   0, // glProgramUniform3ui
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '3',
   'u',
   'i',
   '6',
   '4',
   'A',
   'R',
   'B',
   0, // glProgramUniform3ui64ARB
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '3',
   'u',
   'i',
   '6',
   '4',
   'N',
   'V',
   0, // glProgramUniform3ui64NV
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '3',
   'u',
   'i',
   '6',
   '4',
   'v',
   'A',
   'R',
   'B',
   0, // glProgramUniform3ui64vARB
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '3',
   'u',
   'i',
   '6',
   '4',
   'v',
   'N',
   'V',
   0, // glProgramUniform3ui64vNV
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '3',
   'u',
   'i',
   'E',
   'X',
   'T',
   0, // glProgramUniform3uiEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '3',
   'u',
   'i',
   'v',
   0, // glProgramUniform3uiv
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '3',
   'u',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glProgramUniform3uivEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '4',
   'd',
   0, // glProgramUniform4d
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '4',
   'd',
   'E',
   'X',
   'T',
   0, // glProgramUniform4dEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '4',
   'd',
   'v',
   0, // glProgramUniform4dv
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '4',
   'd',
   'v',
   'E',
   'X',
   'T',
   0, // glProgramUniform4dvEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '4',
   'f',
   0, // glProgramUniform4f
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '4',
   'f',
   'E',
   'X',
   'T',
   0, // glProgramUniform4fEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '4',
   'f',
   'v',
   0, // glProgramUniform4fv
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '4',
   'f',
   'v',
   'E',
   'X',
   'T',
   0, // glProgramUniform4fvEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '4',
   'i',
   0, // glProgramUniform4i
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '4',
   'i',
   '6',
   '4',
   'A',
   'R',
   'B',
   0, // glProgramUniform4i64ARB
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '4',
   'i',
   '6',
   '4',
   'N',
   'V',
   0, // glProgramUniform4i64NV
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '4',
   'i',
   '6',
   '4',
   'v',
   'A',
   'R',
   'B',
   0, // glProgramUniform4i64vARB
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '4',
   'i',
   '6',
   '4',
   'v',
   'N',
   'V',
   0, // glProgramUniform4i64vNV
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '4',
   'i',
   'E',
   'X',
   'T',
   0, // glProgramUniform4iEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '4',
   'i',
   'v',
   0, // glProgramUniform4iv
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '4',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glProgramUniform4ivEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '4',
   'u',
   'i',
   0, // glProgramUniform4ui
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '4',
   'u',
   'i',
   '6',
   '4',
   'A',
   'R',
   'B',
   0, // glProgramUniform4ui64ARB
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '4',
   'u',
   'i',
   '6',
   '4',
   'N',
   'V',
   0, // glProgramUniform4ui64NV
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '4',
   'u',
   'i',
   '6',
   '4',
   'v',
   'A',
   'R',
   'B',
   0, // glProgramUniform4ui64vARB
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '4',
   'u',
   'i',
   '6',
   '4',
   'v',
   'N',
   'V',
   0, // glProgramUniform4ui64vNV
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '4',
   'u',
   'i',
   'E',
   'X',
   'T',
   0, // glProgramUniform4uiEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '4',
   'u',
   'i',
   'v',
   0, // glProgramUniform4uiv
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '4',
   'u',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glProgramUniform4uivEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'H',
   'a',
   'n',
   'd',
   'l',
   'e',
   'u',
   'i',
   '6',
   '4',
   'A',
   'R',
   'B',
   0, // glProgramUniformHandleui64ARB
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'H',
   'a',
   'n',
   'd',
   'l',
   'e',
   'u',
   'i',
   '6',
   '4',
   'I',
   'M',
   'G',
   0, // glProgramUniformHandleui64IMG
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'H',
   'a',
   'n',
   'd',
   'l',
   'e',
   'u',
   'i',
   '6',
   '4',
   'N',
   'V',
   0, // glProgramUniformHandleui64NV
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'H',
   'a',
   'n',
   'd',
   'l',
   'e',
   'u',
   'i',
   '6',
   '4',
   'v',
   'A',
   'R',
   'B',
   0, // glProgramUniformHandleui64vARB
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'H',
   'a',
   'n',
   'd',
   'l',
   'e',
   'u',
   'i',
   '6',
   '4',
   'v',
   'I',
   'M',
   'G',
   0, // glProgramUniformHandleui64vIMG
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'H',
   'a',
   'n',
   'd',
   'l',
   'e',
   'u',
   'i',
   '6',
   '4',
   'v',
   'N',
   'V',
   0, // glProgramUniformHandleui64vNV
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '2',
   'd',
   'v',
   0, // glProgramUniformMatrix2dv
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '2',
   'd',
   'v',
   'E',
   'X',
   'T',
   0, // glProgramUniformMatrix2dvEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '2',
   'f',
   'v',
   0, // glProgramUniformMatrix2fv
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '2',
   'f',
   'v',
   'E',
   'X',
   'T',
   0, // glProgramUniformMatrix2fvEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '2',
   'x',
   '3',
   'd',
   'v',
   0, // glProgramUniformMatrix2x3dv
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '2',
   'x',
   '3',
   'd',
   'v',
   'E',
   'X',
   'T',
   0, // glProgramUniformMatrix2x3dvEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '2',
   'x',
   '3',
   'f',
   'v',
   0, // glProgramUniformMatrix2x3fv
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '2',
   'x',
   '3',
   'f',
   'v',
   'E',
   'X',
   'T',
   0, // glProgramUniformMatrix2x3fvEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '2',
   'x',
   '4',
   'd',
   'v',
   0, // glProgramUniformMatrix2x4dv
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '2',
   'x',
   '4',
   'd',
   'v',
   'E',
   'X',
   'T',
   0, // glProgramUniformMatrix2x4dvEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '2',
   'x',
   '4',
   'f',
   'v',
   0, // glProgramUniformMatrix2x4fv
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '2',
   'x',
   '4',
   'f',
   'v',
   'E',
   'X',
   'T',
   0, // glProgramUniformMatrix2x4fvEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '3',
   'd',
   'v',
   0, // glProgramUniformMatrix3dv
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '3',
   'd',
   'v',
   'E',
   'X',
   'T',
   0, // glProgramUniformMatrix3dvEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '3',
   'f',
   'v',
   0, // glProgramUniformMatrix3fv
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '3',
   'f',
   'v',
   'E',
   'X',
   'T',
   0, // glProgramUniformMatrix3fvEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '3',
   'x',
   '2',
   'd',
   'v',
   0, // glProgramUniformMatrix3x2dv
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '3',
   'x',
   '2',
   'd',
   'v',
   'E',
   'X',
   'T',
   0, // glProgramUniformMatrix3x2dvEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '3',
   'x',
   '2',
   'f',
   'v',
   0, // glProgramUniformMatrix3x2fv
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '3',
   'x',
   '2',
   'f',
   'v',
   'E',
   'X',
   'T',
   0, // glProgramUniformMatrix3x2fvEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '3',
   'x',
   '4',
   'd',
   'v',
   0, // glProgramUniformMatrix3x4dv
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '3',
   'x',
   '4',
   'd',
   'v',
   'E',
   'X',
   'T',
   0, // glProgramUniformMatrix3x4dvEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '3',
   'x',
   '4',
   'f',
   'v',
   0, // glProgramUniformMatrix3x4fv
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '3',
   'x',
   '4',
   'f',
   'v',
   'E',
   'X',
   'T',
   0, // glProgramUniformMatrix3x4fvEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '4',
   'd',
   'v',
   0, // glProgramUniformMatrix4dv
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '4',
   'd',
   'v',
   'E',
   'X',
   'T',
   0, // glProgramUniformMatrix4dvEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '4',
   'f',
   'v',
   0, // glProgramUniformMatrix4fv
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '4',
   'f',
   'v',
   'E',
   'X',
   'T',
   0, // glProgramUniformMatrix4fvEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '4',
   'x',
   '2',
   'd',
   'v',
   0, // glProgramUniformMatrix4x2dv
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '4',
   'x',
   '2',
   'd',
   'v',
   'E',
   'X',
   'T',
   0, // glProgramUniformMatrix4x2dvEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '4',
   'x',
   '2',
   'f',
   'v',
   0, // glProgramUniformMatrix4x2fv
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '4',
   'x',
   '2',
   'f',
   'v',
   'E',
   'X',
   'T',
   0, // glProgramUniformMatrix4x2fvEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '4',
   'x',
   '3',
   'd',
   'v',
   0, // glProgramUniformMatrix4x3dv
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '4',
   'x',
   '3',
   'd',
   'v',
   'E',
   'X',
   'T',
   0, // glProgramUniformMatrix4x3dvEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '4',
   'x',
   '3',
   'f',
   'v',
   0, // glProgramUniformMatrix4x3fv
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '4',
   'x',
   '3',
   'f',
   'v',
   'E',
   'X',
   'T',
   0, // glProgramUniformMatrix4x3fvEXT
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'u',
   'i',
   '6',
   '4',
   'N',
   'V',
   0, // glProgramUniformui64NV
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'u',
   'i',
   '6',
   '4',
   'v',
   'N',
   'V',
   0, // glProgramUniformui64vNV
   'g',
   'l',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'L',
   'i',
   'm',
   'i',
   't',
   'N',
   'V',
   0, // glProgramVertexLimitNV
   'g',
   'l',
   'P',
   'r',
   'o',
   'v',
   'o',
   'k',
   'i',
   'n',
   'g',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   0, // glProvokingVertex
   'g',
   'l',
   'P',
   'r',
   'o',
   'v',
   'o',
   'k',
   'i',
   'n',
   'g',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'E',
   'X',
   'T',
   0, // glProvokingVertexEXT
   'g',
   'l',
   'P',
   'u',
   's',
   'h',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   0, // glPushAttrib
   'g',
   'l',
   'P',
   'u',
   's',
   'h',
   'C',
   'l',
   'i',
   'e',
   'n',
   't',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   0, // glPushClientAttrib
   'g',
   'l',
   'P',
   'u',
   's',
   'h',
   'C',
   'l',
   'i',
   'e',
   'n',
   't',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'D',
   'e',
   'f',
   'a',
   'u',
   'l',
   't',
   'E',
   'X',
   'T',
   0, // glPushClientAttribDefaultEXT
   'g',
   'l',
   'P',
   'u',
   's',
   'h',
   'D',
   'e',
   'b',
   'u',
   'g',
   'G',
   'r',
   'o',
   'u',
   'p',
   0, // glPushDebugGroup
   'g',
   'l',
   'P',
   'u',
   's',
   'h',
   'D',
   'e',
   'b',
   'u',
   'g',
   'G',
   'r',
   'o',
   'u',
   'p',
   'K',
   'H',
   'R',
   0, // glPushDebugGroupKHR
   'g',
   'l',
   'P',
   'u',
   's',
   'h',
   'G',
   'r',
   'o',
   'u',
   'p',
   'M',
   'a',
   'r',
   'k',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glPushGroupMarkerEXT
   'g',
   'l',
   'P',
   'u',
   's',
   'h',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   0, // glPushMatrix
   'g',
   'l',
   'P',
   'u',
   's',
   'h',
   'N',
   'a',
   'm',
   'e',
   0, // glPushName
   'g',
   'l',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'C',
   'o',
   'u',
   'n',
   't',
   'e',
   'r',
   0, // glQueryCounter
   'g',
   'l',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'C',
   'o',
   'u',
   'n',
   't',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glQueryCounterEXT
   'g',
   'l',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'x',
   'O',
   'E',
   'S',
   0, // glQueryMatrixxOES
   'g',
   'l',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'u',
   'i',
   'A',
   'M',
   'D',
   0, // glQueryObjectParameteruiAMD
   'g',
   'l',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'R',
   'e',
   's',
   'o',
   'u',
   'r',
   'c',
   'e',
   'N',
   'V',
   0, // glQueryResourceNV
   'g',
   'l',
   'Q',
   'u',
   'e',
   'r',
   'y',
   'R',
   'e',
   's',
   'o',
   'u',
   'r',
   'c',
   'e',
   'T',
   'a',
   'g',
   'N',
   'V',
   0, // glQueryResourceTagNV
   'g',
   'l',
   'R',
   'a',
   's',
   't',
   'e',
   'r',
   'P',
   'o',
   's',
   '2',
   'd',
   0, // glRasterPos2d
   'g',
   'l',
   'R',
   'a',
   's',
   't',
   'e',
   'r',
   'P',
   'o',
   's',
   '2',
   'd',
   'v',
   0, // glRasterPos2dv
   'g',
   'l',
   'R',
   'a',
   's',
   't',
   'e',
   'r',
   'P',
   'o',
   's',
   '2',
   'f',
   0, // glRasterPos2f
   'g',
   'l',
   'R',
   'a',
   's',
   't',
   'e',
   'r',
   'P',
   'o',
   's',
   '2',
   'f',
   'v',
   0, // glRasterPos2fv
   'g',
   'l',
   'R',
   'a',
   's',
   't',
   'e',
   'r',
   'P',
   'o',
   's',
   '2',
   'i',
   0, // glRasterPos2i
   'g',
   'l',
   'R',
   'a',
   's',
   't',
   'e',
   'r',
   'P',
   'o',
   's',
   '2',
   'i',
   'v',
   0, // glRasterPos2iv
   'g',
   'l',
   'R',
   'a',
   's',
   't',
   'e',
   'r',
   'P',
   'o',
   's',
   '2',
   's',
   0, // glRasterPos2s
   'g',
   'l',
   'R',
   'a',
   's',
   't',
   'e',
   'r',
   'P',
   'o',
   's',
   '2',
   's',
   'v',
   0, // glRasterPos2sv
   'g',
   'l',
   'R',
   'a',
   's',
   't',
   'e',
   'r',
   'P',
   'o',
   's',
   '2',
   'x',
   'O',
   'E',
   'S',
   0, // glRasterPos2xOES
   'g',
   'l',
   'R',
   'a',
   's',
   't',
   'e',
   'r',
   'P',
   'o',
   's',
   '2',
   'x',
   'v',
   'O',
   'E',
   'S',
   0, // glRasterPos2xvOES
   'g',
   'l',
   'R',
   'a',
   's',
   't',
   'e',
   'r',
   'P',
   'o',
   's',
   '3',
   'd',
   0, // glRasterPos3d
   'g',
   'l',
   'R',
   'a',
   's',
   't',
   'e',
   'r',
   'P',
   'o',
   's',
   '3',
   'd',
   'v',
   0, // glRasterPos3dv
   'g',
   'l',
   'R',
   'a',
   's',
   't',
   'e',
   'r',
   'P',
   'o',
   's',
   '3',
   'f',
   0, // glRasterPos3f
   'g',
   'l',
   'R',
   'a',
   's',
   't',
   'e',
   'r',
   'P',
   'o',
   's',
   '3',
   'f',
   'v',
   0, // glRasterPos3fv
   'g',
   'l',
   'R',
   'a',
   's',
   't',
   'e',
   'r',
   'P',
   'o',
   's',
   '3',
   'i',
   0, // glRasterPos3i
   'g',
   'l',
   'R',
   'a',
   's',
   't',
   'e',
   'r',
   'P',
   'o',
   's',
   '3',
   'i',
   'v',
   0, // glRasterPos3iv
   'g',
   'l',
   'R',
   'a',
   's',
   't',
   'e',
   'r',
   'P',
   'o',
   's',
   '3',
   's',
   0, // glRasterPos3s
   'g',
   'l',
   'R',
   'a',
   's',
   't',
   'e',
   'r',
   'P',
   'o',
   's',
   '3',
   's',
   'v',
   0, // glRasterPos3sv
   'g',
   'l',
   'R',
   'a',
   's',
   't',
   'e',
   'r',
   'P',
   'o',
   's',
   '3',
   'x',
   'O',
   'E',
   'S',
   0, // glRasterPos3xOES
   'g',
   'l',
   'R',
   'a',
   's',
   't',
   'e',
   'r',
   'P',
   'o',
   's',
   '3',
   'x',
   'v',
   'O',
   'E',
   'S',
   0, // glRasterPos3xvOES
   'g',
   'l',
   'R',
   'a',
   's',
   't',
   'e',
   'r',
   'P',
   'o',
   's',
   '4',
   'd',
   0, // glRasterPos4d
   'g',
   'l',
   'R',
   'a',
   's',
   't',
   'e',
   'r',
   'P',
   'o',
   's',
   '4',
   'd',
   'v',
   0, // glRasterPos4dv
   'g',
   'l',
   'R',
   'a',
   's',
   't',
   'e',
   'r',
   'P',
   'o',
   's',
   '4',
   'f',
   0, // glRasterPos4f
   'g',
   'l',
   'R',
   'a',
   's',
   't',
   'e',
   'r',
   'P',
   'o',
   's',
   '4',
   'f',
   'v',
   0, // glRasterPos4fv
   'g',
   'l',
   'R',
   'a',
   's',
   't',
   'e',
   'r',
   'P',
   'o',
   's',
   '4',
   'i',
   0, // glRasterPos4i
   'g',
   'l',
   'R',
   'a',
   's',
   't',
   'e',
   'r',
   'P',
   'o',
   's',
   '4',
   'i',
   'v',
   0, // glRasterPos4iv
   'g',
   'l',
   'R',
   'a',
   's',
   't',
   'e',
   'r',
   'P',
   'o',
   's',
   '4',
   's',
   0, // glRasterPos4s
   'g',
   'l',
   'R',
   'a',
   's',
   't',
   'e',
   'r',
   'P',
   'o',
   's',
   '4',
   's',
   'v',
   0, // glRasterPos4sv
   'g',
   'l',
   'R',
   'a',
   's',
   't',
   'e',
   'r',
   'P',
   'o',
   's',
   '4',
   'x',
   'O',
   'E',
   'S',
   0, // glRasterPos4xOES
   'g',
   'l',
   'R',
   'a',
   's',
   't',
   'e',
   'r',
   'P',
   'o',
   's',
   '4',
   'x',
   'v',
   'O',
   'E',
   'S',
   0, // glRasterPos4xvOES
   'g',
   'l',
   'R',
   'a',
   's',
   't',
   'e',
   'r',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   's',
   'E',
   'X',
   'T',
   0, // glRasterSamplesEXT
   'g',
   'l',
   'R',
   'e',
   'a',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   0, // glReadBuffer
   'g',
   'l',
   'R',
   'e',
   'a',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'I',
   'n',
   'd',
   'e',
   'x',
   'e',
   'd',
   'E',
   'X',
   'T',
   0, // glReadBufferIndexedEXT
   'g',
   'l',
   'R',
   'e',
   'a',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'N',
   'V',
   0, // glReadBufferNV
   'g',
   'l',
   'R',
   'e',
   'a',
   'd',
   'I',
   'n',
   's',
   't',
   'r',
   'u',
   'm',
   'e',
   'n',
   't',
   's',
   'S',
   'G',
   'I',
   'X',
   0, // glReadInstrumentsSGIX
   'g',
   'l',
   'R',
   'e',
   'a',
   'd',
   'P',
   'i',
   'x',
   'e',
   'l',
   's',
   0, // glReadPixels
   'g',
   'l',
   'R',
   'e',
   'a',
   'd',
   'n',
   'P',
   'i',
   'x',
   'e',
   'l',
   's',
   0, // glReadnPixels
   'g',
   'l',
   'R',
   'e',
   'a',
   'd',
   'n',
   'P',
   'i',
   'x',
   'e',
   'l',
   's',
   'A',
   'R',
   'B',
   0, // glReadnPixelsARB
   'g',
   'l',
   'R',
   'e',
   'a',
   'd',
   'n',
   'P',
   'i',
   'x',
   'e',
   'l',
   's',
   'E',
   'X',
   'T',
   0, // glReadnPixelsEXT
   'g',
   'l',
   'R',
   'e',
   'a',
   'd',
   'n',
   'P',
   'i',
   'x',
   'e',
   'l',
   's',
   'K',
   'H',
   'R',
   0, // glReadnPixelsKHR
   'g',
   'l',
   'R',
   'e',
   'c',
   't',
   'd',
   0, // glRectd
   'g',
   'l',
   'R',
   'e',
   'c',
   't',
   'd',
   'v',
   0, // glRectdv
   'g',
   'l',
   'R',
   'e',
   'c',
   't',
   'f',
   0, // glRectf
   'g',
   'l',
   'R',
   'e',
   'c',
   't',
   'f',
   'v',
   0, // glRectfv
   'g',
   'l',
   'R',
   'e',
   'c',
   't',
   'i',
   0, // glRecti
   'g',
   'l',
   'R',
   'e',
   'c',
   't',
   'i',
   'v',
   0, // glRectiv
   'g',
   'l',
   'R',
   'e',
   'c',
   't',
   's',
   0, // glRects
   'g',
   'l',
   'R',
   'e',
   'c',
   't',
   's',
   'v',
   0, // glRectsv
   'g',
   'l',
   'R',
   'e',
   'c',
   't',
   'x',
   'O',
   'E',
   'S',
   0, // glRectxOES
   'g',
   'l',
   'R',
   'e',
   'c',
   't',
   'x',
   'v',
   'O',
   'E',
   'S',
   0, // glRectxvOES
   'g',
   'l',
   'R',
   'e',
   'f',
   'e',
   'r',
   'e',
   'n',
   'c',
   'e',
   'P',
   'l',
   'a',
   'n',
   'e',
   'S',
   'G',
   'I',
   'X',
   0, // glReferencePlaneSGIX
   'g',
   'l',
   'R',
   'e',
   'l',
   'e',
   'a',
   's',
   'e',
   'K',
   'e',
   'y',
   'e',
   'd',
   'M',
   'u',
   't',
   'e',
   'x',
   'W',
   'i',
   'n',
   '3',
   '2',
   'E',
   'X',
   'T',
   0, // glReleaseKeyedMutexWin32EXT
   'g',
   'l',
   'R',
   'e',
   'l',
   'e',
   'a',
   's',
   'e',
   'S',
   'h',
   'a',
   'd',
   'e',
   'r',
   'C',
   'o',
   'm',
   'p',
   'i',
   'l',
   'e',
   'r',
   0, // glReleaseShaderCompiler
   'g',
   'l',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'G',
   'p',
   'u',
   'M',
   'a',
   's',
   'k',
   'N',
   'V',
   0, // glRenderGpuMaskNV
   'g',
   'l',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'M',
   'o',
   'd',
   'e',
   0, // glRenderMode
   'g',
   'l',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   0, // glRenderbufferStorage
   'g',
   'l',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   'E',
   'X',
   'T',
   0, // glRenderbufferStorageEXT
   'g',
   'l',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   'M',
   'u',
   'l',
   't',
   'i',
   's',
   'a',
   'm',
   'p',
   'l',
   'e',
   0, // glRenderbufferStorageMultisample
   'g',
   'l',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   'M',
   'u',
   'l',
   't',
   'i',
   's',
   'a',
   'm',
   'p',
   'l',
   'e',
   'A',
   'N',
   'G',
   'L',
   'E',
   0, // glRenderbufferStorageMultisampleANGLE
   'g',
   'l',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   'M',
   'u',
   'l',
   't',
   'i',
   's',
   'a',
   'm',
   'p',
   'l',
   'e',
   'A',
   'P',
   'P',
   'L',
   'E',
   0, // glRenderbufferStorageMultisampleAPPLE
   'g',
   'l',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   'M',
   'u',
   'l',
   't',
   'i',
   's',
   'a',
   'm',
   'p',
   'l',
   'e',
   'A',
   'd',
   'v',
   'a',
   'n',
   'c',
   'e',
   'd',
   'A',
   'M',
   'D',
   0, // glRenderbufferStorageMultisampleAdvancedAMD
   'g',
   'l',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   'M',
   'u',
   'l',
   't',
   'i',
   's',
   'a',
   'm',
   'p',
   'l',
   'e',
   'C',
   'o',
   'v',
   'e',
   'r',
   'a',
   'g',
   'e',
   'N',
   'V',
   0, // glRenderbufferStorageMultisampleCoverageNV
   'g',
   'l',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   'M',
   'u',
   'l',
   't',
   'i',
   's',
   'a',
   'm',
   'p',
   'l',
   'e',
   'E',
   'X',
   'T',
   0, // glRenderbufferStorageMultisampleEXT
   'g',
   'l',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   'M',
   'u',
   'l',
   't',
   'i',
   's',
   'a',
   'm',
   'p',
   'l',
   'e',
   'I',
   'M',
   'G',
   0, // glRenderbufferStorageMultisampleIMG
   'g',
   'l',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   'M',
   'u',
   'l',
   't',
   'i',
   's',
   'a',
   'm',
   'p',
   'l',
   'e',
   'N',
   'V',
   0, // glRenderbufferStorageMultisampleNV
   'g',
   'l',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   'O',
   'E',
   'S',
   0, // glRenderbufferStorageOES
   'g',
   'l',
   'R',
   'e',
   'p',
   'l',
   'a',
   'c',
   'e',
   'm',
   'e',
   'n',
   't',
   'C',
   'o',
   'd',
   'e',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'S',
   'U',
   'N',
   0, // glReplacementCodePointerSUN
   'g',
   'l',
   'R',
   'e',
   'p',
   'l',
   'a',
   'c',
   'e',
   'm',
   'e',
   'n',
   't',
   'C',
   'o',
   'd',
   'e',
   'u',
   'b',
   'S',
   'U',
   'N',
   0, // glReplacementCodeubSUN
   'g',
   'l',
   'R',
   'e',
   'p',
   'l',
   'a',
   'c',
   'e',
   'm',
   'e',
   'n',
   't',
   'C',
   'o',
   'd',
   'e',
   'u',
   'b',
   'v',
   'S',
   'U',
   'N',
   0, // glReplacementCodeubvSUN
   'g',
   'l',
   'R',
   'e',
   'p',
   'l',
   'a',
   'c',
   'e',
   'm',
   'e',
   'n',
   't',
   'C',
   'o',
   'd',
   'e',
   'u',
   'i',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'f',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '3',
   'f',
   'S',
   'U',
   'N',
   0, // glReplacementCodeuiColor3fVertex3fSUN
   'g',
   'l',
   'R',
   'e',
   'p',
   'l',
   'a',
   'c',
   'e',
   'm',
   'e',
   'n',
   't',
   'C',
   'o',
   'd',
   'e',
   'u',
   'i',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'f',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '3',
   'f',
   'v',
   'S',
   'U',
   'N',
   0, // glReplacementCodeuiColor3fVertex3fvSUN
   'g',
   'l',
   'R',
   'e',
   'p',
   'l',
   'a',
   'c',
   'e',
   'm',
   'e',
   'n',
   't',
   'C',
   'o',
   'd',
   'e',
   'u',
   'i',
   'C',
   'o',
   'l',
   'o',
   'r',
   '4',
   'f',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   '3',
   'f',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '3',
   'f',
   'S',
   'U',
   'N',
   0, // glReplacementCodeuiColor4fNormal3fVertex3fSUN
   'g',
   'l',
   'R',
   'e',
   'p',
   'l',
   'a',
   'c',
   'e',
   'm',
   'e',
   'n',
   't',
   'C',
   'o',
   'd',
   'e',
   'u',
   'i',
   'C',
   'o',
   'l',
   'o',
   'r',
   '4',
   'f',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   '3',
   'f',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '3',
   'f',
   'v',
   'S',
   'U',
   'N',
   0, // glReplacementCodeuiColor4fNormal3fVertex3fvSUN
   'g',
   'l',
   'R',
   'e',
   'p',
   'l',
   'a',
   'c',
   'e',
   'm',
   'e',
   'n',
   't',
   'C',
   'o',
   'd',
   'e',
   'u',
   'i',
   'C',
   'o',
   'l',
   'o',
   'r',
   '4',
   'u',
   'b',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '3',
   'f',
   'S',
   'U',
   'N',
   0, // glReplacementCodeuiColor4ubVertex3fSUN
   'g',
   'l',
   'R',
   'e',
   'p',
   'l',
   'a',
   'c',
   'e',
   'm',
   'e',
   'n',
   't',
   'C',
   'o',
   'd',
   'e',
   'u',
   'i',
   'C',
   'o',
   'l',
   'o',
   'r',
   '4',
   'u',
   'b',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '3',
   'f',
   'v',
   'S',
   'U',
   'N',
   0, // glReplacementCodeuiColor4ubVertex3fvSUN
   'g',
   'l',
   'R',
   'e',
   'p',
   'l',
   'a',
   'c',
   'e',
   'm',
   'e',
   'n',
   't',
   'C',
   'o',
   'd',
   'e',
   'u',
   'i',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   '3',
   'f',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '3',
   'f',
   'S',
   'U',
   'N',
   0, // glReplacementCodeuiNormal3fVertex3fSUN
   'g',
   'l',
   'R',
   'e',
   'p',
   'l',
   'a',
   'c',
   'e',
   'm',
   'e',
   'n',
   't',
   'C',
   'o',
   'd',
   'e',
   'u',
   'i',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   '3',
   'f',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '3',
   'f',
   'v',
   'S',
   'U',
   'N',
   0, // glReplacementCodeuiNormal3fVertex3fvSUN
   'g',
   'l',
   'R',
   'e',
   'p',
   'l',
   'a',
   'c',
   'e',
   'm',
   'e',
   'n',
   't',
   'C',
   'o',
   'd',
   'e',
   'u',
   'i',
   'S',
   'U',
   'N',
   0, // glReplacementCodeuiSUN
   'g',
   'l',
   'R',
   'e',
   'p',
   'l',
   'a',
   'c',
   'e',
   'm',
   'e',
   'n',
   't',
   'C',
   'o',
   'd',
   'e',
   'u',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'f',
   'C',
   'o',
   'l',
   'o',
   'r',
   '4',
   'f',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   '3',
   'f',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '3',
   'f',
   'S',
   'U',
   'N',
   0, // glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fSUN
   'g',
   'l',
   'R',
   'e',
   'p',
   'l',
   'a',
   'c',
   'e',
   'm',
   'e',
   'n',
   't',
   'C',
   'o',
   'd',
   'e',
   'u',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'f',
   'C',
   'o',
   'l',
   'o',
   'r',
   '4',
   'f',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   '3',
   'f',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '3',
   'f',
   'v',
   'S',
   'U',
   'N',
   0, // glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fvSUN
   'g',
   'l',
   'R',
   'e',
   'p',
   'l',
   'a',
   'c',
   'e',
   'm',
   'e',
   'n',
   't',
   'C',
   'o',
   'd',
   'e',
   'u',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'f',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   '3',
   'f',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '3',
   'f',
   'S',
   'U',
   'N',
   0, // glReplacementCodeuiTexCoord2fNormal3fVertex3fSUN
   'g',
   'l',
   'R',
   'e',
   'p',
   'l',
   'a',
   'c',
   'e',
   'm',
   'e',
   'n',
   't',
   'C',
   'o',
   'd',
   'e',
   'u',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'f',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   '3',
   'f',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '3',
   'f',
   'v',
   'S',
   'U',
   'N',
   0, // glReplacementCodeuiTexCoord2fNormal3fVertex3fvSUN
   'g',
   'l',
   'R',
   'e',
   'p',
   'l',
   'a',
   'c',
   'e',
   'm',
   'e',
   'n',
   't',
   'C',
   'o',
   'd',
   'e',
   'u',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'f',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '3',
   'f',
   'S',
   'U',
   'N',
   0, // glReplacementCodeuiTexCoord2fVertex3fSUN
   'g',
   'l',
   'R',
   'e',
   'p',
   'l',
   'a',
   'c',
   'e',
   'm',
   'e',
   'n',
   't',
   'C',
   'o',
   'd',
   'e',
   'u',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'f',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '3',
   'f',
   'v',
   'S',
   'U',
   'N',
   0, // glReplacementCodeuiTexCoord2fVertex3fvSUN
   'g',
   'l',
   'R',
   'e',
   'p',
   'l',
   'a',
   'c',
   'e',
   'm',
   'e',
   'n',
   't',
   'C',
   'o',
   'd',
   'e',
   'u',
   'i',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '3',
   'f',
   'S',
   'U',
   'N',
   0, // glReplacementCodeuiVertex3fSUN
   'g',
   'l',
   'R',
   'e',
   'p',
   'l',
   'a',
   'c',
   'e',
   'm',
   'e',
   'n',
   't',
   'C',
   'o',
   'd',
   'e',
   'u',
   'i',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '3',
   'f',
   'v',
   'S',
   'U',
   'N',
   0, // glReplacementCodeuiVertex3fvSUN
   'g',
   'l',
   'R',
   'e',
   'p',
   'l',
   'a',
   'c',
   'e',
   'm',
   'e',
   'n',
   't',
   'C',
   'o',
   'd',
   'e',
   'u',
   'i',
   'v',
   'S',
   'U',
   'N',
   0, // glReplacementCodeuivSUN
   'g',
   'l',
   'R',
   'e',
   'p',
   'l',
   'a',
   'c',
   'e',
   'm',
   'e',
   'n',
   't',
   'C',
   'o',
   'd',
   'e',
   'u',
   's',
   'S',
   'U',
   'N',
   0, // glReplacementCodeusSUN
   'g',
   'l',
   'R',
   'e',
   'p',
   'l',
   'a',
   'c',
   'e',
   'm',
   'e',
   'n',
   't',
   'C',
   'o',
   'd',
   'e',
   'u',
   's',
   'v',
   'S',
   'U',
   'N',
   0, // glReplacementCodeusvSUN
   'g',
   'l',
   'R',
   'e',
   'q',
   'u',
   'e',
   's',
   't',
   'R',
   'e',
   's',
   'i',
   'd',
   'e',
   'n',
   't',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   's',
   'N',
   'V',
   0, // glRequestResidentProgramsNV
   'g',
   'l',
   'R',
   'e',
   's',
   'e',
   't',
   'H',
   'i',
   's',
   't',
   'o',
   'g',
   'r',
   'a',
   'm',
   0, // glResetHistogram
   'g',
   'l',
   'R',
   'e',
   's',
   'e',
   't',
   'H',
   'i',
   's',
   't',
   'o',
   'g',
   'r',
   'a',
   'm',
   'E',
   'X',
   'T',
   0, // glResetHistogramEXT
   'g',
   'l',
   'R',
   'e',
   's',
   'e',
   't',
   'M',
   'e',
   'm',
   'o',
   'r',
   'y',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'N',
   'V',
   0, // glResetMemoryObjectParameterNV
   'g',
   'l',
   'R',
   'e',
   's',
   'e',
   't',
   'M',
   'i',
   'n',
   'm',
   'a',
   'x',
   0, // glResetMinmax
   'g',
   'l',
   'R',
   'e',
   's',
   'e',
   't',
   'M',
   'i',
   'n',
   'm',
   'a',
   'x',
   'E',
   'X',
   'T',
   0, // glResetMinmaxEXT
   'g',
   'l',
   'R',
   'e',
   's',
   'i',
   'z',
   'e',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   's',
   'M',
   'E',
   'S',
   'A',
   0, // glResizeBuffersMESA
   'g',
   'l',
   'R',
   'e',
   's',
   'o',
   'l',
   'v',
   'e',
   'D',
   'e',
   'p',
   't',
   'h',
   'V',
   'a',
   'l',
   'u',
   'e',
   's',
   'N',
   'V',
   0, // glResolveDepthValuesNV
   'g',
   'l',
   'R',
   'e',
   's',
   'o',
   'l',
   'v',
   'e',
   'M',
   'u',
   'l',
   't',
   'i',
   's',
   'a',
   'm',
   'p',
   'l',
   'e',
   'F',
   'r',
   'a',
   'm',
   'e',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'A',
   'P',
   'P',
   'L',
   'E',
   0, // glResolveMultisampleFramebufferAPPLE
   'g',
   'l',
   'R',
   'e',
   's',
   'u',
   'm',
   'e',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'F',
   'e',
   'e',
   'd',
   'b',
   'a',
   'c',
   'k',
   0, // glResumeTransformFeedback
   'g',
   'l',
   'R',
   'e',
   's',
   'u',
   'm',
   'e',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'F',
   'e',
   'e',
   'd',
   'b',
   'a',
   'c',
   'k',
   'N',
   'V',
   0, // glResumeTransformFeedbackNV
   'g',
   'l',
   'R',
   'o',
   't',
   'a',
   't',
   'e',
   'd',
   0, // glRotated
   'g',
   'l',
   'R',
   'o',
   't',
   'a',
   't',
   'e',
   'f',
   0, // glRotatef
   'g',
   'l',
   'R',
   'o',
   't',
   'a',
   't',
   'e',
   'x',
   0, // glRotatex
   'g',
   'l',
   'R',
   'o',
   't',
   'a',
   't',
   'e',
   'x',
   'O',
   'E',
   'S',
   0, // glRotatexOES
   'g',
   'l',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'C',
   'o',
   'v',
   'e',
   'r',
   'a',
   'g',
   'e',
   0, // glSampleCoverage
   'g',
   'l',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'C',
   'o',
   'v',
   'e',
   'r',
   'a',
   'g',
   'e',
   'A',
   'R',
   'B',
   0, // glSampleCoverageARB
   'g',
   'l',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'C',
   'o',
   'v',
   'e',
   'r',
   'a',
   'g',
   'e',
   'x',
   0, // glSampleCoveragex
   'g',
   'l',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'C',
   'o',
   'v',
   'e',
   'r',
   'a',
   'g',
   'e',
   'x',
   'O',
   'E',
   'S',
   0, // glSampleCoveragexOES
   'g',
   'l',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'M',
   'a',
   'p',
   'A',
   'T',
   'I',
   0, // glSampleMapATI
   'g',
   'l',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'M',
   'a',
   's',
   'k',
   'E',
   'X',
   'T',
   0, // glSampleMaskEXT
   'g',
   'l',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'M',
   'a',
   's',
   'k',
   'I',
   'n',
   'd',
   'e',
   'x',
   'e',
   'd',
   'N',
   'V',
   0, // glSampleMaskIndexedNV
   'g',
   'l',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'M',
   'a',
   's',
   'k',
   'S',
   'G',
   'I',
   'S',
   0, // glSampleMaskSGIS
   'g',
   'l',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'M',
   'a',
   's',
   'k',
   'i',
   0, // glSampleMaski
   'g',
   'l',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'P',
   'a',
   't',
   't',
   'e',
   'r',
   'n',
   'E',
   'X',
   'T',
   0, // glSamplePatternEXT
   'g',
   'l',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'P',
   'a',
   't',
   't',
   'e',
   'r',
   'n',
   'S',
   'G',
   'I',
   'S',
   0, // glSamplePatternSGIS
   'g',
   'l',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   'i',
   'v',
   0, // glSamplerParameterIiv
   'g',
   'l',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glSamplerParameterIivEXT
   'g',
   'l',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   'i',
   'v',
   'O',
   'E',
   'S',
   0, // glSamplerParameterIivOES
   'g',
   'l',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   'u',
   'i',
   'v',
   0, // glSamplerParameterIuiv
   'g',
   'l',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   'u',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glSamplerParameterIuivEXT
   'g',
   'l',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   'u',
   'i',
   'v',
   'O',
   'E',
   'S',
   0, // glSamplerParameterIuivOES
   'g',
   'l',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   0, // glSamplerParameterf
   'g',
   'l',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   0, // glSamplerParameterfv
   'g',
   'l',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   0, // glSamplerParameteri
   'g',
   'l',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'r',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   0, // glSamplerParameteriv
   'g',
   'l',
   'S',
   'c',
   'a',
   'l',
   'e',
   'd',
   0, // glScaled
   'g',
   'l',
   'S',
   'c',
   'a',
   'l',
   'e',
   'f',
   0, // glScalef
   'g',
   'l',
   'S',
   'c',
   'a',
   'l',
   'e',
   'x',
   0, // glScalex
   'g',
   'l',
   'S',
   'c',
   'a',
   'l',
   'e',
   'x',
   'O',
   'E',
   'S',
   0, // glScalexOES
   'g',
   'l',
   'S',
   'c',
   'i',
   's',
   's',
   'o',
   'r',
   0, // glScissor
   'g',
   'l',
   'S',
   'c',
   'i',
   's',
   's',
   'o',
   'r',
   'A',
   'r',
   'r',
   'a',
   'y',
   'v',
   0, // glScissorArrayv
   'g',
   'l',
   'S',
   'c',
   'i',
   's',
   's',
   'o',
   'r',
   'A',
   'r',
   'r',
   'a',
   'y',
   'v',
   'N',
   'V',
   0, // glScissorArrayvNV
   'g',
   'l',
   'S',
   'c',
   'i',
   's',
   's',
   'o',
   'r',
   'A',
   'r',
   'r',
   'a',
   'y',
   'v',
   'O',
   'E',
   'S',
   0, // glScissorArrayvOES
   'g',
   'l',
   'S',
   'c',
   'i',
   's',
   's',
   'o',
   'r',
   'E',
   'x',
   'c',
   'l',
   'u',
   's',
   'i',
   'v',
   'e',
   'A',
   'r',
   'r',
   'a',
   'y',
   'v',
   'N',
   'V',
   0, // glScissorExclusiveArrayvNV
   'g',
   'l',
   'S',
   'c',
   'i',
   's',
   's',
   'o',
   'r',
   'E',
   'x',
   'c',
   'l',
   'u',
   's',
   'i',
   'v',
   'e',
   'N',
   'V',
   0, // glScissorExclusiveNV
   'g',
   'l',
   'S',
   'c',
   'i',
   's',
   's',
   'o',
   'r',
   'I',
   'n',
   'd',
   'e',
   'x',
   'e',
   'd',
   0, // glScissorIndexed
   'g',
   'l',
   'S',
   'c',
   'i',
   's',
   's',
   'o',
   'r',
   'I',
   'n',
   'd',
   'e',
   'x',
   'e',
   'd',
   'N',
   'V',
   0, // glScissorIndexedNV
   'g',
   'l',
   'S',
   'c',
   'i',
   's',
   's',
   'o',
   'r',
   'I',
   'n',
   'd',
   'e',
   'x',
   'e',
   'd',
   'O',
   'E',
   'S',
   0, // glScissorIndexedOES
   'g',
   'l',
   'S',
   'c',
   'i',
   's',
   's',
   'o',
   'r',
   'I',
   'n',
   'd',
   'e',
   'x',
   'e',
   'd',
   'v',
   0, // glScissorIndexedv
   'g',
   'l',
   'S',
   'c',
   'i',
   's',
   's',
   'o',
   'r',
   'I',
   'n',
   'd',
   'e',
   'x',
   'e',
   'd',
   'v',
   'N',
   'V',
   0, // glScissorIndexedvNV
   'g',
   'l',
   'S',
   'c',
   'i',
   's',
   's',
   'o',
   'r',
   'I',
   'n',
   'd',
   'e',
   'x',
   'e',
   'd',
   'v',
   'O',
   'E',
   'S',
   0, // glScissorIndexedvOES
   'g',
   'l',
   'S',
   'e',
   'c',
   'o',
   'n',
   'd',
   'a',
   'r',
   'y',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'b',
   0, // glSecondaryColor3b
   'g',
   'l',
   'S',
   'e',
   'c',
   'o',
   'n',
   'd',
   'a',
   'r',
   'y',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'b',
   'E',
   'X',
   'T',
   0, // glSecondaryColor3bEXT
   'g',
   'l',
   'S',
   'e',
   'c',
   'o',
   'n',
   'd',
   'a',
   'r',
   'y',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'b',
   'v',
   0, // glSecondaryColor3bv
   'g',
   'l',
   'S',
   'e',
   'c',
   'o',
   'n',
   'd',
   'a',
   'r',
   'y',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'b',
   'v',
   'E',
   'X',
   'T',
   0, // glSecondaryColor3bvEXT
   'g',
   'l',
   'S',
   'e',
   'c',
   'o',
   'n',
   'd',
   'a',
   'r',
   'y',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'd',
   0, // glSecondaryColor3d
   'g',
   'l',
   'S',
   'e',
   'c',
   'o',
   'n',
   'd',
   'a',
   'r',
   'y',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'd',
   'E',
   'X',
   'T',
   0, // glSecondaryColor3dEXT
   'g',
   'l',
   'S',
   'e',
   'c',
   'o',
   'n',
   'd',
   'a',
   'r',
   'y',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'd',
   'v',
   0, // glSecondaryColor3dv
   'g',
   'l',
   'S',
   'e',
   'c',
   'o',
   'n',
   'd',
   'a',
   'r',
   'y',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'd',
   'v',
   'E',
   'X',
   'T',
   0, // glSecondaryColor3dvEXT
   'g',
   'l',
   'S',
   'e',
   'c',
   'o',
   'n',
   'd',
   'a',
   'r',
   'y',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'f',
   0, // glSecondaryColor3f
   'g',
   'l',
   'S',
   'e',
   'c',
   'o',
   'n',
   'd',
   'a',
   'r',
   'y',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'f',
   'E',
   'X',
   'T',
   0, // glSecondaryColor3fEXT
   'g',
   'l',
   'S',
   'e',
   'c',
   'o',
   'n',
   'd',
   'a',
   'r',
   'y',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'f',
   'v',
   0, // glSecondaryColor3fv
   'g',
   'l',
   'S',
   'e',
   'c',
   'o',
   'n',
   'd',
   'a',
   'r',
   'y',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'f',
   'v',
   'E',
   'X',
   'T',
   0, // glSecondaryColor3fvEXT
   'g',
   'l',
   'S',
   'e',
   'c',
   'o',
   'n',
   'd',
   'a',
   'r',
   'y',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'h',
   'N',
   'V',
   0, // glSecondaryColor3hNV
   'g',
   'l',
   'S',
   'e',
   'c',
   'o',
   'n',
   'd',
   'a',
   'r',
   'y',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'h',
   'v',
   'N',
   'V',
   0, // glSecondaryColor3hvNV
   'g',
   'l',
   'S',
   'e',
   'c',
   'o',
   'n',
   'd',
   'a',
   'r',
   'y',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'i',
   0, // glSecondaryColor3i
   'g',
   'l',
   'S',
   'e',
   'c',
   'o',
   'n',
   'd',
   'a',
   'r',
   'y',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'i',
   'E',
   'X',
   'T',
   0, // glSecondaryColor3iEXT
   'g',
   'l',
   'S',
   'e',
   'c',
   'o',
   'n',
   'd',
   'a',
   'r',
   'y',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'i',
   'v',
   0, // glSecondaryColor3iv
   'g',
   'l',
   'S',
   'e',
   'c',
   'o',
   'n',
   'd',
   'a',
   'r',
   'y',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glSecondaryColor3ivEXT
   'g',
   'l',
   'S',
   'e',
   'c',
   'o',
   'n',
   'd',
   'a',
   'r',
   'y',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   's',
   0, // glSecondaryColor3s
   'g',
   'l',
   'S',
   'e',
   'c',
   'o',
   'n',
   'd',
   'a',
   'r',
   'y',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   's',
   'E',
   'X',
   'T',
   0, // glSecondaryColor3sEXT
   'g',
   'l',
   'S',
   'e',
   'c',
   'o',
   'n',
   'd',
   'a',
   'r',
   'y',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   's',
   'v',
   0, // glSecondaryColor3sv
   'g',
   'l',
   'S',
   'e',
   'c',
   'o',
   'n',
   'd',
   'a',
   'r',
   'y',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   's',
   'v',
   'E',
   'X',
   'T',
   0, // glSecondaryColor3svEXT
   'g',
   'l',
   'S',
   'e',
   'c',
   'o',
   'n',
   'd',
   'a',
   'r',
   'y',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'u',
   'b',
   0, // glSecondaryColor3ub
   'g',
   'l',
   'S',
   'e',
   'c',
   'o',
   'n',
   'd',
   'a',
   'r',
   'y',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'u',
   'b',
   'E',
   'X',
   'T',
   0, // glSecondaryColor3ubEXT
   'g',
   'l',
   'S',
   'e',
   'c',
   'o',
   'n',
   'd',
   'a',
   'r',
   'y',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'u',
   'b',
   'v',
   0, // glSecondaryColor3ubv
   'g',
   'l',
   'S',
   'e',
   'c',
   'o',
   'n',
   'd',
   'a',
   'r',
   'y',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'u',
   'b',
   'v',
   'E',
   'X',
   'T',
   0, // glSecondaryColor3ubvEXT
   'g',
   'l',
   'S',
   'e',
   'c',
   'o',
   'n',
   'd',
   'a',
   'r',
   'y',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'u',
   'i',
   0, // glSecondaryColor3ui
   'g',
   'l',
   'S',
   'e',
   'c',
   'o',
   'n',
   'd',
   'a',
   'r',
   'y',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'u',
   'i',
   'E',
   'X',
   'T',
   0, // glSecondaryColor3uiEXT
   'g',
   'l',
   'S',
   'e',
   'c',
   'o',
   'n',
   'd',
   'a',
   'r',
   'y',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'u',
   'i',
   'v',
   0, // glSecondaryColor3uiv
   'g',
   'l',
   'S',
   'e',
   'c',
   'o',
   'n',
   'd',
   'a',
   'r',
   'y',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'u',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glSecondaryColor3uivEXT
   'g',
   'l',
   'S',
   'e',
   'c',
   'o',
   'n',
   'd',
   'a',
   'r',
   'y',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'u',
   's',
   0, // glSecondaryColor3us
   'g',
   'l',
   'S',
   'e',
   'c',
   'o',
   'n',
   'd',
   'a',
   'r',
   'y',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'u',
   's',
   'E',
   'X',
   'T',
   0, // glSecondaryColor3usEXT
   'g',
   'l',
   'S',
   'e',
   'c',
   'o',
   'n',
   'd',
   'a',
   'r',
   'y',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'u',
   's',
   'v',
   0, // glSecondaryColor3usv
   'g',
   'l',
   'S',
   'e',
   'c',
   'o',
   'n',
   'd',
   'a',
   'r',
   'y',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'u',
   's',
   'v',
   'E',
   'X',
   'T',
   0, // glSecondaryColor3usvEXT
   'g',
   'l',
   'S',
   'e',
   'c',
   'o',
   'n',
   'd',
   'a',
   'r',
   'y',
   'C',
   'o',
   'l',
   'o',
   'r',
   'F',
   'o',
   'r',
   'm',
   'a',
   't',
   'N',
   'V',
   0, // glSecondaryColorFormatNV
   'g',
   'l',
   'S',
   'e',
   'c',
   'o',
   'n',
   'd',
   'a',
   'r',
   'y',
   'C',
   'o',
   'l',
   'o',
   'r',
   'P',
   '3',
   'u',
   'i',
   0, // glSecondaryColorP3ui
   'g',
   'l',
   'S',
   'e',
   'c',
   'o',
   'n',
   'd',
   'a',
   'r',
   'y',
   'C',
   'o',
   'l',
   'o',
   'r',
   'P',
   '3',
   'u',
   'i',
   'v',
   0, // glSecondaryColorP3uiv
   'g',
   'l',
   'S',
   'e',
   'c',
   'o',
   'n',
   'd',
   'a',
   'r',
   'y',
   'C',
   'o',
   'l',
   'o',
   'r',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   0, // glSecondaryColorPointer
   'g',
   'l',
   'S',
   'e',
   'c',
   'o',
   'n',
   'd',
   'a',
   'r',
   'y',
   'C',
   'o',
   'l',
   'o',
   'r',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glSecondaryColorPointerEXT
   'g',
   'l',
   'S',
   'e',
   'c',
   'o',
   'n',
   'd',
   'a',
   'r',
   'y',
   'C',
   'o',
   'l',
   'o',
   'r',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'L',
   'i',
   's',
   't',
   'I',
   'B',
   'M',
   0, // glSecondaryColorPointerListIBM
   'g',
   'l',
   'S',
   'e',
   'l',
   'e',
   'c',
   't',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   0, // glSelectBuffer
   'g',
   'l',
   'S',
   'e',
   'l',
   'e',
   'c',
   't',
   'P',
   'e',
   'r',
   'f',
   'M',
   'o',
   'n',
   'i',
   't',
   'o',
   'r',
   'C',
   'o',
   'u',
   'n',
   't',
   'e',
   'r',
   's',
   'A',
   'M',
   'D',
   0, // glSelectPerfMonitorCountersAMD
   'g',
   'l',
   'S',
   'e',
   'm',
   'a',
   'p',
   'h',
   'o',
   'r',
   'e',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'u',
   'i',
   '6',
   '4',
   'v',
   'E',
   'X',
   'T',
   0, // glSemaphoreParameterui64vEXT
   'g',
   'l',
   'S',
   'e',
   'p',
   'a',
   'r',
   'a',
   'b',
   'l',
   'e',
   'F',
   'i',
   'l',
   't',
   'e',
   'r',
   '2',
   'D',
   0, // glSeparableFilter2D
   'g',
   'l',
   'S',
   'e',
   'p',
   'a',
   'r',
   'a',
   'b',
   'l',
   'e',
   'F',
   'i',
   'l',
   't',
   'e',
   'r',
   '2',
   'D',
   'E',
   'X',
   'T',
   0, // glSeparableFilter2DEXT
   'g',
   'l',
   'S',
   'e',
   't',
   'F',
   'e',
   'n',
   'c',
   'e',
   'A',
   'P',
   'P',
   'L',
   'E',
   0, // glSetFenceAPPLE
   'g',
   'l',
   'S',
   'e',
   't',
   'F',
   'e',
   'n',
   'c',
   'e',
   'N',
   'V',
   0, // glSetFenceNV
   'g',
   'l',
   'S',
   'e',
   't',
   'F',
   'r',
   'a',
   'g',
   'm',
   'e',
   'n',
   't',
   'S',
   'h',
   'a',
   'd',
   'e',
   'r',
   'C',
   'o',
   'n',
   's',
   't',
   'a',
   'n',
   't',
   'A',
   'T',
   'I',
   0, // glSetFragmentShaderConstantATI
   'g',
   'l',
   'S',
   'e',
   't',
   'I',
   'n',
   'v',
   'a',
   'r',
   'i',
   'a',
   'n',
   't',
   'E',
   'X',
   'T',
   0, // glSetInvariantEXT
   'g',
   'l',
   'S',
   'e',
   't',
   'L',
   'o',
   'c',
   'a',
   'l',
   'C',
   'o',
   'n',
   's',
   't',
   'a',
   'n',
   't',
   'E',
   'X',
   'T',
   0, // glSetLocalConstantEXT
   'g',
   'l',
   'S',
   'e',
   't',
   'M',
   'u',
   'l',
   't',
   'i',
   's',
   'a',
   'm',
   'p',
   'l',
   'e',
   'f',
   'v',
   'A',
   'M',
   'D',
   0, // glSetMultisamplefvAMD
   'g',
   'l',
   'S',
   'h',
   'a',
   'd',
   'e',
   'M',
   'o',
   'd',
   'e',
   'l',
   0, // glShadeModel
   'g',
   'l',
   'S',
   'h',
   'a',
   'd',
   'e',
   'r',
   'B',
   'i',
   'n',
   'a',
   'r',
   'y',
   0, // glShaderBinary
   'g',
   'l',
   'S',
   'h',
   'a',
   'd',
   'e',
   'r',
   'O',
   'p',
   '1',
   'E',
   'X',
   'T',
   0, // glShaderOp1EXT
   'g',
   'l',
   'S',
   'h',
   'a',
   'd',
   'e',
   'r',
   'O',
   'p',
   '2',
   'E',
   'X',
   'T',
   0, // glShaderOp2EXT
   'g',
   'l',
   'S',
   'h',
   'a',
   'd',
   'e',
   'r',
   'O',
   'p',
   '3',
   'E',
   'X',
   'T',
   0, // glShaderOp3EXT
   'g',
   'l',
   'S',
   'h',
   'a',
   'd',
   'e',
   'r',
   'S',
   'o',
   'u',
   'r',
   'c',
   'e',
   0, // glShaderSource
   'g',
   'l',
   'S',
   'h',
   'a',
   'd',
   'e',
   'r',
   'S',
   'o',
   'u',
   'r',
   'c',
   'e',
   'A',
   'R',
   'B',
   0, // glShaderSourceARB
   'g',
   'l',
   'S',
   'h',
   'a',
   'd',
   'e',
   'r',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   'B',
   'l',
   'o',
   'c',
   'k',
   'B',
   'i',
   'n',
   'd',
   'i',
   'n',
   'g',
   0, // glShaderStorageBlockBinding
   'g',
   'l',
   'S',
   'h',
   'a',
   'd',
   'i',
   'n',
   'g',
   'R',
   'a',
   't',
   'e',
   'I',
   'm',
   'a',
   'g',
   'e',
   'B',
   'a',
   'r',
   'r',
   'i',
   'e',
   'r',
   'N',
   'V',
   0, // glShadingRateImageBarrierNV
   'g',
   'l',
   'S',
   'h',
   'a',
   'd',
   'i',
   'n',
   'g',
   'R',
   'a',
   't',
   'e',
   'I',
   'm',
   'a',
   'g',
   'e',
   'P',
   'a',
   'l',
   'e',
   't',
   't',
   'e',
   'N',
   'V',
   0, // glShadingRateImagePaletteNV
   'g',
   'l',
   'S',
   'h',
   'a',
   'd',
   'i',
   'n',
   'g',
   'R',
   'a',
   't',
   'e',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'O',
   'r',
   'd',
   'e',
   'r',
   'C',
   'u',
   's',
   't',
   'o',
   'm',
   'N',
   'V',
   0, // glShadingRateSampleOrderCustomNV
   'g',
   'l',
   'S',
   'h',
   'a',
   'd',
   'i',
   'n',
   'g',
   'R',
   'a',
   't',
   'e',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'O',
   'r',
   'd',
   'e',
   'r',
   'N',
   'V',
   0, // glShadingRateSampleOrderNV
   'g',
   'l',
   'S',
   'h',
   'a',
   'r',
   'p',
   'e',
   'n',
   'T',
   'e',
   'x',
   'F',
   'u',
   'n',
   'c',
   'S',
   'G',
   'I',
   'S',
   0, // glSharpenTexFuncSGIS
   'g',
   'l',
   'S',
   'i',
   'g',
   'n',
   'a',
   'l',
   'S',
   'e',
   'm',
   'a',
   'p',
   'h',
   'o',
   'r',
   'e',
   'E',
   'X',
   'T',
   0, // glSignalSemaphoreEXT
   'g',
   'l',
   'S',
   'i',
   'g',
   'n',
   'a',
   'l',
   'S',
   'e',
   'm',
   'a',
   'p',
   'h',
   'o',
   'r',
   'e',
   'u',
   'i',
   '6',
   '4',
   'N',
   'V',
   'X',
   0, // glSignalSemaphoreui64NVX
   'g',
   'l',
   'S',
   'i',
   'g',
   'n',
   'a',
   'l',
   'V',
   'k',
   'F',
   'e',
   'n',
   'c',
   'e',
   'N',
   'V',
   0, // glSignalVkFenceNV
   'g',
   'l',
   'S',
   'i',
   'g',
   'n',
   'a',
   'l',
   'V',
   'k',
   'S',
   'e',
   'm',
   'a',
   'p',
   'h',
   'o',
   'r',
   'e',
   'N',
   'V',
   0, // glSignalVkSemaphoreNV
   'g',
   'l',
   'S',
   'p',
   'e',
   'c',
   'i',
   'a',
   'l',
   'i',
   'z',
   'e',
   'S',
   'h',
   'a',
   'd',
   'e',
   'r',
   0, // glSpecializeShader
   'g',
   'l',
   'S',
   'p',
   'e',
   'c',
   'i',
   'a',
   'l',
   'i',
   'z',
   'e',
   'S',
   'h',
   'a',
   'd',
   'e',
   'r',
   'A',
   'R',
   'B',
   0, // glSpecializeShaderARB
   'g',
   'l',
   'S',
   'p',
   'r',
   'i',
   't',
   'e',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'S',
   'G',
   'I',
   'X',
   0, // glSpriteParameterfSGIX
   'g',
   'l',
   'S',
   'p',
   'r',
   'i',
   't',
   'e',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   'S',
   'G',
   'I',
   'X',
   0, // glSpriteParameterfvSGIX
   'g',
   'l',
   'S',
   'p',
   'r',
   'i',
   't',
   'e',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'S',
   'G',
   'I',
   'X',
   0, // glSpriteParameteriSGIX
   'g',
   'l',
   'S',
   'p',
   'r',
   'i',
   't',
   'e',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'S',
   'G',
   'I',
   'X',
   0, // glSpriteParameterivSGIX
   'g',
   'l',
   'S',
   't',
   'a',
   'r',
   't',
   'I',
   'n',
   's',
   't',
   'r',
   'u',
   'm',
   'e',
   'n',
   't',
   's',
   'S',
   'G',
   'I',
   'X',
   0, // glStartInstrumentsSGIX
   'g',
   'l',
   'S',
   't',
   'a',
   'r',
   't',
   'T',
   'i',
   'l',
   'i',
   'n',
   'g',
   'Q',
   'C',
   'O',
   'M',
   0, // glStartTilingQCOM
   'g',
   'l',
   'S',
   't',
   'a',
   't',
   'e',
   'C',
   'a',
   'p',
   't',
   'u',
   'r',
   'e',
   'N',
   'V',
   0, // glStateCaptureNV
   'g',
   'l',
   'S',
   't',
   'e',
   'n',
   'c',
   'i',
   'l',
   'C',
   'l',
   'e',
   'a',
   'r',
   'T',
   'a',
   'g',
   'E',
   'X',
   'T',
   0, // glStencilClearTagEXT
   'g',
   'l',
   'S',
   't',
   'e',
   'n',
   'c',
   'i',
   'l',
   'F',
   'i',
   'l',
   'l',
   'P',
   'a',
   't',
   'h',
   'I',
   'n',
   's',
   't',
   'a',
   'n',
   'c',
   'e',
   'd',
   'N',
   'V',
   0, // glStencilFillPathInstancedNV
   'g',
   'l',
   'S',
   't',
   'e',
   'n',
   'c',
   'i',
   'l',
   'F',
   'i',
   'l',
   'l',
   'P',
   'a',
   't',
   'h',
   'N',
   'V',
   0, // glStencilFillPathNV
   'g',
   'l',
   'S',
   't',
   'e',
   'n',
   'c',
   'i',
   'l',
   'F',
   'u',
   'n',
   'c',
   0, // glStencilFunc
   'g',
   'l',
   'S',
   't',
   'e',
   'n',
   'c',
   'i',
   'l',
   'F',
   'u',
   'n',
   'c',
   'S',
   'e',
   'p',
   'a',
   'r',
   'a',
   't',
   'e',
   0, // glStencilFuncSeparate
   'g',
   'l',
   'S',
   't',
   'e',
   'n',
   'c',
   'i',
   'l',
   'F',
   'u',
   'n',
   'c',
   'S',
   'e',
   'p',
   'a',
   'r',
   'a',
   't',
   'e',
   'A',
   'T',
   'I',
   0, // glStencilFuncSeparateATI
   'g',
   'l',
   'S',
   't',
   'e',
   'n',
   'c',
   'i',
   'l',
   'M',
   'a',
   's',
   'k',
   0, // glStencilMask
   'g',
   'l',
   'S',
   't',
   'e',
   'n',
   'c',
   'i',
   'l',
   'M',
   'a',
   's',
   'k',
   'S',
   'e',
   'p',
   'a',
   'r',
   'a',
   't',
   'e',
   0, // glStencilMaskSeparate
   'g',
   'l',
   'S',
   't',
   'e',
   'n',
   'c',
   'i',
   'l',
   'O',
   'p',
   0, // glStencilOp
   'g',
   'l',
   'S',
   't',
   'e',
   'n',
   'c',
   'i',
   'l',
   'O',
   'p',
   'S',
   'e',
   'p',
   'a',
   'r',
   'a',
   't',
   'e',
   0, // glStencilOpSeparate
   'g',
   'l',
   'S',
   't',
   'e',
   'n',
   'c',
   'i',
   'l',
   'O',
   'p',
   'S',
   'e',
   'p',
   'a',
   'r',
   'a',
   't',
   'e',
   'A',
   'T',
   'I',
   0, // glStencilOpSeparateATI
   'g',
   'l',
   'S',
   't',
   'e',
   'n',
   'c',
   'i',
   'l',
   'O',
   'p',
   'V',
   'a',
   'l',
   'u',
   'e',
   'A',
   'M',
   'D',
   0, // glStencilOpValueAMD
   'g',
   'l',
   'S',
   't',
   'e',
   'n',
   'c',
   'i',
   'l',
   'S',
   't',
   'r',
   'o',
   'k',
   'e',
   'P',
   'a',
   't',
   'h',
   'I',
   'n',
   's',
   't',
   'a',
   'n',
   'c',
   'e',
   'd',
   'N',
   'V',
   0, // glStencilStrokePathInstancedNV
   'g',
   'l',
   'S',
   't',
   'e',
   'n',
   'c',
   'i',
   'l',
   'S',
   't',
   'r',
   'o',
   'k',
   'e',
   'P',
   'a',
   't',
   'h',
   'N',
   'V',
   0, // glStencilStrokePathNV
   'g',
   'l',
   'S',
   't',
   'e',
   'n',
   'c',
   'i',
   'l',
   'T',
   'h',
   'e',
   'n',
   'C',
   'o',
   'v',
   'e',
   'r',
   'F',
   'i',
   'l',
   'l',
   'P',
   'a',
   't',
   'h',
   'I',
   'n',
   's',
   't',
   'a',
   'n',
   'c',
   'e',
   'd',
   'N',
   'V',
   0, // glStencilThenCoverFillPathInstancedNV
   'g',
   'l',
   'S',
   't',
   'e',
   'n',
   'c',
   'i',
   'l',
   'T',
   'h',
   'e',
   'n',
   'C',
   'o',
   'v',
   'e',
   'r',
   'F',
   'i',
   'l',
   'l',
   'P',
   'a',
   't',
   'h',
   'N',
   'V',
   0, // glStencilThenCoverFillPathNV
   'g',
   'l',
   'S',
   't',
   'e',
   'n',
   'c',
   'i',
   'l',
   'T',
   'h',
   'e',
   'n',
   'C',
   'o',
   'v',
   'e',
   'r',
   'S',
   't',
   'r',
   'o',
   'k',
   'e',
   'P',
   'a',
   't',
   'h',
   'I',
   'n',
   's',
   't',
   'a',
   'n',
   'c',
   'e',
   'd',
   'N',
   'V',
   0, // glStencilThenCoverStrokePathInstancedNV
   'g',
   'l',
   'S',
   't',
   'e',
   'n',
   'c',
   'i',
   'l',
   'T',
   'h',
   'e',
   'n',
   'C',
   'o',
   'v',
   'e',
   'r',
   'S',
   't',
   'r',
   'o',
   'k',
   'e',
   'P',
   'a',
   't',
   'h',
   'N',
   'V',
   0, // glStencilThenCoverStrokePathNV
   'g',
   'l',
   'S',
   't',
   'o',
   'p',
   'I',
   'n',
   's',
   't',
   'r',
   'u',
   'm',
   'e',
   'n',
   't',
   's',
   'S',
   'G',
   'I',
   'X',
   0, // glStopInstrumentsSGIX
   'g',
   'l',
   'S',
   't',
   'r',
   'i',
   'n',
   'g',
   'M',
   'a',
   'r',
   'k',
   'e',
   'r',
   'G',
   'R',
   'E',
   'M',
   'E',
   'D',
   'Y',
   0, // glStringMarkerGREMEDY
   'g',
   'l',
   'S',
   'u',
   'b',
   'p',
   'i',
   'x',
   'e',
   'l',
   'P',
   'r',
   'e',
   'c',
   'i',
   's',
   'i',
   'o',
   'n',
   'B',
   'i',
   'a',
   's',
   'N',
   'V',
   0, // glSubpixelPrecisionBiasNV
   'g',
   'l',
   'S',
   'w',
   'i',
   'z',
   'z',
   'l',
   'e',
   'E',
   'X',
   'T',
   0, // glSwizzleEXT
   'g',
   'l',
   'S',
   'y',
   'n',
   'c',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'I',
   'N',
   'T',
   'E',
   'L',
   0, // glSyncTextureINTEL
   'g',
   'l',
   'T',
   'a',
   'g',
   'S',
   'a',
   'm',
   'p',
   'l',
   'e',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'S',
   'G',
   'I',
   'X',
   0, // glTagSampleBufferSGIX
   'g',
   'l',
   'T',
   'a',
   'n',
   'g',
   'e',
   'n',
   't',
   '3',
   'b',
   'E',
   'X',
   'T',
   0, // glTangent3bEXT
   'g',
   'l',
   'T',
   'a',
   'n',
   'g',
   'e',
   'n',
   't',
   '3',
   'b',
   'v',
   'E',
   'X',
   'T',
   0, // glTangent3bvEXT
   'g',
   'l',
   'T',
   'a',
   'n',
   'g',
   'e',
   'n',
   't',
   '3',
   'd',
   'E',
   'X',
   'T',
   0, // glTangent3dEXT
   'g',
   'l',
   'T',
   'a',
   'n',
   'g',
   'e',
   'n',
   't',
   '3',
   'd',
   'v',
   'E',
   'X',
   'T',
   0, // glTangent3dvEXT
   'g',
   'l',
   'T',
   'a',
   'n',
   'g',
   'e',
   'n',
   't',
   '3',
   'f',
   'E',
   'X',
   'T',
   0, // glTangent3fEXT
   'g',
   'l',
   'T',
   'a',
   'n',
   'g',
   'e',
   'n',
   't',
   '3',
   'f',
   'v',
   'E',
   'X',
   'T',
   0, // glTangent3fvEXT
   'g',
   'l',
   'T',
   'a',
   'n',
   'g',
   'e',
   'n',
   't',
   '3',
   'i',
   'E',
   'X',
   'T',
   0, // glTangent3iEXT
   'g',
   'l',
   'T',
   'a',
   'n',
   'g',
   'e',
   'n',
   't',
   '3',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glTangent3ivEXT
   'g',
   'l',
   'T',
   'a',
   'n',
   'g',
   'e',
   'n',
   't',
   '3',
   's',
   'E',
   'X',
   'T',
   0, // glTangent3sEXT
   'g',
   'l',
   'T',
   'a',
   'n',
   'g',
   'e',
   'n',
   't',
   '3',
   's',
   'v',
   'E',
   'X',
   'T',
   0, // glTangent3svEXT
   'g',
   'l',
   'T',
   'a',
   'n',
   'g',
   'e',
   'n',
   't',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glTangentPointerEXT
   'g',
   'l',
   'T',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'M',
   'a',
   's',
   'k',
   '3',
   'D',
   'F',
   'X',
   0, // glTbufferMask3DFX
   'g',
   'l',
   'T',
   'e',
   's',
   's',
   'e',
   'l',
   'l',
   'a',
   't',
   'i',
   'o',
   'n',
   'F',
   'a',
   'c',
   't',
   'o',
   'r',
   'A',
   'M',
   'D',
   0, // glTessellationFactorAMD
   'g',
   'l',
   'T',
   'e',
   's',
   's',
   'e',
   'l',
   'l',
   'a',
   't',
   'i',
   'o',
   'n',
   'M',
   'o',
   'd',
   'e',
   'A',
   'M',
   'D',
   0, // glTessellationModeAMD
   'g',
   'l',
   'T',
   'e',
   's',
   't',
   'F',
   'e',
   'n',
   'c',
   'e',
   'A',
   'P',
   'P',
   'L',
   'E',
   0, // glTestFenceAPPLE
   'g',
   'l',
   'T',
   'e',
   's',
   't',
   'F',
   'e',
   'n',
   'c',
   'e',
   'N',
   'V',
   0, // glTestFenceNV
   'g',
   'l',
   'T',
   'e',
   's',
   't',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'A',
   'P',
   'P',
   'L',
   'E',
   0, // glTestObjectAPPLE
   'g',
   'l',
   'T',
   'e',
   'x',
   'A',
   't',
   't',
   'a',
   'c',
   'h',
   'M',
   'e',
   'm',
   'o',
   'r',
   'y',
   'N',
   'V',
   0, // glTexAttachMemoryNV
   'g',
   'l',
   'T',
   'e',
   'x',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   0, // glTexBuffer
   'g',
   'l',
   'T',
   'e',
   'x',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'A',
   'R',
   'B',
   0, // glTexBufferARB
   'g',
   'l',
   'T',
   'e',
   'x',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glTexBufferEXT
   'g',
   'l',
   'T',
   'e',
   'x',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'O',
   'E',
   'S',
   0, // glTexBufferOES
   'g',
   'l',
   'T',
   'e',
   'x',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'R',
   'a',
   'n',
   'g',
   'e',
   0, // glTexBufferRange
   'g',
   'l',
   'T',
   'e',
   'x',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'R',
   'a',
   'n',
   'g',
   'e',
   'E',
   'X',
   'T',
   0, // glTexBufferRangeEXT
   'g',
   'l',
   'T',
   'e',
   'x',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'R',
   'a',
   'n',
   'g',
   'e',
   'O',
   'E',
   'S',
   0, // glTexBufferRangeOES
   'g',
   'l',
   'T',
   'e',
   'x',
   'B',
   'u',
   'm',
   'p',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   'A',
   'T',
   'I',
   0, // glTexBumpParameterfvATI
   'g',
   'l',
   'T',
   'e',
   'x',
   'B',
   'u',
   'm',
   'p',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'A',
   'T',
   'I',
   0, // glTexBumpParameterivATI
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '1',
   'b',
   'O',
   'E',
   'S',
   0, // glTexCoord1bOES
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '1',
   'b',
   'v',
   'O',
   'E',
   'S',
   0, // glTexCoord1bvOES
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '1',
   'd',
   0, // glTexCoord1d
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '1',
   'd',
   'v',
   0, // glTexCoord1dv
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '1',
   'f',
   0, // glTexCoord1f
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '1',
   'f',
   'v',
   0, // glTexCoord1fv
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '1',
   'h',
   'N',
   'V',
   0, // glTexCoord1hNV
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '1',
   'h',
   'v',
   'N',
   'V',
   0, // glTexCoord1hvNV
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '1',
   'i',
   0, // glTexCoord1i
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '1',
   'i',
   'v',
   0, // glTexCoord1iv
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '1',
   's',
   0, // glTexCoord1s
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '1',
   's',
   'v',
   0, // glTexCoord1sv
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '1',
   'x',
   'O',
   'E',
   'S',
   0, // glTexCoord1xOES
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '1',
   'x',
   'v',
   'O',
   'E',
   'S',
   0, // glTexCoord1xvOES
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'b',
   'O',
   'E',
   'S',
   0, // glTexCoord2bOES
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'b',
   'v',
   'O',
   'E',
   'S',
   0, // glTexCoord2bvOES
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'd',
   0, // glTexCoord2d
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'd',
   'v',
   0, // glTexCoord2dv
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'f',
   0, // glTexCoord2f
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'f',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'f',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '3',
   'f',
   'S',
   'U',
   'N',
   0, // glTexCoord2fColor3fVertex3fSUN
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'f',
   'C',
   'o',
   'l',
   'o',
   'r',
   '3',
   'f',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '3',
   'f',
   'v',
   'S',
   'U',
   'N',
   0, // glTexCoord2fColor3fVertex3fvSUN
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'f',
   'C',
   'o',
   'l',
   'o',
   'r',
   '4',
   'f',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   '3',
   'f',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '3',
   'f',
   'S',
   'U',
   'N',
   0, // glTexCoord2fColor4fNormal3fVertex3fSUN
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'f',
   'C',
   'o',
   'l',
   'o',
   'r',
   '4',
   'f',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   '3',
   'f',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '3',
   'f',
   'v',
   'S',
   'U',
   'N',
   0, // glTexCoord2fColor4fNormal3fVertex3fvSUN
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'f',
   'C',
   'o',
   'l',
   'o',
   'r',
   '4',
   'u',
   'b',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '3',
   'f',
   'S',
   'U',
   'N',
   0, // glTexCoord2fColor4ubVertex3fSUN
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'f',
   'C',
   'o',
   'l',
   'o',
   'r',
   '4',
   'u',
   'b',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '3',
   'f',
   'v',
   'S',
   'U',
   'N',
   0, // glTexCoord2fColor4ubVertex3fvSUN
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'f',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   '3',
   'f',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '3',
   'f',
   'S',
   'U',
   'N',
   0, // glTexCoord2fNormal3fVertex3fSUN
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'f',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   '3',
   'f',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '3',
   'f',
   'v',
   'S',
   'U',
   'N',
   0, // glTexCoord2fNormal3fVertex3fvSUN
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'f',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '3',
   'f',
   'S',
   'U',
   'N',
   0, // glTexCoord2fVertex3fSUN
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'f',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '3',
   'f',
   'v',
   'S',
   'U',
   'N',
   0, // glTexCoord2fVertex3fvSUN
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'f',
   'v',
   0, // glTexCoord2fv
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'h',
   'N',
   'V',
   0, // glTexCoord2hNV
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'h',
   'v',
   'N',
   'V',
   0, // glTexCoord2hvNV
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'i',
   0, // glTexCoord2i
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'i',
   'v',
   0, // glTexCoord2iv
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   's',
   0, // glTexCoord2s
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   's',
   'v',
   0, // glTexCoord2sv
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'x',
   'O',
   'E',
   'S',
   0, // glTexCoord2xOES
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '2',
   'x',
   'v',
   'O',
   'E',
   'S',
   0, // glTexCoord2xvOES
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '3',
   'b',
   'O',
   'E',
   'S',
   0, // glTexCoord3bOES
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '3',
   'b',
   'v',
   'O',
   'E',
   'S',
   0, // glTexCoord3bvOES
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '3',
   'd',
   0, // glTexCoord3d
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '3',
   'd',
   'v',
   0, // glTexCoord3dv
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '3',
   'f',
   0, // glTexCoord3f
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '3',
   'f',
   'v',
   0, // glTexCoord3fv
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '3',
   'h',
   'N',
   'V',
   0, // glTexCoord3hNV
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '3',
   'h',
   'v',
   'N',
   'V',
   0, // glTexCoord3hvNV
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '3',
   'i',
   0, // glTexCoord3i
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '3',
   'i',
   'v',
   0, // glTexCoord3iv
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '3',
   's',
   0, // glTexCoord3s
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '3',
   's',
   'v',
   0, // glTexCoord3sv
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '3',
   'x',
   'O',
   'E',
   'S',
   0, // glTexCoord3xOES
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '3',
   'x',
   'v',
   'O',
   'E',
   'S',
   0, // glTexCoord3xvOES
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '4',
   'b',
   'O',
   'E',
   'S',
   0, // glTexCoord4bOES
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '4',
   'b',
   'v',
   'O',
   'E',
   'S',
   0, // glTexCoord4bvOES
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '4',
   'd',
   0, // glTexCoord4d
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '4',
   'd',
   'v',
   0, // glTexCoord4dv
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '4',
   'f',
   0, // glTexCoord4f
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '4',
   'f',
   'C',
   'o',
   'l',
   'o',
   'r',
   '4',
   'f',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   '3',
   'f',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '4',
   'f',
   'S',
   'U',
   'N',
   0, // glTexCoord4fColor4fNormal3fVertex4fSUN
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '4',
   'f',
   'C',
   'o',
   'l',
   'o',
   'r',
   '4',
   'f',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   '3',
   'f',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '4',
   'f',
   'v',
   'S',
   'U',
   'N',
   0, // glTexCoord4fColor4fNormal3fVertex4fvSUN
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '4',
   'f',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '4',
   'f',
   'S',
   'U',
   'N',
   0, // glTexCoord4fVertex4fSUN
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '4',
   'f',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '4',
   'f',
   'v',
   'S',
   'U',
   'N',
   0, // glTexCoord4fVertex4fvSUN
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '4',
   'f',
   'v',
   0, // glTexCoord4fv
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '4',
   'h',
   'N',
   'V',
   0, // glTexCoord4hNV
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '4',
   'h',
   'v',
   'N',
   'V',
   0, // glTexCoord4hvNV
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '4',
   'i',
   0, // glTexCoord4i
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '4',
   'i',
   'v',
   0, // glTexCoord4iv
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '4',
   's',
   0, // glTexCoord4s
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '4',
   's',
   'v',
   0, // glTexCoord4sv
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '4',
   'x',
   'O',
   'E',
   'S',
   0, // glTexCoord4xOES
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   '4',
   'x',
   'v',
   'O',
   'E',
   'S',
   0, // glTexCoord4xvOES
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   'F',
   'o',
   'r',
   'm',
   'a',
   't',
   'N',
   'V',
   0, // glTexCoordFormatNV
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   'P',
   '1',
   'u',
   'i',
   0, // glTexCoordP1ui
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   'P',
   '1',
   'u',
   'i',
   'v',
   0, // glTexCoordP1uiv
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   'P',
   '2',
   'u',
   'i',
   0, // glTexCoordP2ui
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   'P',
   '2',
   'u',
   'i',
   'v',
   0, // glTexCoordP2uiv
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   'P',
   '3',
   'u',
   'i',
   0, // glTexCoordP3ui
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   'P',
   '3',
   'u',
   'i',
   'v',
   0, // glTexCoordP3uiv
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   'P',
   '4',
   'u',
   'i',
   0, // glTexCoordP4ui
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   'P',
   '4',
   'u',
   'i',
   'v',
   0, // glTexCoordP4uiv
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   0, // glTexCoordPointer
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glTexCoordPointerEXT
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'L',
   'i',
   's',
   't',
   'I',
   'B',
   'M',
   0, // glTexCoordPointerListIBM
   'g',
   'l',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'v',
   'I',
   'N',
   'T',
   'E',
   'L',
   0, // glTexCoordPointervINTEL
   'g',
   'l',
   'T',
   'e',
   'x',
   'E',
   'n',
   'v',
   'f',
   0, // glTexEnvf
   'g',
   'l',
   'T',
   'e',
   'x',
   'E',
   'n',
   'v',
   'f',
   'v',
   0, // glTexEnvfv
   'g',
   'l',
   'T',
   'e',
   'x',
   'E',
   'n',
   'v',
   'i',
   0, // glTexEnvi
   'g',
   'l',
   'T',
   'e',
   'x',
   'E',
   'n',
   'v',
   'i',
   'v',
   0, // glTexEnviv
   'g',
   'l',
   'T',
   'e',
   'x',
   'E',
   'n',
   'v',
   'x',
   0, // glTexEnvx
   'g',
   'l',
   'T',
   'e',
   'x',
   'E',
   'n',
   'v',
   'x',
   'O',
   'E',
   'S',
   0, // glTexEnvxOES
   'g',
   'l',
   'T',
   'e',
   'x',
   'E',
   'n',
   'v',
   'x',
   'v',
   0, // glTexEnvxv
   'g',
   'l',
   'T',
   'e',
   'x',
   'E',
   'n',
   'v',
   'x',
   'v',
   'O',
   'E',
   'S',
   0, // glTexEnvxvOES
   'g',
   'l',
   'T',
   'e',
   'x',
   'F',
   'i',
   'l',
   't',
   'e',
   'r',
   'F',
   'u',
   'n',
   'c',
   'S',
   'G',
   'I',
   'S',
   0, // glTexFilterFuncSGIS
   'g',
   'l',
   'T',
   'e',
   'x',
   'G',
   'e',
   'n',
   'd',
   0, // glTexGend
   'g',
   'l',
   'T',
   'e',
   'x',
   'G',
   'e',
   'n',
   'd',
   'v',
   0, // glTexGendv
   'g',
   'l',
   'T',
   'e',
   'x',
   'G',
   'e',
   'n',
   'f',
   0, // glTexGenf
   'g',
   'l',
   'T',
   'e',
   'x',
   'G',
   'e',
   'n',
   'f',
   'O',
   'E',
   'S',
   0, // glTexGenfOES
   'g',
   'l',
   'T',
   'e',
   'x',
   'G',
   'e',
   'n',
   'f',
   'v',
   0, // glTexGenfv
   'g',
   'l',
   'T',
   'e',
   'x',
   'G',
   'e',
   'n',
   'f',
   'v',
   'O',
   'E',
   'S',
   0, // glTexGenfvOES
   'g',
   'l',
   'T',
   'e',
   'x',
   'G',
   'e',
   'n',
   'i',
   0, // glTexGeni
   'g',
   'l',
   'T',
   'e',
   'x',
   'G',
   'e',
   'n',
   'i',
   'O',
   'E',
   'S',
   0, // glTexGeniOES
   'g',
   'l',
   'T',
   'e',
   'x',
   'G',
   'e',
   'n',
   'i',
   'v',
   0, // glTexGeniv
   'g',
   'l',
   'T',
   'e',
   'x',
   'G',
   'e',
   'n',
   'i',
   'v',
   'O',
   'E',
   'S',
   0, // glTexGenivOES
   'g',
   'l',
   'T',
   'e',
   'x',
   'G',
   'e',
   'n',
   'x',
   'O',
   'E',
   'S',
   0, // glTexGenxOES
   'g',
   'l',
   'T',
   'e',
   'x',
   'G',
   'e',
   'n',
   'x',
   'v',
   'O',
   'E',
   'S',
   0, // glTexGenxvOES
   'g',
   'l',
   'T',
   'e',
   'x',
   'I',
   'm',
   'a',
   'g',
   'e',
   '1',
   'D',
   0, // glTexImage1D
   'g',
   'l',
   'T',
   'e',
   'x',
   'I',
   'm',
   'a',
   'g',
   'e',
   '2',
   'D',
   0, // glTexImage2D
   'g',
   'l',
   'T',
   'e',
   'x',
   'I',
   'm',
   'a',
   'g',
   'e',
   '2',
   'D',
   'M',
   'u',
   'l',
   't',
   'i',
   's',
   'a',
   'm',
   'p',
   'l',
   'e',
   0, // glTexImage2DMultisample
   'g',
   'l',
   'T',
   'e',
   'x',
   'I',
   'm',
   'a',
   'g',
   'e',
   '2',
   'D',
   'M',
   'u',
   'l',
   't',
   'i',
   's',
   'a',
   'm',
   'p',
   'l',
   'e',
   'C',
   'o',
   'v',
   'e',
   'r',
   'a',
   'g',
   'e',
   'N',
   'V',
   0, // glTexImage2DMultisampleCoverageNV
   'g',
   'l',
   'T',
   'e',
   'x',
   'I',
   'm',
   'a',
   'g',
   'e',
   '3',
   'D',
   0, // glTexImage3D
   'g',
   'l',
   'T',
   'e',
   'x',
   'I',
   'm',
   'a',
   'g',
   'e',
   '3',
   'D',
   'E',
   'X',
   'T',
   0, // glTexImage3DEXT
   'g',
   'l',
   'T',
   'e',
   'x',
   'I',
   'm',
   'a',
   'g',
   'e',
   '3',
   'D',
   'M',
   'u',
   'l',
   't',
   'i',
   's',
   'a',
   'm',
   'p',
   'l',
   'e',
   0, // glTexImage3DMultisample
   'g',
   'l',
   'T',
   'e',
   'x',
   'I',
   'm',
   'a',
   'g',
   'e',
   '3',
   'D',
   'M',
   'u',
   'l',
   't',
   'i',
   's',
   'a',
   'm',
   'p',
   'l',
   'e',
   'C',
   'o',
   'v',
   'e',
   'r',
   'a',
   'g',
   'e',
   'N',
   'V',
   0, // glTexImage3DMultisampleCoverageNV
   'g',
   'l',
   'T',
   'e',
   'x',
   'I',
   'm',
   'a',
   'g',
   'e',
   '3',
   'D',
   'O',
   'E',
   'S',
   0, // glTexImage3DOES
   'g',
   'l',
   'T',
   'e',
   'x',
   'I',
   'm',
   'a',
   'g',
   'e',
   '4',
   'D',
   'S',
   'G',
   'I',
   'S',
   0, // glTexImage4DSGIS
   'g',
   'l',
   'T',
   'e',
   'x',
   'P',
   'a',
   'g',
   'e',
   'C',
   'o',
   'm',
   'm',
   'i',
   't',
   'm',
   'e',
   'n',
   't',
   'A',
   'R',
   'B',
   0, // glTexPageCommitmentARB
   'g',
   'l',
   'T',
   'e',
   'x',
   'P',
   'a',
   'g',
   'e',
   'C',
   'o',
   'm',
   'm',
   'i',
   't',
   'm',
   'e',
   'n',
   't',
   'E',
   'X',
   'T',
   0, // glTexPageCommitmentEXT
   'g',
   'l',
   'T',
   'e',
   'x',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   'i',
   'v',
   0, // glTexParameterIiv
   'g',
   'l',
   'T',
   'e',
   'x',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glTexParameterIivEXT
   'g',
   'l',
   'T',
   'e',
   'x',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   'i',
   'v',
   'O',
   'E',
   'S',
   0, // glTexParameterIivOES
   'g',
   'l',
   'T',
   'e',
   'x',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   'u',
   'i',
   'v',
   0, // glTexParameterIuiv
   'g',
   'l',
   'T',
   'e',
   'x',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   'u',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glTexParameterIuivEXT
   'g',
   'l',
   'T',
   'e',
   'x',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   'u',
   'i',
   'v',
   'O',
   'E',
   'S',
   0, // glTexParameterIuivOES
   'g',
   'l',
   'T',
   'e',
   'x',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   0, // glTexParameterf
   'g',
   'l',
   'T',
   'e',
   'x',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   0, // glTexParameterfv
   'g',
   'l',
   'T',
   'e',
   'x',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   0, // glTexParameteri
   'g',
   'l',
   'T',
   'e',
   'x',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   0, // glTexParameteriv
   'g',
   'l',
   'T',
   'e',
   'x',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'x',
   0, // glTexParameterx
   'g',
   'l',
   'T',
   'e',
   'x',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'x',
   'O',
   'E',
   'S',
   0, // glTexParameterxOES
   'g',
   'l',
   'T',
   'e',
   'x',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'x',
   'v',
   0, // glTexParameterxv
   'g',
   'l',
   'T',
   'e',
   'x',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'x',
   'v',
   'O',
   'E',
   'S',
   0, // glTexParameterxvOES
   'g',
   'l',
   'T',
   'e',
   'x',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'N',
   'V',
   0, // glTexRenderbufferNV
   'g',
   'l',
   'T',
   'e',
   'x',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   '1',
   'D',
   0, // glTexStorage1D
   'g',
   'l',
   'T',
   'e',
   'x',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   '1',
   'D',
   'E',
   'X',
   'T',
   0, // glTexStorage1DEXT
   'g',
   'l',
   'T',
   'e',
   'x',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   '2',
   'D',
   0, // glTexStorage2D
   'g',
   'l',
   'T',
   'e',
   'x',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   '2',
   'D',
   'E',
   'X',
   'T',
   0, // glTexStorage2DEXT
   'g',
   'l',
   'T',
   'e',
   'x',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   '2',
   'D',
   'M',
   'u',
   'l',
   't',
   'i',
   's',
   'a',
   'm',
   'p',
   'l',
   'e',
   0, // glTexStorage2DMultisample
   'g',
   'l',
   'T',
   'e',
   'x',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   '3',
   'D',
   0, // glTexStorage3D
   'g',
   'l',
   'T',
   'e',
   'x',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   '3',
   'D',
   'E',
   'X',
   'T',
   0, // glTexStorage3DEXT
   'g',
   'l',
   'T',
   'e',
   'x',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   '3',
   'D',
   'M',
   'u',
   'l',
   't',
   'i',
   's',
   'a',
   'm',
   'p',
   'l',
   'e',
   0, // glTexStorage3DMultisample
   'g',
   'l',
   'T',
   'e',
   'x',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   '3',
   'D',
   'M',
   'u',
   'l',
   't',
   'i',
   's',
   'a',
   'm',
   'p',
   'l',
   'e',
   'O',
   'E',
   'S',
   0, // glTexStorage3DMultisampleOES
   'g',
   'l',
   'T',
   'e',
   'x',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   'M',
   'e',
   'm',
   '1',
   'D',
   'E',
   'X',
   'T',
   0, // glTexStorageMem1DEXT
   'g',
   'l',
   'T',
   'e',
   'x',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   'M',
   'e',
   'm',
   '2',
   'D',
   'E',
   'X',
   'T',
   0, // glTexStorageMem2DEXT
   'g',
   'l',
   'T',
   'e',
   'x',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   'M',
   'e',
   'm',
   '2',
   'D',
   'M',
   'u',
   'l',
   't',
   'i',
   's',
   'a',
   'm',
   'p',
   'l',
   'e',
   'E',
   'X',
   'T',
   0, // glTexStorageMem2DMultisampleEXT
   'g',
   'l',
   'T',
   'e',
   'x',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   'M',
   'e',
   'm',
   '3',
   'D',
   'E',
   'X',
   'T',
   0, // glTexStorageMem3DEXT
   'g',
   'l',
   'T',
   'e',
   'x',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   'M',
   'e',
   'm',
   '3',
   'D',
   'M',
   'u',
   'l',
   't',
   'i',
   's',
   'a',
   'm',
   'p',
   'l',
   'e',
   'E',
   'X',
   'T',
   0, // glTexStorageMem3DMultisampleEXT
   'g',
   'l',
   'T',
   'e',
   'x',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   'S',
   'p',
   'a',
   'r',
   's',
   'e',
   'A',
   'M',
   'D',
   0, // glTexStorageSparseAMD
   'g',
   'l',
   'T',
   'e',
   'x',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   '1',
   'D',
   0, // glTexSubImage1D
   'g',
   'l',
   'T',
   'e',
   'x',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   '1',
   'D',
   'E',
   'X',
   'T',
   0, // glTexSubImage1DEXT
   'g',
   'l',
   'T',
   'e',
   'x',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   '2',
   'D',
   0, // glTexSubImage2D
   'g',
   'l',
   'T',
   'e',
   'x',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   '2',
   'D',
   'E',
   'X',
   'T',
   0, // glTexSubImage2DEXT
   'g',
   'l',
   'T',
   'e',
   'x',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   '3',
   'D',
   0, // glTexSubImage3D
   'g',
   'l',
   'T',
   'e',
   'x',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   '3',
   'D',
   'E',
   'X',
   'T',
   0, // glTexSubImage3DEXT
   'g',
   'l',
   'T',
   'e',
   'x',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   '3',
   'D',
   'O',
   'E',
   'S',
   0, // glTexSubImage3DOES
   'g',
   'l',
   'T',
   'e',
   'x',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   '4',
   'D',
   'S',
   'G',
   'I',
   'S',
   0, // glTexSubImage4DSGIS
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'A',
   't',
   't',
   'a',
   'c',
   'h',
   'M',
   'e',
   'm',
   'o',
   'r',
   'y',
   'N',
   'V',
   0, // glTextureAttachMemoryNV
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'B',
   'a',
   'r',
   'r',
   'i',
   'e',
   'r',
   0, // glTextureBarrier
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'B',
   'a',
   'r',
   'r',
   'i',
   'e',
   'r',
   'N',
   'V',
   0, // glTextureBarrierNV
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   0, // glTextureBuffer
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glTextureBufferEXT
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'R',
   'a',
   'n',
   'g',
   'e',
   0, // glTextureBufferRange
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'R',
   'a',
   'n',
   'g',
   'e',
   'E',
   'X',
   'T',
   0, // glTextureBufferRangeEXT
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'C',
   'o',
   'l',
   'o',
   'r',
   'M',
   'a',
   's',
   'k',
   'S',
   'G',
   'I',
   'S',
   0, // glTextureColorMaskSGIS
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'F',
   'o',
   'v',
   'e',
   'a',
   't',
   'i',
   'o',
   'n',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   's',
   'Q',
   'C',
   'O',
   'M',
   0, // glTextureFoveationParametersQCOM
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'I',
   'm',
   'a',
   'g',
   'e',
   '1',
   'D',
   'E',
   'X',
   'T',
   0, // glTextureImage1DEXT
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'I',
   'm',
   'a',
   'g',
   'e',
   '2',
   'D',
   'E',
   'X',
   'T',
   0, // glTextureImage2DEXT
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'I',
   'm',
   'a',
   'g',
   'e',
   '2',
   'D',
   'M',
   'u',
   'l',
   't',
   'i',
   's',
   'a',
   'm',
   'p',
   'l',
   'e',
   'C',
   'o',
   'v',
   'e',
   'r',
   'a',
   'g',
   'e',
   'N',
   'V',
   0, // glTextureImage2DMultisampleCoverageNV
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'I',
   'm',
   'a',
   'g',
   'e',
   '2',
   'D',
   'M',
   'u',
   'l',
   't',
   'i',
   's',
   'a',
   'm',
   'p',
   'l',
   'e',
   'N',
   'V',
   0, // glTextureImage2DMultisampleNV
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'I',
   'm',
   'a',
   'g',
   'e',
   '3',
   'D',
   'E',
   'X',
   'T',
   0, // glTextureImage3DEXT
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'I',
   'm',
   'a',
   'g',
   'e',
   '3',
   'D',
   'M',
   'u',
   'l',
   't',
   'i',
   's',
   'a',
   'm',
   'p',
   'l',
   'e',
   'C',
   'o',
   'v',
   'e',
   'r',
   'a',
   'g',
   'e',
   'N',
   'V',
   0, // glTextureImage3DMultisampleCoverageNV
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'I',
   'm',
   'a',
   'g',
   'e',
   '3',
   'D',
   'M',
   'u',
   'l',
   't',
   'i',
   's',
   'a',
   'm',
   'p',
   'l',
   'e',
   'N',
   'V',
   0, // glTextureImage3DMultisampleNV
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'L',
   'i',
   'g',
   'h',
   't',
   'E',
   'X',
   'T',
   0, // glTextureLightEXT
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'M',
   'a',
   't',
   'e',
   'r',
   'i',
   'a',
   'l',
   'E',
   'X',
   'T',
   0, // glTextureMaterialEXT
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   'E',
   'X',
   'T',
   0, // glTextureNormalEXT
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'P',
   'a',
   'g',
   'e',
   'C',
   'o',
   'm',
   'm',
   'i',
   't',
   'm',
   'e',
   'n',
   't',
   'E',
   'X',
   'T',
   0, // glTexturePageCommitmentEXT
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   'i',
   'v',
   0, // glTextureParameterIiv
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glTextureParameterIivEXT
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   'u',
   'i',
   'v',
   0, // glTextureParameterIuiv
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'I',
   'u',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glTextureParameterIuivEXT
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   0, // glTextureParameterf
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'E',
   'X',
   'T',
   0, // glTextureParameterfEXT
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   0, // glTextureParameterfv
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   'E',
   'X',
   'T',
   0, // glTextureParameterfvEXT
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   0, // glTextureParameteri
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'E',
   'X',
   'T',
   0, // glTextureParameteriEXT
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   0, // glTextureParameteriv
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glTextureParameterivEXT
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'R',
   'a',
   'n',
   'g',
   'e',
   'A',
   'P',
   'P',
   'L',
   'E',
   0, // glTextureRangeAPPLE
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'R',
   'e',
   'n',
   'd',
   'e',
   'r',
   'b',
   'u',
   'f',
   'f',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glTextureRenderbufferEXT
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   '1',
   'D',
   0, // glTextureStorage1D
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   '1',
   'D',
   'E',
   'X',
   'T',
   0, // glTextureStorage1DEXT
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   '2',
   'D',
   0, // glTextureStorage2D
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   '2',
   'D',
   'E',
   'X',
   'T',
   0, // glTextureStorage2DEXT
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   '2',
   'D',
   'M',
   'u',
   'l',
   't',
   'i',
   's',
   'a',
   'm',
   'p',
   'l',
   'e',
   0, // glTextureStorage2DMultisample
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   '2',
   'D',
   'M',
   'u',
   'l',
   't',
   'i',
   's',
   'a',
   'm',
   'p',
   'l',
   'e',
   'E',
   'X',
   'T',
   0, // glTextureStorage2DMultisampleEXT
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   '3',
   'D',
   0, // glTextureStorage3D
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   '3',
   'D',
   'E',
   'X',
   'T',
   0, // glTextureStorage3DEXT
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   '3',
   'D',
   'M',
   'u',
   'l',
   't',
   'i',
   's',
   'a',
   'm',
   'p',
   'l',
   'e',
   0, // glTextureStorage3DMultisample
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   '3',
   'D',
   'M',
   'u',
   'l',
   't',
   'i',
   's',
   'a',
   'm',
   'p',
   'l',
   'e',
   'E',
   'X',
   'T',
   0, // glTextureStorage3DMultisampleEXT
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   'M',
   'e',
   'm',
   '1',
   'D',
   'E',
   'X',
   'T',
   0, // glTextureStorageMem1DEXT
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   'M',
   'e',
   'm',
   '2',
   'D',
   'E',
   'X',
   'T',
   0, // glTextureStorageMem2DEXT
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   'M',
   'e',
   'm',
   '2',
   'D',
   'M',
   'u',
   'l',
   't',
   'i',
   's',
   'a',
   'm',
   'p',
   'l',
   'e',
   'E',
   'X',
   'T',
   0, // glTextureStorageMem2DMultisampleEXT
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   'M',
   'e',
   'm',
   '3',
   'D',
   'E',
   'X',
   'T',
   0, // glTextureStorageMem3DEXT
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   'M',
   'e',
   'm',
   '3',
   'D',
   'M',
   'u',
   'l',
   't',
   'i',
   's',
   'a',
   'm',
   'p',
   'l',
   'e',
   'E',
   'X',
   'T',
   0, // glTextureStorageMem3DMultisampleEXT
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'S',
   't',
   'o',
   'r',
   'a',
   'g',
   'e',
   'S',
   'p',
   'a',
   'r',
   's',
   'e',
   'A',
   'M',
   'D',
   0, // glTextureStorageSparseAMD
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   '1',
   'D',
   0, // glTextureSubImage1D
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   '1',
   'D',
   'E',
   'X',
   'T',
   0, // glTextureSubImage1DEXT
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   '2',
   'D',
   0, // glTextureSubImage2D
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   '2',
   'D',
   'E',
   'X',
   'T',
   0, // glTextureSubImage2DEXT
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   '3',
   'D',
   0, // glTextureSubImage3D
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'S',
   'u',
   'b',
   'I',
   'm',
   'a',
   'g',
   'e',
   '3',
   'D',
   'E',
   'X',
   'T',
   0, // glTextureSubImage3DEXT
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'V',
   'i',
   'e',
   'w',
   0, // glTextureView
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'V',
   'i',
   'e',
   'w',
   'E',
   'X',
   'T',
   0, // glTextureViewEXT
   'g',
   'l',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   'V',
   'i',
   'e',
   'w',
   'O',
   'E',
   'S',
   0, // glTextureViewOES
   'g',
   'l',
   'T',
   'r',
   'a',
   'c',
   'k',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   'N',
   'V',
   0, // glTrackMatrixNV
   'g',
   'l',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'F',
   'e',
   'e',
   'd',
   'b',
   'a',
   'c',
   'k',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   's',
   'N',
   'V',
   0, // glTransformFeedbackAttribsNV
   'g',
   'l',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'F',
   'e',
   'e',
   'd',
   'b',
   'a',
   'c',
   'k',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'B',
   'a',
   's',
   'e',
   0, // glTransformFeedbackBufferBase
   'g',
   'l',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'F',
   'e',
   'e',
   'd',
   'b',
   'a',
   'c',
   'k',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'R',
   'a',
   'n',
   'g',
   'e',
   0, // glTransformFeedbackBufferRange
   'g',
   'l',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'F',
   'e',
   'e',
   'd',
   'b',
   'a',
   'c',
   'k',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   's',
   'N',
   'V',
   0, // glTransformFeedbackStreamAttribsNV
   'g',
   'l',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'F',
   'e',
   'e',
   'd',
   'b',
   'a',
   'c',
   'k',
   'V',
   'a',
   'r',
   'y',
   'i',
   'n',
   'g',
   's',
   0, // glTransformFeedbackVaryings
   'g',
   'l',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'F',
   'e',
   'e',
   'd',
   'b',
   'a',
   'c',
   'k',
   'V',
   'a',
   'r',
   'y',
   'i',
   'n',
   'g',
   's',
   'E',
   'X',
   'T',
   0, // glTransformFeedbackVaryingsEXT
   'g',
   'l',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'F',
   'e',
   'e',
   'd',
   'b',
   'a',
   'c',
   'k',
   'V',
   'a',
   'r',
   'y',
   'i',
   'n',
   'g',
   's',
   'N',
   'V',
   0, // glTransformFeedbackVaryingsNV
   'g',
   'l',
   'T',
   'r',
   'a',
   'n',
   's',
   'f',
   'o',
   'r',
   'm',
   'P',
   'a',
   't',
   'h',
   'N',
   'V',
   0, // glTransformPathNV
   'g',
   'l',
   'T',
   'r',
   'a',
   'n',
   's',
   'l',
   'a',
   't',
   'e',
   'd',
   0, // glTranslated
   'g',
   'l',
   'T',
   'r',
   'a',
   'n',
   's',
   'l',
   'a',
   't',
   'e',
   'f',
   0, // glTranslatef
   'g',
   'l',
   'T',
   'r',
   'a',
   'n',
   's',
   'l',
   'a',
   't',
   'e',
   'x',
   0, // glTranslatex
   'g',
   'l',
   'T',
   'r',
   'a',
   'n',
   's',
   'l',
   'a',
   't',
   'e',
   'x',
   'O',
   'E',
   'S',
   0, // glTranslatexOES
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '1',
   'd',
   0, // glUniform1d
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '1',
   'd',
   'v',
   0, // glUniform1dv
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '1',
   'f',
   0, // glUniform1f
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '1',
   'f',
   'A',
   'R',
   'B',
   0, // glUniform1fARB
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '1',
   'f',
   'v',
   0, // glUniform1fv
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '1',
   'f',
   'v',
   'A',
   'R',
   'B',
   0, // glUniform1fvARB
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '1',
   'i',
   0, // glUniform1i
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '1',
   'i',
   '6',
   '4',
   'A',
   'R',
   'B',
   0, // glUniform1i64ARB
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '1',
   'i',
   '6',
   '4',
   'N',
   'V',
   0, // glUniform1i64NV
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '1',
   'i',
   '6',
   '4',
   'v',
   'A',
   'R',
   'B',
   0, // glUniform1i64vARB
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '1',
   'i',
   '6',
   '4',
   'v',
   'N',
   'V',
   0, // glUniform1i64vNV
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '1',
   'i',
   'A',
   'R',
   'B',
   0, // glUniform1iARB
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '1',
   'i',
   'v',
   0, // glUniform1iv
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '1',
   'i',
   'v',
   'A',
   'R',
   'B',
   0, // glUniform1ivARB
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '1',
   'u',
   'i',
   0, // glUniform1ui
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '1',
   'u',
   'i',
   '6',
   '4',
   'A',
   'R',
   'B',
   0, // glUniform1ui64ARB
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '1',
   'u',
   'i',
   '6',
   '4',
   'N',
   'V',
   0, // glUniform1ui64NV
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '1',
   'u',
   'i',
   '6',
   '4',
   'v',
   'A',
   'R',
   'B',
   0, // glUniform1ui64vARB
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '1',
   'u',
   'i',
   '6',
   '4',
   'v',
   'N',
   'V',
   0, // glUniform1ui64vNV
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '1',
   'u',
   'i',
   'E',
   'X',
   'T',
   0, // glUniform1uiEXT
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '1',
   'u',
   'i',
   'v',
   0, // glUniform1uiv
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '1',
   'u',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glUniform1uivEXT
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '2',
   'd',
   0, // glUniform2d
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '2',
   'd',
   'v',
   0, // glUniform2dv
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '2',
   'f',
   0, // glUniform2f
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '2',
   'f',
   'A',
   'R',
   'B',
   0, // glUniform2fARB
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '2',
   'f',
   'v',
   0, // glUniform2fv
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '2',
   'f',
   'v',
   'A',
   'R',
   'B',
   0, // glUniform2fvARB
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '2',
   'i',
   0, // glUniform2i
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '2',
   'i',
   '6',
   '4',
   'A',
   'R',
   'B',
   0, // glUniform2i64ARB
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '2',
   'i',
   '6',
   '4',
   'N',
   'V',
   0, // glUniform2i64NV
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '2',
   'i',
   '6',
   '4',
   'v',
   'A',
   'R',
   'B',
   0, // glUniform2i64vARB
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '2',
   'i',
   '6',
   '4',
   'v',
   'N',
   'V',
   0, // glUniform2i64vNV
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '2',
   'i',
   'A',
   'R',
   'B',
   0, // glUniform2iARB
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '2',
   'i',
   'v',
   0, // glUniform2iv
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '2',
   'i',
   'v',
   'A',
   'R',
   'B',
   0, // glUniform2ivARB
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '2',
   'u',
   'i',
   0, // glUniform2ui
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '2',
   'u',
   'i',
   '6',
   '4',
   'A',
   'R',
   'B',
   0, // glUniform2ui64ARB
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '2',
   'u',
   'i',
   '6',
   '4',
   'N',
   'V',
   0, // glUniform2ui64NV
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '2',
   'u',
   'i',
   '6',
   '4',
   'v',
   'A',
   'R',
   'B',
   0, // glUniform2ui64vARB
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '2',
   'u',
   'i',
   '6',
   '4',
   'v',
   'N',
   'V',
   0, // glUniform2ui64vNV
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '2',
   'u',
   'i',
   'E',
   'X',
   'T',
   0, // glUniform2uiEXT
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '2',
   'u',
   'i',
   'v',
   0, // glUniform2uiv
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '2',
   'u',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glUniform2uivEXT
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '3',
   'd',
   0, // glUniform3d
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '3',
   'd',
   'v',
   0, // glUniform3dv
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '3',
   'f',
   0, // glUniform3f
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '3',
   'f',
   'A',
   'R',
   'B',
   0, // glUniform3fARB
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '3',
   'f',
   'v',
   0, // glUniform3fv
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '3',
   'f',
   'v',
   'A',
   'R',
   'B',
   0, // glUniform3fvARB
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '3',
   'i',
   0, // glUniform3i
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '3',
   'i',
   '6',
   '4',
   'A',
   'R',
   'B',
   0, // glUniform3i64ARB
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '3',
   'i',
   '6',
   '4',
   'N',
   'V',
   0, // glUniform3i64NV
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '3',
   'i',
   '6',
   '4',
   'v',
   'A',
   'R',
   'B',
   0, // glUniform3i64vARB
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '3',
   'i',
   '6',
   '4',
   'v',
   'N',
   'V',
   0, // glUniform3i64vNV
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '3',
   'i',
   'A',
   'R',
   'B',
   0, // glUniform3iARB
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '3',
   'i',
   'v',
   0, // glUniform3iv
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '3',
   'i',
   'v',
   'A',
   'R',
   'B',
   0, // glUniform3ivARB
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '3',
   'u',
   'i',
   0, // glUniform3ui
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '3',
   'u',
   'i',
   '6',
   '4',
   'A',
   'R',
   'B',
   0, // glUniform3ui64ARB
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '3',
   'u',
   'i',
   '6',
   '4',
   'N',
   'V',
   0, // glUniform3ui64NV
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '3',
   'u',
   'i',
   '6',
   '4',
   'v',
   'A',
   'R',
   'B',
   0, // glUniform3ui64vARB
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '3',
   'u',
   'i',
   '6',
   '4',
   'v',
   'N',
   'V',
   0, // glUniform3ui64vNV
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '3',
   'u',
   'i',
   'E',
   'X',
   'T',
   0, // glUniform3uiEXT
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '3',
   'u',
   'i',
   'v',
   0, // glUniform3uiv
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '3',
   'u',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glUniform3uivEXT
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '4',
   'd',
   0, // glUniform4d
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '4',
   'd',
   'v',
   0, // glUniform4dv
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '4',
   'f',
   0, // glUniform4f
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '4',
   'f',
   'A',
   'R',
   'B',
   0, // glUniform4fARB
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '4',
   'f',
   'v',
   0, // glUniform4fv
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '4',
   'f',
   'v',
   'A',
   'R',
   'B',
   0, // glUniform4fvARB
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '4',
   'i',
   0, // glUniform4i
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '4',
   'i',
   '6',
   '4',
   'A',
   'R',
   'B',
   0, // glUniform4i64ARB
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '4',
   'i',
   '6',
   '4',
   'N',
   'V',
   0, // glUniform4i64NV
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '4',
   'i',
   '6',
   '4',
   'v',
   'A',
   'R',
   'B',
   0, // glUniform4i64vARB
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '4',
   'i',
   '6',
   '4',
   'v',
   'N',
   'V',
   0, // glUniform4i64vNV
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '4',
   'i',
   'A',
   'R',
   'B',
   0, // glUniform4iARB
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '4',
   'i',
   'v',
   0, // glUniform4iv
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '4',
   'i',
   'v',
   'A',
   'R',
   'B',
   0, // glUniform4ivARB
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '4',
   'u',
   'i',
   0, // glUniform4ui
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '4',
   'u',
   'i',
   '6',
   '4',
   'A',
   'R',
   'B',
   0, // glUniform4ui64ARB
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '4',
   'u',
   'i',
   '6',
   '4',
   'N',
   'V',
   0, // glUniform4ui64NV
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '4',
   'u',
   'i',
   '6',
   '4',
   'v',
   'A',
   'R',
   'B',
   0, // glUniform4ui64vARB
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '4',
   'u',
   'i',
   '6',
   '4',
   'v',
   'N',
   'V',
   0, // glUniform4ui64vNV
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '4',
   'u',
   'i',
   'E',
   'X',
   'T',
   0, // glUniform4uiEXT
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '4',
   'u',
   'i',
   'v',
   0, // glUniform4uiv
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   '4',
   'u',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glUniform4uivEXT
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'B',
   'l',
   'o',
   'c',
   'k',
   'B',
   'i',
   'n',
   'd',
   'i',
   'n',
   'g',
   0, // glUniformBlockBinding
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glUniformBufferEXT
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'H',
   'a',
   'n',
   'd',
   'l',
   'e',
   'u',
   'i',
   '6',
   '4',
   'A',
   'R',
   'B',
   0, // glUniformHandleui64ARB
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'H',
   'a',
   'n',
   'd',
   'l',
   'e',
   'u',
   'i',
   '6',
   '4',
   'I',
   'M',
   'G',
   0, // glUniformHandleui64IMG
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'H',
   'a',
   'n',
   'd',
   'l',
   'e',
   'u',
   'i',
   '6',
   '4',
   'N',
   'V',
   0, // glUniformHandleui64NV
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'H',
   'a',
   'n',
   'd',
   'l',
   'e',
   'u',
   'i',
   '6',
   '4',
   'v',
   'A',
   'R',
   'B',
   0, // glUniformHandleui64vARB
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'H',
   'a',
   'n',
   'd',
   'l',
   'e',
   'u',
   'i',
   '6',
   '4',
   'v',
   'I',
   'M',
   'G',
   0, // glUniformHandleui64vIMG
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'H',
   'a',
   'n',
   'd',
   'l',
   'e',
   'u',
   'i',
   '6',
   '4',
   'v',
   'N',
   'V',
   0, // glUniformHandleui64vNV
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '2',
   'd',
   'v',
   0, // glUniformMatrix2dv
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '2',
   'f',
   'v',
   0, // glUniformMatrix2fv
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '2',
   'f',
   'v',
   'A',
   'R',
   'B',
   0, // glUniformMatrix2fvARB
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '2',
   'x',
   '3',
   'd',
   'v',
   0, // glUniformMatrix2x3dv
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '2',
   'x',
   '3',
   'f',
   'v',
   0, // glUniformMatrix2x3fv
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '2',
   'x',
   '3',
   'f',
   'v',
   'N',
   'V',
   0, // glUniformMatrix2x3fvNV
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '2',
   'x',
   '4',
   'd',
   'v',
   0, // glUniformMatrix2x4dv
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '2',
   'x',
   '4',
   'f',
   'v',
   0, // glUniformMatrix2x4fv
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '2',
   'x',
   '4',
   'f',
   'v',
   'N',
   'V',
   0, // glUniformMatrix2x4fvNV
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '3',
   'd',
   'v',
   0, // glUniformMatrix3dv
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '3',
   'f',
   'v',
   0, // glUniformMatrix3fv
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '3',
   'f',
   'v',
   'A',
   'R',
   'B',
   0, // glUniformMatrix3fvARB
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '3',
   'x',
   '2',
   'd',
   'v',
   0, // glUniformMatrix3x2dv
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '3',
   'x',
   '2',
   'f',
   'v',
   0, // glUniformMatrix3x2fv
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '3',
   'x',
   '2',
   'f',
   'v',
   'N',
   'V',
   0, // glUniformMatrix3x2fvNV
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '3',
   'x',
   '4',
   'd',
   'v',
   0, // glUniformMatrix3x4dv
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '3',
   'x',
   '4',
   'f',
   'v',
   0, // glUniformMatrix3x4fv
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '3',
   'x',
   '4',
   'f',
   'v',
   'N',
   'V',
   0, // glUniformMatrix3x4fvNV
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '4',
   'd',
   'v',
   0, // glUniformMatrix4dv
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '4',
   'f',
   'v',
   0, // glUniformMatrix4fv
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '4',
   'f',
   'v',
   'A',
   'R',
   'B',
   0, // glUniformMatrix4fvARB
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '4',
   'x',
   '2',
   'd',
   'v',
   0, // glUniformMatrix4x2dv
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '4',
   'x',
   '2',
   'f',
   'v',
   0, // glUniformMatrix4x2fv
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '4',
   'x',
   '2',
   'f',
   'v',
   'N',
   'V',
   0, // glUniformMatrix4x2fvNV
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '4',
   'x',
   '3',
   'd',
   'v',
   0, // glUniformMatrix4x3dv
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '4',
   'x',
   '3',
   'f',
   'v',
   0, // glUniformMatrix4x3fv
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'M',
   'a',
   't',
   'r',
   'i',
   'x',
   '4',
   'x',
   '3',
   'f',
   'v',
   'N',
   'V',
   0, // glUniformMatrix4x3fvNV
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'S',
   'u',
   'b',
   'r',
   'o',
   'u',
   't',
   'i',
   'n',
   'e',
   's',
   'u',
   'i',
   'v',
   0, // glUniformSubroutinesuiv
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'u',
   'i',
   '6',
   '4',
   'N',
   'V',
   0, // glUniformui64NV
   'g',
   'l',
   'U',
   'n',
   'i',
   'f',
   'o',
   'r',
   'm',
   'u',
   'i',
   '6',
   '4',
   'v',
   'N',
   'V',
   0, // glUniformui64vNV
   'g',
   'l',
   'U',
   'n',
   'l',
   'o',
   'c',
   'k',
   'A',
   'r',
   'r',
   'a',
   'y',
   's',
   'E',
   'X',
   'T',
   0, // glUnlockArraysEXT
   'g',
   'l',
   'U',
   'n',
   'm',
   'a',
   'p',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   0, // glUnmapBuffer
   'g',
   'l',
   'U',
   'n',
   'm',
   'a',
   'p',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'A',
   'R',
   'B',
   0, // glUnmapBufferARB
   'g',
   'l',
   'U',
   'n',
   'm',
   'a',
   'p',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'O',
   'E',
   'S',
   0, // glUnmapBufferOES
   'g',
   'l',
   'U',
   'n',
   'm',
   'a',
   'p',
   'N',
   'a',
   'm',
   'e',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   0, // glUnmapNamedBuffer
   'g',
   'l',
   'U',
   'n',
   'm',
   'a',
   'p',
   'N',
   'a',
   'm',
   'e',
   'd',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glUnmapNamedBufferEXT
   'g',
   'l',
   'U',
   'n',
   'm',
   'a',
   'p',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'A',
   'T',
   'I',
   0, // glUnmapObjectBufferATI
   'g',
   'l',
   'U',
   'n',
   'm',
   'a',
   'p',
   'T',
   'e',
   'x',
   't',
   'u',
   'r',
   'e',
   '2',
   'D',
   'I',
   'N',
   'T',
   'E',
   'L',
   0, // glUnmapTexture2DINTEL
   'g',
   'l',
   'U',
   'p',
   'd',
   'a',
   't',
   'e',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'A',
   'T',
   'I',
   0, // glUpdateObjectBufferATI
   'g',
   'l',
   'U',
   'p',
   'l',
   'o',
   'a',
   'd',
   'G',
   'p',
   'u',
   'M',
   'a',
   's',
   'k',
   'N',
   'V',
   'X',
   0, // glUploadGpuMaskNVX
   'g',
   'l',
   'U',
   's',
   'e',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   0, // glUseProgram
   'g',
   'l',
   'U',
   's',
   'e',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'A',
   'R',
   'B',
   0, // glUseProgramObjectARB
   'g',
   'l',
   'U',
   's',
   'e',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'S',
   't',
   'a',
   'g',
   'e',
   's',
   0, // glUseProgramStages
   'g',
   'l',
   'U',
   's',
   'e',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'S',
   't',
   'a',
   'g',
   'e',
   's',
   'E',
   'X',
   'T',
   0, // glUseProgramStagesEXT
   'g',
   'l',
   'U',
   's',
   'e',
   'S',
   'h',
   'a',
   'd',
   'e',
   'r',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'E',
   'X',
   'T',
   0, // glUseShaderProgramEXT
   'g',
   'l',
   'V',
   'D',
   'P',
   'A',
   'U',
   'F',
   'i',
   'n',
   'i',
   'N',
   'V',
   0, // glVDPAUFiniNV
   'g',
   'l',
   'V',
   'D',
   'P',
   'A',
   'U',
   'G',
   'e',
   't',
   'S',
   'u',
   'r',
   'f',
   'a',
   'c',
   'e',
   'i',
   'v',
   'N',
   'V',
   0, // glVDPAUGetSurfaceivNV
   'g',
   'l',
   'V',
   'D',
   'P',
   'A',
   'U',
   'I',
   'n',
   'i',
   't',
   'N',
   'V',
   0, // glVDPAUInitNV
   'g',
   'l',
   'V',
   'D',
   'P',
   'A',
   'U',
   'I',
   's',
   'S',
   'u',
   'r',
   'f',
   'a',
   'c',
   'e',
   'N',
   'V',
   0, // glVDPAUIsSurfaceNV
   'g',
   'l',
   'V',
   'D',
   'P',
   'A',
   'U',
   'M',
   'a',
   'p',
   'S',
   'u',
   'r',
   'f',
   'a',
   'c',
   'e',
   's',
   'N',
   'V',
   0, // glVDPAUMapSurfacesNV
   'g',
   'l',
   'V',
   'D',
   'P',
   'A',
   'U',
   'R',
   'e',
   'g',
   'i',
   's',
   't',
   'e',
   'r',
   'O',
   'u',
   't',
   'p',
   'u',
   't',
   'S',
   'u',
   'r',
   'f',
   'a',
   'c',
   'e',
   'N',
   'V',
   0, // glVDPAURegisterOutputSurfaceNV
   'g',
   'l',
   'V',
   'D',
   'P',
   'A',
   'U',
   'R',
   'e',
   'g',
   'i',
   's',
   't',
   'e',
   'r',
   'V',
   'i',
   'd',
   'e',
   'o',
   'S',
   'u',
   'r',
   'f',
   'a',
   'c',
   'e',
   'N',
   'V',
   0, // glVDPAURegisterVideoSurfaceNV
   'g',
   'l',
   'V',
   'D',
   'P',
   'A',
   'U',
   'R',
   'e',
   'g',
   'i',
   's',
   't',
   'e',
   'r',
   'V',
   'i',
   'd',
   'e',
   'o',
   'S',
   'u',
   'r',
   'f',
   'a',
   'c',
   'e',
   'W',
   'i',
   't',
   'h',
   'P',
   'i',
   'c',
   't',
   'u',
   'r',
   'e',
   'S',
   't',
   'r',
   'u',
   'c',
   't',
   'u',
   'r',
   'e',
   'N',
   'V',
   0, // glVDPAURegisterVideoSurfaceWithPictureStructureNV
   'g',
   'l',
   'V',
   'D',
   'P',
   'A',
   'U',
   'S',
   'u',
   'r',
   'f',
   'a',
   'c',
   'e',
   'A',
   'c',
   'c',
   'e',
   's',
   's',
   'N',
   'V',
   0, // glVDPAUSurfaceAccessNV
   'g',
   'l',
   'V',
   'D',
   'P',
   'A',
   'U',
   'U',
   'n',
   'm',
   'a',
   'p',
   'S',
   'u',
   'r',
   'f',
   'a',
   'c',
   'e',
   's',
   'N',
   'V',
   0, // glVDPAUUnmapSurfacesNV
   'g',
   'l',
   'V',
   'D',
   'P',
   'A',
   'U',
   'U',
   'n',
   'r',
   'e',
   'g',
   'i',
   's',
   't',
   'e',
   'r',
   'S',
   'u',
   'r',
   'f',
   'a',
   'c',
   'e',
   'N',
   'V',
   0, // glVDPAUUnregisterSurfaceNV
   'g',
   'l',
   'V',
   'a',
   'l',
   'i',
   'd',
   'a',
   't',
   'e',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   0, // glValidateProgram
   'g',
   'l',
   'V',
   'a',
   'l',
   'i',
   'd',
   'a',
   't',
   'e',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'A',
   'R',
   'B',
   0, // glValidateProgramARB
   'g',
   'l',
   'V',
   'a',
   'l',
   'i',
   'd',
   'a',
   't',
   'e',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'P',
   'i',
   'p',
   'e',
   'l',
   'i',
   'n',
   'e',
   0, // glValidateProgramPipeline
   'g',
   'l',
   'V',
   'a',
   'l',
   'i',
   'd',
   'a',
   't',
   'e',
   'P',
   'r',
   'o',
   'g',
   'r',
   'a',
   'm',
   'P',
   'i',
   'p',
   'e',
   'l',
   'i',
   'n',
   'e',
   'E',
   'X',
   'T',
   0, // glValidateProgramPipelineEXT
   'g',
   'l',
   'V',
   'a',
   'r',
   'i',
   'a',
   'n',
   't',
   'A',
   'r',
   'r',
   'a',
   'y',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'A',
   'T',
   'I',
   0, // glVariantArrayObjectATI
   'g',
   'l',
   'V',
   'a',
   'r',
   'i',
   'a',
   'n',
   't',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glVariantPointerEXT
   'g',
   'l',
   'V',
   'a',
   'r',
   'i',
   'a',
   'n',
   't',
   'b',
   'v',
   'E',
   'X',
   'T',
   0, // glVariantbvEXT
   'g',
   'l',
   'V',
   'a',
   'r',
   'i',
   'a',
   'n',
   't',
   'd',
   'v',
   'E',
   'X',
   'T',
   0, // glVariantdvEXT
   'g',
   'l',
   'V',
   'a',
   'r',
   'i',
   'a',
   'n',
   't',
   'f',
   'v',
   'E',
   'X',
   'T',
   0, // glVariantfvEXT
   'g',
   'l',
   'V',
   'a',
   'r',
   'i',
   'a',
   'n',
   't',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glVariantivEXT
   'g',
   'l',
   'V',
   'a',
   'r',
   'i',
   'a',
   'n',
   't',
   's',
   'v',
   'E',
   'X',
   'T',
   0, // glVariantsvEXT
   'g',
   'l',
   'V',
   'a',
   'r',
   'i',
   'a',
   'n',
   't',
   'u',
   'b',
   'v',
   'E',
   'X',
   'T',
   0, // glVariantubvEXT
   'g',
   'l',
   'V',
   'a',
   'r',
   'i',
   'a',
   'n',
   't',
   'u',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glVariantuivEXT
   'g',
   'l',
   'V',
   'a',
   'r',
   'i',
   'a',
   'n',
   't',
   'u',
   's',
   'v',
   'E',
   'X',
   'T',
   0, // glVariantusvEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '2',
   'b',
   'O',
   'E',
   'S',
   0, // glVertex2bOES
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '2',
   'b',
   'v',
   'O',
   'E',
   'S',
   0, // glVertex2bvOES
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '2',
   'd',
   0, // glVertex2d
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '2',
   'd',
   'v',
   0, // glVertex2dv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '2',
   'f',
   0, // glVertex2f
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '2',
   'f',
   'v',
   0, // glVertex2fv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '2',
   'h',
   'N',
   'V',
   0, // glVertex2hNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '2',
   'h',
   'v',
   'N',
   'V',
   0, // glVertex2hvNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '2',
   'i',
   0, // glVertex2i
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '2',
   'i',
   'v',
   0, // glVertex2iv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '2',
   's',
   0, // glVertex2s
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '2',
   's',
   'v',
   0, // glVertex2sv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '2',
   'x',
   'O',
   'E',
   'S',
   0, // glVertex2xOES
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '2',
   'x',
   'v',
   'O',
   'E',
   'S',
   0, // glVertex2xvOES
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '3',
   'b',
   'O',
   'E',
   'S',
   0, // glVertex3bOES
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '3',
   'b',
   'v',
   'O',
   'E',
   'S',
   0, // glVertex3bvOES
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '3',
   'd',
   0, // glVertex3d
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '3',
   'd',
   'v',
   0, // glVertex3dv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '3',
   'f',
   0, // glVertex3f
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '3',
   'f',
   'v',
   0, // glVertex3fv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '3',
   'h',
   'N',
   'V',
   0, // glVertex3hNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '3',
   'h',
   'v',
   'N',
   'V',
   0, // glVertex3hvNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '3',
   'i',
   0, // glVertex3i
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '3',
   'i',
   'v',
   0, // glVertex3iv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '3',
   's',
   0, // glVertex3s
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '3',
   's',
   'v',
   0, // glVertex3sv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '3',
   'x',
   'O',
   'E',
   'S',
   0, // glVertex3xOES
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '3',
   'x',
   'v',
   'O',
   'E',
   'S',
   0, // glVertex3xvOES
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '4',
   'b',
   'O',
   'E',
   'S',
   0, // glVertex4bOES
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '4',
   'b',
   'v',
   'O',
   'E',
   'S',
   0, // glVertex4bvOES
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '4',
   'd',
   0, // glVertex4d
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '4',
   'd',
   'v',
   0, // glVertex4dv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '4',
   'f',
   0, // glVertex4f
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '4',
   'f',
   'v',
   0, // glVertex4fv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '4',
   'h',
   'N',
   'V',
   0, // glVertex4hNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '4',
   'h',
   'v',
   'N',
   'V',
   0, // glVertex4hvNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '4',
   'i',
   0, // glVertex4i
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '4',
   'i',
   'v',
   0, // glVertex4iv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '4',
   's',
   0, // glVertex4s
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '4',
   's',
   'v',
   0, // glVertex4sv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '4',
   'x',
   'O',
   'E',
   'S',
   0, // glVertex4xOES
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   '4',
   'x',
   'v',
   'O',
   'E',
   'S',
   0, // glVertex4xvOES
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'B',
   'i',
   'n',
   'd',
   'i',
   'n',
   'g',
   0, // glVertexArrayAttribBinding
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'F',
   'o',
   'r',
   'm',
   'a',
   't',
   0, // glVertexArrayAttribFormat
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   'F',
   'o',
   'r',
   'm',
   'a',
   't',
   0, // glVertexArrayAttribIFormat
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'L',
   'F',
   'o',
   'r',
   'm',
   'a',
   't',
   0, // glVertexArrayAttribLFormat
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'B',
   'i',
   'n',
   'd',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glVertexArrayBindVertexBufferEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'B',
   'i',
   'n',
   'd',
   'i',
   'n',
   'g',
   'D',
   'i',
   'v',
   'i',
   's',
   'o',
   'r',
   0, // glVertexArrayBindingDivisor
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'C',
   'o',
   'l',
   'o',
   'r',
   'O',
   'f',
   'f',
   's',
   'e',
   't',
   'E',
   'X',
   'T',
   0, // glVertexArrayColorOffsetEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'E',
   'd',
   'g',
   'e',
   'F',
   'l',
   'a',
   'g',
   'O',
   'f',
   'f',
   's',
   'e',
   't',
   'E',
   'X',
   'T',
   0, // glVertexArrayEdgeFlagOffsetEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'E',
   'l',
   'e',
   'm',
   'e',
   'n',
   't',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   0, // glVertexArrayElementBuffer
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'F',
   'o',
   'g',
   'C',
   'o',
   'o',
   'r',
   'd',
   'O',
   'f',
   'f',
   's',
   'e',
   't',
   'E',
   'X',
   'T',
   0, // glVertexArrayFogCoordOffsetEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'I',
   'n',
   'd',
   'e',
   'x',
   'O',
   'f',
   'f',
   's',
   'e',
   't',
   'E',
   'X',
   'T',
   0, // glVertexArrayIndexOffsetEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'M',
   'u',
   'l',
   't',
   'i',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   'O',
   'f',
   'f',
   's',
   'e',
   't',
   'E',
   'X',
   'T',
   0, // glVertexArrayMultiTexCoordOffsetEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'N',
   'o',
   'r',
   'm',
   'a',
   'l',
   'O',
   'f',
   'f',
   's',
   'e',
   't',
   'E',
   'X',
   'T',
   0, // glVertexArrayNormalOffsetEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'A',
   'P',
   'P',
   'L',
   'E',
   0, // glVertexArrayParameteriAPPLE
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'R',
   'a',
   'n',
   'g',
   'e',
   'A',
   'P',
   'P',
   'L',
   'E',
   0, // glVertexArrayRangeAPPLE
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'R',
   'a',
   'n',
   'g',
   'e',
   'N',
   'V',
   0, // glVertexArrayRangeNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'S',
   'e',
   'c',
   'o',
   'n',
   'd',
   'a',
   'r',
   'y',
   'C',
   'o',
   'l',
   'o',
   'r',
   'O',
   'f',
   'f',
   's',
   'e',
   't',
   'E',
   'X',
   'T',
   0, // glVertexArraySecondaryColorOffsetEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'T',
   'e',
   'x',
   'C',
   'o',
   'o',
   'r',
   'd',
   'O',
   'f',
   'f',
   's',
   'e',
   't',
   'E',
   'X',
   'T',
   0, // glVertexArrayTexCoordOffsetEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'B',
   'i',
   'n',
   'd',
   'i',
   'n',
   'g',
   'E',
   'X',
   'T',
   0, // glVertexArrayVertexAttribBindingEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'D',
   'i',
   'v',
   'i',
   's',
   'o',
   'r',
   'E',
   'X',
   'T',
   0, // glVertexArrayVertexAttribDivisorEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'F',
   'o',
   'r',
   'm',
   'a',
   't',
   'E',
   'X',
   'T',
   0, // glVertexArrayVertexAttribFormatEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   'F',
   'o',
   'r',
   'm',
   'a',
   't',
   'E',
   'X',
   'T',
   0, // glVertexArrayVertexAttribIFormatEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   'O',
   'f',
   'f',
   's',
   'e',
   't',
   'E',
   'X',
   'T',
   0, // glVertexArrayVertexAttribIOffsetEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'L',
   'F',
   'o',
   'r',
   'm',
   'a',
   't',
   'E',
   'X',
   'T',
   0, // glVertexArrayVertexAttribLFormatEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'L',
   'O',
   'f',
   'f',
   's',
   'e',
   't',
   'E',
   'X',
   'T',
   0, // glVertexArrayVertexAttribLOffsetEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'O',
   'f',
   'f',
   's',
   'e',
   't',
   'E',
   'X',
   'T',
   0, // glVertexArrayVertexAttribOffsetEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'B',
   'i',
   'n',
   'd',
   'i',
   'n',
   'g',
   'D',
   'i',
   'v',
   'i',
   's',
   'o',
   'r',
   'E',
   'X',
   'T',
   0, // glVertexArrayVertexBindingDivisorEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   0, // glVertexArrayVertexBuffer
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'B',
   'u',
   'f',
   'f',
   'e',
   'r',
   's',
   0, // glVertexArrayVertexBuffers
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   'r',
   'r',
   'a',
   'y',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'O',
   'f',
   'f',
   's',
   'e',
   't',
   'E',
   'X',
   'T',
   0, // glVertexArrayVertexOffsetEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '1',
   'd',
   0, // glVertexAttrib1d
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '1',
   'd',
   'A',
   'R',
   'B',
   0, // glVertexAttrib1dARB
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '1',
   'd',
   'N',
   'V',
   0, // glVertexAttrib1dNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '1',
   'd',
   'v',
   0, // glVertexAttrib1dv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '1',
   'd',
   'v',
   'A',
   'R',
   'B',
   0, // glVertexAttrib1dvARB
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '1',
   'd',
   'v',
   'N',
   'V',
   0, // glVertexAttrib1dvNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '1',
   'f',
   0, // glVertexAttrib1f
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '1',
   'f',
   'A',
   'R',
   'B',
   0, // glVertexAttrib1fARB
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '1',
   'f',
   'N',
   'V',
   0, // glVertexAttrib1fNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '1',
   'f',
   'v',
   0, // glVertexAttrib1fv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '1',
   'f',
   'v',
   'A',
   'R',
   'B',
   0, // glVertexAttrib1fvARB
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '1',
   'f',
   'v',
   'N',
   'V',
   0, // glVertexAttrib1fvNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '1',
   'h',
   'N',
   'V',
   0, // glVertexAttrib1hNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '1',
   'h',
   'v',
   'N',
   'V',
   0, // glVertexAttrib1hvNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '1',
   's',
   0, // glVertexAttrib1s
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '1',
   's',
   'A',
   'R',
   'B',
   0, // glVertexAttrib1sARB
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '1',
   's',
   'N',
   'V',
   0, // glVertexAttrib1sNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '1',
   's',
   'v',
   0, // glVertexAttrib1sv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '1',
   's',
   'v',
   'A',
   'R',
   'B',
   0, // glVertexAttrib1svARB
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '1',
   's',
   'v',
   'N',
   'V',
   0, // glVertexAttrib1svNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '2',
   'd',
   0, // glVertexAttrib2d
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '2',
   'd',
   'A',
   'R',
   'B',
   0, // glVertexAttrib2dARB
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '2',
   'd',
   'N',
   'V',
   0, // glVertexAttrib2dNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '2',
   'd',
   'v',
   0, // glVertexAttrib2dv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '2',
   'd',
   'v',
   'A',
   'R',
   'B',
   0, // glVertexAttrib2dvARB
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '2',
   'd',
   'v',
   'N',
   'V',
   0, // glVertexAttrib2dvNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '2',
   'f',
   0, // glVertexAttrib2f
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '2',
   'f',
   'A',
   'R',
   'B',
   0, // glVertexAttrib2fARB
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '2',
   'f',
   'N',
   'V',
   0, // glVertexAttrib2fNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '2',
   'f',
   'v',
   0, // glVertexAttrib2fv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '2',
   'f',
   'v',
   'A',
   'R',
   'B',
   0, // glVertexAttrib2fvARB
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '2',
   'f',
   'v',
   'N',
   'V',
   0, // glVertexAttrib2fvNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '2',
   'h',
   'N',
   'V',
   0, // glVertexAttrib2hNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '2',
   'h',
   'v',
   'N',
   'V',
   0, // glVertexAttrib2hvNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '2',
   's',
   0, // glVertexAttrib2s
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '2',
   's',
   'A',
   'R',
   'B',
   0, // glVertexAttrib2sARB
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '2',
   's',
   'N',
   'V',
   0, // glVertexAttrib2sNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '2',
   's',
   'v',
   0, // glVertexAttrib2sv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '2',
   's',
   'v',
   'A',
   'R',
   'B',
   0, // glVertexAttrib2svARB
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '2',
   's',
   'v',
   'N',
   'V',
   0, // glVertexAttrib2svNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '3',
   'd',
   0, // glVertexAttrib3d
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '3',
   'd',
   'A',
   'R',
   'B',
   0, // glVertexAttrib3dARB
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '3',
   'd',
   'N',
   'V',
   0, // glVertexAttrib3dNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '3',
   'd',
   'v',
   0, // glVertexAttrib3dv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '3',
   'd',
   'v',
   'A',
   'R',
   'B',
   0, // glVertexAttrib3dvARB
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '3',
   'd',
   'v',
   'N',
   'V',
   0, // glVertexAttrib3dvNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '3',
   'f',
   0, // glVertexAttrib3f
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '3',
   'f',
   'A',
   'R',
   'B',
   0, // glVertexAttrib3fARB
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '3',
   'f',
   'N',
   'V',
   0, // glVertexAttrib3fNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '3',
   'f',
   'v',
   0, // glVertexAttrib3fv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '3',
   'f',
   'v',
   'A',
   'R',
   'B',
   0, // glVertexAttrib3fvARB
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '3',
   'f',
   'v',
   'N',
   'V',
   0, // glVertexAttrib3fvNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '3',
   'h',
   'N',
   'V',
   0, // glVertexAttrib3hNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '3',
   'h',
   'v',
   'N',
   'V',
   0, // glVertexAttrib3hvNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '3',
   's',
   0, // glVertexAttrib3s
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '3',
   's',
   'A',
   'R',
   'B',
   0, // glVertexAttrib3sARB
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '3',
   's',
   'N',
   'V',
   0, // glVertexAttrib3sNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '3',
   's',
   'v',
   0, // glVertexAttrib3sv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '3',
   's',
   'v',
   'A',
   'R',
   'B',
   0, // glVertexAttrib3svARB
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '3',
   's',
   'v',
   'N',
   'V',
   0, // glVertexAttrib3svNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '4',
   'N',
   'b',
   'v',
   0, // glVertexAttrib4Nbv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '4',
   'N',
   'b',
   'v',
   'A',
   'R',
   'B',
   0, // glVertexAttrib4NbvARB
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '4',
   'N',
   'i',
   'v',
   0, // glVertexAttrib4Niv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '4',
   'N',
   'i',
   'v',
   'A',
   'R',
   'B',
   0, // glVertexAttrib4NivARB
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '4',
   'N',
   's',
   'v',
   0, // glVertexAttrib4Nsv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '4',
   'N',
   's',
   'v',
   'A',
   'R',
   'B',
   0, // glVertexAttrib4NsvARB
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '4',
   'N',
   'u',
   'b',
   0, // glVertexAttrib4Nub
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '4',
   'N',
   'u',
   'b',
   'A',
   'R',
   'B',
   0, // glVertexAttrib4NubARB
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '4',
   'N',
   'u',
   'b',
   'v',
   0, // glVertexAttrib4Nubv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '4',
   'N',
   'u',
   'b',
   'v',
   'A',
   'R',
   'B',
   0, // glVertexAttrib4NubvARB
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '4',
   'N',
   'u',
   'i',
   'v',
   0, // glVertexAttrib4Nuiv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '4',
   'N',
   'u',
   'i',
   'v',
   'A',
   'R',
   'B',
   0, // glVertexAttrib4NuivARB
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '4',
   'N',
   'u',
   's',
   'v',
   0, // glVertexAttrib4Nusv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '4',
   'N',
   'u',
   's',
   'v',
   'A',
   'R',
   'B',
   0, // glVertexAttrib4NusvARB
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '4',
   'b',
   'v',
   0, // glVertexAttrib4bv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '4',
   'b',
   'v',
   'A',
   'R',
   'B',
   0, // glVertexAttrib4bvARB
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '4',
   'd',
   0, // glVertexAttrib4d
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '4',
   'd',
   'A',
   'R',
   'B',
   0, // glVertexAttrib4dARB
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '4',
   'd',
   'N',
   'V',
   0, // glVertexAttrib4dNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '4',
   'd',
   'v',
   0, // glVertexAttrib4dv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '4',
   'd',
   'v',
   'A',
   'R',
   'B',
   0, // glVertexAttrib4dvARB
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '4',
   'd',
   'v',
   'N',
   'V',
   0, // glVertexAttrib4dvNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '4',
   'f',
   0, // glVertexAttrib4f
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '4',
   'f',
   'A',
   'R',
   'B',
   0, // glVertexAttrib4fARB
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '4',
   'f',
   'N',
   'V',
   0, // glVertexAttrib4fNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '4',
   'f',
   'v',
   0, // glVertexAttrib4fv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '4',
   'f',
   'v',
   'A',
   'R',
   'B',
   0, // glVertexAttrib4fvARB
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '4',
   'f',
   'v',
   'N',
   'V',
   0, // glVertexAttrib4fvNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '4',
   'h',
   'N',
   'V',
   0, // glVertexAttrib4hNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '4',
   'h',
   'v',
   'N',
   'V',
   0, // glVertexAttrib4hvNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '4',
   'i',
   'v',
   0, // glVertexAttrib4iv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '4',
   'i',
   'v',
   'A',
   'R',
   'B',
   0, // glVertexAttrib4ivARB
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '4',
   's',
   0, // glVertexAttrib4s
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '4',
   's',
   'A',
   'R',
   'B',
   0, // glVertexAttrib4sARB
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '4',
   's',
   'N',
   'V',
   0, // glVertexAttrib4sNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '4',
   's',
   'v',
   0, // glVertexAttrib4sv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '4',
   's',
   'v',
   'A',
   'R',
   'B',
   0, // glVertexAttrib4svARB
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '4',
   's',
   'v',
   'N',
   'V',
   0, // glVertexAttrib4svNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '4',
   'u',
   'b',
   'N',
   'V',
   0, // glVertexAttrib4ubNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '4',
   'u',
   'b',
   'v',
   0, // glVertexAttrib4ubv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '4',
   'u',
   'b',
   'v',
   'A',
   'R',
   'B',
   0, // glVertexAttrib4ubvARB
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '4',
   'u',
   'b',
   'v',
   'N',
   'V',
   0, // glVertexAttrib4ubvNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '4',
   'u',
   'i',
   'v',
   0, // glVertexAttrib4uiv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '4',
   'u',
   'i',
   'v',
   'A',
   'R',
   'B',
   0, // glVertexAttrib4uivARB
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '4',
   'u',
   's',
   'v',
   0, // glVertexAttrib4usv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   '4',
   'u',
   's',
   'v',
   'A',
   'R',
   'B',
   0, // glVertexAttrib4usvARB
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'A',
   'r',
   'r',
   'a',
   'y',
   'O',
   'b',
   'j',
   'e',
   'c',
   't',
   'A',
   'T',
   'I',
   0, // glVertexAttribArrayObjectATI
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'B',
   'i',
   'n',
   'd',
   'i',
   'n',
   'g',
   0, // glVertexAttribBinding
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'D',
   'i',
   'v',
   'i',
   's',
   'o',
   'r',
   0, // glVertexAttribDivisor
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'D',
   'i',
   'v',
   'i',
   's',
   'o',
   'r',
   'A',
   'N',
   'G',
   'L',
   'E',
   0, // glVertexAttribDivisorANGLE
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'D',
   'i',
   'v',
   'i',
   's',
   'o',
   'r',
   'A',
   'R',
   'B',
   0, // glVertexAttribDivisorARB
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'D',
   'i',
   'v',
   'i',
   's',
   'o',
   'r',
   'E',
   'X',
   'T',
   0, // glVertexAttribDivisorEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'D',
   'i',
   'v',
   'i',
   's',
   'o',
   'r',
   'N',
   'V',
   0, // glVertexAttribDivisorNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'F',
   'o',
   'r',
   'm',
   'a',
   't',
   0, // glVertexAttribFormat
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'F',
   'o',
   'r',
   'm',
   'a',
   't',
   'N',
   'V',
   0, // glVertexAttribFormatNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   '1',
   'i',
   0, // glVertexAttribI1i
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   '1',
   'i',
   'E',
   'X',
   'T',
   0, // glVertexAttribI1iEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   '1',
   'i',
   'v',
   0, // glVertexAttribI1iv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   '1',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glVertexAttribI1ivEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   '1',
   'u',
   'i',
   0, // glVertexAttribI1ui
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   '1',
   'u',
   'i',
   'E',
   'X',
   'T',
   0, // glVertexAttribI1uiEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   '1',
   'u',
   'i',
   'v',
   0, // glVertexAttribI1uiv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   '1',
   'u',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glVertexAttribI1uivEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   '2',
   'i',
   0, // glVertexAttribI2i
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   '2',
   'i',
   'E',
   'X',
   'T',
   0, // glVertexAttribI2iEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   '2',
   'i',
   'v',
   0, // glVertexAttribI2iv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   '2',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glVertexAttribI2ivEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   '2',
   'u',
   'i',
   0, // glVertexAttribI2ui
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   '2',
   'u',
   'i',
   'E',
   'X',
   'T',
   0, // glVertexAttribI2uiEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   '2',
   'u',
   'i',
   'v',
   0, // glVertexAttribI2uiv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   '2',
   'u',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glVertexAttribI2uivEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   '3',
   'i',
   0, // glVertexAttribI3i
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   '3',
   'i',
   'E',
   'X',
   'T',
   0, // glVertexAttribI3iEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   '3',
   'i',
   'v',
   0, // glVertexAttribI3iv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   '3',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glVertexAttribI3ivEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   '3',
   'u',
   'i',
   0, // glVertexAttribI3ui
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   '3',
   'u',
   'i',
   'E',
   'X',
   'T',
   0, // glVertexAttribI3uiEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   '3',
   'u',
   'i',
   'v',
   0, // glVertexAttribI3uiv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   '3',
   'u',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glVertexAttribI3uivEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   '4',
   'b',
   'v',
   0, // glVertexAttribI4bv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   '4',
   'b',
   'v',
   'E',
   'X',
   'T',
   0, // glVertexAttribI4bvEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   '4',
   'i',
   0, // glVertexAttribI4i
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   '4',
   'i',
   'E',
   'X',
   'T',
   0, // glVertexAttribI4iEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   '4',
   'i',
   'v',
   0, // glVertexAttribI4iv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   '4',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glVertexAttribI4ivEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   '4',
   's',
   'v',
   0, // glVertexAttribI4sv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   '4',
   's',
   'v',
   'E',
   'X',
   'T',
   0, // glVertexAttribI4svEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   '4',
   'u',
   'b',
   'v',
   0, // glVertexAttribI4ubv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   '4',
   'u',
   'b',
   'v',
   'E',
   'X',
   'T',
   0, // glVertexAttribI4ubvEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   '4',
   'u',
   'i',
   0, // glVertexAttribI4ui
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   '4',
   'u',
   'i',
   'E',
   'X',
   'T',
   0, // glVertexAttribI4uiEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   '4',
   'u',
   'i',
   'v',
   0, // glVertexAttribI4uiv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   '4',
   'u',
   'i',
   'v',
   'E',
   'X',
   'T',
   0, // glVertexAttribI4uivEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   '4',
   'u',
   's',
   'v',
   0, // glVertexAttribI4usv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   '4',
   'u',
   's',
   'v',
   'E',
   'X',
   'T',
   0, // glVertexAttribI4usvEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   'F',
   'o',
   'r',
   'm',
   'a',
   't',
   0, // glVertexAttribIFormat
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   'F',
   'o',
   'r',
   'm',
   'a',
   't',
   'N',
   'V',
   0, // glVertexAttribIFormatNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   0, // glVertexAttribIPointer
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'I',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glVertexAttribIPointerEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'L',
   '1',
   'd',
   0, // glVertexAttribL1d
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'L',
   '1',
   'd',
   'E',
   'X',
   'T',
   0, // glVertexAttribL1dEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'L',
   '1',
   'd',
   'v',
   0, // glVertexAttribL1dv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'L',
   '1',
   'd',
   'v',
   'E',
   'X',
   'T',
   0, // glVertexAttribL1dvEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'L',
   '1',
   'i',
   '6',
   '4',
   'N',
   'V',
   0, // glVertexAttribL1i64NV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'L',
   '1',
   'i',
   '6',
   '4',
   'v',
   'N',
   'V',
   0, // glVertexAttribL1i64vNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'L',
   '1',
   'u',
   'i',
   '6',
   '4',
   'A',
   'R',
   'B',
   0, // glVertexAttribL1ui64ARB
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'L',
   '1',
   'u',
   'i',
   '6',
   '4',
   'N',
   'V',
   0, // glVertexAttribL1ui64NV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'L',
   '1',
   'u',
   'i',
   '6',
   '4',
   'v',
   'A',
   'R',
   'B',
   0, // glVertexAttribL1ui64vARB
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'L',
   '1',
   'u',
   'i',
   '6',
   '4',
   'v',
   'N',
   'V',
   0, // glVertexAttribL1ui64vNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'L',
   '2',
   'd',
   0, // glVertexAttribL2d
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'L',
   '2',
   'd',
   'E',
   'X',
   'T',
   0, // glVertexAttribL2dEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'L',
   '2',
   'd',
   'v',
   0, // glVertexAttribL2dv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'L',
   '2',
   'd',
   'v',
   'E',
   'X',
   'T',
   0, // glVertexAttribL2dvEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'L',
   '2',
   'i',
   '6',
   '4',
   'N',
   'V',
   0, // glVertexAttribL2i64NV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'L',
   '2',
   'i',
   '6',
   '4',
   'v',
   'N',
   'V',
   0, // glVertexAttribL2i64vNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'L',
   '2',
   'u',
   'i',
   '6',
   '4',
   'N',
   'V',
   0, // glVertexAttribL2ui64NV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'L',
   '2',
   'u',
   'i',
   '6',
   '4',
   'v',
   'N',
   'V',
   0, // glVertexAttribL2ui64vNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'L',
   '3',
   'd',
   0, // glVertexAttribL3d
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'L',
   '3',
   'd',
   'E',
   'X',
   'T',
   0, // glVertexAttribL3dEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'L',
   '3',
   'd',
   'v',
   0, // glVertexAttribL3dv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'L',
   '3',
   'd',
   'v',
   'E',
   'X',
   'T',
   0, // glVertexAttribL3dvEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'L',
   '3',
   'i',
   '6',
   '4',
   'N',
   'V',
   0, // glVertexAttribL3i64NV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'L',
   '3',
   'i',
   '6',
   '4',
   'v',
   'N',
   'V',
   0, // glVertexAttribL3i64vNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'L',
   '3',
   'u',
   'i',
   '6',
   '4',
   'N',
   'V',
   0, // glVertexAttribL3ui64NV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'L',
   '3',
   'u',
   'i',
   '6',
   '4',
   'v',
   'N',
   'V',
   0, // glVertexAttribL3ui64vNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'L',
   '4',
   'd',
   0, // glVertexAttribL4d
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'L',
   '4',
   'd',
   'E',
   'X',
   'T',
   0, // glVertexAttribL4dEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'L',
   '4',
   'd',
   'v',
   0, // glVertexAttribL4dv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'L',
   '4',
   'd',
   'v',
   'E',
   'X',
   'T',
   0, // glVertexAttribL4dvEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'L',
   '4',
   'i',
   '6',
   '4',
   'N',
   'V',
   0, // glVertexAttribL4i64NV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'L',
   '4',
   'i',
   '6',
   '4',
   'v',
   'N',
   'V',
   0, // glVertexAttribL4i64vNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'L',
   '4',
   'u',
   'i',
   '6',
   '4',
   'N',
   'V',
   0, // glVertexAttribL4ui64NV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'L',
   '4',
   'u',
   'i',
   '6',
   '4',
   'v',
   'N',
   'V',
   0, // glVertexAttribL4ui64vNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'L',
   'F',
   'o',
   'r',
   'm',
   'a',
   't',
   0, // glVertexAttribLFormat
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'L',
   'F',
   'o',
   'r',
   'm',
   'a',
   't',
   'N',
   'V',
   0, // glVertexAttribLFormatNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'L',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   0, // glVertexAttribLPointer
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'L',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glVertexAttribLPointerEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'P',
   '1',
   'u',
   'i',
   0, // glVertexAttribP1ui
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'P',
   '1',
   'u',
   'i',
   'v',
   0, // glVertexAttribP1uiv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'P',
   '2',
   'u',
   'i',
   0, // glVertexAttribP2ui
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'P',
   '2',
   'u',
   'i',
   'v',
   0, // glVertexAttribP2uiv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'P',
   '3',
   'u',
   'i',
   0, // glVertexAttribP3ui
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'P',
   '3',
   'u',
   'i',
   'v',
   0, // glVertexAttribP3uiv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'P',
   '4',
   'u',
   'i',
   0, // glVertexAttribP4ui
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'P',
   '4',
   'u',
   'i',
   'v',
   0, // glVertexAttribP4uiv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'A',
   'M',
   'D',
   0, // glVertexAttribParameteriAMD
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   0, // glVertexAttribPointer
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'A',
   'R',
   'B',
   0, // glVertexAttribPointerARB
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'N',
   'V',
   0, // glVertexAttribPointerNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   's',
   '1',
   'd',
   'v',
   'N',
   'V',
   0, // glVertexAttribs1dvNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   's',
   '1',
   'f',
   'v',
   'N',
   'V',
   0, // glVertexAttribs1fvNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   's',
   '1',
   'h',
   'v',
   'N',
   'V',
   0, // glVertexAttribs1hvNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   's',
   '1',
   's',
   'v',
   'N',
   'V',
   0, // glVertexAttribs1svNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   's',
   '2',
   'd',
   'v',
   'N',
   'V',
   0, // glVertexAttribs2dvNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   's',
   '2',
   'f',
   'v',
   'N',
   'V',
   0, // glVertexAttribs2fvNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   's',
   '2',
   'h',
   'v',
   'N',
   'V',
   0, // glVertexAttribs2hvNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   's',
   '2',
   's',
   'v',
   'N',
   'V',
   0, // glVertexAttribs2svNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   's',
   '3',
   'd',
   'v',
   'N',
   'V',
   0, // glVertexAttribs3dvNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   's',
   '3',
   'f',
   'v',
   'N',
   'V',
   0, // glVertexAttribs3fvNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   's',
   '3',
   'h',
   'v',
   'N',
   'V',
   0, // glVertexAttribs3hvNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   's',
   '3',
   's',
   'v',
   'N',
   'V',
   0, // glVertexAttribs3svNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   's',
   '4',
   'd',
   'v',
   'N',
   'V',
   0, // glVertexAttribs4dvNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   's',
   '4',
   'f',
   'v',
   'N',
   'V',
   0, // glVertexAttribs4fvNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   's',
   '4',
   'h',
   'v',
   'N',
   'V',
   0, // glVertexAttribs4hvNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   's',
   '4',
   's',
   'v',
   'N',
   'V',
   0, // glVertexAttribs4svNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'A',
   't',
   't',
   'r',
   'i',
   'b',
   's',
   '4',
   'u',
   'b',
   'v',
   'N',
   'V',
   0, // glVertexAttribs4ubvNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'B',
   'i',
   'n',
   'd',
   'i',
   'n',
   'g',
   'D',
   'i',
   'v',
   'i',
   's',
   'o',
   'r',
   0, // glVertexBindingDivisor
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'B',
   'l',
   'e',
   'n',
   'd',
   'A',
   'R',
   'B',
   0, // glVertexBlendARB
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'B',
   'l',
   'e',
   'n',
   'd',
   'E',
   'n',
   'v',
   'f',
   'A',
   'T',
   'I',
   0, // glVertexBlendEnvfATI
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'B',
   'l',
   'e',
   'n',
   'd',
   'E',
   'n',
   'v',
   'i',
   'A',
   'T',
   'I',
   0, // glVertexBlendEnviATI
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'F',
   'o',
   'r',
   'm',
   'a',
   't',
   'N',
   'V',
   0, // glVertexFormatNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'P',
   '2',
   'u',
   'i',
   0, // glVertexP2ui
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'P',
   '2',
   'u',
   'i',
   'v',
   0, // glVertexP2uiv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'P',
   '3',
   'u',
   'i',
   0, // glVertexP3ui
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'P',
   '3',
   'u',
   'i',
   'v',
   0, // glVertexP3uiv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'P',
   '4',
   'u',
   'i',
   0, // glVertexP4ui
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'P',
   '4',
   'u',
   'i',
   'v',
   0, // glVertexP4uiv
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   0, // glVertexPointer
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glVertexPointerEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'L',
   'i',
   's',
   't',
   'I',
   'B',
   'M',
   0, // glVertexPointerListIBM
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'v',
   'I',
   'N',
   'T',
   'E',
   'L',
   0, // glVertexPointervINTEL
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   '1',
   'd',
   'A',
   'T',
   'I',
   0, // glVertexStream1dATI
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   '1',
   'd',
   'v',
   'A',
   'T',
   'I',
   0, // glVertexStream1dvATI
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   '1',
   'f',
   'A',
   'T',
   'I',
   0, // glVertexStream1fATI
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   '1',
   'f',
   'v',
   'A',
   'T',
   'I',
   0, // glVertexStream1fvATI
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   '1',
   'i',
   'A',
   'T',
   'I',
   0, // glVertexStream1iATI
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   '1',
   'i',
   'v',
   'A',
   'T',
   'I',
   0, // glVertexStream1ivATI
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   '1',
   's',
   'A',
   'T',
   'I',
   0, // glVertexStream1sATI
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   '1',
   's',
   'v',
   'A',
   'T',
   'I',
   0, // glVertexStream1svATI
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   '2',
   'd',
   'A',
   'T',
   'I',
   0, // glVertexStream2dATI
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   '2',
   'd',
   'v',
   'A',
   'T',
   'I',
   0, // glVertexStream2dvATI
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   '2',
   'f',
   'A',
   'T',
   'I',
   0, // glVertexStream2fATI
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   '2',
   'f',
   'v',
   'A',
   'T',
   'I',
   0, // glVertexStream2fvATI
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   '2',
   'i',
   'A',
   'T',
   'I',
   0, // glVertexStream2iATI
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   '2',
   'i',
   'v',
   'A',
   'T',
   'I',
   0, // glVertexStream2ivATI
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   '2',
   's',
   'A',
   'T',
   'I',
   0, // glVertexStream2sATI
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   '2',
   's',
   'v',
   'A',
   'T',
   'I',
   0, // glVertexStream2svATI
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   '3',
   'd',
   'A',
   'T',
   'I',
   0, // glVertexStream3dATI
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   '3',
   'd',
   'v',
   'A',
   'T',
   'I',
   0, // glVertexStream3dvATI
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   '3',
   'f',
   'A',
   'T',
   'I',
   0, // glVertexStream3fATI
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   '3',
   'f',
   'v',
   'A',
   'T',
   'I',
   0, // glVertexStream3fvATI
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   '3',
   'i',
   'A',
   'T',
   'I',
   0, // glVertexStream3iATI
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   '3',
   'i',
   'v',
   'A',
   'T',
   'I',
   0, // glVertexStream3ivATI
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   '3',
   's',
   'A',
   'T',
   'I',
   0, // glVertexStream3sATI
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   '3',
   's',
   'v',
   'A',
   'T',
   'I',
   0, // glVertexStream3svATI
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   '4',
   'd',
   'A',
   'T',
   'I',
   0, // glVertexStream4dATI
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   '4',
   'd',
   'v',
   'A',
   'T',
   'I',
   0, // glVertexStream4dvATI
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   '4',
   'f',
   'A',
   'T',
   'I',
   0, // glVertexStream4fATI
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   '4',
   'f',
   'v',
   'A',
   'T',
   'I',
   0, // glVertexStream4fvATI
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   '4',
   'i',
   'A',
   'T',
   'I',
   0, // glVertexStream4iATI
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   '4',
   'i',
   'v',
   'A',
   'T',
   'I',
   0, // glVertexStream4ivATI
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   '4',
   's',
   'A',
   'T',
   'I',
   0, // glVertexStream4sATI
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   '4',
   's',
   'v',
   'A',
   'T',
   'I',
   0, // glVertexStream4svATI
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'W',
   'e',
   'i',
   'g',
   'h',
   't',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'E',
   'X',
   'T',
   0, // glVertexWeightPointerEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'W',
   'e',
   'i',
   'g',
   'h',
   't',
   'f',
   'E',
   'X',
   'T',
   0, // glVertexWeightfEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'W',
   'e',
   'i',
   'g',
   'h',
   't',
   'f',
   'v',
   'E',
   'X',
   'T',
   0, // glVertexWeightfvEXT
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'W',
   'e',
   'i',
   'g',
   'h',
   't',
   'h',
   'N',
   'V',
   0, // glVertexWeighthNV
   'g',
   'l',
   'V',
   'e',
   'r',
   't',
   'e',
   'x',
   'W',
   'e',
   'i',
   'g',
   'h',
   't',
   'h',
   'v',
   'N',
   'V',
   0, // glVertexWeighthvNV
   'g',
   'l',
   'V',
   'i',
   'd',
   'e',
   'o',
   'C',
   'a',
   'p',
   't',
   'u',
   'r',
   'e',
   'N',
   'V',
   0, // glVideoCaptureNV
   'g',
   'l',
   'V',
   'i',
   'd',
   'e',
   'o',
   'C',
   'a',
   'p',
   't',
   'u',
   'r',
   'e',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'd',
   'v',
   'N',
   'V',
   0, // glVideoCaptureStreamParameterdvNV
   'g',
   'l',
   'V',
   'i',
   'd',
   'e',
   'o',
   'C',
   'a',
   'p',
   't',
   'u',
   'r',
   'e',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'f',
   'v',
   'N',
   'V',
   0, // glVideoCaptureStreamParameterfvNV
   'g',
   'l',
   'V',
   'i',
   'd',
   'e',
   'o',
   'C',
   'a',
   'p',
   't',
   'u',
   'r',
   'e',
   'S',
   't',
   'r',
   'e',
   'a',
   'm',
   'P',
   'a',
   'r',
   'a',
   'm',
   'e',
   't',
   'e',
   'r',
   'i',
   'v',
   'N',
   'V',
   0, // glVideoCaptureStreamParameterivNV
   'g',
   'l',
   'V',
   'i',
   'e',
   'w',
   'p',
   'o',
   'r',
   't',
   0, // glViewport
   'g',
   'l',
   'V',
   'i',
   'e',
   'w',
   'p',
   'o',
   'r',
   't',
   'A',
   'r',
   'r',
   'a',
   'y',
   'v',
   0, // glViewportArrayv
   'g',
   'l',
   'V',
   'i',
   'e',
   'w',
   'p',
   'o',
   'r',
   't',
   'A',
   'r',
   'r',
   'a',
   'y',
   'v',
   'N',
   'V',
   0, // glViewportArrayvNV
   'g',
   'l',
   'V',
   'i',
   'e',
   'w',
   'p',
   'o',
   'r',
   't',
   'A',
   'r',
   'r',
   'a',
   'y',
   'v',
   'O',
   'E',
   'S',
   0, // glViewportArrayvOES
   'g',
   'l',
   'V',
   'i',
   'e',
   'w',
   'p',
   'o',
   'r',
   't',
   'I',
   'n',
   'd',
   'e',
   'x',
   'e',
   'd',
   'f',
   0, // glViewportIndexedf
   'g',
   'l',
   'V',
   'i',
   'e',
   'w',
   'p',
   'o',
   'r',
   't',
   'I',
   'n',
   'd',
   'e',
   'x',
   'e',
   'd',
   'f',
   'N',
   'V',
   0, // glViewportIndexedfNV
   'g',
   'l',
   'V',
   'i',
   'e',
   'w',
   'p',
   'o',
   'r',
   't',
   'I',
   'n',
   'd',
   'e',
   'x',
   'e',
   'd',
   'f',
   'O',
   'E',
   'S',
   0, // glViewportIndexedfOES
   'g',
   'l',
   'V',
   'i',
   'e',
   'w',
   'p',
   'o',
   'r',
   't',
   'I',
   'n',
   'd',
   'e',
   'x',
   'e',
   'd',
   'f',
   'v',
   0, // glViewportIndexedfv
   'g',
   'l',
   'V',
   'i',
   'e',
   'w',
   'p',
   'o',
   'r',
   't',
   'I',
   'n',
   'd',
   'e',
   'x',
   'e',
   'd',
   'f',
   'v',
   'N',
   'V',
   0, // glViewportIndexedfvNV
   'g',
   'l',
   'V',
   'i',
   'e',
   'w',
   'p',
   'o',
   'r',
   't',
   'I',
   'n',
   'd',
   'e',
   'x',
   'e',
   'd',
   'f',
   'v',
   'O',
   'E',
   'S',
   0, // glViewportIndexedfvOES
   'g',
   'l',
   'V',
   'i',
   'e',
   'w',
   'p',
   'o',
   'r',
   't',
   'P',
   'o',
   's',
   'i',
   't',
   'i',
   'o',
   'n',
   'W',
   'S',
   'c',
   'a',
   'l',
   'e',
   'N',
   'V',
   0, // glViewportPositionWScaleNV
   'g',
   'l',
   'V',
   'i',
   'e',
   'w',
   'p',
   'o',
   'r',
   't',
   'S',
   'w',
   'i',
   'z',
   'z',
   'l',
   'e',
   'N',
   'V',
   0, // glViewportSwizzleNV
   'g',
   'l',
   'W',
   'a',
   'i',
   't',
   'S',
   'e',
   'm',
   'a',
   'p',
   'h',
   'o',
   'r',
   'e',
   'E',
   'X',
   'T',
   0, // glWaitSemaphoreEXT
   'g',
   'l',
   'W',
   'a',
   'i',
   't',
   'S',
   'e',
   'm',
   'a',
   'p',
   'h',
   'o',
   'r',
   'e',
   'u',
   'i',
   '6',
   '4',
   'N',
   'V',
   'X',
   0, // glWaitSemaphoreui64NVX
   'g',
   'l',
   'W',
   'a',
   'i',
   't',
   'S',
   'y',
   'n',
   'c',
   0, // glWaitSync
   'g',
   'l',
   'W',
   'a',
   'i',
   't',
   'S',
   'y',
   'n',
   'c',
   'A',
   'P',
   'P',
   'L',
   'E',
   0, // glWaitSyncAPPLE
   'g',
   'l',
   'W',
   'a',
   'i',
   't',
   'V',
   'k',
   'S',
   'e',
   'm',
   'a',
   'p',
   'h',
   'o',
   'r',
   'e',
   'N',
   'V',
   0, // glWaitVkSemaphoreNV
   'g',
   'l',
   'W',
   'e',
   'i',
   'g',
   'h',
   't',
   'P',
   'a',
   't',
   'h',
   's',
   'N',
   'V',
   0, // glWeightPathsNV
   'g',
   'l',
   'W',
   'e',
   'i',
   'g',
   'h',
   't',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'A',
   'R',
   'B',
   0, // glWeightPointerARB
   'g',
   'l',
   'W',
   'e',
   'i',
   'g',
   'h',
   't',
   'P',
   'o',
   'i',
   'n',
   't',
   'e',
   'r',
   'O',
   'E',
   'S',
   0, // glWeightPointerOES
   'g',
   'l',
   'W',
   'e',
   'i',
   'g',
   'h',
   't',
   'b',
   'v',
   'A',
   'R',
   'B',
   0, // glWeightbvARB
   'g',
   'l',
   'W',
   'e',
   'i',
   'g',
   'h',
   't',
   'd',
   'v',
   'A',
   'R',
   'B',
   0, // glWeightdvARB
   'g',
   'l',
   'W',
   'e',
   'i',
   'g',
   'h',
   't',
   'f',
   'v',
   'A',
   'R',
   'B',
   0, // glWeightfvARB
   'g',
   'l',
   'W',
   'e',
   'i',
   'g',
   'h',
   't',
   'i',
   'v',
   'A',
   'R',
   'B',
   0, // glWeightivARB
   'g',
   'l',
   'W',
   'e',
   'i',
   'g',
   'h',
   't',
   's',
   'v',
   'A',
   'R',
   'B',
   0, // glWeightsvARB
   'g',
   'l',
   'W',
   'e',
   'i',
   'g',
   'h',
   't',
   'u',
   'b',
   'v',
   'A',
   'R',
   'B',
   0, // glWeightubvARB
   'g',
   'l',
   'W',
   'e',
   'i',
   'g',
   'h',
   't',
   'u',
   'i',
   'v',
   'A',
   'R',
   'B',
   0, // glWeightuivARB
   'g',
   'l',
   'W',
   'e',
   'i',
   'g',
   'h',
   't',
   'u',
   's',
   'v',
   'A',
   'R',
   'B',
   0, // glWeightusvARB
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '2',
   'd',
   0, // glWindowPos2d
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '2',
   'd',
   'A',
   'R',
   'B',
   0, // glWindowPos2dARB
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '2',
   'd',
   'M',
   'E',
   'S',
   'A',
   0, // glWindowPos2dMESA
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '2',
   'd',
   'v',
   0, // glWindowPos2dv
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '2',
   'd',
   'v',
   'A',
   'R',
   'B',
   0, // glWindowPos2dvARB
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '2',
   'd',
   'v',
   'M',
   'E',
   'S',
   'A',
   0, // glWindowPos2dvMESA
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '2',
   'f',
   0, // glWindowPos2f
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '2',
   'f',
   'A',
   'R',
   'B',
   0, // glWindowPos2fARB
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '2',
   'f',
   'M',
   'E',
   'S',
   'A',
   0, // glWindowPos2fMESA
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '2',
   'f',
   'v',
   0, // glWindowPos2fv
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '2',
   'f',
   'v',
   'A',
   'R',
   'B',
   0, // glWindowPos2fvARB
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '2',
   'f',
   'v',
   'M',
   'E',
   'S',
   'A',
   0, // glWindowPos2fvMESA
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '2',
   'i',
   0, // glWindowPos2i
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '2',
   'i',
   'A',
   'R',
   'B',
   0, // glWindowPos2iARB
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '2',
   'i',
   'M',
   'E',
   'S',
   'A',
   0, // glWindowPos2iMESA
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '2',
   'i',
   'v',
   0, // glWindowPos2iv
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '2',
   'i',
   'v',
   'A',
   'R',
   'B',
   0, // glWindowPos2ivARB
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '2',
   'i',
   'v',
   'M',
   'E',
   'S',
   'A',
   0, // glWindowPos2ivMESA
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '2',
   's',
   0, // glWindowPos2s
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '2',
   's',
   'A',
   'R',
   'B',
   0, // glWindowPos2sARB
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '2',
   's',
   'M',
   'E',
   'S',
   'A',
   0, // glWindowPos2sMESA
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '2',
   's',
   'v',
   0, // glWindowPos2sv
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '2',
   's',
   'v',
   'A',
   'R',
   'B',
   0, // glWindowPos2svARB
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '2',
   's',
   'v',
   'M',
   'E',
   'S',
   'A',
   0, // glWindowPos2svMESA
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '3',
   'd',
   0, // glWindowPos3d
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '3',
   'd',
   'A',
   'R',
   'B',
   0, // glWindowPos3dARB
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '3',
   'd',
   'M',
   'E',
   'S',
   'A',
   0, // glWindowPos3dMESA
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '3',
   'd',
   'v',
   0, // glWindowPos3dv
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '3',
   'd',
   'v',
   'A',
   'R',
   'B',
   0, // glWindowPos3dvARB
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '3',
   'd',
   'v',
   'M',
   'E',
   'S',
   'A',
   0, // glWindowPos3dvMESA
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '3',
   'f',
   0, // glWindowPos3f
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '3',
   'f',
   'A',
   'R',
   'B',
   0, // glWindowPos3fARB
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '3',
   'f',
   'M',
   'E',
   'S',
   'A',
   0, // glWindowPos3fMESA
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '3',
   'f',
   'v',
   0, // glWindowPos3fv
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '3',
   'f',
   'v',
   'A',
   'R',
   'B',
   0, // glWindowPos3fvARB
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '3',
   'f',
   'v',
   'M',
   'E',
   'S',
   'A',
   0, // glWindowPos3fvMESA
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '3',
   'i',
   0, // glWindowPos3i
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '3',
   'i',
   'A',
   'R',
   'B',
   0, // glWindowPos3iARB
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '3',
   'i',
   'M',
   'E',
   'S',
   'A',
   0, // glWindowPos3iMESA
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '3',
   'i',
   'v',
   0, // glWindowPos3iv
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '3',
   'i',
   'v',
   'A',
   'R',
   'B',
   0, // glWindowPos3ivARB
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '3',
   'i',
   'v',
   'M',
   'E',
   'S',
   'A',
   0, // glWindowPos3ivMESA
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '3',
   's',
   0, // glWindowPos3s
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '3',
   's',
   'A',
   'R',
   'B',
   0, // glWindowPos3sARB
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '3',
   's',
   'M',
   'E',
   'S',
   'A',
   0, // glWindowPos3sMESA
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '3',
   's',
   'v',
   0, // glWindowPos3sv
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '3',
   's',
   'v',
   'A',
   'R',
   'B',
   0, // glWindowPos3svARB
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '3',
   's',
   'v',
   'M',
   'E',
   'S',
   'A',
   0, // glWindowPos3svMESA
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '4',
   'd',
   'M',
   'E',
   'S',
   'A',
   0, // glWindowPos4dMESA
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '4',
   'd',
   'v',
   'M',
   'E',
   'S',
   'A',
   0, // glWindowPos4dvMESA
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '4',
   'f',
   'M',
   'E',
   'S',
   'A',
   0, // glWindowPos4fMESA
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '4',
   'f',
   'v',
   'M',
   'E',
   'S',
   'A',
   0, // glWindowPos4fvMESA
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '4',
   'i',
   'M',
   'E',
   'S',
   'A',
   0, // glWindowPos4iMESA
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '4',
   'i',
   'v',
   'M',
   'E',
   'S',
   'A',
   0, // glWindowPos4ivMESA
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '4',
   's',
   'M',
   'E',
   'S',
   'A',
   0, // glWindowPos4sMESA
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'P',
   'o',
   's',
   '4',
   's',
   'v',
   'M',
   'E',
   'S',
   'A',
   0, // glWindowPos4svMESA
   'g',
   'l',
   'W',
   'i',
   'n',
   'd',
   'o',
   'w',
   'R',
   'e',
   'c',
   't',
   'a',
   'n',
   'g',
   'l',
   'e',
   's',
   'E',
   'X',
   'T',
   0, // glWindowRectanglesEXT
   'g',
   'l',
   'W',
   'r',
   'i',
   't',
   'e',
   'M',
   'a',
   's',
   'k',
   'E',
   'X',
   'T',
   0, // glWriteMaskEXT
    0 };

static void *gl_provider_resolver(const char *name,
                                   const enum gl_provider *providers,
                                   const uint32_t *entrypoints)
{
    int i;
    for (i = 0; providers[i] != gl_provider_terminator; i++) {
        const char *provider_name = enum_string + enum_string_offsets[providers[i]];
        switch (providers[i]) {

        case PROVIDER_Desktop_OpenGL_1_0:
            if (epoxy_is_desktop_gl())
                return epoxy_get_core_proc_address(entrypoint_strings + entrypoints[i], 10);
            break;
        case PROVIDER_Desktop_OpenGL_1_1:
            if (epoxy_is_desktop_gl() && epoxy_conservative_gl_version() >= 11)
                return epoxy_get_core_proc_address(entrypoint_strings + entrypoints[i], 11);
            break;
        case PROVIDER_Desktop_OpenGL_1_2:
            if (epoxy_is_desktop_gl() && epoxy_conservative_gl_version() >= 12)
                return epoxy_get_core_proc_address(entrypoint_strings + entrypoints[i], 12);
            break;
        case PROVIDER_Desktop_OpenGL_1_3:
            if (epoxy_is_desktop_gl() && epoxy_conservative_gl_version() >= 13)
                return epoxy_get_core_proc_address(entrypoint_strings + entrypoints[i], 13);
            break;
        case PROVIDER_Desktop_OpenGL_1_4:
            if (epoxy_is_desktop_gl() && epoxy_conservative_gl_version() >= 14)
                return epoxy_get_core_proc_address(entrypoint_strings + entrypoints[i], 14);
            break;
        case PROVIDER_Desktop_OpenGL_1_5:
            if (epoxy_is_desktop_gl() && epoxy_conservative_gl_version() >= 15)
                return epoxy_get_core_proc_address(entrypoint_strings + entrypoints[i], 15);
            break;
        case PROVIDER_Desktop_OpenGL_2_0:
            if (epoxy_is_desktop_gl() && epoxy_conservative_gl_version() >= 20)
                return epoxy_get_core_proc_address(entrypoint_strings + entrypoints[i], 20);
            break;
        case PROVIDER_Desktop_OpenGL_2_1:
            if (epoxy_is_desktop_gl() && epoxy_conservative_gl_version() >= 21)
                return epoxy_get_core_proc_address(entrypoint_strings + entrypoints[i], 21);
            break;
        case PROVIDER_Desktop_OpenGL_3_0:
            if (epoxy_is_desktop_gl() && epoxy_conservative_gl_version() >= 30)
                return epoxy_get_core_proc_address(entrypoint_strings + entrypoints[i], 30);
            break;
        case PROVIDER_Desktop_OpenGL_3_1:
            if (epoxy_is_desktop_gl() && epoxy_conservative_gl_version() >= 31)
                return epoxy_get_core_proc_address(entrypoint_strings + entrypoints[i], 31);
            break;
        case PROVIDER_Desktop_OpenGL_3_2:
            if (epoxy_is_desktop_gl() && epoxy_conservative_gl_version() >= 32)
                return epoxy_get_core_proc_address(entrypoint_strings + entrypoints[i], 32);
            break;
        case PROVIDER_Desktop_OpenGL_3_3:
            if (epoxy_is_desktop_gl() && epoxy_conservative_gl_version() >= 33)
                return epoxy_get_core_proc_address(entrypoint_strings + entrypoints[i], 33);
            break;
        case PROVIDER_Desktop_OpenGL_4_0:
            if (epoxy_is_desktop_gl() && epoxy_conservative_gl_version() >= 40)
                return epoxy_get_core_proc_address(entrypoint_strings + entrypoints[i], 40);
            break;
        case PROVIDER_Desktop_OpenGL_4_1:
            if (epoxy_is_desktop_gl() && epoxy_conservative_gl_version() >= 41)
                return epoxy_get_core_proc_address(entrypoint_strings + entrypoints[i], 41);
            break;
        case PROVIDER_Desktop_OpenGL_4_2:
            if (epoxy_is_desktop_gl() && epoxy_conservative_gl_version() >= 42)
                return epoxy_get_core_proc_address(entrypoint_strings + entrypoints[i], 42);
            break;
        case PROVIDER_Desktop_OpenGL_4_3:
            if (epoxy_is_desktop_gl() && epoxy_conservative_gl_version() >= 43)
                return epoxy_get_core_proc_address(entrypoint_strings + entrypoints[i], 43);
            break;
        case PROVIDER_Desktop_OpenGL_4_4:
            if (epoxy_is_desktop_gl() && epoxy_conservative_gl_version() >= 44)
                return epoxy_get_core_proc_address(entrypoint_strings + entrypoints[i], 44);
            break;
        case PROVIDER_Desktop_OpenGL_4_5:
            if (epoxy_is_desktop_gl() && epoxy_conservative_gl_version() >= 45)
                return epoxy_get_core_proc_address(entrypoint_strings + entrypoints[i], 45);
            break;
        case PROVIDER_Desktop_OpenGL_4_6:
            if (epoxy_is_desktop_gl() && epoxy_conservative_gl_version() >= 46)
                return epoxy_get_core_proc_address(entrypoint_strings + entrypoints[i], 46);
            break;
        case PROVIDER_GL_3DFX_tbuffer:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_AMD_debug_output:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_AMD_draw_buffers_blend:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_AMD_framebuffer_multisample_advanced:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_AMD_framebuffer_sample_positions:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_AMD_gpu_shader_int64:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_AMD_interleaved_elements:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_AMD_multi_draw_indirect:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_AMD_name_gen_delete:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_AMD_occlusion_query_event:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_AMD_performance_monitor:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_AMD_sample_positions:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_AMD_sparse_texture:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_AMD_stencil_operation_extended:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_AMD_vertex_shader_tessellator:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ANGLE_framebuffer_blit:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ANGLE_framebuffer_multisample:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ANGLE_instanced_arrays:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ANGLE_translated_shader_source:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_APPLE_copy_texture_levels:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_APPLE_element_array:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_APPLE_fence:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_APPLE_flush_buffer_range:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_APPLE_framebuffer_multisample:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_APPLE_object_purgeable:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_APPLE_sync:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_APPLE_texture_range:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_APPLE_vertex_array_object:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_APPLE_vertex_array_range:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_APPLE_vertex_program_evaluators:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_ES2_compatibility:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_ES3_1_compatibility:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_ES3_2_compatibility:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_base_instance:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_bindless_texture:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_blend_func_extended:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_buffer_storage:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_cl_event:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_clear_buffer_object:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_clear_texture:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_clip_control:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_color_buffer_float:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_compute_shader:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_compute_variable_group_size:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_copy_buffer:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_copy_image:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_debug_output:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_direct_state_access:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_draw_buffers:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_draw_buffers_blend:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_draw_elements_base_vertex:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_draw_indirect:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_draw_instanced:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_fragment_program:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_framebuffer_no_attachments:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_framebuffer_object:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_geometry_shader4:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_get_program_binary:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_get_texture_sub_image:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_gl_spirv:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_gpu_shader_fp64:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_gpu_shader_int64:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_imaging:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_indirect_parameters:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_instanced_arrays:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_internalformat_query:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_internalformat_query2:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_invalidate_subdata:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_map_buffer_range:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_matrix_palette:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_multi_bind:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_multi_draw_indirect:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_multisample:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_multitexture:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_occlusion_query:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_parallel_shader_compile:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_point_parameters:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_polygon_offset_clamp:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_program_interface_query:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_provoking_vertex:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_robustness:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_sample_locations:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_sample_shading:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_sampler_objects:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_separate_shader_objects:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_shader_atomic_counters:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_shader_image_load_store:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_shader_objects:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_shader_storage_buffer_object:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_shader_subroutine:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_shading_language_include:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_sparse_buffer:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_sparse_texture:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_sync:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_tessellation_shader:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_texture_barrier:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_texture_buffer_object:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_texture_buffer_range:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_texture_compression:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_texture_multisample:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_texture_storage:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_texture_storage_multisample:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_texture_view:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_timer_query:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_transform_feedback2:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_transform_feedback3:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_transform_feedback_instanced:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_transpose_matrix:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_uniform_buffer_object:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_vertex_array_object:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_vertex_attrib_64bit:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_vertex_attrib_binding:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_vertex_blend:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_vertex_buffer_object:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_vertex_program:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_vertex_shader:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_vertex_type_2_10_10_10_rev:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_viewport_array:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ARB_window_pos:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ATI_draw_buffers:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ATI_element_array:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ATI_envmap_bumpmap:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ATI_fragment_shader:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ATI_map_object_buffer:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ATI_pn_triangles:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ATI_separate_stencil:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ATI_vertex_array_object:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ATI_vertex_attrib_array_object:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_ATI_vertex_streams:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_EGL_image_storage:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_base_instance:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_bindable_uniform:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_blend_color:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_blend_equation_separate:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_blend_func_extended:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_blend_func_separate:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_blend_minmax:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_buffer_storage:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_clear_texture:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_clip_control:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_color_subtable:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_compiled_vertex_array:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_convolution:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_coordinate_frame:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_copy_image:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_copy_texture:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_cull_vertex:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_debug_label:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_debug_marker:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_depth_bounds_test:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_direct_state_access:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_discard_framebuffer:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_disjoint_timer_query:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_draw_buffers:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_draw_buffers2:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_draw_buffers_indexed:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_draw_elements_base_vertex:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_draw_instanced:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_draw_range_elements:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_draw_transform_feedback:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_external_buffer:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_fog_coord:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_framebuffer_blit:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_framebuffer_multisample:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_framebuffer_object:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_geometry_shader:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_geometry_shader4:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_gpu_program_parameters:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_gpu_shader4:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_histogram:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_index_func:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_index_material:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_instanced_arrays:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_light_texture:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_map_buffer_range:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_memory_object:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_memory_object_fd:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_memory_object_win32:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_multi_draw_arrays:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_multi_draw_indirect:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_multisample:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_multisampled_render_to_texture:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_multiview_draw_buffers:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_occlusion_query_boolean:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_paletted_texture:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_pixel_transform:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_point_parameters:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_polygon_offset:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_polygon_offset_clamp:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_primitive_bounding_box:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_provoking_vertex:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_raster_multisample:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_robustness:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_secondary_color:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_semaphore:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_semaphore_fd:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_semaphore_win32:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_separate_shader_objects:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_shader_framebuffer_fetch_non_coherent:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_shader_image_load_store:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_shader_pixel_local_storage2:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_sparse_texture:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_stencil_clear_tag:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_stencil_two_side:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_subtexture:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_tessellation_shader:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_texture3D:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_texture_array:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_texture_border_clamp:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_texture_buffer:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_texture_buffer_object:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_texture_integer:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_texture_object:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_texture_perturb_normal:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_texture_storage:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_texture_view:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_timer_query:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_transform_feedback:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_vertex_array:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_vertex_attrib_64bit:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_vertex_shader:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_vertex_weighting:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_win32_keyed_mutex:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_window_rectangles:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_EXT_x11_sync_object:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_GREMEDY_frame_terminator:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_GREMEDY_string_marker:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_HP_image_transform:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_IBM_multimode_draw_arrays:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_IBM_static_data:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_IBM_vertex_array_lists:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_IMG_bindless_texture:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_IMG_framebuffer_downsample:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_IMG_multisampled_render_to_texture:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_IMG_user_clip_plane:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_INGR_blend_func_separate:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_INTEL_framebuffer_CMAA:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_INTEL_map_texture:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_INTEL_parallel_arrays:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_INTEL_performance_query:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_KHR_blend_equation_advanced:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_KHR_debug:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_KHR_parallel_shader_compile:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_KHR_robustness:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_MESA_framebuffer_flip_y:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_MESA_resize_buffers:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_MESA_window_pos:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NVX_conditional_render:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NVX_gpu_multicast2:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NVX_linked_gpu_multicast:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NVX_progress_fence:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_alpha_to_coverage_dither_control:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_bindless_multi_draw_indirect:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_bindless_multi_draw_indirect_count:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_bindless_texture:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_blend_equation_advanced:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_clip_space_w_scaling:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_command_list:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_conditional_render:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_conservative_raster:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_conservative_raster_dilate:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_conservative_raster_pre_snap_triangles:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_copy_buffer:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_copy_image:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_coverage_sample:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_depth_buffer_float:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_draw_buffers:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_draw_instanced:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_draw_texture:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_draw_vulkan_image:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_evaluators:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_explicit_multisample:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_fence:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_fragment_coverage_to_color:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_fragment_program:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_framebuffer_blit:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_framebuffer_mixed_samples:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_framebuffer_multisample:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_framebuffer_multisample_coverage:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_geometry_program4:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_gpu_multicast:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_gpu_program4:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_gpu_program5:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_gpu_shader5:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_half_float:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_instanced_arrays:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_internalformat_sample_query:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_memory_attachment:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_mesh_shader:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_non_square_matrices:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_occlusion_query:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_parameter_buffer_object:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_path_rendering:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_pixel_data_range:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_point_sprite:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_polygon_mode:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_present_video:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_primitive_restart:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_query_resource:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_query_resource_tag:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_read_buffer:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_register_combiners:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_register_combiners2:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_sample_locations:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_scissor_exclusive:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_shader_buffer_load:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_shading_rate_image:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_texture_barrier:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_texture_multisample:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_transform_feedback:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_transform_feedback2:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_vdpau_interop:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_vdpau_interop2:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_vertex_array_range:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_vertex_attrib_integer_64bit:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_vertex_buffer_unified_memory:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_vertex_program:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_vertex_program4:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_video_capture:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_viewport_array:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_NV_viewport_swizzle:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_OES_EGL_image:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_OES_blend_equation_separate:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_OES_blend_func_separate:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_OES_blend_subtract:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_OES_byte_coordinates:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_OES_copy_image:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_OES_draw_buffers_indexed:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_OES_draw_elements_base_vertex:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_OES_draw_texture:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_OES_fixed_point:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_OES_framebuffer_object:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_OES_geometry_shader:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_OES_get_program_binary:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_OES_mapbuffer:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_OES_matrix_palette:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_OES_point_size_array:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_OES_primitive_bounding_box:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_OES_query_matrix:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_OES_sample_shading:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_OES_single_precision:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_OES_tessellation_shader:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_OES_texture_3D:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_OES_texture_border_clamp:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_OES_texture_buffer:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_OES_texture_cube_map:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_OES_texture_storage_multisample_2d_array:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_OES_texture_view:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_OES_vertex_array_object:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_OES_viewport_array:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_OVR_multiview:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_OVR_multiview_multisampled_render_to_texture:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_PGI_misc_hints:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_QCOM_alpha_test:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_QCOM_driver_control:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_QCOM_extended_get:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_QCOM_extended_get2:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_QCOM_framebuffer_foveated:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_QCOM_shader_framebuffer_fetch_noncoherent:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_QCOM_texture_foveated:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_QCOM_tiled_rendering:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_SGIS_detail_texture:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_SGIS_fog_function:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_SGIS_multisample:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_SGIS_pixel_texture:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_SGIS_point_parameters:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_SGIS_sharpen_texture:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_SGIS_texture4D:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_SGIS_texture_color_mask:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_SGIS_texture_filter4:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_SGIX_async:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_SGIX_flush_raster:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_SGIX_fragment_lighting:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_SGIX_framezoom:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_SGIX_igloo_interface:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_SGIX_instruments:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_SGIX_list_priority:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_SGIX_pixel_texture:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_SGIX_polynomial_ffd:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_SGIX_reference_plane:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_SGIX_sprite:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_SGIX_tag_sample_buffer:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_SGI_color_table:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_SUNX_constant_data:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_SUN_global_alpha:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_SUN_mesh_array:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_SUN_triangle_list:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_GL_SUN_vertex:
            if (epoxy_conservative_has_gl_extension(provider_name))
                return epoxy_get_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_OpenGL_ES_1_0:
            if (!epoxy_is_desktop_gl() && epoxy_gl_version() >= 10 && epoxy_gl_version() < 20)
                return epoxy_gles1_dlsym(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_OpenGL_ES_2_0:
            if (!epoxy_is_desktop_gl() && epoxy_gl_version() >= 20)
                return epoxy_gles2_dlsym(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_OpenGL_ES_3_0:
            if (!epoxy_is_desktop_gl() && epoxy_gl_version() >= 30)
                return epoxy_gles3_dlsym(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_OpenGL_ES_3_1:
            if (!epoxy_is_desktop_gl() && epoxy_gl_version() >= 31)
                return epoxy_gles3_dlsym(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_OpenGL_ES_3_2:
            if (!epoxy_is_desktop_gl() && epoxy_gl_version() >= 32)
                return epoxy_gles3_dlsym(entrypoint_strings + entrypoints[i]);
            break;
        case PROVIDER_always_present:
            if (true)
                return epoxy_get_bootstrap_proc_address(entrypoint_strings + entrypoints[i]);
            break;
        case gl_provider_terminator:
            abort(); /* Not reached */
        }
    }

    if (epoxy_resolver_failure_handler)
        return epoxy_resolver_failure_handler(name);

    fprintf(stderr, "No provider of %s found.  Requires one of:\n", name);
    for (i = 0; providers[i] != gl_provider_terminator; i++) {
        fprintf(stderr, "    %s\n", enum_string + enum_string_offsets[providers[i]]);
    }
    if (providers[0] == gl_provider_terminator) {
        fprintf(stderr, "    No known providers.  This is likely a bug "
                        "in libepoxy code generation\n");
    }
    abort();
}

EPOXY_NOINLINE static void *
gl_single_resolver(enum gl_provider provider, uint32_t entrypoint_offset);

static void *
gl_single_resolver(enum gl_provider provider, uint32_t entrypoint_offset)
{
    enum gl_provider providers[] = {
        provider,
        gl_provider_terminator
    };
    return gl_provider_resolver(entrypoint_strings + entrypoint_offset,
                                providers, &entrypoint_offset);
}

static PFNGLACCUMPROC
epoxy_glAccum_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 0 /* glAccum */);
}

static PFNGLACCUMXOESPROC
epoxy_glAccumxOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 8 /* glAccumxOES */);
}

static PFNGLACQUIREKEYEDMUTEXWIN32EXTPROC
epoxy_glAcquireKeyedMutexWin32EXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_win32_keyed_mutex, 20 /* glAcquireKeyedMutexWin32EXT */);
}

static PFNGLACTIVEPROGRAMEXTPROC
epoxy_glActiveProgramEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_separate_shader_objects, 48 /* glActiveProgramEXT */);
}

static PFNGLACTIVESHADERPROGRAMPROC
epoxy_glActiveShaderProgram_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        67 /* "glActiveShaderProgram" */,
        67 /* "glActiveShaderProgram" */,
        67 /* "glActiveShaderProgram" */,
    };
    return gl_provider_resolver(entrypoint_strings + 67 /* "glActiveShaderProgram" */,
                                providers, entrypoints);
}

static PFNGLACTIVESHADERPROGRAMEXTPROC
epoxy_glActiveShaderProgramEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_separate_shader_objects, 89 /* glActiveShaderProgramEXT */);
}

static PFNGLACTIVESTENCILFACEEXTPROC
epoxy_glActiveStencilFaceEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_stencil_two_side, 114 /* glActiveStencilFaceEXT */);
}

static PFNGLACTIVETEXTUREPROC
epoxy_glActiveTexture_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_multitexture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        137 /* "glActiveTexture" */,
        137 /* "glActiveTexture" */,
        137 /* "glActiveTexture" */,
        153 /* "glActiveTextureARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 137 /* "glActiveTexture" */,
                                providers, entrypoints);
}

static PFNGLACTIVETEXTUREARBPROC
epoxy_glActiveTextureARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_multitexture,
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        153 /* "glActiveTextureARB" */,
        137 /* "glActiveTexture" */,
        137 /* "glActiveTexture" */,
        137 /* "glActiveTexture" */,
    };
    return gl_provider_resolver(entrypoint_strings + 153 /* "glActiveTextureARB" */,
                                providers, entrypoints);
}

static PFNGLACTIVEVARYINGNVPROC
epoxy_glActiveVaryingNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_transform_feedback, 172 /* glActiveVaryingNV */);
}

static PFNGLALPHAFRAGMENTOP1ATIPROC
epoxy_glAlphaFragmentOp1ATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_fragment_shader, 190 /* glAlphaFragmentOp1ATI */);
}

static PFNGLALPHAFRAGMENTOP2ATIPROC
epoxy_glAlphaFragmentOp2ATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_fragment_shader, 212 /* glAlphaFragmentOp2ATI */);
}

static PFNGLALPHAFRAGMENTOP3ATIPROC
epoxy_glAlphaFragmentOp3ATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_fragment_shader, 234 /* glAlphaFragmentOp3ATI */);
}

static PFNGLALPHAFUNCPROC
epoxy_glAlphaFunc_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        256 /* "glAlphaFunc" */,
        256 /* "glAlphaFunc" */,
    };
    return gl_provider_resolver(entrypoint_strings + 256 /* "glAlphaFunc" */,
                                providers, entrypoints);
}

static PFNGLALPHAFUNCQCOMPROC
epoxy_glAlphaFuncQCOM_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_QCOM_alpha_test, 268 /* glAlphaFuncQCOM */);
}

static PFNGLALPHAFUNCXPROC
epoxy_glAlphaFuncx_resolver(void)
{
    return gl_single_resolver(PROVIDER_OpenGL_ES_1_0, 284 /* glAlphaFuncx */);
}

static PFNGLALPHAFUNCXOESPROC
epoxy_glAlphaFuncxOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 297 /* glAlphaFuncxOES */);
}

static PFNGLALPHATOCOVERAGEDITHERCONTROLNVPROC
epoxy_glAlphaToCoverageDitherControlNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_alpha_to_coverage_dither_control, 313 /* glAlphaToCoverageDitherControlNV */);
}

static PFNGLAPPLYFRAMEBUFFERATTACHMENTCMAAINTELPROC
epoxy_glApplyFramebufferAttachmentCMAAINTEL_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_INTEL_framebuffer_CMAA, 346 /* glApplyFramebufferAttachmentCMAAINTEL */);
}

static PFNGLAPPLYTEXTUREEXTPROC
epoxy_glApplyTextureEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_light_texture, 384 /* glApplyTextureEXT */);
}

static PFNGLAREPROGRAMSRESIDENTNVPROC
epoxy_glAreProgramsResidentNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_program, 402 /* glAreProgramsResidentNV */);
}

static PFNGLARETEXTURESRESIDENTPROC
epoxy_glAreTexturesResident_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_1, 426 /* glAreTexturesResident */);
}

static PFNGLARETEXTURESRESIDENTEXTPROC
epoxy_glAreTexturesResidentEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_texture_object, 448 /* glAreTexturesResidentEXT */);
}

static PFNGLARRAYELEMENTPROC
epoxy_glArrayElement_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_1,
        PROVIDER_GL_EXT_vertex_array,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        473 /* "glArrayElement" */,
        488 /* "glArrayElementEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 473 /* "glArrayElement" */,
                                providers, entrypoints);
}

static PFNGLARRAYELEMENTEXTPROC
epoxy_glArrayElementEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_vertex_array,
        PROVIDER_Desktop_OpenGL_1_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        488 /* "glArrayElementEXT" */,
        473 /* "glArrayElement" */,
    };
    return gl_provider_resolver(entrypoint_strings + 488 /* "glArrayElementEXT" */,
                                providers, entrypoints);
}

static PFNGLARRAYOBJECTATIPROC
epoxy_glArrayObjectATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_array_object, 506 /* glArrayObjectATI */);
}

static PFNGLASYNCCOPYBUFFERSUBDATANVXPROC
epoxy_glAsyncCopyBufferSubDataNVX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NVX_gpu_multicast2, 523 /* glAsyncCopyBufferSubDataNVX */);
}

static PFNGLASYNCCOPYIMAGESUBDATANVXPROC
epoxy_glAsyncCopyImageSubDataNVX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NVX_gpu_multicast2, 551 /* glAsyncCopyImageSubDataNVX */);
}

static PFNGLASYNCMARKERSGIXPROC
epoxy_glAsyncMarkerSGIX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIX_async, 578 /* glAsyncMarkerSGIX */);
}

static PFNGLATTACHOBJECTARBPROC
epoxy_glAttachObjectARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_shader_objects,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        596 /* "glAttachObjectARB" */,
        614 /* "glAttachShader" */,
        614 /* "glAttachShader" */,
    };
    return gl_provider_resolver(entrypoint_strings + 596 /* "glAttachObjectARB" */,
                                providers, entrypoints);
}

static PFNGLATTACHSHADERPROC
epoxy_glAttachShader_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        614 /* "glAttachShader" */,
        614 /* "glAttachShader" */,
        596 /* "glAttachObjectARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 614 /* "glAttachShader" */,
                                providers, entrypoints);
}

static PFNGLBEGINPROC
epoxy_glBegin_unwrapped_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 629 /* glBegin */);
}

static PFNGLBEGINCONDITIONALRENDERPROC
epoxy_glBeginConditionalRender_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_NV_conditional_render,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        637 /* "glBeginConditionalRender" */,
        662 /* "glBeginConditionalRenderNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 637 /* "glBeginConditionalRender" */,
                                providers, entrypoints);
}

static PFNGLBEGINCONDITIONALRENDERNVPROC
epoxy_glBeginConditionalRenderNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_conditional_render,
        PROVIDER_Desktop_OpenGL_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        662 /* "glBeginConditionalRenderNV" */,
        637 /* "glBeginConditionalRender" */,
    };
    return gl_provider_resolver(entrypoint_strings + 662 /* "glBeginConditionalRenderNV" */,
                                providers, entrypoints);
}

static PFNGLBEGINCONDITIONALRENDERNVXPROC
epoxy_glBeginConditionalRenderNVX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NVX_conditional_render, 689 /* glBeginConditionalRenderNVX */);
}

static PFNGLBEGINFRAGMENTSHADERATIPROC
epoxy_glBeginFragmentShaderATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_fragment_shader, 717 /* glBeginFragmentShaderATI */);
}

static PFNGLBEGINOCCLUSIONQUERYNVPROC
epoxy_glBeginOcclusionQueryNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_occlusion_query, 742 /* glBeginOcclusionQueryNV */);
}

static PFNGLBEGINPERFMONITORAMDPROC
epoxy_glBeginPerfMonitorAMD_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_AMD_performance_monitor, 766 /* glBeginPerfMonitorAMD */);
}

static PFNGLBEGINPERFQUERYINTELPROC
epoxy_glBeginPerfQueryINTEL_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_INTEL_performance_query, 788 /* glBeginPerfQueryINTEL */);
}

static PFNGLBEGINQUERYPROC
epoxy_glBeginQuery_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_5,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_ARB_occlusion_query,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        810 /* "glBeginQuery" */,
        810 /* "glBeginQuery" */,
        823 /* "glBeginQueryARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 810 /* "glBeginQuery" */,
                                providers, entrypoints);
}

static PFNGLBEGINQUERYARBPROC
epoxy_glBeginQueryARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_occlusion_query,
        PROVIDER_Desktop_OpenGL_1_5,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        823 /* "glBeginQueryARB" */,
        810 /* "glBeginQuery" */,
        810 /* "glBeginQuery" */,
    };
    return gl_provider_resolver(entrypoint_strings + 823 /* "glBeginQueryARB" */,
                                providers, entrypoints);
}

static PFNGLBEGINQUERYEXTPROC
epoxy_glBeginQueryEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_disjoint_timer_query,
        PROVIDER_GL_EXT_occlusion_query_boolean,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        839 /* "glBeginQueryEXT" */,
        839 /* "glBeginQueryEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 839 /* "glBeginQueryEXT" */,
                                providers, entrypoints);
}

static PFNGLBEGINQUERYINDEXEDPROC
epoxy_glBeginQueryIndexed_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_GL_ARB_transform_feedback3,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        855 /* "glBeginQueryIndexed" */,
        855 /* "glBeginQueryIndexed" */,
    };
    return gl_provider_resolver(entrypoint_strings + 855 /* "glBeginQueryIndexed" */,
                                providers, entrypoints);
}

static PFNGLBEGINTRANSFORMFEEDBACKPROC
epoxy_glBeginTransformFeedback_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_EXT_transform_feedback,
        PROVIDER_GL_NV_transform_feedback,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        875 /* "glBeginTransformFeedback" */,
        875 /* "glBeginTransformFeedback" */,
        900 /* "glBeginTransformFeedbackEXT" */,
        928 /* "glBeginTransformFeedbackNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 875 /* "glBeginTransformFeedback" */,
                                providers, entrypoints);
}

static PFNGLBEGINTRANSFORMFEEDBACKEXTPROC
epoxy_glBeginTransformFeedbackEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_transform_feedback,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_NV_transform_feedback,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        900 /* "glBeginTransformFeedbackEXT" */,
        875 /* "glBeginTransformFeedback" */,
        875 /* "glBeginTransformFeedback" */,
        928 /* "glBeginTransformFeedbackNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 900 /* "glBeginTransformFeedbackEXT" */,
                                providers, entrypoints);
}

static PFNGLBEGINTRANSFORMFEEDBACKNVPROC
epoxy_glBeginTransformFeedbackNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_transform_feedback,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_EXT_transform_feedback,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        928 /* "glBeginTransformFeedbackNV" */,
        875 /* "glBeginTransformFeedback" */,
        875 /* "glBeginTransformFeedback" */,
        900 /* "glBeginTransformFeedbackEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 928 /* "glBeginTransformFeedbackNV" */,
                                providers, entrypoints);
}

static PFNGLBEGINVERTEXSHADEREXTPROC
epoxy_glBeginVertexShaderEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_shader, 955 /* glBeginVertexShaderEXT */);
}

static PFNGLBEGINVIDEOCAPTURENVPROC
epoxy_glBeginVideoCaptureNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_video_capture, 978 /* glBeginVideoCaptureNV */);
}

static PFNGLBINDATTRIBLOCATIONPROC
epoxy_glBindAttribLocation_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_vertex_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        1000 /* "glBindAttribLocation" */,
        1000 /* "glBindAttribLocation" */,
        1021 /* "glBindAttribLocationARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 1000 /* "glBindAttribLocation" */,
                                providers, entrypoints);
}

static PFNGLBINDATTRIBLOCATIONARBPROC
epoxy_glBindAttribLocationARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        1021 /* "glBindAttribLocationARB" */,
        1000 /* "glBindAttribLocation" */,
        1000 /* "glBindAttribLocation" */,
    };
    return gl_provider_resolver(entrypoint_strings + 1021 /* "glBindAttribLocationARB" */,
                                providers, entrypoints);
}

static PFNGLBINDBUFFERPROC
epoxy_glBindBuffer_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_5,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_vertex_buffer_object,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        1045 /* "glBindBuffer" */,
        1045 /* "glBindBuffer" */,
        1045 /* "glBindBuffer" */,
        1058 /* "glBindBufferARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 1045 /* "glBindBuffer" */,
                                providers, entrypoints);
}

static PFNGLBINDBUFFERARBPROC
epoxy_glBindBufferARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_buffer_object,
        PROVIDER_Desktop_OpenGL_1_5,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        1058 /* "glBindBufferARB" */,
        1045 /* "glBindBuffer" */,
        1045 /* "glBindBuffer" */,
        1045 /* "glBindBuffer" */,
    };
    return gl_provider_resolver(entrypoint_strings + 1058 /* "glBindBufferARB" */,
                                providers, entrypoints);
}

static PFNGLBINDBUFFERBASEPROC
epoxy_glBindBufferBase_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_Desktop_OpenGL_3_1,
        PROVIDER_GL_ARB_uniform_buffer_object,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_EXT_transform_feedback,
        PROVIDER_GL_NV_transform_feedback,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        1074 /* "glBindBufferBase" */,
        1074 /* "glBindBufferBase" */,
        1074 /* "glBindBufferBase" */,
        1074 /* "glBindBufferBase" */,
        1091 /* "glBindBufferBaseEXT" */,
        1111 /* "glBindBufferBaseNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 1074 /* "glBindBufferBase" */,
                                providers, entrypoints);
}

static PFNGLBINDBUFFERBASEEXTPROC
epoxy_glBindBufferBaseEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_transform_feedback,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_Desktop_OpenGL_3_1,
        PROVIDER_GL_ARB_uniform_buffer_object,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_NV_transform_feedback,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        1091 /* "glBindBufferBaseEXT" */,
        1074 /* "glBindBufferBase" */,
        1074 /* "glBindBufferBase" */,
        1074 /* "glBindBufferBase" */,
        1074 /* "glBindBufferBase" */,
        1111 /* "glBindBufferBaseNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 1091 /* "glBindBufferBaseEXT" */,
                                providers, entrypoints);
}

static PFNGLBINDBUFFERBASENVPROC
epoxy_glBindBufferBaseNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_transform_feedback,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_Desktop_OpenGL_3_1,
        PROVIDER_GL_ARB_uniform_buffer_object,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_EXT_transform_feedback,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        1111 /* "glBindBufferBaseNV" */,
        1074 /* "glBindBufferBase" */,
        1074 /* "glBindBufferBase" */,
        1074 /* "glBindBufferBase" */,
        1074 /* "glBindBufferBase" */,
        1091 /* "glBindBufferBaseEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 1111 /* "glBindBufferBaseNV" */,
                                providers, entrypoints);
}

static PFNGLBINDBUFFEROFFSETEXTPROC
epoxy_glBindBufferOffsetEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_transform_feedback,
        PROVIDER_GL_NV_transform_feedback,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        1130 /* "glBindBufferOffsetEXT" */,
        1152 /* "glBindBufferOffsetNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 1130 /* "glBindBufferOffsetEXT" */,
                                providers, entrypoints);
}

static PFNGLBINDBUFFEROFFSETNVPROC
epoxy_glBindBufferOffsetNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_transform_feedback,
        PROVIDER_GL_EXT_transform_feedback,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        1152 /* "glBindBufferOffsetNV" */,
        1130 /* "glBindBufferOffsetEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 1152 /* "glBindBufferOffsetNV" */,
                                providers, entrypoints);
}

static PFNGLBINDBUFFERRANGEPROC
epoxy_glBindBufferRange_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_Desktop_OpenGL_3_1,
        PROVIDER_GL_ARB_uniform_buffer_object,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_EXT_transform_feedback,
        PROVIDER_GL_NV_transform_feedback,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        1173 /* "glBindBufferRange" */,
        1173 /* "glBindBufferRange" */,
        1173 /* "glBindBufferRange" */,
        1173 /* "glBindBufferRange" */,
        1191 /* "glBindBufferRangeEXT" */,
        1212 /* "glBindBufferRangeNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 1173 /* "glBindBufferRange" */,
                                providers, entrypoints);
}

static PFNGLBINDBUFFERRANGEEXTPROC
epoxy_glBindBufferRangeEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_transform_feedback,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_Desktop_OpenGL_3_1,
        PROVIDER_GL_ARB_uniform_buffer_object,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_NV_transform_feedback,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        1191 /* "glBindBufferRangeEXT" */,
        1173 /* "glBindBufferRange" */,
        1173 /* "glBindBufferRange" */,
        1173 /* "glBindBufferRange" */,
        1173 /* "glBindBufferRange" */,
        1212 /* "glBindBufferRangeNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 1191 /* "glBindBufferRangeEXT" */,
                                providers, entrypoints);
}

static PFNGLBINDBUFFERRANGENVPROC
epoxy_glBindBufferRangeNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_transform_feedback,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_Desktop_OpenGL_3_1,
        PROVIDER_GL_ARB_uniform_buffer_object,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_EXT_transform_feedback,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        1212 /* "glBindBufferRangeNV" */,
        1173 /* "glBindBufferRange" */,
        1173 /* "glBindBufferRange" */,
        1173 /* "glBindBufferRange" */,
        1173 /* "glBindBufferRange" */,
        1191 /* "glBindBufferRangeEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 1212 /* "glBindBufferRangeNV" */,
                                providers, entrypoints);
}

static PFNGLBINDBUFFERSBASEPROC
epoxy_glBindBuffersBase_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_4,
        PROVIDER_GL_ARB_multi_bind,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        1232 /* "glBindBuffersBase" */,
        1232 /* "glBindBuffersBase" */,
    };
    return gl_provider_resolver(entrypoint_strings + 1232 /* "glBindBuffersBase" */,
                                providers, entrypoints);
}

static PFNGLBINDBUFFERSRANGEPROC
epoxy_glBindBuffersRange_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_4,
        PROVIDER_GL_ARB_multi_bind,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        1250 /* "glBindBuffersRange" */,
        1250 /* "glBindBuffersRange" */,
    };
    return gl_provider_resolver(entrypoint_strings + 1250 /* "glBindBuffersRange" */,
                                providers, entrypoints);
}

static PFNGLBINDFRAGDATALOCATIONPROC
epoxy_glBindFragDataLocation_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_EXT_blend_func_extended,
        PROVIDER_GL_EXT_gpu_shader4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        1269 /* "glBindFragDataLocation" */,
        1292 /* "glBindFragDataLocationEXT" */,
        1292 /* "glBindFragDataLocationEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 1269 /* "glBindFragDataLocation" */,
                                providers, entrypoints);
}

static PFNGLBINDFRAGDATALOCATIONEXTPROC
epoxy_glBindFragDataLocationEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_blend_func_extended,
        PROVIDER_GL_EXT_gpu_shader4,
        PROVIDER_Desktop_OpenGL_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        1292 /* "glBindFragDataLocationEXT" */,
        1292 /* "glBindFragDataLocationEXT" */,
        1269 /* "glBindFragDataLocation" */,
    };
    return gl_provider_resolver(entrypoint_strings + 1292 /* "glBindFragDataLocationEXT" */,
                                providers, entrypoints);
}

static PFNGLBINDFRAGDATALOCATIONINDEXEDPROC
epoxy_glBindFragDataLocationIndexed_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_blend_func_extended,
        PROVIDER_GL_EXT_blend_func_extended,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        1318 /* "glBindFragDataLocationIndexed" */,
        1318 /* "glBindFragDataLocationIndexed" */,
        1348 /* "glBindFragDataLocationIndexedEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 1318 /* "glBindFragDataLocationIndexed" */,
                                providers, entrypoints);
}

static PFNGLBINDFRAGDATALOCATIONINDEXEDEXTPROC
epoxy_glBindFragDataLocationIndexedEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_blend_func_extended,
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_blend_func_extended,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        1348 /* "glBindFragDataLocationIndexedEXT" */,
        1318 /* "glBindFragDataLocationIndexed" */,
        1318 /* "glBindFragDataLocationIndexed" */,
    };
    return gl_provider_resolver(entrypoint_strings + 1348 /* "glBindFragDataLocationIndexedEXT" */,
                                providers, entrypoints);
}

static PFNGLBINDFRAGMENTSHADERATIPROC
epoxy_glBindFragmentShaderATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_fragment_shader, 1381 /* glBindFragmentShaderATI */);
}

static PFNGLBINDFRAMEBUFFERPROC
epoxy_glBindFramebuffer_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_framebuffer_object,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_EXT_framebuffer_object,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        1405 /* "glBindFramebuffer" */,
        1405 /* "glBindFramebuffer" */,
        1405 /* "glBindFramebuffer" */,
        1423 /* "glBindFramebufferEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 1405 /* "glBindFramebuffer" */,
                                providers, entrypoints);
}

static PFNGLBINDFRAMEBUFFEREXTPROC
epoxy_glBindFramebufferEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_framebuffer_object,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_framebuffer_object,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        1423 /* "glBindFramebufferEXT" */,
        1405 /* "glBindFramebuffer" */,
        1405 /* "glBindFramebuffer" */,
        1405 /* "glBindFramebuffer" */,
    };
    return gl_provider_resolver(entrypoint_strings + 1423 /* "glBindFramebufferEXT" */,
                                providers, entrypoints);
}

static PFNGLBINDFRAMEBUFFEROESPROC
epoxy_glBindFramebufferOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_framebuffer_object, 1444 /* glBindFramebufferOES */);
}

static PFNGLBINDIMAGETEXTUREPROC
epoxy_glBindImageTexture_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_2,
        PROVIDER_GL_ARB_shader_image_load_store,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        1465 /* "glBindImageTexture" */,
        1465 /* "glBindImageTexture" */,
        1465 /* "glBindImageTexture" */,
    };
    return gl_provider_resolver(entrypoint_strings + 1465 /* "glBindImageTexture" */,
                                providers, entrypoints);
}

static PFNGLBINDIMAGETEXTUREEXTPROC
epoxy_glBindImageTextureEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_shader_image_load_store, 1484 /* glBindImageTextureEXT */);
}

static PFNGLBINDIMAGETEXTURESPROC
epoxy_glBindImageTextures_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_4,
        PROVIDER_GL_ARB_multi_bind,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        1506 /* "glBindImageTextures" */,
        1506 /* "glBindImageTextures" */,
    };
    return gl_provider_resolver(entrypoint_strings + 1506 /* "glBindImageTextures" */,
                                providers, entrypoints);
}

static PFNGLBINDLIGHTPARAMETEREXTPROC
epoxy_glBindLightParameterEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_shader, 1526 /* glBindLightParameterEXT */);
}

static PFNGLBINDMATERIALPARAMETEREXTPROC
epoxy_glBindMaterialParameterEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_shader, 1550 /* glBindMaterialParameterEXT */);
}

static PFNGLBINDMULTITEXTUREEXTPROC
epoxy_glBindMultiTextureEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 1577 /* glBindMultiTextureEXT */);
}

static PFNGLBINDPARAMETEREXTPROC
epoxy_glBindParameterEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_shader, 1599 /* glBindParameterEXT */);
}

static PFNGLBINDPROGRAMARBPROC
epoxy_glBindProgramARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_fragment_program,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        1618 /* "glBindProgramARB" */,
        1618 /* "glBindProgramARB" */,
        1635 /* "glBindProgramNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 1618 /* "glBindProgramARB" */,
                                providers, entrypoints);
}

static PFNGLBINDPROGRAMNVPROC
epoxy_glBindProgramNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program,
        PROVIDER_GL_ARB_fragment_program,
        PROVIDER_GL_ARB_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        1635 /* "glBindProgramNV" */,
        1618 /* "glBindProgramARB" */,
        1618 /* "glBindProgramARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 1635 /* "glBindProgramNV" */,
                                providers, entrypoints);
}

static PFNGLBINDPROGRAMPIPELINEPROC
epoxy_glBindProgramPipeline_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        1651 /* "glBindProgramPipeline" */,
        1651 /* "glBindProgramPipeline" */,
        1651 /* "glBindProgramPipeline" */,
    };
    return gl_provider_resolver(entrypoint_strings + 1651 /* "glBindProgramPipeline" */,
                                providers, entrypoints);
}

static PFNGLBINDPROGRAMPIPELINEEXTPROC
epoxy_glBindProgramPipelineEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_separate_shader_objects, 1673 /* glBindProgramPipelineEXT */);
}

static PFNGLBINDRENDERBUFFERPROC
epoxy_glBindRenderbuffer_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_framebuffer_object,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_EXT_framebuffer_object,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        1698 /* "glBindRenderbuffer" */,
        1698 /* "glBindRenderbuffer" */,
        1698 /* "glBindRenderbuffer" */,
        1717 /* "glBindRenderbufferEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 1698 /* "glBindRenderbuffer" */,
                                providers, entrypoints);
}

static PFNGLBINDRENDERBUFFEREXTPROC
epoxy_glBindRenderbufferEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_framebuffer_object,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_framebuffer_object,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        1717 /* "glBindRenderbufferEXT" */,
        1698 /* "glBindRenderbuffer" */,
        1698 /* "glBindRenderbuffer" */,
        1698 /* "glBindRenderbuffer" */,
    };
    return gl_provider_resolver(entrypoint_strings + 1717 /* "glBindRenderbufferEXT" */,
                                providers, entrypoints);
}

static PFNGLBINDRENDERBUFFEROESPROC
epoxy_glBindRenderbufferOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_framebuffer_object, 1739 /* glBindRenderbufferOES */);
}

static PFNGLBINDSAMPLERPROC
epoxy_glBindSampler_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_sampler_objects,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        1761 /* "glBindSampler" */,
        1761 /* "glBindSampler" */,
        1761 /* "glBindSampler" */,
    };
    return gl_provider_resolver(entrypoint_strings + 1761 /* "glBindSampler" */,
                                providers, entrypoints);
}

static PFNGLBINDSAMPLERSPROC
epoxy_glBindSamplers_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_4,
        PROVIDER_GL_ARB_multi_bind,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        1775 /* "glBindSamplers" */,
        1775 /* "glBindSamplers" */,
    };
    return gl_provider_resolver(entrypoint_strings + 1775 /* "glBindSamplers" */,
                                providers, entrypoints);
}

static PFNGLBINDSHADINGRATEIMAGENVPROC
epoxy_glBindShadingRateImageNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_shading_rate_image, 1790 /* glBindShadingRateImageNV */);
}

static PFNGLBINDTEXGENPARAMETEREXTPROC
epoxy_glBindTexGenParameterEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_shader, 1815 /* glBindTexGenParameterEXT */);
}

static PFNGLBINDTEXTUREPROC
epoxy_glBindTexture_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_1,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_EXT_texture_object,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        1840 /* "glBindTexture" */,
        1840 /* "glBindTexture" */,
        1840 /* "glBindTexture" */,
        1854 /* "glBindTextureEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 1840 /* "glBindTexture" */,
                                providers, entrypoints);
}

static PFNGLBINDTEXTUREEXTPROC
epoxy_glBindTextureEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_texture_object,
        PROVIDER_Desktop_OpenGL_1_1,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        1854 /* "glBindTextureEXT" */,
        1840 /* "glBindTexture" */,
        1840 /* "glBindTexture" */,
        1840 /* "glBindTexture" */,
    };
    return gl_provider_resolver(entrypoint_strings + 1854 /* "glBindTextureEXT" */,
                                providers, entrypoints);
}

static PFNGLBINDTEXTUREUNITPROC
epoxy_glBindTextureUnit_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        1871 /* "glBindTextureUnit" */,
        1871 /* "glBindTextureUnit" */,
    };
    return gl_provider_resolver(entrypoint_strings + 1871 /* "glBindTextureUnit" */,
                                providers, entrypoints);
}

static PFNGLBINDTEXTUREUNITPARAMETEREXTPROC
epoxy_glBindTextureUnitParameterEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_shader, 1889 /* glBindTextureUnitParameterEXT */);
}

static PFNGLBINDTEXTURESPROC
epoxy_glBindTextures_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_4,
        PROVIDER_GL_ARB_multi_bind,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        1919 /* "glBindTextures" */,
        1919 /* "glBindTextures" */,
    };
    return gl_provider_resolver(entrypoint_strings + 1919 /* "glBindTextures" */,
                                providers, entrypoints);
}

static PFNGLBINDTRANSFORMFEEDBACKPROC
epoxy_glBindTransformFeedback_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_GL_ARB_transform_feedback2,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        1934 /* "glBindTransformFeedback" */,
        1934 /* "glBindTransformFeedback" */,
        1934 /* "glBindTransformFeedback" */,
    };
    return gl_provider_resolver(entrypoint_strings + 1934 /* "glBindTransformFeedback" */,
                                providers, entrypoints);
}

static PFNGLBINDTRANSFORMFEEDBACKNVPROC
epoxy_glBindTransformFeedbackNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_transform_feedback2, 1958 /* glBindTransformFeedbackNV */);
}

static PFNGLBINDVERTEXARRAYPROC
epoxy_glBindVertexArray_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_vertex_array_object,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_APPLE_vertex_array_object,
        PROVIDER_GL_OES_vertex_array_object,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        1984 /* "glBindVertexArray" */,
        1984 /* "glBindVertexArray" */,
        1984 /* "glBindVertexArray" */,
        2002 /* "glBindVertexArrayAPPLE" */,
        2025 /* "glBindVertexArrayOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 1984 /* "glBindVertexArray" */,
                                providers, entrypoints);
}

static PFNGLBINDVERTEXARRAYAPPLEPROC
epoxy_glBindVertexArrayAPPLE_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_APPLE_vertex_array_object,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_vertex_array_object,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        2002 /* "glBindVertexArrayAPPLE" */,
        1984 /* "glBindVertexArray" */,
        1984 /* "glBindVertexArray" */,
        1984 /* "glBindVertexArray" */,
    };
    return gl_provider_resolver(entrypoint_strings + 2002 /* "glBindVertexArrayAPPLE" */,
                                providers, entrypoints);
}

static PFNGLBINDVERTEXARRAYOESPROC
epoxy_glBindVertexArrayOES_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_OES_vertex_array_object,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_vertex_array_object,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        2025 /* "glBindVertexArrayOES" */,
        1984 /* "glBindVertexArray" */,
        1984 /* "glBindVertexArray" */,
        1984 /* "glBindVertexArray" */,
    };
    return gl_provider_resolver(entrypoint_strings + 2025 /* "glBindVertexArrayOES" */,
                                providers, entrypoints);
}

static PFNGLBINDVERTEXBUFFERPROC
epoxy_glBindVertexBuffer_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_ARB_vertex_attrib_binding,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        2046 /* "glBindVertexBuffer" */,
        2046 /* "glBindVertexBuffer" */,
        2046 /* "glBindVertexBuffer" */,
    };
    return gl_provider_resolver(entrypoint_strings + 2046 /* "glBindVertexBuffer" */,
                                providers, entrypoints);
}

static PFNGLBINDVERTEXBUFFERSPROC
epoxy_glBindVertexBuffers_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_4,
        PROVIDER_GL_ARB_multi_bind,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        2065 /* "glBindVertexBuffers" */,
        2065 /* "glBindVertexBuffers" */,
    };
    return gl_provider_resolver(entrypoint_strings + 2065 /* "glBindVertexBuffers" */,
                                providers, entrypoints);
}

static PFNGLBINDVERTEXSHADEREXTPROC
epoxy_glBindVertexShaderEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_shader, 2085 /* glBindVertexShaderEXT */);
}

static PFNGLBINDVIDEOCAPTURESTREAMBUFFERNVPROC
epoxy_glBindVideoCaptureStreamBufferNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_video_capture, 2107 /* glBindVideoCaptureStreamBufferNV */);
}

static PFNGLBINDVIDEOCAPTURESTREAMTEXTURENVPROC
epoxy_glBindVideoCaptureStreamTextureNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_video_capture, 2140 /* glBindVideoCaptureStreamTextureNV */);
}

static PFNGLBINORMAL3BEXTPROC
epoxy_glBinormal3bEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_coordinate_frame, 2174 /* glBinormal3bEXT */);
}

static PFNGLBINORMAL3BVEXTPROC
epoxy_glBinormal3bvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_coordinate_frame, 2190 /* glBinormal3bvEXT */);
}

static PFNGLBINORMAL3DEXTPROC
epoxy_glBinormal3dEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_coordinate_frame, 2207 /* glBinormal3dEXT */);
}

static PFNGLBINORMAL3DVEXTPROC
epoxy_glBinormal3dvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_coordinate_frame, 2223 /* glBinormal3dvEXT */);
}

static PFNGLBINORMAL3FEXTPROC
epoxy_glBinormal3fEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_coordinate_frame, 2240 /* glBinormal3fEXT */);
}

static PFNGLBINORMAL3FVEXTPROC
epoxy_glBinormal3fvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_coordinate_frame, 2256 /* glBinormal3fvEXT */);
}

static PFNGLBINORMAL3IEXTPROC
epoxy_glBinormal3iEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_coordinate_frame, 2273 /* glBinormal3iEXT */);
}

static PFNGLBINORMAL3IVEXTPROC
epoxy_glBinormal3ivEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_coordinate_frame, 2289 /* glBinormal3ivEXT */);
}

static PFNGLBINORMAL3SEXTPROC
epoxy_glBinormal3sEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_coordinate_frame, 2306 /* glBinormal3sEXT */);
}

static PFNGLBINORMAL3SVEXTPROC
epoxy_glBinormal3svEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_coordinate_frame, 2322 /* glBinormal3svEXT */);
}

static PFNGLBINORMALPOINTEREXTPROC
epoxy_glBinormalPointerEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_coordinate_frame, 2339 /* glBinormalPointerEXT */);
}

static PFNGLBITMAPPROC
epoxy_glBitmap_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 2360 /* glBitmap */);
}

static PFNGLBITMAPXOESPROC
epoxy_glBitmapxOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 2369 /* glBitmapxOES */);
}

static PFNGLBLENDBARRIERPROC
epoxy_glBlendBarrier_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_KHR_blend_equation_advanced,
        PROVIDER_GL_NV_blend_equation_advanced,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        2382 /* "glBlendBarrier" */,
        2397 /* "glBlendBarrierKHR" */,
        2415 /* "glBlendBarrierNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 2382 /* "glBlendBarrier" */,
                                providers, entrypoints);
}

static PFNGLBLENDBARRIERKHRPROC
epoxy_glBlendBarrierKHR_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_KHR_blend_equation_advanced,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_NV_blend_equation_advanced,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        2397 /* "glBlendBarrierKHR" */,
        2382 /* "glBlendBarrier" */,
        2415 /* "glBlendBarrierNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 2397 /* "glBlendBarrierKHR" */,
                                providers, entrypoints);
}

static PFNGLBLENDBARRIERNVPROC
epoxy_glBlendBarrierNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_blend_equation_advanced,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_KHR_blend_equation_advanced,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        2415 /* "glBlendBarrierNV" */,
        2382 /* "glBlendBarrier" */,
        2397 /* "glBlendBarrierKHR" */,
    };
    return gl_provider_resolver(entrypoint_strings + 2415 /* "glBlendBarrierNV" */,
                                providers, entrypoints);
}

static PFNGLBLENDCOLORPROC
epoxy_glBlendColor_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_ARB_imaging,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_EXT_blend_color,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        2432 /* "glBlendColor" */,
        2432 /* "glBlendColor" */,
        2432 /* "glBlendColor" */,
        2445 /* "glBlendColorEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 2432 /* "glBlendColor" */,
                                providers, entrypoints);
}

static PFNGLBLENDCOLOREXTPROC
epoxy_glBlendColorEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_blend_color,
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_ARB_imaging,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        2445 /* "glBlendColorEXT" */,
        2432 /* "glBlendColor" */,
        2432 /* "glBlendColor" */,
        2432 /* "glBlendColor" */,
    };
    return gl_provider_resolver(entrypoint_strings + 2445 /* "glBlendColorEXT" */,
                                providers, entrypoints);
}

static PFNGLBLENDCOLORXOESPROC
epoxy_glBlendColorxOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 2461 /* glBlendColorxOES */);
}

static PFNGLBLENDEQUATIONPROC
epoxy_glBlendEquation_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_ARB_imaging,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_EXT_blend_minmax,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        2478 /* "glBlendEquation" */,
        2478 /* "glBlendEquation" */,
        2478 /* "glBlendEquation" */,
        2494 /* "glBlendEquationEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 2478 /* "glBlendEquation" */,
                                providers, entrypoints);
}

static PFNGLBLENDEQUATIONEXTPROC
epoxy_glBlendEquationEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_blend_minmax,
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_ARB_imaging,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        2494 /* "glBlendEquationEXT" */,
        2478 /* "glBlendEquation" */,
        2478 /* "glBlendEquation" */,
        2478 /* "glBlendEquation" */,
    };
    return gl_provider_resolver(entrypoint_strings + 2494 /* "glBlendEquationEXT" */,
                                providers, entrypoints);
}

static PFNGLBLENDEQUATIONINDEXEDAMDPROC
epoxy_glBlendEquationIndexedAMD_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_AMD_draw_buffers_blend,
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_ARB_draw_buffers_blend,
        PROVIDER_GL_EXT_draw_buffers_indexed,
        PROVIDER_GL_OES_draw_buffers_indexed,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        2513 /* "glBlendEquationIndexedAMD" */,
        2779 /* "glBlendEquationi" */,
        2779 /* "glBlendEquationi" */,
        2796 /* "glBlendEquationiARB" */,
        2816 /* "glBlendEquationiEXT" */,
        2836 /* "glBlendEquationiOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 2513 /* "glBlendEquationIndexedAMD" */,
                                providers, entrypoints);
}

static PFNGLBLENDEQUATIONOESPROC
epoxy_glBlendEquationOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_blend_subtract, 2539 /* glBlendEquationOES */);
}

static PFNGLBLENDEQUATIONSEPARATEPROC
epoxy_glBlendEquationSeparate_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_EXT_blend_equation_separate,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        2558 /* "glBlendEquationSeparate" */,
        2558 /* "glBlendEquationSeparate" */,
        2582 /* "glBlendEquationSeparateEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 2558 /* "glBlendEquationSeparate" */,
                                providers, entrypoints);
}

static PFNGLBLENDEQUATIONSEPARATEEXTPROC
epoxy_glBlendEquationSeparateEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_blend_equation_separate,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        2582 /* "glBlendEquationSeparateEXT" */,
        2558 /* "glBlendEquationSeparate" */,
        2558 /* "glBlendEquationSeparate" */,
    };
    return gl_provider_resolver(entrypoint_strings + 2582 /* "glBlendEquationSeparateEXT" */,
                                providers, entrypoints);
}

static PFNGLBLENDEQUATIONSEPARATEINDEXEDAMDPROC
epoxy_glBlendEquationSeparateIndexedAMD_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_AMD_draw_buffers_blend,
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_ARB_draw_buffers_blend,
        PROVIDER_GL_EXT_draw_buffers_indexed,
        PROVIDER_GL_OES_draw_buffers_indexed,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        2609 /* "glBlendEquationSeparateIndexedAMD" */,
        2670 /* "glBlendEquationSeparatei" */,
        2670 /* "glBlendEquationSeparatei" */,
        2695 /* "glBlendEquationSeparateiARB" */,
        2723 /* "glBlendEquationSeparateiEXT" */,
        2751 /* "glBlendEquationSeparateiOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 2609 /* "glBlendEquationSeparateIndexedAMD" */,
                                providers, entrypoints);
}

static PFNGLBLENDEQUATIONSEPARATEOESPROC
epoxy_glBlendEquationSeparateOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_blend_equation_separate, 2643 /* glBlendEquationSeparateOES */);
}

static PFNGLBLENDEQUATIONSEPARATEIPROC
epoxy_glBlendEquationSeparatei_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_AMD_draw_buffers_blend,
        PROVIDER_GL_ARB_draw_buffers_blend,
        PROVIDER_GL_EXT_draw_buffers_indexed,
        PROVIDER_GL_OES_draw_buffers_indexed,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        2670 /* "glBlendEquationSeparatei" */,
        2670 /* "glBlendEquationSeparatei" */,
        2609 /* "glBlendEquationSeparateIndexedAMD" */,
        2695 /* "glBlendEquationSeparateiARB" */,
        2723 /* "glBlendEquationSeparateiEXT" */,
        2751 /* "glBlendEquationSeparateiOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 2670 /* "glBlendEquationSeparatei" */,
                                providers, entrypoints);
}

static PFNGLBLENDEQUATIONSEPARATEIARBPROC
epoxy_glBlendEquationSeparateiARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_draw_buffers_blend,
        PROVIDER_GL_AMD_draw_buffers_blend,
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_draw_buffers_indexed,
        PROVIDER_GL_OES_draw_buffers_indexed,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        2695 /* "glBlendEquationSeparateiARB" */,
        2609 /* "glBlendEquationSeparateIndexedAMD" */,
        2670 /* "glBlendEquationSeparatei" */,
        2670 /* "glBlendEquationSeparatei" */,
        2723 /* "glBlendEquationSeparateiEXT" */,
        2751 /* "glBlendEquationSeparateiOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 2695 /* "glBlendEquationSeparateiARB" */,
                                providers, entrypoints);
}

static PFNGLBLENDEQUATIONSEPARATEIEXTPROC
epoxy_glBlendEquationSeparateiEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_draw_buffers_indexed,
        PROVIDER_GL_AMD_draw_buffers_blend,
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_ARB_draw_buffers_blend,
        PROVIDER_GL_OES_draw_buffers_indexed,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        2723 /* "glBlendEquationSeparateiEXT" */,
        2609 /* "glBlendEquationSeparateIndexedAMD" */,
        2670 /* "glBlendEquationSeparatei" */,
        2670 /* "glBlendEquationSeparatei" */,
        2695 /* "glBlendEquationSeparateiARB" */,
        2751 /* "glBlendEquationSeparateiOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 2723 /* "glBlendEquationSeparateiEXT" */,
                                providers, entrypoints);
}

static PFNGLBLENDEQUATIONSEPARATEIOESPROC
epoxy_glBlendEquationSeparateiOES_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_OES_draw_buffers_indexed,
        PROVIDER_GL_AMD_draw_buffers_blend,
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_ARB_draw_buffers_blend,
        PROVIDER_GL_EXT_draw_buffers_indexed,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        2751 /* "glBlendEquationSeparateiOES" */,
        2609 /* "glBlendEquationSeparateIndexedAMD" */,
        2670 /* "glBlendEquationSeparatei" */,
        2670 /* "glBlendEquationSeparatei" */,
        2695 /* "glBlendEquationSeparateiARB" */,
        2723 /* "glBlendEquationSeparateiEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 2751 /* "glBlendEquationSeparateiOES" */,
                                providers, entrypoints);
}

static PFNGLBLENDEQUATIONIPROC
epoxy_glBlendEquationi_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_AMD_draw_buffers_blend,
        PROVIDER_GL_ARB_draw_buffers_blend,
        PROVIDER_GL_EXT_draw_buffers_indexed,
        PROVIDER_GL_OES_draw_buffers_indexed,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        2779 /* "glBlendEquationi" */,
        2779 /* "glBlendEquationi" */,
        2513 /* "glBlendEquationIndexedAMD" */,
        2796 /* "glBlendEquationiARB" */,
        2816 /* "glBlendEquationiEXT" */,
        2836 /* "glBlendEquationiOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 2779 /* "glBlendEquationi" */,
                                providers, entrypoints);
}

static PFNGLBLENDEQUATIONIARBPROC
epoxy_glBlendEquationiARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_draw_buffers_blend,
        PROVIDER_GL_AMD_draw_buffers_blend,
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_draw_buffers_indexed,
        PROVIDER_GL_OES_draw_buffers_indexed,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        2796 /* "glBlendEquationiARB" */,
        2513 /* "glBlendEquationIndexedAMD" */,
        2779 /* "glBlendEquationi" */,
        2779 /* "glBlendEquationi" */,
        2816 /* "glBlendEquationiEXT" */,
        2836 /* "glBlendEquationiOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 2796 /* "glBlendEquationiARB" */,
                                providers, entrypoints);
}

static PFNGLBLENDEQUATIONIEXTPROC
epoxy_glBlendEquationiEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_draw_buffers_indexed,
        PROVIDER_GL_AMD_draw_buffers_blend,
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_ARB_draw_buffers_blend,
        PROVIDER_GL_OES_draw_buffers_indexed,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        2816 /* "glBlendEquationiEXT" */,
        2513 /* "glBlendEquationIndexedAMD" */,
        2779 /* "glBlendEquationi" */,
        2779 /* "glBlendEquationi" */,
        2796 /* "glBlendEquationiARB" */,
        2836 /* "glBlendEquationiOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 2816 /* "glBlendEquationiEXT" */,
                                providers, entrypoints);
}

static PFNGLBLENDEQUATIONIOESPROC
epoxy_glBlendEquationiOES_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_OES_draw_buffers_indexed,
        PROVIDER_GL_AMD_draw_buffers_blend,
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_ARB_draw_buffers_blend,
        PROVIDER_GL_EXT_draw_buffers_indexed,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        2836 /* "glBlendEquationiOES" */,
        2513 /* "glBlendEquationIndexedAMD" */,
        2779 /* "glBlendEquationi" */,
        2779 /* "glBlendEquationi" */,
        2796 /* "glBlendEquationiARB" */,
        2816 /* "glBlendEquationiEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 2836 /* "glBlendEquationiOES" */,
                                providers, entrypoints);
}

static PFNGLBLENDFUNCPROC
epoxy_glBlendFunc_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        2856 /* "glBlendFunc" */,
        2856 /* "glBlendFunc" */,
        2856 /* "glBlendFunc" */,
    };
    return gl_provider_resolver(entrypoint_strings + 2856 /* "glBlendFunc" */,
                                providers, entrypoints);
}

static PFNGLBLENDFUNCINDEXEDAMDPROC
epoxy_glBlendFuncIndexedAMD_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_AMD_draw_buffers_blend,
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_ARB_draw_buffers_blend,
        PROVIDER_GL_EXT_draw_buffers_indexed,
        PROVIDER_GL_OES_draw_buffers_indexed,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        2868 /* "glBlendFuncIndexedAMD" */,
        3103 /* "glBlendFunci" */,
        3103 /* "glBlendFunci" */,
        3116 /* "glBlendFunciARB" */,
        3132 /* "glBlendFunciEXT" */,
        3148 /* "glBlendFunciOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 2868 /* "glBlendFuncIndexedAMD" */,
                                providers, entrypoints);
}

static PFNGLBLENDFUNCSEPARATEPROC
epoxy_glBlendFuncSeparate_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_EXT_blend_func_separate,
        PROVIDER_GL_INGR_blend_func_separate,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        2890 /* "glBlendFuncSeparate" */,
        2890 /* "glBlendFuncSeparate" */,
        2910 /* "glBlendFuncSeparateEXT" */,
        2933 /* "glBlendFuncSeparateINGR" */,
    };
    return gl_provider_resolver(entrypoint_strings + 2890 /* "glBlendFuncSeparate" */,
                                providers, entrypoints);
}

static PFNGLBLENDFUNCSEPARATEEXTPROC
epoxy_glBlendFuncSeparateEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_blend_func_separate,
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_INGR_blend_func_separate,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        2910 /* "glBlendFuncSeparateEXT" */,
        2890 /* "glBlendFuncSeparate" */,
        2890 /* "glBlendFuncSeparate" */,
        2933 /* "glBlendFuncSeparateINGR" */,
    };
    return gl_provider_resolver(entrypoint_strings + 2910 /* "glBlendFuncSeparateEXT" */,
                                providers, entrypoints);
}

static PFNGLBLENDFUNCSEPARATEINGRPROC
epoxy_glBlendFuncSeparateINGR_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_INGR_blend_func_separate,
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_EXT_blend_func_separate,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        2933 /* "glBlendFuncSeparateINGR" */,
        2890 /* "glBlendFuncSeparate" */,
        2890 /* "glBlendFuncSeparate" */,
        2910 /* "glBlendFuncSeparateEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 2933 /* "glBlendFuncSeparateINGR" */,
                                providers, entrypoints);
}

static PFNGLBLENDFUNCSEPARATEINDEXEDAMDPROC
epoxy_glBlendFuncSeparateIndexedAMD_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_AMD_draw_buffers_blend,
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_ARB_draw_buffers_blend,
        PROVIDER_GL_EXT_draw_buffers_indexed,
        PROVIDER_GL_OES_draw_buffers_indexed,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        2957 /* "glBlendFuncSeparateIndexedAMD" */,
        3010 /* "glBlendFuncSeparatei" */,
        3010 /* "glBlendFuncSeparatei" */,
        3031 /* "glBlendFuncSeparateiARB" */,
        3055 /* "glBlendFuncSeparateiEXT" */,
        3079 /* "glBlendFuncSeparateiOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 2957 /* "glBlendFuncSeparateIndexedAMD" */,
                                providers, entrypoints);
}

static PFNGLBLENDFUNCSEPARATEOESPROC
epoxy_glBlendFuncSeparateOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_blend_func_separate, 2987 /* glBlendFuncSeparateOES */);
}

static PFNGLBLENDFUNCSEPARATEIPROC
epoxy_glBlendFuncSeparatei_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_AMD_draw_buffers_blend,
        PROVIDER_GL_ARB_draw_buffers_blend,
        PROVIDER_GL_EXT_draw_buffers_indexed,
        PROVIDER_GL_OES_draw_buffers_indexed,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        3010 /* "glBlendFuncSeparatei" */,
        3010 /* "glBlendFuncSeparatei" */,
        2957 /* "glBlendFuncSeparateIndexedAMD" */,
        3031 /* "glBlendFuncSeparateiARB" */,
        3055 /* "glBlendFuncSeparateiEXT" */,
        3079 /* "glBlendFuncSeparateiOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 3010 /* "glBlendFuncSeparatei" */,
                                providers, entrypoints);
}

static PFNGLBLENDFUNCSEPARATEIARBPROC
epoxy_glBlendFuncSeparateiARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_draw_buffers_blend,
        PROVIDER_GL_AMD_draw_buffers_blend,
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_draw_buffers_indexed,
        PROVIDER_GL_OES_draw_buffers_indexed,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        3031 /* "glBlendFuncSeparateiARB" */,
        2957 /* "glBlendFuncSeparateIndexedAMD" */,
        3010 /* "glBlendFuncSeparatei" */,
        3010 /* "glBlendFuncSeparatei" */,
        3055 /* "glBlendFuncSeparateiEXT" */,
        3079 /* "glBlendFuncSeparateiOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 3031 /* "glBlendFuncSeparateiARB" */,
                                providers, entrypoints);
}

static PFNGLBLENDFUNCSEPARATEIEXTPROC
epoxy_glBlendFuncSeparateiEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_draw_buffers_indexed,
        PROVIDER_GL_AMD_draw_buffers_blend,
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_ARB_draw_buffers_blend,
        PROVIDER_GL_OES_draw_buffers_indexed,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        3055 /* "glBlendFuncSeparateiEXT" */,
        2957 /* "glBlendFuncSeparateIndexedAMD" */,
        3010 /* "glBlendFuncSeparatei" */,
        3010 /* "glBlendFuncSeparatei" */,
        3031 /* "glBlendFuncSeparateiARB" */,
        3079 /* "glBlendFuncSeparateiOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 3055 /* "glBlendFuncSeparateiEXT" */,
                                providers, entrypoints);
}

static PFNGLBLENDFUNCSEPARATEIOESPROC
epoxy_glBlendFuncSeparateiOES_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_OES_draw_buffers_indexed,
        PROVIDER_GL_AMD_draw_buffers_blend,
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_ARB_draw_buffers_blend,
        PROVIDER_GL_EXT_draw_buffers_indexed,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        3079 /* "glBlendFuncSeparateiOES" */,
        2957 /* "glBlendFuncSeparateIndexedAMD" */,
        3010 /* "glBlendFuncSeparatei" */,
        3010 /* "glBlendFuncSeparatei" */,
        3031 /* "glBlendFuncSeparateiARB" */,
        3055 /* "glBlendFuncSeparateiEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 3079 /* "glBlendFuncSeparateiOES" */,
                                providers, entrypoints);
}

static PFNGLBLENDFUNCIPROC
epoxy_glBlendFunci_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_AMD_draw_buffers_blend,
        PROVIDER_GL_ARB_draw_buffers_blend,
        PROVIDER_GL_EXT_draw_buffers_indexed,
        PROVIDER_GL_OES_draw_buffers_indexed,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        3103 /* "glBlendFunci" */,
        3103 /* "glBlendFunci" */,
        2868 /* "glBlendFuncIndexedAMD" */,
        3116 /* "glBlendFunciARB" */,
        3132 /* "glBlendFunciEXT" */,
        3148 /* "glBlendFunciOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 3103 /* "glBlendFunci" */,
                                providers, entrypoints);
}

static PFNGLBLENDFUNCIARBPROC
epoxy_glBlendFunciARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_draw_buffers_blend,
        PROVIDER_GL_AMD_draw_buffers_blend,
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_draw_buffers_indexed,
        PROVIDER_GL_OES_draw_buffers_indexed,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        3116 /* "glBlendFunciARB" */,
        2868 /* "glBlendFuncIndexedAMD" */,
        3103 /* "glBlendFunci" */,
        3103 /* "glBlendFunci" */,
        3132 /* "glBlendFunciEXT" */,
        3148 /* "glBlendFunciOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 3116 /* "glBlendFunciARB" */,
                                providers, entrypoints);
}

static PFNGLBLENDFUNCIEXTPROC
epoxy_glBlendFunciEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_draw_buffers_indexed,
        PROVIDER_GL_AMD_draw_buffers_blend,
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_ARB_draw_buffers_blend,
        PROVIDER_GL_OES_draw_buffers_indexed,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        3132 /* "glBlendFunciEXT" */,
        2868 /* "glBlendFuncIndexedAMD" */,
        3103 /* "glBlendFunci" */,
        3103 /* "glBlendFunci" */,
        3116 /* "glBlendFunciARB" */,
        3148 /* "glBlendFunciOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 3132 /* "glBlendFunciEXT" */,
                                providers, entrypoints);
}

static PFNGLBLENDFUNCIOESPROC
epoxy_glBlendFunciOES_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_OES_draw_buffers_indexed,
        PROVIDER_GL_AMD_draw_buffers_blend,
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_ARB_draw_buffers_blend,
        PROVIDER_GL_EXT_draw_buffers_indexed,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        3148 /* "glBlendFunciOES" */,
        2868 /* "glBlendFuncIndexedAMD" */,
        3103 /* "glBlendFunci" */,
        3103 /* "glBlendFunci" */,
        3116 /* "glBlendFunciARB" */,
        3132 /* "glBlendFunciEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 3148 /* "glBlendFunciOES" */,
                                providers, entrypoints);
}

static PFNGLBLENDPARAMETERINVPROC
epoxy_glBlendParameteriNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_blend_equation_advanced, 3164 /* glBlendParameteriNV */);
}

static PFNGLBLITFRAMEBUFFERPROC
epoxy_glBlitFramebuffer_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_framebuffer_object,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_EXT_framebuffer_blit,
        PROVIDER_GL_NV_framebuffer_blit,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        3184 /* "glBlitFramebuffer" */,
        3184 /* "glBlitFramebuffer" */,
        3184 /* "glBlitFramebuffer" */,
        3225 /* "glBlitFramebufferEXT" */,
        3246 /* "glBlitFramebufferNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 3184 /* "glBlitFramebuffer" */,
                                providers, entrypoints);
}

static PFNGLBLITFRAMEBUFFERANGLEPROC
epoxy_glBlitFramebufferANGLE_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ANGLE_framebuffer_blit, 3202 /* glBlitFramebufferANGLE */);
}

static PFNGLBLITFRAMEBUFFEREXTPROC
epoxy_glBlitFramebufferEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_framebuffer_blit,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_framebuffer_object,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_NV_framebuffer_blit,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        3225 /* "glBlitFramebufferEXT" */,
        3184 /* "glBlitFramebuffer" */,
        3184 /* "glBlitFramebuffer" */,
        3184 /* "glBlitFramebuffer" */,
        3246 /* "glBlitFramebufferNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 3225 /* "glBlitFramebufferEXT" */,
                                providers, entrypoints);
}

static PFNGLBLITFRAMEBUFFERNVPROC
epoxy_glBlitFramebufferNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_framebuffer_blit,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_framebuffer_object,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_EXT_framebuffer_blit,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        3246 /* "glBlitFramebufferNV" */,
        3184 /* "glBlitFramebuffer" */,
        3184 /* "glBlitFramebuffer" */,
        3184 /* "glBlitFramebuffer" */,
        3225 /* "glBlitFramebufferEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 3246 /* "glBlitFramebufferNV" */,
                                providers, entrypoints);
}

static PFNGLBLITNAMEDFRAMEBUFFERPROC
epoxy_glBlitNamedFramebuffer_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        3266 /* "glBlitNamedFramebuffer" */,
        3266 /* "glBlitNamedFramebuffer" */,
    };
    return gl_provider_resolver(entrypoint_strings + 3266 /* "glBlitNamedFramebuffer" */,
                                providers, entrypoints);
}

static PFNGLBUFFERADDRESSRANGENVPROC
epoxy_glBufferAddressRangeNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_buffer_unified_memory, 3289 /* glBufferAddressRangeNV */);
}

static PFNGLBUFFERATTACHMEMORYNVPROC
epoxy_glBufferAttachMemoryNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_memory_attachment, 3312 /* glBufferAttachMemoryNV */);
}

static PFNGLBUFFERDATAPROC
epoxy_glBufferData_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_5,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_vertex_buffer_object,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        3335 /* "glBufferData" */,
        3335 /* "glBufferData" */,
        3335 /* "glBufferData" */,
        3348 /* "glBufferDataARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 3335 /* "glBufferData" */,
                                providers, entrypoints);
}

static PFNGLBUFFERDATAARBPROC
epoxy_glBufferDataARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_buffer_object,
        PROVIDER_Desktop_OpenGL_1_5,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        3348 /* "glBufferDataARB" */,
        3335 /* "glBufferData" */,
        3335 /* "glBufferData" */,
        3335 /* "glBufferData" */,
    };
    return gl_provider_resolver(entrypoint_strings + 3348 /* "glBufferDataARB" */,
                                providers, entrypoints);
}

static PFNGLBUFFERPAGECOMMITMENTARBPROC
epoxy_glBufferPageCommitmentARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_sparse_buffer, 3364 /* glBufferPageCommitmentARB */);
}

static PFNGLBUFFERPARAMETERIAPPLEPROC
epoxy_glBufferParameteriAPPLE_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_APPLE_flush_buffer_range, 3390 /* glBufferParameteriAPPLE */);
}

static PFNGLBUFFERSTORAGEPROC
epoxy_glBufferStorage_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_4,
        PROVIDER_GL_ARB_buffer_storage,
        PROVIDER_GL_EXT_buffer_storage,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        3414 /* "glBufferStorage" */,
        3414 /* "glBufferStorage" */,
        3430 /* "glBufferStorageEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 3414 /* "glBufferStorage" */,
                                providers, entrypoints);
}

static PFNGLBUFFERSTORAGEEXTPROC
epoxy_glBufferStorageEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_buffer_storage,
        PROVIDER_Desktop_OpenGL_4_4,
        PROVIDER_GL_ARB_buffer_storage,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        3430 /* "glBufferStorageEXT" */,
        3414 /* "glBufferStorage" */,
        3414 /* "glBufferStorage" */,
    };
    return gl_provider_resolver(entrypoint_strings + 3430 /* "glBufferStorageEXT" */,
                                providers, entrypoints);
}

static PFNGLBUFFERSTORAGEEXTERNALEXTPROC
epoxy_glBufferStorageExternalEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_external_buffer, 3449 /* glBufferStorageExternalEXT */);
}

static PFNGLBUFFERSTORAGEMEMEXTPROC
epoxy_glBufferStorageMemEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_memory_object, 3476 /* glBufferStorageMemEXT */);
}

static PFNGLBUFFERSUBDATAPROC
epoxy_glBufferSubData_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_5,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_vertex_buffer_object,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        3498 /* "glBufferSubData" */,
        3498 /* "glBufferSubData" */,
        3498 /* "glBufferSubData" */,
        3514 /* "glBufferSubDataARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 3498 /* "glBufferSubData" */,
                                providers, entrypoints);
}

static PFNGLBUFFERSUBDATAARBPROC
epoxy_glBufferSubDataARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_buffer_object,
        PROVIDER_Desktop_OpenGL_1_5,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        3514 /* "glBufferSubDataARB" */,
        3498 /* "glBufferSubData" */,
        3498 /* "glBufferSubData" */,
        3498 /* "glBufferSubData" */,
    };
    return gl_provider_resolver(entrypoint_strings + 3514 /* "glBufferSubDataARB" */,
                                providers, entrypoints);
}

static PFNGLCALLCOMMANDLISTNVPROC
epoxy_glCallCommandListNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_command_list, 3533 /* glCallCommandListNV */);
}

static PFNGLCALLLISTPROC
epoxy_glCallList_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 3553 /* glCallList */);
}

static PFNGLCALLLISTSPROC
epoxy_glCallLists_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 3564 /* glCallLists */);
}

static PFNGLCHECKFRAMEBUFFERSTATUSPROC
epoxy_glCheckFramebufferStatus_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_framebuffer_object,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_EXT_framebuffer_object,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        3576 /* "glCheckFramebufferStatus" */,
        3576 /* "glCheckFramebufferStatus" */,
        3576 /* "glCheckFramebufferStatus" */,
        3601 /* "glCheckFramebufferStatusEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 3576 /* "glCheckFramebufferStatus" */,
                                providers, entrypoints);
}

static PFNGLCHECKFRAMEBUFFERSTATUSEXTPROC
epoxy_glCheckFramebufferStatusEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_framebuffer_object,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_framebuffer_object,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        3601 /* "glCheckFramebufferStatusEXT" */,
        3576 /* "glCheckFramebufferStatus" */,
        3576 /* "glCheckFramebufferStatus" */,
        3576 /* "glCheckFramebufferStatus" */,
    };
    return gl_provider_resolver(entrypoint_strings + 3601 /* "glCheckFramebufferStatusEXT" */,
                                providers, entrypoints);
}

static PFNGLCHECKFRAMEBUFFERSTATUSOESPROC
epoxy_glCheckFramebufferStatusOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_framebuffer_object, 3629 /* glCheckFramebufferStatusOES */);
}

static PFNGLCHECKNAMEDFRAMEBUFFERSTATUSPROC
epoxy_glCheckNamedFramebufferStatus_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        3657 /* "glCheckNamedFramebufferStatus" */,
        3657 /* "glCheckNamedFramebufferStatus" */,
    };
    return gl_provider_resolver(entrypoint_strings + 3657 /* "glCheckNamedFramebufferStatus" */,
                                providers, entrypoints);
}

static PFNGLCHECKNAMEDFRAMEBUFFERSTATUSEXTPROC
epoxy_glCheckNamedFramebufferStatusEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 3687 /* glCheckNamedFramebufferStatusEXT */);
}

static PFNGLCLAMPCOLORPROC
epoxy_glClampColor_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_color_buffer_float,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        3720 /* "glClampColor" */,
        3733 /* "glClampColorARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 3720 /* "glClampColor" */,
                                providers, entrypoints);
}

static PFNGLCLAMPCOLORARBPROC
epoxy_glClampColorARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_color_buffer_float,
        PROVIDER_Desktop_OpenGL_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        3733 /* "glClampColorARB" */,
        3720 /* "glClampColor" */,
    };
    return gl_provider_resolver(entrypoint_strings + 3733 /* "glClampColorARB" */,
                                providers, entrypoints);
}

static PFNGLCLEARPROC
epoxy_glClear_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        3749 /* "glClear" */,
        3749 /* "glClear" */,
        3749 /* "glClear" */,
    };
    return gl_provider_resolver(entrypoint_strings + 3749 /* "glClear" */,
                                providers, entrypoints);
}

static PFNGLCLEARACCUMPROC
epoxy_glClearAccum_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 3757 /* glClearAccum */);
}

static PFNGLCLEARACCUMXOESPROC
epoxy_glClearAccumxOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 3770 /* glClearAccumxOES */);
}

static PFNGLCLEARBUFFERDATAPROC
epoxy_glClearBufferData_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_ARB_clear_buffer_object,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        3787 /* "glClearBufferData" */,
        3787 /* "glClearBufferData" */,
    };
    return gl_provider_resolver(entrypoint_strings + 3787 /* "glClearBufferData" */,
                                providers, entrypoints);
}

static PFNGLCLEARBUFFERSUBDATAPROC
epoxy_glClearBufferSubData_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_ARB_clear_buffer_object,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        3805 /* "glClearBufferSubData" */,
        3805 /* "glClearBufferSubData" */,
    };
    return gl_provider_resolver(entrypoint_strings + 3805 /* "glClearBufferSubData" */,
                                providers, entrypoints);
}

static PFNGLCLEARBUFFERFIPROC
epoxy_glClearBufferfi_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        3826 /* "glClearBufferfi" */,
        3826 /* "glClearBufferfi" */,
    };
    return gl_provider_resolver(entrypoint_strings + 3826 /* "glClearBufferfi" */,
                                providers, entrypoints);
}

static PFNGLCLEARBUFFERFVPROC
epoxy_glClearBufferfv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        3842 /* "glClearBufferfv" */,
        3842 /* "glClearBufferfv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 3842 /* "glClearBufferfv" */,
                                providers, entrypoints);
}

static PFNGLCLEARBUFFERIVPROC
epoxy_glClearBufferiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        3858 /* "glClearBufferiv" */,
        3858 /* "glClearBufferiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 3858 /* "glClearBufferiv" */,
                                providers, entrypoints);
}

static PFNGLCLEARBUFFERUIVPROC
epoxy_glClearBufferuiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        3874 /* "glClearBufferuiv" */,
        3874 /* "glClearBufferuiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 3874 /* "glClearBufferuiv" */,
                                providers, entrypoints);
}

static PFNGLCLEARCOLORPROC
epoxy_glClearColor_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        3891 /* "glClearColor" */,
        3891 /* "glClearColor" */,
        3891 /* "glClearColor" */,
    };
    return gl_provider_resolver(entrypoint_strings + 3891 /* "glClearColor" */,
                                providers, entrypoints);
}

static PFNGLCLEARCOLORIIEXTPROC
epoxy_glClearColorIiEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_texture_integer, 3904 /* glClearColorIiEXT */);
}

static PFNGLCLEARCOLORIUIEXTPROC
epoxy_glClearColorIuiEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_texture_integer, 3922 /* glClearColorIuiEXT */);
}

static PFNGLCLEARCOLORXPROC
epoxy_glClearColorx_resolver(void)
{
    return gl_single_resolver(PROVIDER_OpenGL_ES_1_0, 3941 /* glClearColorx */);
}

static PFNGLCLEARCOLORXOESPROC
epoxy_glClearColorxOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 3955 /* glClearColorxOES */);
}

static PFNGLCLEARDEPTHPROC
epoxy_glClearDepth_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 3972 /* glClearDepth */);
}

static PFNGLCLEARDEPTHDNVPROC
epoxy_glClearDepthdNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_depth_buffer_float, 3985 /* glClearDepthdNV */);
}

static PFNGLCLEARDEPTHFPROC
epoxy_glClearDepthf_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_ES2_compatibility,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_OES_single_precision,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        4001 /* "glClearDepthf" */,
        4001 /* "glClearDepthf" */,
        4001 /* "glClearDepthf" */,
        4001 /* "glClearDepthf" */,
        4015 /* "glClearDepthfOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 4001 /* "glClearDepthf" */,
                                providers, entrypoints);
}

static PFNGLCLEARDEPTHFOESPROC
epoxy_glClearDepthfOES_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_OES_single_precision,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_ES2_compatibility,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        4015 /* "glClearDepthfOES" */,
        4001 /* "glClearDepthf" */,
        4001 /* "glClearDepthf" */,
        4001 /* "glClearDepthf" */,
        4001 /* "glClearDepthf" */,
    };
    return gl_provider_resolver(entrypoint_strings + 4015 /* "glClearDepthfOES" */,
                                providers, entrypoints);
}

static PFNGLCLEARDEPTHXPROC
epoxy_glClearDepthx_resolver(void)
{
    return gl_single_resolver(PROVIDER_OpenGL_ES_1_0, 4032 /* glClearDepthx */);
}

static PFNGLCLEARDEPTHXOESPROC
epoxy_glClearDepthxOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 4046 /* glClearDepthxOES */);
}

static PFNGLCLEARINDEXPROC
epoxy_glClearIndex_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 4063 /* glClearIndex */);
}

static PFNGLCLEARNAMEDBUFFERDATAPROC
epoxy_glClearNamedBufferData_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        4076 /* "glClearNamedBufferData" */,
        4076 /* "glClearNamedBufferData" */,
    };
    return gl_provider_resolver(entrypoint_strings + 4076 /* "glClearNamedBufferData" */,
                                providers, entrypoints);
}

static PFNGLCLEARNAMEDBUFFERDATAEXTPROC
epoxy_glClearNamedBufferDataEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 4099 /* glClearNamedBufferDataEXT */);
}

static PFNGLCLEARNAMEDBUFFERSUBDATAPROC
epoxy_glClearNamedBufferSubData_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        4125 /* "glClearNamedBufferSubData" */,
        4125 /* "glClearNamedBufferSubData" */,
    };
    return gl_provider_resolver(entrypoint_strings + 4125 /* "glClearNamedBufferSubData" */,
                                providers, entrypoints);
}

static PFNGLCLEARNAMEDBUFFERSUBDATAEXTPROC
epoxy_glClearNamedBufferSubDataEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 4151 /* glClearNamedBufferSubDataEXT */);
}

static PFNGLCLEARNAMEDFRAMEBUFFERFIPROC
epoxy_glClearNamedFramebufferfi_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        4180 /* "glClearNamedFramebufferfi" */,
        4180 /* "glClearNamedFramebufferfi" */,
    };
    return gl_provider_resolver(entrypoint_strings + 4180 /* "glClearNamedFramebufferfi" */,
                                providers, entrypoints);
}

static PFNGLCLEARNAMEDFRAMEBUFFERFVPROC
epoxy_glClearNamedFramebufferfv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        4206 /* "glClearNamedFramebufferfv" */,
        4206 /* "glClearNamedFramebufferfv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 4206 /* "glClearNamedFramebufferfv" */,
                                providers, entrypoints);
}

static PFNGLCLEARNAMEDFRAMEBUFFERIVPROC
epoxy_glClearNamedFramebufferiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        4232 /* "glClearNamedFramebufferiv" */,
        4232 /* "glClearNamedFramebufferiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 4232 /* "glClearNamedFramebufferiv" */,
                                providers, entrypoints);
}

static PFNGLCLEARNAMEDFRAMEBUFFERUIVPROC
epoxy_glClearNamedFramebufferuiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        4258 /* "glClearNamedFramebufferuiv" */,
        4258 /* "glClearNamedFramebufferuiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 4258 /* "glClearNamedFramebufferuiv" */,
                                providers, entrypoints);
}

static PFNGLCLEARPIXELLOCALSTORAGEUIEXTPROC
epoxy_glClearPixelLocalStorageuiEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_shader_pixel_local_storage2, 4285 /* glClearPixelLocalStorageuiEXT */);
}

static PFNGLCLEARSTENCILPROC
epoxy_glClearStencil_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        4315 /* "glClearStencil" */,
        4315 /* "glClearStencil" */,
        4315 /* "glClearStencil" */,
    };
    return gl_provider_resolver(entrypoint_strings + 4315 /* "glClearStencil" */,
                                providers, entrypoints);
}

static PFNGLCLEARTEXIMAGEPROC
epoxy_glClearTexImage_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_4,
        PROVIDER_GL_ARB_clear_texture,
        PROVIDER_GL_EXT_clear_texture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        4330 /* "glClearTexImage" */,
        4330 /* "glClearTexImage" */,
        4346 /* "glClearTexImageEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 4330 /* "glClearTexImage" */,
                                providers, entrypoints);
}

static PFNGLCLEARTEXIMAGEEXTPROC
epoxy_glClearTexImageEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_clear_texture,
        PROVIDER_Desktop_OpenGL_4_4,
        PROVIDER_GL_ARB_clear_texture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        4346 /* "glClearTexImageEXT" */,
        4330 /* "glClearTexImage" */,
        4330 /* "glClearTexImage" */,
    };
    return gl_provider_resolver(entrypoint_strings + 4346 /* "glClearTexImageEXT" */,
                                providers, entrypoints);
}

static PFNGLCLEARTEXSUBIMAGEPROC
epoxy_glClearTexSubImage_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_4,
        PROVIDER_GL_ARB_clear_texture,
        PROVIDER_GL_EXT_clear_texture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        4365 /* "glClearTexSubImage" */,
        4365 /* "glClearTexSubImage" */,
        4384 /* "glClearTexSubImageEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 4365 /* "glClearTexSubImage" */,
                                providers, entrypoints);
}

static PFNGLCLEARTEXSUBIMAGEEXTPROC
epoxy_glClearTexSubImageEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_clear_texture,
        PROVIDER_Desktop_OpenGL_4_4,
        PROVIDER_GL_ARB_clear_texture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        4384 /* "glClearTexSubImageEXT" */,
        4365 /* "glClearTexSubImage" */,
        4365 /* "glClearTexSubImage" */,
    };
    return gl_provider_resolver(entrypoint_strings + 4384 /* "glClearTexSubImageEXT" */,
                                providers, entrypoints);
}

static PFNGLCLIENTACTIVETEXTUREPROC
epoxy_glClientActiveTexture_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_GL_ARB_multitexture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        4406 /* "glClientActiveTexture" */,
        4406 /* "glClientActiveTexture" */,
        4428 /* "glClientActiveTextureARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 4406 /* "glClientActiveTexture" */,
                                providers, entrypoints);
}

static PFNGLCLIENTACTIVETEXTUREARBPROC
epoxy_glClientActiveTextureARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_multitexture,
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_OpenGL_ES_1_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        4428 /* "glClientActiveTextureARB" */,
        4406 /* "glClientActiveTexture" */,
        4406 /* "glClientActiveTexture" */,
    };
    return gl_provider_resolver(entrypoint_strings + 4428 /* "glClientActiveTextureARB" */,
                                providers, entrypoints);
}

static PFNGLCLIENTACTIVEVERTEXSTREAMATIPROC
epoxy_glClientActiveVertexStreamATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_streams, 4453 /* glClientActiveVertexStreamATI */);
}

static PFNGLCLIENTATTRIBDEFAULTEXTPROC
epoxy_glClientAttribDefaultEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 4483 /* glClientAttribDefaultEXT */);
}

static PFNGLCLIENTWAITSEMAPHOREUI64NVXPROC
epoxy_glClientWaitSemaphoreui64NVX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NVX_progress_fence, 4508 /* glClientWaitSemaphoreui64NVX */);
}

static PFNGLCLIENTWAITSYNCPROC
epoxy_glClientWaitSync_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_2,
        PROVIDER_GL_ARB_sync,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_APPLE_sync,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        4537 /* "glClientWaitSync" */,
        4537 /* "glClientWaitSync" */,
        4537 /* "glClientWaitSync" */,
        4554 /* "glClientWaitSyncAPPLE" */,
    };
    return gl_provider_resolver(entrypoint_strings + 4537 /* "glClientWaitSync" */,
                                providers, entrypoints);
}

static PFNGLCLIENTWAITSYNCAPPLEPROC
epoxy_glClientWaitSyncAPPLE_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_APPLE_sync,
        PROVIDER_Desktop_OpenGL_3_2,
        PROVIDER_GL_ARB_sync,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        4554 /* "glClientWaitSyncAPPLE" */,
        4537 /* "glClientWaitSync" */,
        4537 /* "glClientWaitSync" */,
        4537 /* "glClientWaitSync" */,
    };
    return gl_provider_resolver(entrypoint_strings + 4554 /* "glClientWaitSyncAPPLE" */,
                                providers, entrypoints);
}

static PFNGLCLIPCONTROLPROC
epoxy_glClipControl_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_clip_control,
        PROVIDER_GL_EXT_clip_control,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        4576 /* "glClipControl" */,
        4576 /* "glClipControl" */,
        4590 /* "glClipControlEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 4576 /* "glClipControl" */,
                                providers, entrypoints);
}

static PFNGLCLIPCONTROLEXTPROC
epoxy_glClipControlEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_clip_control,
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_clip_control,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        4590 /* "glClipControlEXT" */,
        4576 /* "glClipControl" */,
        4576 /* "glClipControl" */,
    };
    return gl_provider_resolver(entrypoint_strings + 4590 /* "glClipControlEXT" */,
                                providers, entrypoints);
}

static PFNGLCLIPPLANEPROC
epoxy_glClipPlane_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 4607 /* glClipPlane */);
}

static PFNGLCLIPPLANEFPROC
epoxy_glClipPlanef_resolver(void)
{
    return gl_single_resolver(PROVIDER_OpenGL_ES_1_0, 4619 /* glClipPlanef */);
}

static PFNGLCLIPPLANEFIMGPROC
epoxy_glClipPlanefIMG_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_IMG_user_clip_plane, 4632 /* glClipPlanefIMG */);
}

static PFNGLCLIPPLANEFOESPROC
epoxy_glClipPlanefOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_single_precision, 4648 /* glClipPlanefOES */);
}

static PFNGLCLIPPLANEXPROC
epoxy_glClipPlanex_resolver(void)
{
    return gl_single_resolver(PROVIDER_OpenGL_ES_1_0, 4664 /* glClipPlanex */);
}

static PFNGLCLIPPLANEXIMGPROC
epoxy_glClipPlanexIMG_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_IMG_user_clip_plane, 4677 /* glClipPlanexIMG */);
}

static PFNGLCLIPPLANEXOESPROC
epoxy_glClipPlanexOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 4693 /* glClipPlanexOES */);
}

static PFNGLCOLOR3BPROC
epoxy_glColor3b_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 4709 /* glColor3b */);
}

static PFNGLCOLOR3BVPROC
epoxy_glColor3bv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 4719 /* glColor3bv */);
}

static PFNGLCOLOR3DPROC
epoxy_glColor3d_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 4730 /* glColor3d */);
}

static PFNGLCOLOR3DVPROC
epoxy_glColor3dv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 4740 /* glColor3dv */);
}

static PFNGLCOLOR3FPROC
epoxy_glColor3f_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 4751 /* glColor3f */);
}

static PFNGLCOLOR3FVERTEX3FSUNPROC
epoxy_glColor3fVertex3fSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_vertex, 4761 /* glColor3fVertex3fSUN */);
}

static PFNGLCOLOR3FVERTEX3FVSUNPROC
epoxy_glColor3fVertex3fvSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_vertex, 4782 /* glColor3fVertex3fvSUN */);
}

static PFNGLCOLOR3FVPROC
epoxy_glColor3fv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 4804 /* glColor3fv */);
}

static PFNGLCOLOR3HNVPROC
epoxy_glColor3hNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_half_float, 4815 /* glColor3hNV */);
}

static PFNGLCOLOR3HVNVPROC
epoxy_glColor3hvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_half_float, 4827 /* glColor3hvNV */);
}

static PFNGLCOLOR3IPROC
epoxy_glColor3i_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 4840 /* glColor3i */);
}

static PFNGLCOLOR3IVPROC
epoxy_glColor3iv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 4850 /* glColor3iv */);
}

static PFNGLCOLOR3SPROC
epoxy_glColor3s_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 4861 /* glColor3s */);
}

static PFNGLCOLOR3SVPROC
epoxy_glColor3sv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 4871 /* glColor3sv */);
}

static PFNGLCOLOR3UBPROC
epoxy_glColor3ub_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 4882 /* glColor3ub */);
}

static PFNGLCOLOR3UBVPROC
epoxy_glColor3ubv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 4893 /* glColor3ubv */);
}

static PFNGLCOLOR3UIPROC
epoxy_glColor3ui_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 4905 /* glColor3ui */);
}

static PFNGLCOLOR3UIVPROC
epoxy_glColor3uiv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 4916 /* glColor3uiv */);
}

static PFNGLCOLOR3USPROC
epoxy_glColor3us_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 4928 /* glColor3us */);
}

static PFNGLCOLOR3USVPROC
epoxy_glColor3usv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 4939 /* glColor3usv */);
}

static PFNGLCOLOR3XOESPROC
epoxy_glColor3xOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 4951 /* glColor3xOES */);
}

static PFNGLCOLOR3XVOESPROC
epoxy_glColor3xvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 4964 /* glColor3xvOES */);
}

static PFNGLCOLOR4BPROC
epoxy_glColor4b_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 4978 /* glColor4b */);
}

static PFNGLCOLOR4BVPROC
epoxy_glColor4bv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 4988 /* glColor4bv */);
}

static PFNGLCOLOR4DPROC
epoxy_glColor4d_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 4999 /* glColor4d */);
}

static PFNGLCOLOR4DVPROC
epoxy_glColor4dv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 5009 /* glColor4dv */);
}

static PFNGLCOLOR4FPROC
epoxy_glColor4f_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        5020 /* "glColor4f" */,
        5020 /* "glColor4f" */,
    };
    return gl_provider_resolver(entrypoint_strings + 5020 /* "glColor4f" */,
                                providers, entrypoints);
}

static PFNGLCOLOR4FNORMAL3FVERTEX3FSUNPROC
epoxy_glColor4fNormal3fVertex3fSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_vertex, 5030 /* glColor4fNormal3fVertex3fSUN */);
}

static PFNGLCOLOR4FNORMAL3FVERTEX3FVSUNPROC
epoxy_glColor4fNormal3fVertex3fvSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_vertex, 5059 /* glColor4fNormal3fVertex3fvSUN */);
}

static PFNGLCOLOR4FVPROC
epoxy_glColor4fv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 5089 /* glColor4fv */);
}

static PFNGLCOLOR4HNVPROC
epoxy_glColor4hNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_half_float, 5100 /* glColor4hNV */);
}

static PFNGLCOLOR4HVNVPROC
epoxy_glColor4hvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_half_float, 5112 /* glColor4hvNV */);
}

static PFNGLCOLOR4IPROC
epoxy_glColor4i_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 5125 /* glColor4i */);
}

static PFNGLCOLOR4IVPROC
epoxy_glColor4iv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 5135 /* glColor4iv */);
}

static PFNGLCOLOR4SPROC
epoxy_glColor4s_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 5146 /* glColor4s */);
}

static PFNGLCOLOR4SVPROC
epoxy_glColor4sv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 5156 /* glColor4sv */);
}

static PFNGLCOLOR4UBPROC
epoxy_glColor4ub_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        5167 /* "glColor4ub" */,
        5167 /* "glColor4ub" */,
    };
    return gl_provider_resolver(entrypoint_strings + 5167 /* "glColor4ub" */,
                                providers, entrypoints);
}

static PFNGLCOLOR4UBVERTEX2FSUNPROC
epoxy_glColor4ubVertex2fSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_vertex, 5178 /* glColor4ubVertex2fSUN */);
}

static PFNGLCOLOR4UBVERTEX2FVSUNPROC
epoxy_glColor4ubVertex2fvSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_vertex, 5200 /* glColor4ubVertex2fvSUN */);
}

static PFNGLCOLOR4UBVERTEX3FSUNPROC
epoxy_glColor4ubVertex3fSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_vertex, 5223 /* glColor4ubVertex3fSUN */);
}

static PFNGLCOLOR4UBVERTEX3FVSUNPROC
epoxy_glColor4ubVertex3fvSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_vertex, 5245 /* glColor4ubVertex3fvSUN */);
}

static PFNGLCOLOR4UBVPROC
epoxy_glColor4ubv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 5268 /* glColor4ubv */);
}

static PFNGLCOLOR4UIPROC
epoxy_glColor4ui_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 5280 /* glColor4ui */);
}

static PFNGLCOLOR4UIVPROC
epoxy_glColor4uiv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 5291 /* glColor4uiv */);
}

static PFNGLCOLOR4USPROC
epoxy_glColor4us_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 5303 /* glColor4us */);
}

static PFNGLCOLOR4USVPROC
epoxy_glColor4usv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 5314 /* glColor4usv */);
}

static PFNGLCOLOR4XPROC
epoxy_glColor4x_resolver(void)
{
    return gl_single_resolver(PROVIDER_OpenGL_ES_1_0, 5326 /* glColor4x */);
}

static PFNGLCOLOR4XOESPROC
epoxy_glColor4xOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 5336 /* glColor4xOES */);
}

static PFNGLCOLOR4XVOESPROC
epoxy_glColor4xvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 5349 /* glColor4xvOES */);
}

static PFNGLCOLORFORMATNVPROC
epoxy_glColorFormatNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_buffer_unified_memory, 5363 /* glColorFormatNV */);
}

static PFNGLCOLORFRAGMENTOP1ATIPROC
epoxy_glColorFragmentOp1ATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_fragment_shader, 5379 /* glColorFragmentOp1ATI */);
}

static PFNGLCOLORFRAGMENTOP2ATIPROC
epoxy_glColorFragmentOp2ATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_fragment_shader, 5401 /* glColorFragmentOp2ATI */);
}

static PFNGLCOLORFRAGMENTOP3ATIPROC
epoxy_glColorFragmentOp3ATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_fragment_shader, 5423 /* glColorFragmentOp3ATI */);
}

static PFNGLCOLORMASKPROC
epoxy_glColorMask_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        5445 /* "glColorMask" */,
        5445 /* "glColorMask" */,
        5445 /* "glColorMask" */,
    };
    return gl_provider_resolver(entrypoint_strings + 5445 /* "glColorMask" */,
                                providers, entrypoints);
}

static PFNGLCOLORMASKINDEXEDEXTPROC
epoxy_glColorMaskIndexedEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_draw_buffers2,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_draw_buffers_indexed,
        PROVIDER_GL_OES_draw_buffers_indexed,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        5457 /* "glColorMaskIndexedEXT" */,
        5479 /* "glColorMaski" */,
        5479 /* "glColorMaski" */,
        5492 /* "glColorMaskiEXT" */,
        5508 /* "glColorMaskiOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 5457 /* "glColorMaskIndexedEXT" */,
                                providers, entrypoints);
}

static PFNGLCOLORMASKIPROC
epoxy_glColorMaski_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_draw_buffers2,
        PROVIDER_GL_EXT_draw_buffers_indexed,
        PROVIDER_GL_OES_draw_buffers_indexed,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        5479 /* "glColorMaski" */,
        5479 /* "glColorMaski" */,
        5457 /* "glColorMaskIndexedEXT" */,
        5492 /* "glColorMaskiEXT" */,
        5508 /* "glColorMaskiOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 5479 /* "glColorMaski" */,
                                providers, entrypoints);
}

static PFNGLCOLORMASKIEXTPROC
epoxy_glColorMaskiEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_draw_buffers_indexed,
        PROVIDER_GL_EXT_draw_buffers2,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_OES_draw_buffers_indexed,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        5492 /* "glColorMaskiEXT" */,
        5457 /* "glColorMaskIndexedEXT" */,
        5479 /* "glColorMaski" */,
        5479 /* "glColorMaski" */,
        5508 /* "glColorMaskiOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 5492 /* "glColorMaskiEXT" */,
                                providers, entrypoints);
}

static PFNGLCOLORMASKIOESPROC
epoxy_glColorMaskiOES_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_OES_draw_buffers_indexed,
        PROVIDER_GL_EXT_draw_buffers2,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_draw_buffers_indexed,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        5508 /* "glColorMaskiOES" */,
        5457 /* "glColorMaskIndexedEXT" */,
        5479 /* "glColorMaski" */,
        5479 /* "glColorMaski" */,
        5492 /* "glColorMaskiEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 5508 /* "glColorMaskiOES" */,
                                providers, entrypoints);
}

static PFNGLCOLORMATERIALPROC
epoxy_glColorMaterial_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 5524 /* glColorMaterial */);
}

static PFNGLCOLORP3UIPROC
epoxy_glColorP3ui_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_vertex_type_2_10_10_10_rev,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        5540 /* "glColorP3ui" */,
        5540 /* "glColorP3ui" */,
    };
    return gl_provider_resolver(entrypoint_strings + 5540 /* "glColorP3ui" */,
                                providers, entrypoints);
}

static PFNGLCOLORP3UIVPROC
epoxy_glColorP3uiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_vertex_type_2_10_10_10_rev,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        5552 /* "glColorP3uiv" */,
        5552 /* "glColorP3uiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 5552 /* "glColorP3uiv" */,
                                providers, entrypoints);
}

static PFNGLCOLORP4UIPROC
epoxy_glColorP4ui_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_vertex_type_2_10_10_10_rev,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        5565 /* "glColorP4ui" */,
        5565 /* "glColorP4ui" */,
    };
    return gl_provider_resolver(entrypoint_strings + 5565 /* "glColorP4ui" */,
                                providers, entrypoints);
}

static PFNGLCOLORP4UIVPROC
epoxy_glColorP4uiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_vertex_type_2_10_10_10_rev,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        5577 /* "glColorP4uiv" */,
        5577 /* "glColorP4uiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 5577 /* "glColorP4uiv" */,
                                providers, entrypoints);
}

static PFNGLCOLORPOINTERPROC
epoxy_glColorPointer_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_1,
        PROVIDER_OpenGL_ES_1_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        5590 /* "glColorPointer" */,
        5590 /* "glColorPointer" */,
    };
    return gl_provider_resolver(entrypoint_strings + 5590 /* "glColorPointer" */,
                                providers, entrypoints);
}

static PFNGLCOLORPOINTEREXTPROC
epoxy_glColorPointerEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_array, 5605 /* glColorPointerEXT */);
}

static PFNGLCOLORPOINTERLISTIBMPROC
epoxy_glColorPointerListIBM_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_IBM_vertex_array_lists, 5623 /* glColorPointerListIBM */);
}

static PFNGLCOLORPOINTERVINTELPROC
epoxy_glColorPointervINTEL_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_INTEL_parallel_arrays, 5645 /* glColorPointervINTEL */);
}

static PFNGLCOLORSUBTABLEPROC
epoxy_glColorSubTable_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_imaging,
        PROVIDER_GL_EXT_color_subtable,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        5666 /* "glColorSubTable" */,
        5682 /* "glColorSubTableEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 5666 /* "glColorSubTable" */,
                                providers, entrypoints);
}

static PFNGLCOLORSUBTABLEEXTPROC
epoxy_glColorSubTableEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_color_subtable,
        PROVIDER_GL_ARB_imaging,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        5682 /* "glColorSubTableEXT" */,
        5666 /* "glColorSubTable" */,
    };
    return gl_provider_resolver(entrypoint_strings + 5682 /* "glColorSubTableEXT" */,
                                providers, entrypoints);
}

static PFNGLCOLORTABLEPROC
epoxy_glColorTable_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_imaging,
        PROVIDER_GL_EXT_paletted_texture,
        PROVIDER_GL_SGI_color_table,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        5701 /* "glColorTable" */,
        5714 /* "glColorTableEXT" */,
        5832 /* "glColorTableSGI" */,
    };
    return gl_provider_resolver(entrypoint_strings + 5701 /* "glColorTable" */,
                                providers, entrypoints);
}

static PFNGLCOLORTABLEEXTPROC
epoxy_glColorTableEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_paletted_texture,
        PROVIDER_GL_ARB_imaging,
        PROVIDER_GL_SGI_color_table,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        5714 /* "glColorTableEXT" */,
        5701 /* "glColorTable" */,
        5832 /* "glColorTableSGI" */,
    };
    return gl_provider_resolver(entrypoint_strings + 5714 /* "glColorTableEXT" */,
                                providers, entrypoints);
}

static PFNGLCOLORTABLEPARAMETERFVPROC
epoxy_glColorTableParameterfv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_imaging,
        PROVIDER_GL_SGI_color_table,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        5730 /* "glColorTableParameterfv" */,
        5754 /* "glColorTableParameterfvSGI" */,
    };
    return gl_provider_resolver(entrypoint_strings + 5730 /* "glColorTableParameterfv" */,
                                providers, entrypoints);
}

static PFNGLCOLORTABLEPARAMETERFVSGIPROC
epoxy_glColorTableParameterfvSGI_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_SGI_color_table,
        PROVIDER_GL_ARB_imaging,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        5754 /* "glColorTableParameterfvSGI" */,
        5730 /* "glColorTableParameterfv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 5754 /* "glColorTableParameterfvSGI" */,
                                providers, entrypoints);
}

static PFNGLCOLORTABLEPARAMETERIVPROC
epoxy_glColorTableParameteriv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_imaging,
        PROVIDER_GL_SGI_color_table,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        5781 /* "glColorTableParameteriv" */,
        5805 /* "glColorTableParameterivSGI" */,
    };
    return gl_provider_resolver(entrypoint_strings + 5781 /* "glColorTableParameteriv" */,
                                providers, entrypoints);
}

static PFNGLCOLORTABLEPARAMETERIVSGIPROC
epoxy_glColorTableParameterivSGI_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_SGI_color_table,
        PROVIDER_GL_ARB_imaging,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        5805 /* "glColorTableParameterivSGI" */,
        5781 /* "glColorTableParameteriv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 5805 /* "glColorTableParameterivSGI" */,
                                providers, entrypoints);
}

static PFNGLCOLORTABLESGIPROC
epoxy_glColorTableSGI_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_SGI_color_table,
        PROVIDER_GL_ARB_imaging,
        PROVIDER_GL_EXT_paletted_texture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        5832 /* "glColorTableSGI" */,
        5701 /* "glColorTable" */,
        5714 /* "glColorTableEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 5832 /* "glColorTableSGI" */,
                                providers, entrypoints);
}

static PFNGLCOMBINERINPUTNVPROC
epoxy_glCombinerInputNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_register_combiners, 5848 /* glCombinerInputNV */);
}

static PFNGLCOMBINEROUTPUTNVPROC
epoxy_glCombinerOutputNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_register_combiners, 5866 /* glCombinerOutputNV */);
}

static PFNGLCOMBINERPARAMETERFNVPROC
epoxy_glCombinerParameterfNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_register_combiners, 5885 /* glCombinerParameterfNV */);
}

static PFNGLCOMBINERPARAMETERFVNVPROC
epoxy_glCombinerParameterfvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_register_combiners, 5908 /* glCombinerParameterfvNV */);
}

static PFNGLCOMBINERPARAMETERINVPROC
epoxy_glCombinerParameteriNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_register_combiners, 5932 /* glCombinerParameteriNV */);
}

static PFNGLCOMBINERPARAMETERIVNVPROC
epoxy_glCombinerParameterivNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_register_combiners, 5955 /* glCombinerParameterivNV */);
}

static PFNGLCOMBINERSTAGEPARAMETERFVNVPROC
epoxy_glCombinerStageParameterfvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_register_combiners2, 5979 /* glCombinerStageParameterfvNV */);
}

static PFNGLCOMMANDLISTSEGMENTSNVPROC
epoxy_glCommandListSegmentsNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_command_list, 6008 /* glCommandListSegmentsNV */);
}

static PFNGLCOMPILECOMMANDLISTNVPROC
epoxy_glCompileCommandListNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_command_list, 6032 /* glCompileCommandListNV */);
}

static PFNGLCOMPILESHADERPROC
epoxy_glCompileShader_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        6055 /* "glCompileShader" */,
        6055 /* "glCompileShader" */,
        6071 /* "glCompileShaderARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 6055 /* "glCompileShader" */,
                                providers, entrypoints);
}

static PFNGLCOMPILESHADERARBPROC
epoxy_glCompileShaderARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_shader_objects,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        6071 /* "glCompileShaderARB" */,
        6055 /* "glCompileShader" */,
        6055 /* "glCompileShader" */,
    };
    return gl_provider_resolver(entrypoint_strings + 6071 /* "glCompileShaderARB" */,
                                providers, entrypoints);
}

static PFNGLCOMPILESHADERINCLUDEARBPROC
epoxy_glCompileShaderIncludeARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_shading_language_include, 6090 /* glCompileShaderIncludeARB */);
}

static PFNGLCOMPRESSEDMULTITEXIMAGE1DEXTPROC
epoxy_glCompressedMultiTexImage1DEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 6116 /* glCompressedMultiTexImage1DEXT */);
}

static PFNGLCOMPRESSEDMULTITEXIMAGE2DEXTPROC
epoxy_glCompressedMultiTexImage2DEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 6147 /* glCompressedMultiTexImage2DEXT */);
}

static PFNGLCOMPRESSEDMULTITEXIMAGE3DEXTPROC
epoxy_glCompressedMultiTexImage3DEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 6178 /* glCompressedMultiTexImage3DEXT */);
}

static PFNGLCOMPRESSEDMULTITEXSUBIMAGE1DEXTPROC
epoxy_glCompressedMultiTexSubImage1DEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 6209 /* glCompressedMultiTexSubImage1DEXT */);
}

static PFNGLCOMPRESSEDMULTITEXSUBIMAGE2DEXTPROC
epoxy_glCompressedMultiTexSubImage2DEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 6243 /* glCompressedMultiTexSubImage2DEXT */);
}

static PFNGLCOMPRESSEDMULTITEXSUBIMAGE3DEXTPROC
epoxy_glCompressedMultiTexSubImage3DEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 6277 /* glCompressedMultiTexSubImage3DEXT */);
}

static PFNGLCOMPRESSEDTEXIMAGE1DPROC
epoxy_glCompressedTexImage1D_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_GL_ARB_texture_compression,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        6311 /* "glCompressedTexImage1D" */,
        6334 /* "glCompressedTexImage1DARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 6311 /* "glCompressedTexImage1D" */,
                                providers, entrypoints);
}

static PFNGLCOMPRESSEDTEXIMAGE1DARBPROC
epoxy_glCompressedTexImage1DARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_texture_compression,
        PROVIDER_Desktop_OpenGL_1_3,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        6334 /* "glCompressedTexImage1DARB" */,
        6311 /* "glCompressedTexImage1D" */,
    };
    return gl_provider_resolver(entrypoint_strings + 6334 /* "glCompressedTexImage1DARB" */,
                                providers, entrypoints);
}

static PFNGLCOMPRESSEDTEXIMAGE2DPROC
epoxy_glCompressedTexImage2D_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_texture_compression,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        6360 /* "glCompressedTexImage2D" */,
        6360 /* "glCompressedTexImage2D" */,
        6360 /* "glCompressedTexImage2D" */,
        6383 /* "glCompressedTexImage2DARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 6360 /* "glCompressedTexImage2D" */,
                                providers, entrypoints);
}

static PFNGLCOMPRESSEDTEXIMAGE2DARBPROC
epoxy_glCompressedTexImage2DARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_texture_compression,
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        6383 /* "glCompressedTexImage2DARB" */,
        6360 /* "glCompressedTexImage2D" */,
        6360 /* "glCompressedTexImage2D" */,
        6360 /* "glCompressedTexImage2D" */,
    };
    return gl_provider_resolver(entrypoint_strings + 6383 /* "glCompressedTexImage2DARB" */,
                                providers, entrypoints);
}

static PFNGLCOMPRESSEDTEXIMAGE3DPROC
epoxy_glCompressedTexImage3D_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_ARB_texture_compression,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        6409 /* "glCompressedTexImage3D" */,
        6409 /* "glCompressedTexImage3D" */,
        6432 /* "glCompressedTexImage3DARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 6409 /* "glCompressedTexImage3D" */,
                                providers, entrypoints);
}

static PFNGLCOMPRESSEDTEXIMAGE3DARBPROC
epoxy_glCompressedTexImage3DARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_texture_compression,
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        6432 /* "glCompressedTexImage3DARB" */,
        6409 /* "glCompressedTexImage3D" */,
        6409 /* "glCompressedTexImage3D" */,
    };
    return gl_provider_resolver(entrypoint_strings + 6432 /* "glCompressedTexImage3DARB" */,
                                providers, entrypoints);
}

static PFNGLCOMPRESSEDTEXIMAGE3DOESPROC
epoxy_glCompressedTexImage3DOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_texture_3D, 6458 /* glCompressedTexImage3DOES */);
}

static PFNGLCOMPRESSEDTEXSUBIMAGE1DPROC
epoxy_glCompressedTexSubImage1D_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_GL_ARB_texture_compression,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        6484 /* "glCompressedTexSubImage1D" */,
        6510 /* "glCompressedTexSubImage1DARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 6484 /* "glCompressedTexSubImage1D" */,
                                providers, entrypoints);
}

static PFNGLCOMPRESSEDTEXSUBIMAGE1DARBPROC
epoxy_glCompressedTexSubImage1DARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_texture_compression,
        PROVIDER_Desktop_OpenGL_1_3,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        6510 /* "glCompressedTexSubImage1DARB" */,
        6484 /* "glCompressedTexSubImage1D" */,
    };
    return gl_provider_resolver(entrypoint_strings + 6510 /* "glCompressedTexSubImage1DARB" */,
                                providers, entrypoints);
}

static PFNGLCOMPRESSEDTEXSUBIMAGE2DPROC
epoxy_glCompressedTexSubImage2D_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_texture_compression,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        6539 /* "glCompressedTexSubImage2D" */,
        6539 /* "glCompressedTexSubImage2D" */,
        6539 /* "glCompressedTexSubImage2D" */,
        6565 /* "glCompressedTexSubImage2DARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 6539 /* "glCompressedTexSubImage2D" */,
                                providers, entrypoints);
}

static PFNGLCOMPRESSEDTEXSUBIMAGE2DARBPROC
epoxy_glCompressedTexSubImage2DARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_texture_compression,
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        6565 /* "glCompressedTexSubImage2DARB" */,
        6539 /* "glCompressedTexSubImage2D" */,
        6539 /* "glCompressedTexSubImage2D" */,
        6539 /* "glCompressedTexSubImage2D" */,
    };
    return gl_provider_resolver(entrypoint_strings + 6565 /* "glCompressedTexSubImage2DARB" */,
                                providers, entrypoints);
}

static PFNGLCOMPRESSEDTEXSUBIMAGE3DPROC
epoxy_glCompressedTexSubImage3D_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_ARB_texture_compression,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        6594 /* "glCompressedTexSubImage3D" */,
        6594 /* "glCompressedTexSubImage3D" */,
        6620 /* "glCompressedTexSubImage3DARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 6594 /* "glCompressedTexSubImage3D" */,
                                providers, entrypoints);
}

static PFNGLCOMPRESSEDTEXSUBIMAGE3DARBPROC
epoxy_glCompressedTexSubImage3DARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_texture_compression,
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        6620 /* "glCompressedTexSubImage3DARB" */,
        6594 /* "glCompressedTexSubImage3D" */,
        6594 /* "glCompressedTexSubImage3D" */,
    };
    return gl_provider_resolver(entrypoint_strings + 6620 /* "glCompressedTexSubImage3DARB" */,
                                providers, entrypoints);
}

static PFNGLCOMPRESSEDTEXSUBIMAGE3DOESPROC
epoxy_glCompressedTexSubImage3DOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_texture_3D, 6649 /* glCompressedTexSubImage3DOES */);
}

static PFNGLCOMPRESSEDTEXTUREIMAGE1DEXTPROC
epoxy_glCompressedTextureImage1DEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 6678 /* glCompressedTextureImage1DEXT */);
}

static PFNGLCOMPRESSEDTEXTUREIMAGE2DEXTPROC
epoxy_glCompressedTextureImage2DEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 6708 /* glCompressedTextureImage2DEXT */);
}

static PFNGLCOMPRESSEDTEXTUREIMAGE3DEXTPROC
epoxy_glCompressedTextureImage3DEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 6738 /* glCompressedTextureImage3DEXT */);
}

static PFNGLCOMPRESSEDTEXTURESUBIMAGE1DPROC
epoxy_glCompressedTextureSubImage1D_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        6768 /* "glCompressedTextureSubImage1D" */,
        6768 /* "glCompressedTextureSubImage1D" */,
    };
    return gl_provider_resolver(entrypoint_strings + 6768 /* "glCompressedTextureSubImage1D" */,
                                providers, entrypoints);
}

static PFNGLCOMPRESSEDTEXTURESUBIMAGE1DEXTPROC
epoxy_glCompressedTextureSubImage1DEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 6798 /* glCompressedTextureSubImage1DEXT */);
}

static PFNGLCOMPRESSEDTEXTURESUBIMAGE2DPROC
epoxy_glCompressedTextureSubImage2D_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        6831 /* "glCompressedTextureSubImage2D" */,
        6831 /* "glCompressedTextureSubImage2D" */,
    };
    return gl_provider_resolver(entrypoint_strings + 6831 /* "glCompressedTextureSubImage2D" */,
                                providers, entrypoints);
}

static PFNGLCOMPRESSEDTEXTURESUBIMAGE2DEXTPROC
epoxy_glCompressedTextureSubImage2DEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 6861 /* glCompressedTextureSubImage2DEXT */);
}

static PFNGLCOMPRESSEDTEXTURESUBIMAGE3DPROC
epoxy_glCompressedTextureSubImage3D_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        6894 /* "glCompressedTextureSubImage3D" */,
        6894 /* "glCompressedTextureSubImage3D" */,
    };
    return gl_provider_resolver(entrypoint_strings + 6894 /* "glCompressedTextureSubImage3D" */,
                                providers, entrypoints);
}

static PFNGLCOMPRESSEDTEXTURESUBIMAGE3DEXTPROC
epoxy_glCompressedTextureSubImage3DEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 6924 /* glCompressedTextureSubImage3DEXT */);
}

static PFNGLCONSERVATIVERASTERPARAMETERFNVPROC
epoxy_glConservativeRasterParameterfNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_conservative_raster_dilate, 6957 /* glConservativeRasterParameterfNV */);
}

static PFNGLCONSERVATIVERASTERPARAMETERINVPROC
epoxy_glConservativeRasterParameteriNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_conservative_raster_pre_snap_triangles, 6990 /* glConservativeRasterParameteriNV */);
}

static PFNGLCONVOLUTIONFILTER1DPROC
epoxy_glConvolutionFilter1D_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_imaging,
        PROVIDER_GL_EXT_convolution,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        7023 /* "glConvolutionFilter1D" */,
        7045 /* "glConvolutionFilter1DEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 7023 /* "glConvolutionFilter1D" */,
                                providers, entrypoints);
}

static PFNGLCONVOLUTIONFILTER1DEXTPROC
epoxy_glConvolutionFilter1DEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_convolution,
        PROVIDER_GL_ARB_imaging,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        7045 /* "glConvolutionFilter1DEXT" */,
        7023 /* "glConvolutionFilter1D" */,
    };
    return gl_provider_resolver(entrypoint_strings + 7045 /* "glConvolutionFilter1DEXT" */,
                                providers, entrypoints);
}

static PFNGLCONVOLUTIONFILTER2DPROC
epoxy_glConvolutionFilter2D_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_imaging,
        PROVIDER_GL_EXT_convolution,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        7070 /* "glConvolutionFilter2D" */,
        7092 /* "glConvolutionFilter2DEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 7070 /* "glConvolutionFilter2D" */,
                                providers, entrypoints);
}

static PFNGLCONVOLUTIONFILTER2DEXTPROC
epoxy_glConvolutionFilter2DEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_convolution,
        PROVIDER_GL_ARB_imaging,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        7092 /* "glConvolutionFilter2DEXT" */,
        7070 /* "glConvolutionFilter2D" */,
    };
    return gl_provider_resolver(entrypoint_strings + 7092 /* "glConvolutionFilter2DEXT" */,
                                providers, entrypoints);
}

static PFNGLCONVOLUTIONPARAMETERFPROC
epoxy_glConvolutionParameterf_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_imaging,
        PROVIDER_GL_EXT_convolution,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        7117 /* "glConvolutionParameterf" */,
        7141 /* "glConvolutionParameterfEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 7117 /* "glConvolutionParameterf" */,
                                providers, entrypoints);
}

static PFNGLCONVOLUTIONPARAMETERFEXTPROC
epoxy_glConvolutionParameterfEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_convolution,
        PROVIDER_GL_ARB_imaging,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        7141 /* "glConvolutionParameterfEXT" */,
        7117 /* "glConvolutionParameterf" */,
    };
    return gl_provider_resolver(entrypoint_strings + 7141 /* "glConvolutionParameterfEXT" */,
                                providers, entrypoints);
}

static PFNGLCONVOLUTIONPARAMETERFVPROC
epoxy_glConvolutionParameterfv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_imaging,
        PROVIDER_GL_EXT_convolution,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        7168 /* "glConvolutionParameterfv" */,
        7193 /* "glConvolutionParameterfvEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 7168 /* "glConvolutionParameterfv" */,
                                providers, entrypoints);
}

static PFNGLCONVOLUTIONPARAMETERFVEXTPROC
epoxy_glConvolutionParameterfvEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_convolution,
        PROVIDER_GL_ARB_imaging,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        7193 /* "glConvolutionParameterfvEXT" */,
        7168 /* "glConvolutionParameterfv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 7193 /* "glConvolutionParameterfvEXT" */,
                                providers, entrypoints);
}

static PFNGLCONVOLUTIONPARAMETERIPROC
epoxy_glConvolutionParameteri_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_imaging,
        PROVIDER_GL_EXT_convolution,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        7221 /* "glConvolutionParameteri" */,
        7245 /* "glConvolutionParameteriEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 7221 /* "glConvolutionParameteri" */,
                                providers, entrypoints);
}

static PFNGLCONVOLUTIONPARAMETERIEXTPROC
epoxy_glConvolutionParameteriEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_convolution,
        PROVIDER_GL_ARB_imaging,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        7245 /* "glConvolutionParameteriEXT" */,
        7221 /* "glConvolutionParameteri" */,
    };
    return gl_provider_resolver(entrypoint_strings + 7245 /* "glConvolutionParameteriEXT" */,
                                providers, entrypoints);
}

static PFNGLCONVOLUTIONPARAMETERIVPROC
epoxy_glConvolutionParameteriv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_imaging,
        PROVIDER_GL_EXT_convolution,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        7272 /* "glConvolutionParameteriv" */,
        7297 /* "glConvolutionParameterivEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 7272 /* "glConvolutionParameteriv" */,
                                providers, entrypoints);
}

static PFNGLCONVOLUTIONPARAMETERIVEXTPROC
epoxy_glConvolutionParameterivEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_convolution,
        PROVIDER_GL_ARB_imaging,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        7297 /* "glConvolutionParameterivEXT" */,
        7272 /* "glConvolutionParameteriv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 7297 /* "glConvolutionParameterivEXT" */,
                                providers, entrypoints);
}

static PFNGLCONVOLUTIONPARAMETERXOESPROC
epoxy_glConvolutionParameterxOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 7325 /* glConvolutionParameterxOES */);
}

static PFNGLCONVOLUTIONPARAMETERXVOESPROC
epoxy_glConvolutionParameterxvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 7352 /* glConvolutionParameterxvOES */);
}

static PFNGLCOPYBUFFERSUBDATAPROC
epoxy_glCopyBufferSubData_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_1,
        PROVIDER_GL_ARB_copy_buffer,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_NV_copy_buffer,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        7380 /* "glCopyBufferSubData" */,
        7380 /* "glCopyBufferSubData" */,
        7380 /* "glCopyBufferSubData" */,
        7400 /* "glCopyBufferSubDataNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 7380 /* "glCopyBufferSubData" */,
                                providers, entrypoints);
}

static PFNGLCOPYBUFFERSUBDATANVPROC
epoxy_glCopyBufferSubDataNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_copy_buffer,
        PROVIDER_Desktop_OpenGL_3_1,
        PROVIDER_GL_ARB_copy_buffer,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        7400 /* "glCopyBufferSubDataNV" */,
        7380 /* "glCopyBufferSubData" */,
        7380 /* "glCopyBufferSubData" */,
        7380 /* "glCopyBufferSubData" */,
    };
    return gl_provider_resolver(entrypoint_strings + 7400 /* "glCopyBufferSubDataNV" */,
                                providers, entrypoints);
}

static PFNGLCOPYCOLORSUBTABLEPROC
epoxy_glCopyColorSubTable_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_imaging,
        PROVIDER_GL_EXT_color_subtable,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        7422 /* "glCopyColorSubTable" */,
        7442 /* "glCopyColorSubTableEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 7422 /* "glCopyColorSubTable" */,
                                providers, entrypoints);
}

static PFNGLCOPYCOLORSUBTABLEEXTPROC
epoxy_glCopyColorSubTableEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_color_subtable,
        PROVIDER_GL_ARB_imaging,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        7442 /* "glCopyColorSubTableEXT" */,
        7422 /* "glCopyColorSubTable" */,
    };
    return gl_provider_resolver(entrypoint_strings + 7442 /* "glCopyColorSubTableEXT" */,
                                providers, entrypoints);
}

static PFNGLCOPYCOLORTABLEPROC
epoxy_glCopyColorTable_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_imaging,
        PROVIDER_GL_SGI_color_table,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        7465 /* "glCopyColorTable" */,
        7482 /* "glCopyColorTableSGI" */,
    };
    return gl_provider_resolver(entrypoint_strings + 7465 /* "glCopyColorTable" */,
                                providers, entrypoints);
}

static PFNGLCOPYCOLORTABLESGIPROC
epoxy_glCopyColorTableSGI_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_SGI_color_table,
        PROVIDER_GL_ARB_imaging,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        7482 /* "glCopyColorTableSGI" */,
        7465 /* "glCopyColorTable" */,
    };
    return gl_provider_resolver(entrypoint_strings + 7482 /* "glCopyColorTableSGI" */,
                                providers, entrypoints);
}

static PFNGLCOPYCONVOLUTIONFILTER1DPROC
epoxy_glCopyConvolutionFilter1D_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_imaging,
        PROVIDER_GL_EXT_convolution,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        7502 /* "glCopyConvolutionFilter1D" */,
        7528 /* "glCopyConvolutionFilter1DEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 7502 /* "glCopyConvolutionFilter1D" */,
                                providers, entrypoints);
}

static PFNGLCOPYCONVOLUTIONFILTER1DEXTPROC
epoxy_glCopyConvolutionFilter1DEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_convolution,
        PROVIDER_GL_ARB_imaging,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        7528 /* "glCopyConvolutionFilter1DEXT" */,
        7502 /* "glCopyConvolutionFilter1D" */,
    };
    return gl_provider_resolver(entrypoint_strings + 7528 /* "glCopyConvolutionFilter1DEXT" */,
                                providers, entrypoints);
}

static PFNGLCOPYCONVOLUTIONFILTER2DPROC
epoxy_glCopyConvolutionFilter2D_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_imaging,
        PROVIDER_GL_EXT_convolution,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        7557 /* "glCopyConvolutionFilter2D" */,
        7583 /* "glCopyConvolutionFilter2DEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 7557 /* "glCopyConvolutionFilter2D" */,
                                providers, entrypoints);
}

static PFNGLCOPYCONVOLUTIONFILTER2DEXTPROC
epoxy_glCopyConvolutionFilter2DEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_convolution,
        PROVIDER_GL_ARB_imaging,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        7583 /* "glCopyConvolutionFilter2DEXT" */,
        7557 /* "glCopyConvolutionFilter2D" */,
    };
    return gl_provider_resolver(entrypoint_strings + 7583 /* "glCopyConvolutionFilter2DEXT" */,
                                providers, entrypoints);
}

static PFNGLCOPYIMAGESUBDATAPROC
epoxy_glCopyImageSubData_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_ARB_copy_image,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_copy_image,
        PROVIDER_GL_OES_copy_image,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        7612 /* "glCopyImageSubData" */,
        7612 /* "glCopyImageSubData" */,
        7612 /* "glCopyImageSubData" */,
        7631 /* "glCopyImageSubDataEXT" */,
        7674 /* "glCopyImageSubDataOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 7612 /* "glCopyImageSubData" */,
                                providers, entrypoints);
}

static PFNGLCOPYIMAGESUBDATAEXTPROC
epoxy_glCopyImageSubDataEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_copy_image,
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_ARB_copy_image,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_OES_copy_image,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        7631 /* "glCopyImageSubDataEXT" */,
        7612 /* "glCopyImageSubData" */,
        7612 /* "glCopyImageSubData" */,
        7612 /* "glCopyImageSubData" */,
        7674 /* "glCopyImageSubDataOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 7631 /* "glCopyImageSubDataEXT" */,
                                providers, entrypoints);
}

static PFNGLCOPYIMAGESUBDATANVPROC
epoxy_glCopyImageSubDataNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_copy_image, 7653 /* glCopyImageSubDataNV */);
}

static PFNGLCOPYIMAGESUBDATAOESPROC
epoxy_glCopyImageSubDataOES_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_OES_copy_image,
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_ARB_copy_image,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_copy_image,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        7674 /* "glCopyImageSubDataOES" */,
        7612 /* "glCopyImageSubData" */,
        7612 /* "glCopyImageSubData" */,
        7612 /* "glCopyImageSubData" */,
        7631 /* "glCopyImageSubDataEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 7674 /* "glCopyImageSubDataOES" */,
                                providers, entrypoints);
}

static PFNGLCOPYMULTITEXIMAGE1DEXTPROC
epoxy_glCopyMultiTexImage1DEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 7696 /* glCopyMultiTexImage1DEXT */);
}

static PFNGLCOPYMULTITEXIMAGE2DEXTPROC
epoxy_glCopyMultiTexImage2DEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 7721 /* glCopyMultiTexImage2DEXT */);
}

static PFNGLCOPYMULTITEXSUBIMAGE1DEXTPROC
epoxy_glCopyMultiTexSubImage1DEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 7746 /* glCopyMultiTexSubImage1DEXT */);
}

static PFNGLCOPYMULTITEXSUBIMAGE2DEXTPROC
epoxy_glCopyMultiTexSubImage2DEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 7774 /* glCopyMultiTexSubImage2DEXT */);
}

static PFNGLCOPYMULTITEXSUBIMAGE3DEXTPROC
epoxy_glCopyMultiTexSubImage3DEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 7802 /* glCopyMultiTexSubImage3DEXT */);
}

static PFNGLCOPYNAMEDBUFFERSUBDATAPROC
epoxy_glCopyNamedBufferSubData_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        7830 /* "glCopyNamedBufferSubData" */,
        7830 /* "glCopyNamedBufferSubData" */,
    };
    return gl_provider_resolver(entrypoint_strings + 7830 /* "glCopyNamedBufferSubData" */,
                                providers, entrypoints);
}

static PFNGLCOPYPATHNVPROC
epoxy_glCopyPathNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 7855 /* glCopyPathNV */);
}

static PFNGLCOPYPIXELSPROC
epoxy_glCopyPixels_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 7868 /* glCopyPixels */);
}

static PFNGLCOPYTEXIMAGE1DPROC
epoxy_glCopyTexImage1D_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_1,
        PROVIDER_GL_EXT_copy_texture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        7881 /* "glCopyTexImage1D" */,
        7898 /* "glCopyTexImage1DEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 7881 /* "glCopyTexImage1D" */,
                                providers, entrypoints);
}

static PFNGLCOPYTEXIMAGE1DEXTPROC
epoxy_glCopyTexImage1DEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_copy_texture,
        PROVIDER_Desktop_OpenGL_1_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        7898 /* "glCopyTexImage1DEXT" */,
        7881 /* "glCopyTexImage1D" */,
    };
    return gl_provider_resolver(entrypoint_strings + 7898 /* "glCopyTexImage1DEXT" */,
                                providers, entrypoints);
}

static PFNGLCOPYTEXIMAGE2DPROC
epoxy_glCopyTexImage2D_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_1,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_EXT_copy_texture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        7918 /* "glCopyTexImage2D" */,
        7918 /* "glCopyTexImage2D" */,
        7918 /* "glCopyTexImage2D" */,
        7935 /* "glCopyTexImage2DEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 7918 /* "glCopyTexImage2D" */,
                                providers, entrypoints);
}

static PFNGLCOPYTEXIMAGE2DEXTPROC
epoxy_glCopyTexImage2DEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_copy_texture,
        PROVIDER_Desktop_OpenGL_1_1,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        7935 /* "glCopyTexImage2DEXT" */,
        7918 /* "glCopyTexImage2D" */,
        7918 /* "glCopyTexImage2D" */,
        7918 /* "glCopyTexImage2D" */,
    };
    return gl_provider_resolver(entrypoint_strings + 7935 /* "glCopyTexImage2DEXT" */,
                                providers, entrypoints);
}

static PFNGLCOPYTEXSUBIMAGE1DPROC
epoxy_glCopyTexSubImage1D_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_1,
        PROVIDER_GL_EXT_copy_texture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        7955 /* "glCopyTexSubImage1D" */,
        7975 /* "glCopyTexSubImage1DEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 7955 /* "glCopyTexSubImage1D" */,
                                providers, entrypoints);
}

static PFNGLCOPYTEXSUBIMAGE1DEXTPROC
epoxy_glCopyTexSubImage1DEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_copy_texture,
        PROVIDER_Desktop_OpenGL_1_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        7975 /* "glCopyTexSubImage1DEXT" */,
        7955 /* "glCopyTexSubImage1D" */,
    };
    return gl_provider_resolver(entrypoint_strings + 7975 /* "glCopyTexSubImage1DEXT" */,
                                providers, entrypoints);
}

static PFNGLCOPYTEXSUBIMAGE2DPROC
epoxy_glCopyTexSubImage2D_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_1,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_EXT_copy_texture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        7998 /* "glCopyTexSubImage2D" */,
        7998 /* "glCopyTexSubImage2D" */,
        7998 /* "glCopyTexSubImage2D" */,
        8018 /* "glCopyTexSubImage2DEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 7998 /* "glCopyTexSubImage2D" */,
                                providers, entrypoints);
}

static PFNGLCOPYTEXSUBIMAGE2DEXTPROC
epoxy_glCopyTexSubImage2DEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_copy_texture,
        PROVIDER_Desktop_OpenGL_1_1,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        8018 /* "glCopyTexSubImage2DEXT" */,
        7998 /* "glCopyTexSubImage2D" */,
        7998 /* "glCopyTexSubImage2D" */,
        7998 /* "glCopyTexSubImage2D" */,
    };
    return gl_provider_resolver(entrypoint_strings + 8018 /* "glCopyTexSubImage2DEXT" */,
                                providers, entrypoints);
}

static PFNGLCOPYTEXSUBIMAGE3DPROC
epoxy_glCopyTexSubImage3D_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_2,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_EXT_copy_texture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        8041 /* "glCopyTexSubImage3D" */,
        8041 /* "glCopyTexSubImage3D" */,
        8061 /* "glCopyTexSubImage3DEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 8041 /* "glCopyTexSubImage3D" */,
                                providers, entrypoints);
}

static PFNGLCOPYTEXSUBIMAGE3DEXTPROC
epoxy_glCopyTexSubImage3DEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_copy_texture,
        PROVIDER_Desktop_OpenGL_1_2,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        8061 /* "glCopyTexSubImage3DEXT" */,
        8041 /* "glCopyTexSubImage3D" */,
        8041 /* "glCopyTexSubImage3D" */,
    };
    return gl_provider_resolver(entrypoint_strings + 8061 /* "glCopyTexSubImage3DEXT" */,
                                providers, entrypoints);
}

static PFNGLCOPYTEXSUBIMAGE3DOESPROC
epoxy_glCopyTexSubImage3DOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_texture_3D, 8084 /* glCopyTexSubImage3DOES */);
}

static PFNGLCOPYTEXTUREIMAGE1DEXTPROC
epoxy_glCopyTextureImage1DEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 8107 /* glCopyTextureImage1DEXT */);
}

static PFNGLCOPYTEXTUREIMAGE2DEXTPROC
epoxy_glCopyTextureImage2DEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 8131 /* glCopyTextureImage2DEXT */);
}

static PFNGLCOPYTEXTURELEVELSAPPLEPROC
epoxy_glCopyTextureLevelsAPPLE_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_APPLE_copy_texture_levels, 8155 /* glCopyTextureLevelsAPPLE */);
}

static PFNGLCOPYTEXTURESUBIMAGE1DPROC
epoxy_glCopyTextureSubImage1D_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        8180 /* "glCopyTextureSubImage1D" */,
        8180 /* "glCopyTextureSubImage1D" */,
    };
    return gl_provider_resolver(entrypoint_strings + 8180 /* "glCopyTextureSubImage1D" */,
                                providers, entrypoints);
}

static PFNGLCOPYTEXTURESUBIMAGE1DEXTPROC
epoxy_glCopyTextureSubImage1DEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 8204 /* glCopyTextureSubImage1DEXT */);
}

static PFNGLCOPYTEXTURESUBIMAGE2DPROC
epoxy_glCopyTextureSubImage2D_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        8231 /* "glCopyTextureSubImage2D" */,
        8231 /* "glCopyTextureSubImage2D" */,
    };
    return gl_provider_resolver(entrypoint_strings + 8231 /* "glCopyTextureSubImage2D" */,
                                providers, entrypoints);
}

static PFNGLCOPYTEXTURESUBIMAGE2DEXTPROC
epoxy_glCopyTextureSubImage2DEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 8255 /* glCopyTextureSubImage2DEXT */);
}

static PFNGLCOPYTEXTURESUBIMAGE3DPROC
epoxy_glCopyTextureSubImage3D_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        8282 /* "glCopyTextureSubImage3D" */,
        8282 /* "glCopyTextureSubImage3D" */,
    };
    return gl_provider_resolver(entrypoint_strings + 8282 /* "glCopyTextureSubImage3D" */,
                                providers, entrypoints);
}

static PFNGLCOPYTEXTURESUBIMAGE3DEXTPROC
epoxy_glCopyTextureSubImage3DEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 8306 /* glCopyTextureSubImage3DEXT */);
}

static PFNGLCOVERFILLPATHINSTANCEDNVPROC
epoxy_glCoverFillPathInstancedNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 8333 /* glCoverFillPathInstancedNV */);
}

static PFNGLCOVERFILLPATHNVPROC
epoxy_glCoverFillPathNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 8360 /* glCoverFillPathNV */);
}

static PFNGLCOVERSTROKEPATHINSTANCEDNVPROC
epoxy_glCoverStrokePathInstancedNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 8378 /* glCoverStrokePathInstancedNV */);
}

static PFNGLCOVERSTROKEPATHNVPROC
epoxy_glCoverStrokePathNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 8407 /* glCoverStrokePathNV */);
}

static PFNGLCOVERAGEMASKNVPROC
epoxy_glCoverageMaskNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_coverage_sample, 8427 /* glCoverageMaskNV */);
}

static PFNGLCOVERAGEMODULATIONNVPROC
epoxy_glCoverageModulationNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_framebuffer_mixed_samples, 8444 /* glCoverageModulationNV */);
}

static PFNGLCOVERAGEMODULATIONTABLENVPROC
epoxy_glCoverageModulationTableNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_framebuffer_mixed_samples, 8467 /* glCoverageModulationTableNV */);
}

static PFNGLCOVERAGEOPERATIONNVPROC
epoxy_glCoverageOperationNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_coverage_sample, 8495 /* glCoverageOperationNV */);
}

static PFNGLCREATEBUFFERSPROC
epoxy_glCreateBuffers_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        8517 /* "glCreateBuffers" */,
        8517 /* "glCreateBuffers" */,
    };
    return gl_provider_resolver(entrypoint_strings + 8517 /* "glCreateBuffers" */,
                                providers, entrypoints);
}

static PFNGLCREATECOMMANDLISTSNVPROC
epoxy_glCreateCommandListsNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_command_list, 8533 /* glCreateCommandListsNV */);
}

static PFNGLCREATEFRAMEBUFFERSPROC
epoxy_glCreateFramebuffers_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        8556 /* "glCreateFramebuffers" */,
        8556 /* "glCreateFramebuffers" */,
    };
    return gl_provider_resolver(entrypoint_strings + 8556 /* "glCreateFramebuffers" */,
                                providers, entrypoints);
}

static PFNGLCREATEMEMORYOBJECTSEXTPROC
epoxy_glCreateMemoryObjectsEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_memory_object, 8577 /* glCreateMemoryObjectsEXT */);
}

static PFNGLCREATEPERFQUERYINTELPROC
epoxy_glCreatePerfQueryINTEL_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_INTEL_performance_query, 8602 /* glCreatePerfQueryINTEL */);
}

static PFNGLCREATEPROGRAMPROC
epoxy_glCreateProgram_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        8625 /* "glCreateProgram" */,
        8625 /* "glCreateProgram" */,
        8641 /* "glCreateProgramObjectARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 8625 /* "glCreateProgram" */,
                                providers, entrypoints);
}

static PFNGLCREATEPROGRAMOBJECTARBPROC
epoxy_glCreateProgramObjectARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_shader_objects,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        8641 /* "glCreateProgramObjectARB" */,
        8625 /* "glCreateProgram" */,
        8625 /* "glCreateProgram" */,
    };
    return gl_provider_resolver(entrypoint_strings + 8641 /* "glCreateProgramObjectARB" */,
                                providers, entrypoints);
}

static PFNGLCREATEPROGRAMPIPELINESPROC
epoxy_glCreateProgramPipelines_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        8666 /* "glCreateProgramPipelines" */,
        8666 /* "glCreateProgramPipelines" */,
    };
    return gl_provider_resolver(entrypoint_strings + 8666 /* "glCreateProgramPipelines" */,
                                providers, entrypoints);
}

static PFNGLCREATEPROGRESSFENCENVXPROC
epoxy_glCreateProgressFenceNVX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NVX_progress_fence, 8691 /* glCreateProgressFenceNVX */);
}

static PFNGLCREATEQUERIESPROC
epoxy_glCreateQueries_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        8716 /* "glCreateQueries" */,
        8716 /* "glCreateQueries" */,
    };
    return gl_provider_resolver(entrypoint_strings + 8716 /* "glCreateQueries" */,
                                providers, entrypoints);
}

static PFNGLCREATERENDERBUFFERSPROC
epoxy_glCreateRenderbuffers_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        8732 /* "glCreateRenderbuffers" */,
        8732 /* "glCreateRenderbuffers" */,
    };
    return gl_provider_resolver(entrypoint_strings + 8732 /* "glCreateRenderbuffers" */,
                                providers, entrypoints);
}

static PFNGLCREATESAMPLERSPROC
epoxy_glCreateSamplers_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        8754 /* "glCreateSamplers" */,
        8754 /* "glCreateSamplers" */,
    };
    return gl_provider_resolver(entrypoint_strings + 8754 /* "glCreateSamplers" */,
                                providers, entrypoints);
}

static PFNGLCREATESHADERPROC
epoxy_glCreateShader_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        8771 /* "glCreateShader" */,
        8771 /* "glCreateShader" */,
        8786 /* "glCreateShaderObjectARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 8771 /* "glCreateShader" */,
                                providers, entrypoints);
}

static PFNGLCREATESHADEROBJECTARBPROC
epoxy_glCreateShaderObjectARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_shader_objects,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        8786 /* "glCreateShaderObjectARB" */,
        8771 /* "glCreateShader" */,
        8771 /* "glCreateShader" */,
    };
    return gl_provider_resolver(entrypoint_strings + 8786 /* "glCreateShaderObjectARB" */,
                                providers, entrypoints);
}

static PFNGLCREATESHADERPROGRAMEXTPROC
epoxy_glCreateShaderProgramEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_separate_shader_objects, 8810 /* glCreateShaderProgramEXT */);
}

static PFNGLCREATESHADERPROGRAMVPROC
epoxy_glCreateShaderProgramv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        8835 /* "glCreateShaderProgramv" */,
        8835 /* "glCreateShaderProgramv" */,
        8835 /* "glCreateShaderProgramv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 8835 /* "glCreateShaderProgramv" */,
                                providers, entrypoints);
}

static PFNGLCREATESHADERPROGRAMVEXTPROC
epoxy_glCreateShaderProgramvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_separate_shader_objects, 8858 /* glCreateShaderProgramvEXT */);
}

static PFNGLCREATESTATESNVPROC
epoxy_glCreateStatesNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_command_list, 8884 /* glCreateStatesNV */);
}

static PFNGLCREATESYNCFROMCLEVENTARBPROC
epoxy_glCreateSyncFromCLeventARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_cl_event, 8901 /* glCreateSyncFromCLeventARB */);
}

static PFNGLCREATETEXTURESPROC
epoxy_glCreateTextures_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        8928 /* "glCreateTextures" */,
        8928 /* "glCreateTextures" */,
    };
    return gl_provider_resolver(entrypoint_strings + 8928 /* "glCreateTextures" */,
                                providers, entrypoints);
}

static PFNGLCREATETRANSFORMFEEDBACKSPROC
epoxy_glCreateTransformFeedbacks_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        8945 /* "glCreateTransformFeedbacks" */,
        8945 /* "glCreateTransformFeedbacks" */,
    };
    return gl_provider_resolver(entrypoint_strings + 8945 /* "glCreateTransformFeedbacks" */,
                                providers, entrypoints);
}

static PFNGLCREATEVERTEXARRAYSPROC
epoxy_glCreateVertexArrays_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        8972 /* "glCreateVertexArrays" */,
        8972 /* "glCreateVertexArrays" */,
    };
    return gl_provider_resolver(entrypoint_strings + 8972 /* "glCreateVertexArrays" */,
                                providers, entrypoints);
}

static PFNGLCULLFACEPROC
epoxy_glCullFace_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        8993 /* "glCullFace" */,
        8993 /* "glCullFace" */,
        8993 /* "glCullFace" */,
    };
    return gl_provider_resolver(entrypoint_strings + 8993 /* "glCullFace" */,
                                providers, entrypoints);
}

static PFNGLCULLPARAMETERDVEXTPROC
epoxy_glCullParameterdvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_cull_vertex, 9004 /* glCullParameterdvEXT */);
}

static PFNGLCULLPARAMETERFVEXTPROC
epoxy_glCullParameterfvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_cull_vertex, 9025 /* glCullParameterfvEXT */);
}

static PFNGLCURRENTPALETTEMATRIXARBPROC
epoxy_glCurrentPaletteMatrixARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_matrix_palette, 9046 /* glCurrentPaletteMatrixARB */);
}

static PFNGLCURRENTPALETTEMATRIXOESPROC
epoxy_glCurrentPaletteMatrixOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_matrix_palette, 9072 /* glCurrentPaletteMatrixOES */);
}

static PFNGLDEBUGMESSAGECALLBACKPROC
epoxy_glDebugMessageCallback_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_KHR_debug,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_ARB_debug_output,
        PROVIDER_GL_KHR_debug,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        9098 /* "glDebugMessageCallback" */,
        9098 /* "glDebugMessageCallback" */,
        9098 /* "glDebugMessageCallback" */,
        9147 /* "glDebugMessageCallbackARB" */,
        9173 /* "glDebugMessageCallbackKHR" */,
    };
    return gl_provider_resolver(entrypoint_strings + 9098 /* "glDebugMessageCallback" */,
                                providers, entrypoints);
}

static PFNGLDEBUGMESSAGECALLBACKAMDPROC
epoxy_glDebugMessageCallbackAMD_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_AMD_debug_output, 9121 /* glDebugMessageCallbackAMD */);
}

static PFNGLDEBUGMESSAGECALLBACKARBPROC
epoxy_glDebugMessageCallbackARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_debug_output,
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_KHR_debug,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_KHR_debug,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        9147 /* "glDebugMessageCallbackARB" */,
        9098 /* "glDebugMessageCallback" */,
        9098 /* "glDebugMessageCallback" */,
        9098 /* "glDebugMessageCallback" */,
        9173 /* "glDebugMessageCallbackKHR" */,
    };
    return gl_provider_resolver(entrypoint_strings + 9147 /* "glDebugMessageCallbackARB" */,
                                providers, entrypoints);
}

static PFNGLDEBUGMESSAGECALLBACKKHRPROC
epoxy_glDebugMessageCallbackKHR_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_KHR_debug,
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_KHR_debug,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_ARB_debug_output,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        9173 /* "glDebugMessageCallbackKHR" */,
        9098 /* "glDebugMessageCallback" */,
        9098 /* "glDebugMessageCallback" */,
        9098 /* "glDebugMessageCallback" */,
        9147 /* "glDebugMessageCallbackARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 9173 /* "glDebugMessageCallbackKHR" */,
                                providers, entrypoints);
}

static PFNGLDEBUGMESSAGECONTROLPROC
epoxy_glDebugMessageControl_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_KHR_debug,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_ARB_debug_output,
        PROVIDER_GL_KHR_debug,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        9199 /* "glDebugMessageControl" */,
        9199 /* "glDebugMessageControl" */,
        9199 /* "glDebugMessageControl" */,
        9221 /* "glDebugMessageControlARB" */,
        9246 /* "glDebugMessageControlKHR" */,
    };
    return gl_provider_resolver(entrypoint_strings + 9199 /* "glDebugMessageControl" */,
                                providers, entrypoints);
}

static PFNGLDEBUGMESSAGECONTROLARBPROC
epoxy_glDebugMessageControlARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_debug_output,
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_KHR_debug,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_KHR_debug,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        9221 /* "glDebugMessageControlARB" */,
        9199 /* "glDebugMessageControl" */,
        9199 /* "glDebugMessageControl" */,
        9199 /* "glDebugMessageControl" */,
        9246 /* "glDebugMessageControlKHR" */,
    };
    return gl_provider_resolver(entrypoint_strings + 9221 /* "glDebugMessageControlARB" */,
                                providers, entrypoints);
}

static PFNGLDEBUGMESSAGECONTROLKHRPROC
epoxy_glDebugMessageControlKHR_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_KHR_debug,
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_KHR_debug,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_ARB_debug_output,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        9246 /* "glDebugMessageControlKHR" */,
        9199 /* "glDebugMessageControl" */,
        9199 /* "glDebugMessageControl" */,
        9199 /* "glDebugMessageControl" */,
        9221 /* "glDebugMessageControlARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 9246 /* "glDebugMessageControlKHR" */,
                                providers, entrypoints);
}

static PFNGLDEBUGMESSAGEENABLEAMDPROC
epoxy_glDebugMessageEnableAMD_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_AMD_debug_output, 9271 /* glDebugMessageEnableAMD */);
}

static PFNGLDEBUGMESSAGEINSERTPROC
epoxy_glDebugMessageInsert_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_KHR_debug,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_ARB_debug_output,
        PROVIDER_GL_KHR_debug,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        9295 /* "glDebugMessageInsert" */,
        9295 /* "glDebugMessageInsert" */,
        9295 /* "glDebugMessageInsert" */,
        9340 /* "glDebugMessageInsertARB" */,
        9364 /* "glDebugMessageInsertKHR" */,
    };
    return gl_provider_resolver(entrypoint_strings + 9295 /* "glDebugMessageInsert" */,
                                providers, entrypoints);
}

static PFNGLDEBUGMESSAGEINSERTAMDPROC
epoxy_glDebugMessageInsertAMD_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_AMD_debug_output, 9316 /* glDebugMessageInsertAMD */);
}

static PFNGLDEBUGMESSAGEINSERTARBPROC
epoxy_glDebugMessageInsertARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_debug_output,
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_KHR_debug,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_KHR_debug,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        9340 /* "glDebugMessageInsertARB" */,
        9295 /* "glDebugMessageInsert" */,
        9295 /* "glDebugMessageInsert" */,
        9295 /* "glDebugMessageInsert" */,
        9364 /* "glDebugMessageInsertKHR" */,
    };
    return gl_provider_resolver(entrypoint_strings + 9340 /* "glDebugMessageInsertARB" */,
                                providers, entrypoints);
}

static PFNGLDEBUGMESSAGEINSERTKHRPROC
epoxy_glDebugMessageInsertKHR_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_KHR_debug,
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_KHR_debug,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_ARB_debug_output,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        9364 /* "glDebugMessageInsertKHR" */,
        9295 /* "glDebugMessageInsert" */,
        9295 /* "glDebugMessageInsert" */,
        9295 /* "glDebugMessageInsert" */,
        9340 /* "glDebugMessageInsertARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 9364 /* "glDebugMessageInsertKHR" */,
                                providers, entrypoints);
}

static PFNGLDEFORMSGIXPROC
epoxy_glDeformSGIX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIX_polynomial_ffd, 9388 /* glDeformSGIX */);
}

static PFNGLDEFORMATIONMAP3DSGIXPROC
epoxy_glDeformationMap3dSGIX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIX_polynomial_ffd, 9401 /* glDeformationMap3dSGIX */);
}

static PFNGLDEFORMATIONMAP3FSGIXPROC
epoxy_glDeformationMap3fSGIX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIX_polynomial_ffd, 9424 /* glDeformationMap3fSGIX */);
}

static PFNGLDELETEASYNCMARKERSSGIXPROC
epoxy_glDeleteAsyncMarkersSGIX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIX_async, 9447 /* glDeleteAsyncMarkersSGIX */);
}

static PFNGLDELETEBUFFERSPROC
epoxy_glDeleteBuffers_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_5,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_vertex_buffer_object,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        9472 /* "glDeleteBuffers" */,
        9472 /* "glDeleteBuffers" */,
        9472 /* "glDeleteBuffers" */,
        9488 /* "glDeleteBuffersARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 9472 /* "glDeleteBuffers" */,
                                providers, entrypoints);
}

static PFNGLDELETEBUFFERSARBPROC
epoxy_glDeleteBuffersARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_buffer_object,
        PROVIDER_Desktop_OpenGL_1_5,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        9488 /* "glDeleteBuffersARB" */,
        9472 /* "glDeleteBuffers" */,
        9472 /* "glDeleteBuffers" */,
        9472 /* "glDeleteBuffers" */,
    };
    return gl_provider_resolver(entrypoint_strings + 9488 /* "glDeleteBuffersARB" */,
                                providers, entrypoints);
}

static PFNGLDELETECOMMANDLISTSNVPROC
epoxy_glDeleteCommandListsNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_command_list, 9507 /* glDeleteCommandListsNV */);
}

static PFNGLDELETEFENCESAPPLEPROC
epoxy_glDeleteFencesAPPLE_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_APPLE_fence, 9530 /* glDeleteFencesAPPLE */);
}

static PFNGLDELETEFENCESNVPROC
epoxy_glDeleteFencesNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_fence, 9550 /* glDeleteFencesNV */);
}

static PFNGLDELETEFRAGMENTSHADERATIPROC
epoxy_glDeleteFragmentShaderATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_fragment_shader, 9567 /* glDeleteFragmentShaderATI */);
}

static PFNGLDELETEFRAMEBUFFERSPROC
epoxy_glDeleteFramebuffers_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_framebuffer_object,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_EXT_framebuffer_object,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        9593 /* "glDeleteFramebuffers" */,
        9593 /* "glDeleteFramebuffers" */,
        9593 /* "glDeleteFramebuffers" */,
        9614 /* "glDeleteFramebuffersEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 9593 /* "glDeleteFramebuffers" */,
                                providers, entrypoints);
}

static PFNGLDELETEFRAMEBUFFERSEXTPROC
epoxy_glDeleteFramebuffersEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_framebuffer_object,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_framebuffer_object,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        9614 /* "glDeleteFramebuffersEXT" */,
        9593 /* "glDeleteFramebuffers" */,
        9593 /* "glDeleteFramebuffers" */,
        9593 /* "glDeleteFramebuffers" */,
    };
    return gl_provider_resolver(entrypoint_strings + 9614 /* "glDeleteFramebuffersEXT" */,
                                providers, entrypoints);
}

static PFNGLDELETEFRAMEBUFFERSOESPROC
epoxy_glDeleteFramebuffersOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_framebuffer_object, 9638 /* glDeleteFramebuffersOES */);
}

static PFNGLDELETELISTSPROC
epoxy_glDeleteLists_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 9662 /* glDeleteLists */);
}

static PFNGLDELETEMEMORYOBJECTSEXTPROC
epoxy_glDeleteMemoryObjectsEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_memory_object, 9676 /* glDeleteMemoryObjectsEXT */);
}

static PFNGLDELETENAMEDSTRINGARBPROC
epoxy_glDeleteNamedStringARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_shading_language_include, 9701 /* glDeleteNamedStringARB */);
}

static PFNGLDELETENAMESAMDPROC
epoxy_glDeleteNamesAMD_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_AMD_name_gen_delete, 9724 /* glDeleteNamesAMD */);
}

static PFNGLDELETEOBJECTARBPROC
epoxy_glDeleteObjectARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_shader_objects, 9741 /* glDeleteObjectARB */);
}

static PFNGLDELETEOCCLUSIONQUERIESNVPROC
epoxy_glDeleteOcclusionQueriesNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_occlusion_query, 9759 /* glDeleteOcclusionQueriesNV */);
}

static PFNGLDELETEPATHSNVPROC
epoxy_glDeletePathsNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 9786 /* glDeletePathsNV */);
}

static PFNGLDELETEPERFMONITORSAMDPROC
epoxy_glDeletePerfMonitorsAMD_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_AMD_performance_monitor, 9802 /* glDeletePerfMonitorsAMD */);
}

static PFNGLDELETEPERFQUERYINTELPROC
epoxy_glDeletePerfQueryINTEL_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_INTEL_performance_query, 9826 /* glDeletePerfQueryINTEL */);
}

static PFNGLDELETEPROGRAMPROC
epoxy_glDeleteProgram_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        9849 /* "glDeleteProgram" */,
        9849 /* "glDeleteProgram" */,
    };
    return gl_provider_resolver(entrypoint_strings + 9849 /* "glDeleteProgram" */,
                                providers, entrypoints);
}

static PFNGLDELETEPROGRAMPIPELINESPROC
epoxy_glDeleteProgramPipelines_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        9865 /* "glDeleteProgramPipelines" */,
        9865 /* "glDeleteProgramPipelines" */,
        9865 /* "glDeleteProgramPipelines" */,
    };
    return gl_provider_resolver(entrypoint_strings + 9865 /* "glDeleteProgramPipelines" */,
                                providers, entrypoints);
}

static PFNGLDELETEPROGRAMPIPELINESEXTPROC
epoxy_glDeleteProgramPipelinesEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_separate_shader_objects, 9890 /* glDeleteProgramPipelinesEXT */);
}

static PFNGLDELETEPROGRAMSARBPROC
epoxy_glDeleteProgramsARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_fragment_program,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        9918 /* "glDeleteProgramsARB" */,
        9918 /* "glDeleteProgramsARB" */,
        9938 /* "glDeleteProgramsNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 9918 /* "glDeleteProgramsARB" */,
                                providers, entrypoints);
}

static PFNGLDELETEPROGRAMSNVPROC
epoxy_glDeleteProgramsNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program,
        PROVIDER_GL_ARB_fragment_program,
        PROVIDER_GL_ARB_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        9938 /* "glDeleteProgramsNV" */,
        9918 /* "glDeleteProgramsARB" */,
        9918 /* "glDeleteProgramsARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 9938 /* "glDeleteProgramsNV" */,
                                providers, entrypoints);
}

static PFNGLDELETEQUERIESPROC
epoxy_glDeleteQueries_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_5,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_ARB_occlusion_query,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        9957 /* "glDeleteQueries" */,
        9957 /* "glDeleteQueries" */,
        9973 /* "glDeleteQueriesARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 9957 /* "glDeleteQueries" */,
                                providers, entrypoints);
}

static PFNGLDELETEQUERIESARBPROC
epoxy_glDeleteQueriesARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_occlusion_query,
        PROVIDER_Desktop_OpenGL_1_5,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        9973 /* "glDeleteQueriesARB" */,
        9957 /* "glDeleteQueries" */,
        9957 /* "glDeleteQueries" */,
    };
    return gl_provider_resolver(entrypoint_strings + 9973 /* "glDeleteQueriesARB" */,
                                providers, entrypoints);
}

static PFNGLDELETEQUERIESEXTPROC
epoxy_glDeleteQueriesEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_disjoint_timer_query,
        PROVIDER_GL_EXT_occlusion_query_boolean,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        9992 /* "glDeleteQueriesEXT" */,
        9992 /* "glDeleteQueriesEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 9992 /* "glDeleteQueriesEXT" */,
                                providers, entrypoints);
}

static PFNGLDELETEQUERYRESOURCETAGNVPROC
epoxy_glDeleteQueryResourceTagNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_query_resource_tag, 10011 /* glDeleteQueryResourceTagNV */);
}

static PFNGLDELETERENDERBUFFERSPROC
epoxy_glDeleteRenderbuffers_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_framebuffer_object,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_EXT_framebuffer_object,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        10038 /* "glDeleteRenderbuffers" */,
        10038 /* "glDeleteRenderbuffers" */,
        10038 /* "glDeleteRenderbuffers" */,
        10060 /* "glDeleteRenderbuffersEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 10038 /* "glDeleteRenderbuffers" */,
                                providers, entrypoints);
}

static PFNGLDELETERENDERBUFFERSEXTPROC
epoxy_glDeleteRenderbuffersEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_framebuffer_object,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_framebuffer_object,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        10060 /* "glDeleteRenderbuffersEXT" */,
        10038 /* "glDeleteRenderbuffers" */,
        10038 /* "glDeleteRenderbuffers" */,
        10038 /* "glDeleteRenderbuffers" */,
    };
    return gl_provider_resolver(entrypoint_strings + 10060 /* "glDeleteRenderbuffersEXT" */,
                                providers, entrypoints);
}

static PFNGLDELETERENDERBUFFERSOESPROC
epoxy_glDeleteRenderbuffersOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_framebuffer_object, 10085 /* glDeleteRenderbuffersOES */);
}

static PFNGLDELETESAMPLERSPROC
epoxy_glDeleteSamplers_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_sampler_objects,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        10110 /* "glDeleteSamplers" */,
        10110 /* "glDeleteSamplers" */,
        10110 /* "glDeleteSamplers" */,
    };
    return gl_provider_resolver(entrypoint_strings + 10110 /* "glDeleteSamplers" */,
                                providers, entrypoints);
}

static PFNGLDELETESEMAPHORESEXTPROC
epoxy_glDeleteSemaphoresEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_semaphore, 10127 /* glDeleteSemaphoresEXT */);
}

static PFNGLDELETESHADERPROC
epoxy_glDeleteShader_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        10149 /* "glDeleteShader" */,
        10149 /* "glDeleteShader" */,
    };
    return gl_provider_resolver(entrypoint_strings + 10149 /* "glDeleteShader" */,
                                providers, entrypoints);
}

static PFNGLDELETESTATESNVPROC
epoxy_glDeleteStatesNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_command_list, 10164 /* glDeleteStatesNV */);
}

static PFNGLDELETESYNCPROC
epoxy_glDeleteSync_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_2,
        PROVIDER_GL_ARB_sync,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_APPLE_sync,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        10181 /* "glDeleteSync" */,
        10181 /* "glDeleteSync" */,
        10181 /* "glDeleteSync" */,
        10194 /* "glDeleteSyncAPPLE" */,
    };
    return gl_provider_resolver(entrypoint_strings + 10181 /* "glDeleteSync" */,
                                providers, entrypoints);
}

static PFNGLDELETESYNCAPPLEPROC
epoxy_glDeleteSyncAPPLE_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_APPLE_sync,
        PROVIDER_Desktop_OpenGL_3_2,
        PROVIDER_GL_ARB_sync,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        10194 /* "glDeleteSyncAPPLE" */,
        10181 /* "glDeleteSync" */,
        10181 /* "glDeleteSync" */,
        10181 /* "glDeleteSync" */,
    };
    return gl_provider_resolver(entrypoint_strings + 10194 /* "glDeleteSyncAPPLE" */,
                                providers, entrypoints);
}

static PFNGLDELETETEXTURESPROC
epoxy_glDeleteTextures_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_1,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        10212 /* "glDeleteTextures" */,
        10212 /* "glDeleteTextures" */,
        10212 /* "glDeleteTextures" */,
    };
    return gl_provider_resolver(entrypoint_strings + 10212 /* "glDeleteTextures" */,
                                providers, entrypoints);
}

static PFNGLDELETETEXTURESEXTPROC
epoxy_glDeleteTexturesEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_texture_object, 10229 /* glDeleteTexturesEXT */);
}

static PFNGLDELETETRANSFORMFEEDBACKSPROC
epoxy_glDeleteTransformFeedbacks_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_GL_ARB_transform_feedback2,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_NV_transform_feedback2,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        10249 /* "glDeleteTransformFeedbacks" */,
        10249 /* "glDeleteTransformFeedbacks" */,
        10249 /* "glDeleteTransformFeedbacks" */,
        10276 /* "glDeleteTransformFeedbacksNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 10249 /* "glDeleteTransformFeedbacks" */,
                                providers, entrypoints);
}

static PFNGLDELETETRANSFORMFEEDBACKSNVPROC
epoxy_glDeleteTransformFeedbacksNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_transform_feedback2,
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_GL_ARB_transform_feedback2,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        10276 /* "glDeleteTransformFeedbacksNV" */,
        10249 /* "glDeleteTransformFeedbacks" */,
        10249 /* "glDeleteTransformFeedbacks" */,
        10249 /* "glDeleteTransformFeedbacks" */,
    };
    return gl_provider_resolver(entrypoint_strings + 10276 /* "glDeleteTransformFeedbacksNV" */,
                                providers, entrypoints);
}

static PFNGLDELETEVERTEXARRAYSPROC
epoxy_glDeleteVertexArrays_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_vertex_array_object,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_APPLE_vertex_array_object,
        PROVIDER_GL_OES_vertex_array_object,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        10305 /* "glDeleteVertexArrays" */,
        10305 /* "glDeleteVertexArrays" */,
        10305 /* "glDeleteVertexArrays" */,
        10326 /* "glDeleteVertexArraysAPPLE" */,
        10352 /* "glDeleteVertexArraysOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 10305 /* "glDeleteVertexArrays" */,
                                providers, entrypoints);
}

static PFNGLDELETEVERTEXARRAYSAPPLEPROC
epoxy_glDeleteVertexArraysAPPLE_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_APPLE_vertex_array_object,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_vertex_array_object,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_OES_vertex_array_object,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        10326 /* "glDeleteVertexArraysAPPLE" */,
        10305 /* "glDeleteVertexArrays" */,
        10305 /* "glDeleteVertexArrays" */,
        10305 /* "glDeleteVertexArrays" */,
        10352 /* "glDeleteVertexArraysOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 10326 /* "glDeleteVertexArraysAPPLE" */,
                                providers, entrypoints);
}

static PFNGLDELETEVERTEXARRAYSOESPROC
epoxy_glDeleteVertexArraysOES_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_OES_vertex_array_object,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_vertex_array_object,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_APPLE_vertex_array_object,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        10352 /* "glDeleteVertexArraysOES" */,
        10305 /* "glDeleteVertexArrays" */,
        10305 /* "glDeleteVertexArrays" */,
        10305 /* "glDeleteVertexArrays" */,
        10326 /* "glDeleteVertexArraysAPPLE" */,
    };
    return gl_provider_resolver(entrypoint_strings + 10352 /* "glDeleteVertexArraysOES" */,
                                providers, entrypoints);
}

static PFNGLDELETEVERTEXSHADEREXTPROC
epoxy_glDeleteVertexShaderEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_shader, 10376 /* glDeleteVertexShaderEXT */);
}

static PFNGLDEPTHBOUNDSEXTPROC
epoxy_glDepthBoundsEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_depth_bounds_test, 10400 /* glDepthBoundsEXT */);
}

static PFNGLDEPTHBOUNDSDNVPROC
epoxy_glDepthBoundsdNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_depth_buffer_float, 10417 /* glDepthBoundsdNV */);
}

static PFNGLDEPTHFUNCPROC
epoxy_glDepthFunc_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        10434 /* "glDepthFunc" */,
        10434 /* "glDepthFunc" */,
        10434 /* "glDepthFunc" */,
    };
    return gl_provider_resolver(entrypoint_strings + 10434 /* "glDepthFunc" */,
                                providers, entrypoints);
}

static PFNGLDEPTHMASKPROC
epoxy_glDepthMask_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        10446 /* "glDepthMask" */,
        10446 /* "glDepthMask" */,
        10446 /* "glDepthMask" */,
    };
    return gl_provider_resolver(entrypoint_strings + 10446 /* "glDepthMask" */,
                                providers, entrypoints);
}

static PFNGLDEPTHRANGEPROC
epoxy_glDepthRange_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 10458 /* glDepthRange */);
}

static PFNGLDEPTHRANGEARRAYFVNVPROC
epoxy_glDepthRangeArrayfvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_viewport_array, 10471 /* glDepthRangeArrayfvNV */);
}

static PFNGLDEPTHRANGEARRAYFVOESPROC
epoxy_glDepthRangeArrayfvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_viewport_array, 10493 /* glDepthRangeArrayfvOES */);
}

static PFNGLDEPTHRANGEARRAYVPROC
epoxy_glDepthRangeArrayv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_viewport_array,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        10516 /* "glDepthRangeArrayv" */,
        10516 /* "glDepthRangeArrayv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 10516 /* "glDepthRangeArrayv" */,
                                providers, entrypoints);
}

static PFNGLDEPTHRANGEINDEXEDPROC
epoxy_glDepthRangeIndexed_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_viewport_array,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        10535 /* "glDepthRangeIndexed" */,
        10535 /* "glDepthRangeIndexed" */,
    };
    return gl_provider_resolver(entrypoint_strings + 10535 /* "glDepthRangeIndexed" */,
                                providers, entrypoints);
}

static PFNGLDEPTHRANGEINDEXEDFNVPROC
epoxy_glDepthRangeIndexedfNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_viewport_array, 10555 /* glDepthRangeIndexedfNV */);
}

static PFNGLDEPTHRANGEINDEXEDFOESPROC
epoxy_glDepthRangeIndexedfOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_viewport_array, 10578 /* glDepthRangeIndexedfOES */);
}

static PFNGLDEPTHRANGEDNVPROC
epoxy_glDepthRangedNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_depth_buffer_float, 10602 /* glDepthRangedNV */);
}

static PFNGLDEPTHRANGEFPROC
epoxy_glDepthRangef_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_ES2_compatibility,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_OES_single_precision,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        10618 /* "glDepthRangef" */,
        10618 /* "glDepthRangef" */,
        10618 /* "glDepthRangef" */,
        10618 /* "glDepthRangef" */,
        10632 /* "glDepthRangefOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 10618 /* "glDepthRangef" */,
                                providers, entrypoints);
}

static PFNGLDEPTHRANGEFOESPROC
epoxy_glDepthRangefOES_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_OES_single_precision,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_ES2_compatibility,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        10632 /* "glDepthRangefOES" */,
        10618 /* "glDepthRangef" */,
        10618 /* "glDepthRangef" */,
        10618 /* "glDepthRangef" */,
        10618 /* "glDepthRangef" */,
    };
    return gl_provider_resolver(entrypoint_strings + 10632 /* "glDepthRangefOES" */,
                                providers, entrypoints);
}

static PFNGLDEPTHRANGEXPROC
epoxy_glDepthRangex_resolver(void)
{
    return gl_single_resolver(PROVIDER_OpenGL_ES_1_0, 10649 /* glDepthRangex */);
}

static PFNGLDEPTHRANGEXOESPROC
epoxy_glDepthRangexOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 10663 /* glDepthRangexOES */);
}

static PFNGLDETACHOBJECTARBPROC
epoxy_glDetachObjectARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_shader_objects,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        10680 /* "glDetachObjectARB" */,
        10698 /* "glDetachShader" */,
        10698 /* "glDetachShader" */,
    };
    return gl_provider_resolver(entrypoint_strings + 10680 /* "glDetachObjectARB" */,
                                providers, entrypoints);
}

static PFNGLDETACHSHADERPROC
epoxy_glDetachShader_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        10698 /* "glDetachShader" */,
        10698 /* "glDetachShader" */,
        10680 /* "glDetachObjectARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 10698 /* "glDetachShader" */,
                                providers, entrypoints);
}

static PFNGLDETAILTEXFUNCSGISPROC
epoxy_glDetailTexFuncSGIS_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIS_detail_texture, 10713 /* glDetailTexFuncSGIS */);
}

static PFNGLDISABLEPROC
epoxy_glDisable_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        10733 /* "glDisable" */,
        10733 /* "glDisable" */,
        10733 /* "glDisable" */,
    };
    return gl_provider_resolver(entrypoint_strings + 10733 /* "glDisable" */,
                                providers, entrypoints);
}

static PFNGLDISABLECLIENTSTATEPROC
epoxy_glDisableClientState_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_1,
        PROVIDER_OpenGL_ES_1_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        10743 /* "glDisableClientState" */,
        10743 /* "glDisableClientState" */,
    };
    return gl_provider_resolver(entrypoint_strings + 10743 /* "glDisableClientState" */,
                                providers, entrypoints);
}

static PFNGLDISABLECLIENTSTATEINDEXEDEXTPROC
epoxy_glDisableClientStateIndexedEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 10764 /* glDisableClientStateIndexedEXT */);
}

static PFNGLDISABLECLIENTSTATEIEXTPROC
epoxy_glDisableClientStateiEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 10795 /* glDisableClientStateiEXT */);
}

static PFNGLDISABLEDRIVERCONTROLQCOMPROC
epoxy_glDisableDriverControlQCOM_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_QCOM_driver_control, 10820 /* glDisableDriverControlQCOM */);
}

static PFNGLDISABLEINDEXEDEXTPROC
epoxy_glDisableIndexedEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_draw_buffers2,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_draw_buffers_indexed,
        PROVIDER_GL_NV_viewport_array,
        PROVIDER_GL_OES_draw_buffers_indexed,
        PROVIDER_GL_OES_viewport_array,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        10847 /* "glDisableIndexedEXT" */,
        10847 /* "glDisableIndexedEXT" */,
        11063 /* "glDisablei" */,
        11063 /* "glDisablei" */,
        11074 /* "glDisableiEXT" */,
        11088 /* "glDisableiNV" */,
        11101 /* "glDisableiOES" */,
        11101 /* "glDisableiOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 10847 /* "glDisableIndexedEXT" */,
                                providers, entrypoints);
}

static PFNGLDISABLEVARIANTCLIENTSTATEEXTPROC
epoxy_glDisableVariantClientStateEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_shader, 10867 /* glDisableVariantClientStateEXT */);
}

static PFNGLDISABLEVERTEXARRAYATTRIBPROC
epoxy_glDisableVertexArrayAttrib_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        10898 /* "glDisableVertexArrayAttrib" */,
        10898 /* "glDisableVertexArrayAttrib" */,
    };
    return gl_provider_resolver(entrypoint_strings + 10898 /* "glDisableVertexArrayAttrib" */,
                                providers, entrypoints);
}

static PFNGLDISABLEVERTEXARRAYATTRIBEXTPROC
epoxy_glDisableVertexArrayAttribEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 10925 /* glDisableVertexArrayAttribEXT */);
}

static PFNGLDISABLEVERTEXARRAYEXTPROC
epoxy_glDisableVertexArrayEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 10955 /* glDisableVertexArrayEXT */);
}

static PFNGLDISABLEVERTEXATTRIBAPPLEPROC
epoxy_glDisableVertexAttribAPPLE_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_APPLE_vertex_program_evaluators, 10979 /* glDisableVertexAttribAPPLE */);
}

static PFNGLDISABLEVERTEXATTRIBARRAYPROC
epoxy_glDisableVertexAttribArray_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        11006 /* "glDisableVertexAttribArray" */,
        11006 /* "glDisableVertexAttribArray" */,
        11033 /* "glDisableVertexAttribArrayARB" */,
        11033 /* "glDisableVertexAttribArrayARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 11006 /* "glDisableVertexAttribArray" */,
                                providers, entrypoints);
}

static PFNGLDISABLEVERTEXATTRIBARRAYARBPROC
epoxy_glDisableVertexAttribArrayARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        11033 /* "glDisableVertexAttribArrayARB" */,
        11033 /* "glDisableVertexAttribArrayARB" */,
        11006 /* "glDisableVertexAttribArray" */,
        11006 /* "glDisableVertexAttribArray" */,
    };
    return gl_provider_resolver(entrypoint_strings + 11033 /* "glDisableVertexAttribArrayARB" */,
                                providers, entrypoints);
}

static PFNGLDISABLEIPROC
epoxy_glDisablei_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_draw_buffers2,
        PROVIDER_GL_EXT_draw_buffers_indexed,
        PROVIDER_GL_NV_viewport_array,
        PROVIDER_GL_OES_draw_buffers_indexed,
        PROVIDER_GL_OES_viewport_array,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        11063 /* "glDisablei" */,
        11063 /* "glDisablei" */,
        10847 /* "glDisableIndexedEXT" */,
        10847 /* "glDisableIndexedEXT" */,
        11074 /* "glDisableiEXT" */,
        11088 /* "glDisableiNV" */,
        11101 /* "glDisableiOES" */,
        11101 /* "glDisableiOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 11063 /* "glDisablei" */,
                                providers, entrypoints);
}

static PFNGLDISABLEIEXTPROC
epoxy_glDisableiEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_draw_buffers_indexed,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_draw_buffers2,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_NV_viewport_array,
        PROVIDER_GL_OES_draw_buffers_indexed,
        PROVIDER_GL_OES_viewport_array,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        11074 /* "glDisableiEXT" */,
        10847 /* "glDisableIndexedEXT" */,
        10847 /* "glDisableIndexedEXT" */,
        11063 /* "glDisablei" */,
        11063 /* "glDisablei" */,
        11088 /* "glDisableiNV" */,
        11101 /* "glDisableiOES" */,
        11101 /* "glDisableiOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 11074 /* "glDisableiEXT" */,
                                providers, entrypoints);
}

static PFNGLDISABLEINVPROC
epoxy_glDisableiNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_viewport_array,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_draw_buffers2,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_draw_buffers_indexed,
        PROVIDER_GL_OES_draw_buffers_indexed,
        PROVIDER_GL_OES_viewport_array,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        11088 /* "glDisableiNV" */,
        10847 /* "glDisableIndexedEXT" */,
        10847 /* "glDisableIndexedEXT" */,
        11063 /* "glDisablei" */,
        11063 /* "glDisablei" */,
        11074 /* "glDisableiEXT" */,
        11101 /* "glDisableiOES" */,
        11101 /* "glDisableiOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 11088 /* "glDisableiNV" */,
                                providers, entrypoints);
}

static PFNGLDISABLEIOESPROC
epoxy_glDisableiOES_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_OES_draw_buffers_indexed,
        PROVIDER_GL_OES_viewport_array,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_draw_buffers2,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_draw_buffers_indexed,
        PROVIDER_GL_NV_viewport_array,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        11101 /* "glDisableiOES" */,
        11101 /* "glDisableiOES" */,
        10847 /* "glDisableIndexedEXT" */,
        10847 /* "glDisableIndexedEXT" */,
        11063 /* "glDisablei" */,
        11063 /* "glDisablei" */,
        11074 /* "glDisableiEXT" */,
        11088 /* "glDisableiNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 11101 /* "glDisableiOES" */,
                                providers, entrypoints);
}

static PFNGLDISCARDFRAMEBUFFEREXTPROC
epoxy_glDiscardFramebufferEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_discard_framebuffer, 11115 /* glDiscardFramebufferEXT */);
}

static PFNGLDISPATCHCOMPUTEPROC
epoxy_glDispatchCompute_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_ARB_compute_shader,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        11139 /* "glDispatchCompute" */,
        11139 /* "glDispatchCompute" */,
        11139 /* "glDispatchCompute" */,
    };
    return gl_provider_resolver(entrypoint_strings + 11139 /* "glDispatchCompute" */,
                                providers, entrypoints);
}

static PFNGLDISPATCHCOMPUTEGROUPSIZEARBPROC
epoxy_glDispatchComputeGroupSizeARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_compute_variable_group_size, 11157 /* glDispatchComputeGroupSizeARB */);
}

static PFNGLDISPATCHCOMPUTEINDIRECTPROC
epoxy_glDispatchComputeIndirect_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_ARB_compute_shader,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        11187 /* "glDispatchComputeIndirect" */,
        11187 /* "glDispatchComputeIndirect" */,
        11187 /* "glDispatchComputeIndirect" */,
    };
    return gl_provider_resolver(entrypoint_strings + 11187 /* "glDispatchComputeIndirect" */,
                                providers, entrypoints);
}

static PFNGLDRAWARRAYSPROC
epoxy_glDrawArrays_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_1,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_EXT_vertex_array,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        11213 /* "glDrawArrays" */,
        11213 /* "glDrawArrays" */,
        11213 /* "glDrawArrays" */,
        11226 /* "glDrawArraysEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 11213 /* "glDrawArrays" */,
                                providers, entrypoints);
}

static PFNGLDRAWARRAYSEXTPROC
epoxy_glDrawArraysEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_vertex_array,
        PROVIDER_Desktop_OpenGL_1_1,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        11226 /* "glDrawArraysEXT" */,
        11213 /* "glDrawArrays" */,
        11213 /* "glDrawArrays" */,
        11213 /* "glDrawArrays" */,
    };
    return gl_provider_resolver(entrypoint_strings + 11226 /* "glDrawArraysEXT" */,
                                providers, entrypoints);
}

static PFNGLDRAWARRAYSINDIRECTPROC
epoxy_glDrawArraysIndirect_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_GL_ARB_draw_indirect,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        11242 /* "glDrawArraysIndirect" */,
        11242 /* "glDrawArraysIndirect" */,
        11242 /* "glDrawArraysIndirect" */,
    };
    return gl_provider_resolver(entrypoint_strings + 11242 /* "glDrawArraysIndirect" */,
                                providers, entrypoints);
}

static PFNGLDRAWARRAYSINSTANCEDPROC
epoxy_glDrawArraysInstanced_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_1,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_ANGLE_instanced_arrays,
        PROVIDER_GL_ARB_draw_instanced,
        PROVIDER_GL_EXT_draw_instanced,
        PROVIDER_GL_EXT_instanced_arrays,
        PROVIDER_GL_NV_draw_instanced,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        11263 /* "glDrawArraysInstanced" */,
        11263 /* "glDrawArraysInstanced" */,
        11285 /* "glDrawArraysInstancedANGLE" */,
        11312 /* "glDrawArraysInstancedARB" */,
        11408 /* "glDrawArraysInstancedEXT" */,
        11408 /* "glDrawArraysInstancedEXT" */,
        11433 /* "glDrawArraysInstancedNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 11263 /* "glDrawArraysInstanced" */,
                                providers, entrypoints);
}

static PFNGLDRAWARRAYSINSTANCEDANGLEPROC
epoxy_glDrawArraysInstancedANGLE_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ANGLE_instanced_arrays,
        PROVIDER_Desktop_OpenGL_3_1,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_ARB_draw_instanced,
        PROVIDER_GL_EXT_draw_instanced,
        PROVIDER_GL_EXT_instanced_arrays,
        PROVIDER_GL_NV_draw_instanced,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        11285 /* "glDrawArraysInstancedANGLE" */,
        11263 /* "glDrawArraysInstanced" */,
        11263 /* "glDrawArraysInstanced" */,
        11312 /* "glDrawArraysInstancedARB" */,
        11408 /* "glDrawArraysInstancedEXT" */,
        11408 /* "glDrawArraysInstancedEXT" */,
        11433 /* "glDrawArraysInstancedNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 11285 /* "glDrawArraysInstancedANGLE" */,
                                providers, entrypoints);
}

static PFNGLDRAWARRAYSINSTANCEDARBPROC
epoxy_glDrawArraysInstancedARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_draw_instanced,
        PROVIDER_Desktop_OpenGL_3_1,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_ANGLE_instanced_arrays,
        PROVIDER_GL_EXT_draw_instanced,
        PROVIDER_GL_EXT_instanced_arrays,
        PROVIDER_GL_NV_draw_instanced,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        11312 /* "glDrawArraysInstancedARB" */,
        11263 /* "glDrawArraysInstanced" */,
        11263 /* "glDrawArraysInstanced" */,
        11285 /* "glDrawArraysInstancedANGLE" */,
        11408 /* "glDrawArraysInstancedEXT" */,
        11408 /* "glDrawArraysInstancedEXT" */,
        11433 /* "glDrawArraysInstancedNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 11312 /* "glDrawArraysInstancedARB" */,
                                providers, entrypoints);
}

static PFNGLDRAWARRAYSINSTANCEDBASEINSTANCEPROC
epoxy_glDrawArraysInstancedBaseInstance_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_2,
        PROVIDER_GL_ARB_base_instance,
        PROVIDER_GL_EXT_base_instance,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        11337 /* "glDrawArraysInstancedBaseInstance" */,
        11337 /* "glDrawArraysInstancedBaseInstance" */,
        11371 /* "glDrawArraysInstancedBaseInstanceEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 11337 /* "glDrawArraysInstancedBaseInstance" */,
                                providers, entrypoints);
}

static PFNGLDRAWARRAYSINSTANCEDBASEINSTANCEEXTPROC
epoxy_glDrawArraysInstancedBaseInstanceEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_base_instance,
        PROVIDER_Desktop_OpenGL_4_2,
        PROVIDER_GL_ARB_base_instance,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        11371 /* "glDrawArraysInstancedBaseInstanceEXT" */,
        11337 /* "glDrawArraysInstancedBaseInstance" */,
        11337 /* "glDrawArraysInstancedBaseInstance" */,
    };
    return gl_provider_resolver(entrypoint_strings + 11371 /* "glDrawArraysInstancedBaseInstanceEXT" */,
                                providers, entrypoints);
}

static PFNGLDRAWARRAYSINSTANCEDEXTPROC
epoxy_glDrawArraysInstancedEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_draw_instanced,
        PROVIDER_GL_EXT_instanced_arrays,
        PROVIDER_Desktop_OpenGL_3_1,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_ANGLE_instanced_arrays,
        PROVIDER_GL_ARB_draw_instanced,
        PROVIDER_GL_NV_draw_instanced,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        11408 /* "glDrawArraysInstancedEXT" */,
        11408 /* "glDrawArraysInstancedEXT" */,
        11263 /* "glDrawArraysInstanced" */,
        11263 /* "glDrawArraysInstanced" */,
        11285 /* "glDrawArraysInstancedANGLE" */,
        11312 /* "glDrawArraysInstancedARB" */,
        11433 /* "glDrawArraysInstancedNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 11408 /* "glDrawArraysInstancedEXT" */,
                                providers, entrypoints);
}

static PFNGLDRAWARRAYSINSTANCEDNVPROC
epoxy_glDrawArraysInstancedNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_draw_instanced,
        PROVIDER_Desktop_OpenGL_3_1,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_ANGLE_instanced_arrays,
        PROVIDER_GL_ARB_draw_instanced,
        PROVIDER_GL_EXT_draw_instanced,
        PROVIDER_GL_EXT_instanced_arrays,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        11433 /* "glDrawArraysInstancedNV" */,
        11263 /* "glDrawArraysInstanced" */,
        11263 /* "glDrawArraysInstanced" */,
        11285 /* "glDrawArraysInstancedANGLE" */,
        11312 /* "glDrawArraysInstancedARB" */,
        11408 /* "glDrawArraysInstancedEXT" */,
        11408 /* "glDrawArraysInstancedEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 11433 /* "glDrawArraysInstancedNV" */,
                                providers, entrypoints);
}

static PFNGLDRAWBUFFERPROC
epoxy_glDrawBuffer_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 11457 /* glDrawBuffer */);
}

static PFNGLDRAWBUFFERSPROC
epoxy_glDrawBuffers_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_ARB_draw_buffers,
        PROVIDER_GL_ATI_draw_buffers,
        PROVIDER_GL_EXT_draw_buffers,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        11470 /* "glDrawBuffers" */,
        11470 /* "glDrawBuffers" */,
        11484 /* "glDrawBuffersARB" */,
        11501 /* "glDrawBuffersATI" */,
        11518 /* "glDrawBuffersEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 11470 /* "glDrawBuffers" */,
                                providers, entrypoints);
}

static PFNGLDRAWBUFFERSARBPROC
epoxy_glDrawBuffersARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_draw_buffers,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_ATI_draw_buffers,
        PROVIDER_GL_EXT_draw_buffers,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        11484 /* "glDrawBuffersARB" */,
        11470 /* "glDrawBuffers" */,
        11470 /* "glDrawBuffers" */,
        11501 /* "glDrawBuffersATI" */,
        11518 /* "glDrawBuffersEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 11484 /* "glDrawBuffersARB" */,
                                providers, entrypoints);
}

static PFNGLDRAWBUFFERSATIPROC
epoxy_glDrawBuffersATI_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ATI_draw_buffers,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_ARB_draw_buffers,
        PROVIDER_GL_EXT_draw_buffers,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        11501 /* "glDrawBuffersATI" */,
        11470 /* "glDrawBuffers" */,
        11470 /* "glDrawBuffers" */,
        11484 /* "glDrawBuffersARB" */,
        11518 /* "glDrawBuffersEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 11501 /* "glDrawBuffersATI" */,
                                providers, entrypoints);
}

static PFNGLDRAWBUFFERSEXTPROC
epoxy_glDrawBuffersEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_draw_buffers,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_ARB_draw_buffers,
        PROVIDER_GL_ATI_draw_buffers,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        11518 /* "glDrawBuffersEXT" */,
        11470 /* "glDrawBuffers" */,
        11470 /* "glDrawBuffers" */,
        11484 /* "glDrawBuffersARB" */,
        11501 /* "glDrawBuffersATI" */,
    };
    return gl_provider_resolver(entrypoint_strings + 11518 /* "glDrawBuffersEXT" */,
                                providers, entrypoints);
}

static PFNGLDRAWBUFFERSINDEXEDEXTPROC
epoxy_glDrawBuffersIndexedEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_multiview_draw_buffers, 11535 /* glDrawBuffersIndexedEXT */);
}

static PFNGLDRAWBUFFERSNVPROC
epoxy_glDrawBuffersNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_draw_buffers, 11559 /* glDrawBuffersNV */);
}

static PFNGLDRAWCOMMANDSADDRESSNVPROC
epoxy_glDrawCommandsAddressNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_command_list, 11575 /* glDrawCommandsAddressNV */);
}

static PFNGLDRAWCOMMANDSNVPROC
epoxy_glDrawCommandsNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_command_list, 11599 /* glDrawCommandsNV */);
}

static PFNGLDRAWCOMMANDSSTATESADDRESSNVPROC
epoxy_glDrawCommandsStatesAddressNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_command_list, 11616 /* glDrawCommandsStatesAddressNV */);
}

static PFNGLDRAWCOMMANDSSTATESNVPROC
epoxy_glDrawCommandsStatesNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_command_list, 11646 /* glDrawCommandsStatesNV */);
}

static PFNGLDRAWELEMENTARRAYAPPLEPROC
epoxy_glDrawElementArrayAPPLE_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_APPLE_element_array, 11669 /* glDrawElementArrayAPPLE */);
}

static PFNGLDRAWELEMENTARRAYATIPROC
epoxy_glDrawElementArrayATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_element_array, 11693 /* glDrawElementArrayATI */);
}

static PFNGLDRAWELEMENTSPROC
epoxy_glDrawElements_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_1,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        11715 /* "glDrawElements" */,
        11715 /* "glDrawElements" */,
        11715 /* "glDrawElements" */,
    };
    return gl_provider_resolver(entrypoint_strings + 11715 /* "glDrawElements" */,
                                providers, entrypoints);
}

static PFNGLDRAWELEMENTSBASEVERTEXPROC
epoxy_glDrawElementsBaseVertex_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_2,
        PROVIDER_GL_ARB_draw_elements_base_vertex,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_draw_elements_base_vertex,
        PROVIDER_GL_OES_draw_elements_base_vertex,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        11730 /* "glDrawElementsBaseVertex" */,
        11730 /* "glDrawElementsBaseVertex" */,
        11730 /* "glDrawElementsBaseVertex" */,
        11755 /* "glDrawElementsBaseVertexEXT" */,
        11783 /* "glDrawElementsBaseVertexOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 11730 /* "glDrawElementsBaseVertex" */,
                                providers, entrypoints);
}

static PFNGLDRAWELEMENTSBASEVERTEXEXTPROC
epoxy_glDrawElementsBaseVertexEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_draw_elements_base_vertex,
        PROVIDER_Desktop_OpenGL_3_2,
        PROVIDER_GL_ARB_draw_elements_base_vertex,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_OES_draw_elements_base_vertex,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        11755 /* "glDrawElementsBaseVertexEXT" */,
        11730 /* "glDrawElementsBaseVertex" */,
        11730 /* "glDrawElementsBaseVertex" */,
        11730 /* "glDrawElementsBaseVertex" */,
        11783 /* "glDrawElementsBaseVertexOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 11755 /* "glDrawElementsBaseVertexEXT" */,
                                providers, entrypoints);
}

static PFNGLDRAWELEMENTSBASEVERTEXOESPROC
epoxy_glDrawElementsBaseVertexOES_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_OES_draw_elements_base_vertex,
        PROVIDER_Desktop_OpenGL_3_2,
        PROVIDER_GL_ARB_draw_elements_base_vertex,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_draw_elements_base_vertex,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        11783 /* "glDrawElementsBaseVertexOES" */,
        11730 /* "glDrawElementsBaseVertex" */,
        11730 /* "glDrawElementsBaseVertex" */,
        11730 /* "glDrawElementsBaseVertex" */,
        11755 /* "glDrawElementsBaseVertexEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 11783 /* "glDrawElementsBaseVertexOES" */,
                                providers, entrypoints);
}

static PFNGLDRAWELEMENTSINDIRECTPROC
epoxy_glDrawElementsIndirect_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_GL_ARB_draw_indirect,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        11811 /* "glDrawElementsIndirect" */,
        11811 /* "glDrawElementsIndirect" */,
        11811 /* "glDrawElementsIndirect" */,
    };
    return gl_provider_resolver(entrypoint_strings + 11811 /* "glDrawElementsIndirect" */,
                                providers, entrypoints);
}

static PFNGLDRAWELEMENTSINSTANCEDPROC
epoxy_glDrawElementsInstanced_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_1,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_ANGLE_instanced_arrays,
        PROVIDER_GL_ARB_draw_instanced,
        PROVIDER_GL_EXT_draw_instanced,
        PROVIDER_GL_EXT_instanced_arrays,
        PROVIDER_GL_NV_draw_instanced,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        11834 /* "glDrawElementsInstanced" */,
        11834 /* "glDrawElementsInstanced" */,
        11858 /* "glDrawElementsInstancedANGLE" */,
        11887 /* "glDrawElementsInstancedARB" */,
        12192 /* "glDrawElementsInstancedEXT" */,
        12192 /* "glDrawElementsInstancedEXT" */,
        12219 /* "glDrawElementsInstancedNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 11834 /* "glDrawElementsInstanced" */,
                                providers, entrypoints);
}

static PFNGLDRAWELEMENTSINSTANCEDANGLEPROC
epoxy_glDrawElementsInstancedANGLE_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ANGLE_instanced_arrays,
        PROVIDER_Desktop_OpenGL_3_1,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_ARB_draw_instanced,
        PROVIDER_GL_EXT_draw_instanced,
        PROVIDER_GL_EXT_instanced_arrays,
        PROVIDER_GL_NV_draw_instanced,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        11858 /* "glDrawElementsInstancedANGLE" */,
        11834 /* "glDrawElementsInstanced" */,
        11834 /* "glDrawElementsInstanced" */,
        11887 /* "glDrawElementsInstancedARB" */,
        12192 /* "glDrawElementsInstancedEXT" */,
        12192 /* "glDrawElementsInstancedEXT" */,
        12219 /* "glDrawElementsInstancedNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 11858 /* "glDrawElementsInstancedANGLE" */,
                                providers, entrypoints);
}

static PFNGLDRAWELEMENTSINSTANCEDARBPROC
epoxy_glDrawElementsInstancedARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_draw_instanced,
        PROVIDER_Desktop_OpenGL_3_1,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_ANGLE_instanced_arrays,
        PROVIDER_GL_EXT_draw_instanced,
        PROVIDER_GL_EXT_instanced_arrays,
        PROVIDER_GL_NV_draw_instanced,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        11887 /* "glDrawElementsInstancedARB" */,
        11834 /* "glDrawElementsInstanced" */,
        11834 /* "glDrawElementsInstanced" */,
        11858 /* "glDrawElementsInstancedANGLE" */,
        12192 /* "glDrawElementsInstancedEXT" */,
        12192 /* "glDrawElementsInstancedEXT" */,
        12219 /* "glDrawElementsInstancedNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 11887 /* "glDrawElementsInstancedARB" */,
                                providers, entrypoints);
}

static PFNGLDRAWELEMENTSINSTANCEDBASEINSTANCEPROC
epoxy_glDrawElementsInstancedBaseInstance_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_2,
        PROVIDER_GL_ARB_base_instance,
        PROVIDER_GL_EXT_base_instance,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        11914 /* "glDrawElementsInstancedBaseInstance" */,
        11914 /* "glDrawElementsInstancedBaseInstance" */,
        11950 /* "glDrawElementsInstancedBaseInstanceEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 11914 /* "glDrawElementsInstancedBaseInstance" */,
                                providers, entrypoints);
}

static PFNGLDRAWELEMENTSINSTANCEDBASEINSTANCEEXTPROC
epoxy_glDrawElementsInstancedBaseInstanceEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_base_instance,
        PROVIDER_Desktop_OpenGL_4_2,
        PROVIDER_GL_ARB_base_instance,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        11950 /* "glDrawElementsInstancedBaseInstanceEXT" */,
        11914 /* "glDrawElementsInstancedBaseInstance" */,
        11914 /* "glDrawElementsInstancedBaseInstance" */,
    };
    return gl_provider_resolver(entrypoint_strings + 11950 /* "glDrawElementsInstancedBaseInstanceEXT" */,
                                providers, entrypoints);
}

static PFNGLDRAWELEMENTSINSTANCEDBASEVERTEXPROC
epoxy_glDrawElementsInstancedBaseVertex_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_2,
        PROVIDER_GL_ARB_draw_elements_base_vertex,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_draw_elements_base_vertex,
        PROVIDER_GL_OES_draw_elements_base_vertex,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        11989 /* "glDrawElementsInstancedBaseVertex" */,
        11989 /* "glDrawElementsInstancedBaseVertex" */,
        11989 /* "glDrawElementsInstancedBaseVertex" */,
        12118 /* "glDrawElementsInstancedBaseVertexEXT" */,
        12155 /* "glDrawElementsInstancedBaseVertexOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 11989 /* "glDrawElementsInstancedBaseVertex" */,
                                providers, entrypoints);
}

static PFNGLDRAWELEMENTSINSTANCEDBASEVERTEXBASEINSTANCEPROC
epoxy_glDrawElementsInstancedBaseVertexBaseInstance_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_2,
        PROVIDER_GL_ARB_base_instance,
        PROVIDER_GL_EXT_base_instance,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        12023 /* "glDrawElementsInstancedBaseVertexBaseInstance" */,
        12023 /* "glDrawElementsInstancedBaseVertexBaseInstance" */,
        12069 /* "glDrawElementsInstancedBaseVertexBaseInstanceEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 12023 /* "glDrawElementsInstancedBaseVertexBaseInstance" */,
                                providers, entrypoints);
}

static PFNGLDRAWELEMENTSINSTANCEDBASEVERTEXBASEINSTANCEEXTPROC
epoxy_glDrawElementsInstancedBaseVertexBaseInstanceEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_base_instance,
        PROVIDER_Desktop_OpenGL_4_2,
        PROVIDER_GL_ARB_base_instance,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        12069 /* "glDrawElementsInstancedBaseVertexBaseInstanceEXT" */,
        12023 /* "glDrawElementsInstancedBaseVertexBaseInstance" */,
        12023 /* "glDrawElementsInstancedBaseVertexBaseInstance" */,
    };
    return gl_provider_resolver(entrypoint_strings + 12069 /* "glDrawElementsInstancedBaseVertexBaseInstanceEXT" */,
                                providers, entrypoints);
}

static PFNGLDRAWELEMENTSINSTANCEDBASEVERTEXEXTPROC
epoxy_glDrawElementsInstancedBaseVertexEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_draw_elements_base_vertex,
        PROVIDER_Desktop_OpenGL_3_2,
        PROVIDER_GL_ARB_draw_elements_base_vertex,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_OES_draw_elements_base_vertex,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        12118 /* "glDrawElementsInstancedBaseVertexEXT" */,
        11989 /* "glDrawElementsInstancedBaseVertex" */,
        11989 /* "glDrawElementsInstancedBaseVertex" */,
        11989 /* "glDrawElementsInstancedBaseVertex" */,
        12155 /* "glDrawElementsInstancedBaseVertexOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 12118 /* "glDrawElementsInstancedBaseVertexEXT" */,
                                providers, entrypoints);
}

static PFNGLDRAWELEMENTSINSTANCEDBASEVERTEXOESPROC
epoxy_glDrawElementsInstancedBaseVertexOES_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_OES_draw_elements_base_vertex,
        PROVIDER_Desktop_OpenGL_3_2,
        PROVIDER_GL_ARB_draw_elements_base_vertex,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_draw_elements_base_vertex,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        12155 /* "glDrawElementsInstancedBaseVertexOES" */,
        11989 /* "glDrawElementsInstancedBaseVertex" */,
        11989 /* "glDrawElementsInstancedBaseVertex" */,
        11989 /* "glDrawElementsInstancedBaseVertex" */,
        12118 /* "glDrawElementsInstancedBaseVertexEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 12155 /* "glDrawElementsInstancedBaseVertexOES" */,
                                providers, entrypoints);
}

static PFNGLDRAWELEMENTSINSTANCEDEXTPROC
epoxy_glDrawElementsInstancedEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_draw_instanced,
        PROVIDER_GL_EXT_instanced_arrays,
        PROVIDER_Desktop_OpenGL_3_1,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_ANGLE_instanced_arrays,
        PROVIDER_GL_ARB_draw_instanced,
        PROVIDER_GL_NV_draw_instanced,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        12192 /* "glDrawElementsInstancedEXT" */,
        12192 /* "glDrawElementsInstancedEXT" */,
        11834 /* "glDrawElementsInstanced" */,
        11834 /* "glDrawElementsInstanced" */,
        11858 /* "glDrawElementsInstancedANGLE" */,
        11887 /* "glDrawElementsInstancedARB" */,
        12219 /* "glDrawElementsInstancedNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 12192 /* "glDrawElementsInstancedEXT" */,
                                providers, entrypoints);
}

static PFNGLDRAWELEMENTSINSTANCEDNVPROC
epoxy_glDrawElementsInstancedNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_draw_instanced,
        PROVIDER_Desktop_OpenGL_3_1,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_ANGLE_instanced_arrays,
        PROVIDER_GL_ARB_draw_instanced,
        PROVIDER_GL_EXT_draw_instanced,
        PROVIDER_GL_EXT_instanced_arrays,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        12219 /* "glDrawElementsInstancedNV" */,
        11834 /* "glDrawElementsInstanced" */,
        11834 /* "glDrawElementsInstanced" */,
        11858 /* "glDrawElementsInstancedANGLE" */,
        11887 /* "glDrawElementsInstancedARB" */,
        12192 /* "glDrawElementsInstancedEXT" */,
        12192 /* "glDrawElementsInstancedEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 12219 /* "glDrawElementsInstancedNV" */,
                                providers, entrypoints);
}

static PFNGLDRAWMESHARRAYSSUNPROC
epoxy_glDrawMeshArraysSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_mesh_array, 12245 /* glDrawMeshArraysSUN */);
}

static PFNGLDRAWMESHTASKSINDIRECTNVPROC
epoxy_glDrawMeshTasksIndirectNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_mesh_shader, 12265 /* glDrawMeshTasksIndirectNV */);
}

static PFNGLDRAWMESHTASKSNVPROC
epoxy_glDrawMeshTasksNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_mesh_shader, 12291 /* glDrawMeshTasksNV */);
}

static PFNGLDRAWPIXELSPROC
epoxy_glDrawPixels_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 12309 /* glDrawPixels */);
}

static PFNGLDRAWRANGEELEMENTARRAYAPPLEPROC
epoxy_glDrawRangeElementArrayAPPLE_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_APPLE_element_array, 12322 /* glDrawRangeElementArrayAPPLE */);
}

static PFNGLDRAWRANGEELEMENTARRAYATIPROC
epoxy_glDrawRangeElementArrayATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_element_array, 12351 /* glDrawRangeElementArrayATI */);
}

static PFNGLDRAWRANGEELEMENTSPROC
epoxy_glDrawRangeElements_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_2,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_EXT_draw_range_elements,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        12378 /* "glDrawRangeElements" */,
        12378 /* "glDrawRangeElements" */,
        12494 /* "glDrawRangeElementsEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 12378 /* "glDrawRangeElements" */,
                                providers, entrypoints);
}

static PFNGLDRAWRANGEELEMENTSBASEVERTEXPROC
epoxy_glDrawRangeElementsBaseVertex_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_2,
        PROVIDER_GL_ARB_draw_elements_base_vertex,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_draw_elements_base_vertex,
        PROVIDER_GL_OES_draw_elements_base_vertex,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        12398 /* "glDrawRangeElementsBaseVertex" */,
        12398 /* "glDrawRangeElementsBaseVertex" */,
        12398 /* "glDrawRangeElementsBaseVertex" */,
        12428 /* "glDrawRangeElementsBaseVertexEXT" */,
        12461 /* "glDrawRangeElementsBaseVertexOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 12398 /* "glDrawRangeElementsBaseVertex" */,
                                providers, entrypoints);
}

static PFNGLDRAWRANGEELEMENTSBASEVERTEXEXTPROC
epoxy_glDrawRangeElementsBaseVertexEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_draw_elements_base_vertex,
        PROVIDER_Desktop_OpenGL_3_2,
        PROVIDER_GL_ARB_draw_elements_base_vertex,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_OES_draw_elements_base_vertex,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        12428 /* "glDrawRangeElementsBaseVertexEXT" */,
        12398 /* "glDrawRangeElementsBaseVertex" */,
        12398 /* "glDrawRangeElementsBaseVertex" */,
        12398 /* "glDrawRangeElementsBaseVertex" */,
        12461 /* "glDrawRangeElementsBaseVertexOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 12428 /* "glDrawRangeElementsBaseVertexEXT" */,
                                providers, entrypoints);
}

static PFNGLDRAWRANGEELEMENTSBASEVERTEXOESPROC
epoxy_glDrawRangeElementsBaseVertexOES_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_OES_draw_elements_base_vertex,
        PROVIDER_Desktop_OpenGL_3_2,
        PROVIDER_GL_ARB_draw_elements_base_vertex,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_draw_elements_base_vertex,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        12461 /* "glDrawRangeElementsBaseVertexOES" */,
        12398 /* "glDrawRangeElementsBaseVertex" */,
        12398 /* "glDrawRangeElementsBaseVertex" */,
        12398 /* "glDrawRangeElementsBaseVertex" */,
        12428 /* "glDrawRangeElementsBaseVertexEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 12461 /* "glDrawRangeElementsBaseVertexOES" */,
                                providers, entrypoints);
}

static PFNGLDRAWRANGEELEMENTSEXTPROC
epoxy_glDrawRangeElementsEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_draw_range_elements,
        PROVIDER_Desktop_OpenGL_1_2,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        12494 /* "glDrawRangeElementsEXT" */,
        12378 /* "glDrawRangeElements" */,
        12378 /* "glDrawRangeElements" */,
    };
    return gl_provider_resolver(entrypoint_strings + 12494 /* "glDrawRangeElementsEXT" */,
                                providers, entrypoints);
}

static PFNGLDRAWTEXFOESPROC
epoxy_glDrawTexfOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_draw_texture, 12517 /* glDrawTexfOES */);
}

static PFNGLDRAWTEXFVOESPROC
epoxy_glDrawTexfvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_draw_texture, 12531 /* glDrawTexfvOES */);
}

static PFNGLDRAWTEXIOESPROC
epoxy_glDrawTexiOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_draw_texture, 12546 /* glDrawTexiOES */);
}

static PFNGLDRAWTEXIVOESPROC
epoxy_glDrawTexivOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_draw_texture, 12560 /* glDrawTexivOES */);
}

static PFNGLDRAWTEXSOESPROC
epoxy_glDrawTexsOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_draw_texture, 12575 /* glDrawTexsOES */);
}

static PFNGLDRAWTEXSVOESPROC
epoxy_glDrawTexsvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_draw_texture, 12589 /* glDrawTexsvOES */);
}

static PFNGLDRAWTEXTURENVPROC
epoxy_glDrawTextureNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_draw_texture, 12604 /* glDrawTextureNV */);
}

static PFNGLDRAWTEXXOESPROC
epoxy_glDrawTexxOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_draw_texture, 12620 /* glDrawTexxOES */);
}

static PFNGLDRAWTEXXVOESPROC
epoxy_glDrawTexxvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_draw_texture, 12634 /* glDrawTexxvOES */);
}

static PFNGLDRAWTRANSFORMFEEDBACKPROC
epoxy_glDrawTransformFeedback_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_GL_ARB_transform_feedback2,
        PROVIDER_GL_EXT_draw_transform_feedback,
        PROVIDER_GL_NV_transform_feedback2,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        12649 /* "glDrawTransformFeedback" */,
        12649 /* "glDrawTransformFeedback" */,
        12673 /* "glDrawTransformFeedbackEXT" */,
        12769 /* "glDrawTransformFeedbackNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 12649 /* "glDrawTransformFeedback" */,
                                providers, entrypoints);
}

static PFNGLDRAWTRANSFORMFEEDBACKEXTPROC
epoxy_glDrawTransformFeedbackEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_draw_transform_feedback,
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_GL_ARB_transform_feedback2,
        PROVIDER_GL_NV_transform_feedback2,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        12673 /* "glDrawTransformFeedbackEXT" */,
        12649 /* "glDrawTransformFeedback" */,
        12649 /* "glDrawTransformFeedback" */,
        12769 /* "glDrawTransformFeedbackNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 12673 /* "glDrawTransformFeedbackEXT" */,
                                providers, entrypoints);
}

static PFNGLDRAWTRANSFORMFEEDBACKINSTANCEDPROC
epoxy_glDrawTransformFeedbackInstanced_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_2,
        PROVIDER_GL_ARB_transform_feedback_instanced,
        PROVIDER_GL_EXT_draw_transform_feedback,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        12700 /* "glDrawTransformFeedbackInstanced" */,
        12700 /* "glDrawTransformFeedbackInstanced" */,
        12733 /* "glDrawTransformFeedbackInstancedEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 12700 /* "glDrawTransformFeedbackInstanced" */,
                                providers, entrypoints);
}

static PFNGLDRAWTRANSFORMFEEDBACKINSTANCEDEXTPROC
epoxy_glDrawTransformFeedbackInstancedEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_draw_transform_feedback,
        PROVIDER_Desktop_OpenGL_4_2,
        PROVIDER_GL_ARB_transform_feedback_instanced,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        12733 /* "glDrawTransformFeedbackInstancedEXT" */,
        12700 /* "glDrawTransformFeedbackInstanced" */,
        12700 /* "glDrawTransformFeedbackInstanced" */,
    };
    return gl_provider_resolver(entrypoint_strings + 12733 /* "glDrawTransformFeedbackInstancedEXT" */,
                                providers, entrypoints);
}

static PFNGLDRAWTRANSFORMFEEDBACKNVPROC
epoxy_glDrawTransformFeedbackNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_transform_feedback2,
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_GL_ARB_transform_feedback2,
        PROVIDER_GL_EXT_draw_transform_feedback,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        12769 /* "glDrawTransformFeedbackNV" */,
        12649 /* "glDrawTransformFeedback" */,
        12649 /* "glDrawTransformFeedback" */,
        12673 /* "glDrawTransformFeedbackEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 12769 /* "glDrawTransformFeedbackNV" */,
                                providers, entrypoints);
}

static PFNGLDRAWTRANSFORMFEEDBACKSTREAMPROC
epoxy_glDrawTransformFeedbackStream_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_GL_ARB_transform_feedback3,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        12795 /* "glDrawTransformFeedbackStream" */,
        12795 /* "glDrawTransformFeedbackStream" */,
    };
    return gl_provider_resolver(entrypoint_strings + 12795 /* "glDrawTransformFeedbackStream" */,
                                providers, entrypoints);
}

static PFNGLDRAWTRANSFORMFEEDBACKSTREAMINSTANCEDPROC
epoxy_glDrawTransformFeedbackStreamInstanced_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_2,
        PROVIDER_GL_ARB_transform_feedback_instanced,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        12825 /* "glDrawTransformFeedbackStreamInstanced" */,
        12825 /* "glDrawTransformFeedbackStreamInstanced" */,
    };
    return gl_provider_resolver(entrypoint_strings + 12825 /* "glDrawTransformFeedbackStreamInstanced" */,
                                providers, entrypoints);
}

static PFNGLDRAWVKIMAGENVPROC
epoxy_glDrawVkImageNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_draw_vulkan_image, 12864 /* glDrawVkImageNV */);
}

static PFNGLEGLIMAGETARGETRENDERBUFFERSTORAGEOESPROC
epoxy_glEGLImageTargetRenderbufferStorageOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_EGL_image, 12880 /* glEGLImageTargetRenderbufferStorageOES */);
}

static PFNGLEGLIMAGETARGETTEXSTORAGEEXTPROC
epoxy_glEGLImageTargetTexStorageEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_EGL_image_storage, 12919 /* glEGLImageTargetTexStorageEXT */);
}

static PFNGLEGLIMAGETARGETTEXTURE2DOESPROC
epoxy_glEGLImageTargetTexture2DOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_EGL_image, 12949 /* glEGLImageTargetTexture2DOES */);
}

static PFNGLEGLIMAGETARGETTEXTURESTORAGEEXTPROC
epoxy_glEGLImageTargetTextureStorageEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_EGL_image_storage, 12978 /* glEGLImageTargetTextureStorageEXT */);
}

static PFNGLEDGEFLAGPROC
epoxy_glEdgeFlag_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 13012 /* glEdgeFlag */);
}

static PFNGLEDGEFLAGFORMATNVPROC
epoxy_glEdgeFlagFormatNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_buffer_unified_memory, 13023 /* glEdgeFlagFormatNV */);
}

static PFNGLEDGEFLAGPOINTERPROC
epoxy_glEdgeFlagPointer_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_1, 13042 /* glEdgeFlagPointer */);
}

static PFNGLEDGEFLAGPOINTEREXTPROC
epoxy_glEdgeFlagPointerEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_array, 13060 /* glEdgeFlagPointerEXT */);
}

static PFNGLEDGEFLAGPOINTERLISTIBMPROC
epoxy_glEdgeFlagPointerListIBM_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_IBM_vertex_array_lists, 13081 /* glEdgeFlagPointerListIBM */);
}

static PFNGLEDGEFLAGVPROC
epoxy_glEdgeFlagv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 13106 /* glEdgeFlagv */);
}

static PFNGLELEMENTPOINTERAPPLEPROC
epoxy_glElementPointerAPPLE_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_APPLE_element_array, 13118 /* glElementPointerAPPLE */);
}

static PFNGLELEMENTPOINTERATIPROC
epoxy_glElementPointerATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_element_array, 13140 /* glElementPointerATI */);
}

static PFNGLENABLEPROC
epoxy_glEnable_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        13160 /* "glEnable" */,
        13160 /* "glEnable" */,
        13160 /* "glEnable" */,
    };
    return gl_provider_resolver(entrypoint_strings + 13160 /* "glEnable" */,
                                providers, entrypoints);
}

static PFNGLENABLECLIENTSTATEPROC
epoxy_glEnableClientState_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_1,
        PROVIDER_OpenGL_ES_1_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        13169 /* "glEnableClientState" */,
        13169 /* "glEnableClientState" */,
    };
    return gl_provider_resolver(entrypoint_strings + 13169 /* "glEnableClientState" */,
                                providers, entrypoints);
}

static PFNGLENABLECLIENTSTATEINDEXEDEXTPROC
epoxy_glEnableClientStateIndexedEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 13189 /* glEnableClientStateIndexedEXT */);
}

static PFNGLENABLECLIENTSTATEIEXTPROC
epoxy_glEnableClientStateiEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 13219 /* glEnableClientStateiEXT */);
}

static PFNGLENABLEDRIVERCONTROLQCOMPROC
epoxy_glEnableDriverControlQCOM_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_QCOM_driver_control, 13243 /* glEnableDriverControlQCOM */);
}

static PFNGLENABLEINDEXEDEXTPROC
epoxy_glEnableIndexedEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_draw_buffers2,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_draw_buffers_indexed,
        PROVIDER_GL_NV_viewport_array,
        PROVIDER_GL_OES_draw_buffers_indexed,
        PROVIDER_GL_OES_viewport_array,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        13269 /* "glEnableIndexedEXT" */,
        13269 /* "glEnableIndexedEXT" */,
        13477 /* "glEnablei" */,
        13477 /* "glEnablei" */,
        13487 /* "glEnableiEXT" */,
        13500 /* "glEnableiNV" */,
        13512 /* "glEnableiOES" */,
        13512 /* "glEnableiOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 13269 /* "glEnableIndexedEXT" */,
                                providers, entrypoints);
}

static PFNGLENABLEVARIANTCLIENTSTATEEXTPROC
epoxy_glEnableVariantClientStateEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_shader, 13288 /* glEnableVariantClientStateEXT */);
}

static PFNGLENABLEVERTEXARRAYATTRIBPROC
epoxy_glEnableVertexArrayAttrib_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        13318 /* "glEnableVertexArrayAttrib" */,
        13318 /* "glEnableVertexArrayAttrib" */,
    };
    return gl_provider_resolver(entrypoint_strings + 13318 /* "glEnableVertexArrayAttrib" */,
                                providers, entrypoints);
}

static PFNGLENABLEVERTEXARRAYATTRIBEXTPROC
epoxy_glEnableVertexArrayAttribEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 13344 /* glEnableVertexArrayAttribEXT */);
}

static PFNGLENABLEVERTEXARRAYEXTPROC
epoxy_glEnableVertexArrayEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 13373 /* glEnableVertexArrayEXT */);
}

static PFNGLENABLEVERTEXATTRIBAPPLEPROC
epoxy_glEnableVertexAttribAPPLE_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_APPLE_vertex_program_evaluators, 13396 /* glEnableVertexAttribAPPLE */);
}

static PFNGLENABLEVERTEXATTRIBARRAYPROC
epoxy_glEnableVertexAttribArray_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        13422 /* "glEnableVertexAttribArray" */,
        13422 /* "glEnableVertexAttribArray" */,
        13448 /* "glEnableVertexAttribArrayARB" */,
        13448 /* "glEnableVertexAttribArrayARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 13422 /* "glEnableVertexAttribArray" */,
                                providers, entrypoints);
}

static PFNGLENABLEVERTEXATTRIBARRAYARBPROC
epoxy_glEnableVertexAttribArrayARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        13448 /* "glEnableVertexAttribArrayARB" */,
        13448 /* "glEnableVertexAttribArrayARB" */,
        13422 /* "glEnableVertexAttribArray" */,
        13422 /* "glEnableVertexAttribArray" */,
    };
    return gl_provider_resolver(entrypoint_strings + 13448 /* "glEnableVertexAttribArrayARB" */,
                                providers, entrypoints);
}

static PFNGLENABLEIPROC
epoxy_glEnablei_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_draw_buffers2,
        PROVIDER_GL_EXT_draw_buffers_indexed,
        PROVIDER_GL_NV_viewport_array,
        PROVIDER_GL_OES_draw_buffers_indexed,
        PROVIDER_GL_OES_viewport_array,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        13477 /* "glEnablei" */,
        13477 /* "glEnablei" */,
        13269 /* "glEnableIndexedEXT" */,
        13269 /* "glEnableIndexedEXT" */,
        13487 /* "glEnableiEXT" */,
        13500 /* "glEnableiNV" */,
        13512 /* "glEnableiOES" */,
        13512 /* "glEnableiOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 13477 /* "glEnablei" */,
                                providers, entrypoints);
}

static PFNGLENABLEIEXTPROC
epoxy_glEnableiEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_draw_buffers_indexed,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_draw_buffers2,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_NV_viewport_array,
        PROVIDER_GL_OES_draw_buffers_indexed,
        PROVIDER_GL_OES_viewport_array,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        13487 /* "glEnableiEXT" */,
        13269 /* "glEnableIndexedEXT" */,
        13269 /* "glEnableIndexedEXT" */,
        13477 /* "glEnablei" */,
        13477 /* "glEnablei" */,
        13500 /* "glEnableiNV" */,
        13512 /* "glEnableiOES" */,
        13512 /* "glEnableiOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 13487 /* "glEnableiEXT" */,
                                providers, entrypoints);
}

static PFNGLENABLEINVPROC
epoxy_glEnableiNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_viewport_array,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_draw_buffers2,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_draw_buffers_indexed,
        PROVIDER_GL_OES_draw_buffers_indexed,
        PROVIDER_GL_OES_viewport_array,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        13500 /* "glEnableiNV" */,
        13269 /* "glEnableIndexedEXT" */,
        13269 /* "glEnableIndexedEXT" */,
        13477 /* "glEnablei" */,
        13477 /* "glEnablei" */,
        13487 /* "glEnableiEXT" */,
        13512 /* "glEnableiOES" */,
        13512 /* "glEnableiOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 13500 /* "glEnableiNV" */,
                                providers, entrypoints);
}

static PFNGLENABLEIOESPROC
epoxy_glEnableiOES_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_OES_draw_buffers_indexed,
        PROVIDER_GL_OES_viewport_array,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_draw_buffers2,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_draw_buffers_indexed,
        PROVIDER_GL_NV_viewport_array,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        13512 /* "glEnableiOES" */,
        13512 /* "glEnableiOES" */,
        13269 /* "glEnableIndexedEXT" */,
        13269 /* "glEnableIndexedEXT" */,
        13477 /* "glEnablei" */,
        13477 /* "glEnablei" */,
        13487 /* "glEnableiEXT" */,
        13500 /* "glEnableiNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 13512 /* "glEnableiOES" */,
                                providers, entrypoints);
}

static PFNGLENDPROC
epoxy_glEnd_unwrapped_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 13525 /* glEnd */);
}

static PFNGLENDCONDITIONALRENDERPROC
epoxy_glEndConditionalRender_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_NV_conditional_render,
        PROVIDER_GL_NVX_conditional_render,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        13531 /* "glEndConditionalRender" */,
        13554 /* "glEndConditionalRenderNV" */,
        13579 /* "glEndConditionalRenderNVX" */,
    };
    return gl_provider_resolver(entrypoint_strings + 13531 /* "glEndConditionalRender" */,
                                providers, entrypoints);
}

static PFNGLENDCONDITIONALRENDERNVPROC
epoxy_glEndConditionalRenderNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_conditional_render,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_NVX_conditional_render,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        13554 /* "glEndConditionalRenderNV" */,
        13531 /* "glEndConditionalRender" */,
        13579 /* "glEndConditionalRenderNVX" */,
    };
    return gl_provider_resolver(entrypoint_strings + 13554 /* "glEndConditionalRenderNV" */,
                                providers, entrypoints);
}

static PFNGLENDCONDITIONALRENDERNVXPROC
epoxy_glEndConditionalRenderNVX_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NVX_conditional_render,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_NV_conditional_render,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        13579 /* "glEndConditionalRenderNVX" */,
        13531 /* "glEndConditionalRender" */,
        13554 /* "glEndConditionalRenderNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 13579 /* "glEndConditionalRenderNVX" */,
                                providers, entrypoints);
}

static PFNGLENDFRAGMENTSHADERATIPROC
epoxy_glEndFragmentShaderATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_fragment_shader, 13605 /* glEndFragmentShaderATI */);
}

static PFNGLENDLISTPROC
epoxy_glEndList_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 13628 /* glEndList */);
}

static PFNGLENDOCCLUSIONQUERYNVPROC
epoxy_glEndOcclusionQueryNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_occlusion_query, 13638 /* glEndOcclusionQueryNV */);
}

static PFNGLENDPERFMONITORAMDPROC
epoxy_glEndPerfMonitorAMD_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_AMD_performance_monitor, 13660 /* glEndPerfMonitorAMD */);
}

static PFNGLENDPERFQUERYINTELPROC
epoxy_glEndPerfQueryINTEL_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_INTEL_performance_query, 13680 /* glEndPerfQueryINTEL */);
}

static PFNGLENDQUERYPROC
epoxy_glEndQuery_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_5,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_ARB_occlusion_query,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        13700 /* "glEndQuery" */,
        13700 /* "glEndQuery" */,
        13711 /* "glEndQueryARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 13700 /* "glEndQuery" */,
                                providers, entrypoints);
}

static PFNGLENDQUERYARBPROC
epoxy_glEndQueryARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_occlusion_query,
        PROVIDER_Desktop_OpenGL_1_5,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        13711 /* "glEndQueryARB" */,
        13700 /* "glEndQuery" */,
        13700 /* "glEndQuery" */,
    };
    return gl_provider_resolver(entrypoint_strings + 13711 /* "glEndQueryARB" */,
                                providers, entrypoints);
}

static PFNGLENDQUERYEXTPROC
epoxy_glEndQueryEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_disjoint_timer_query,
        PROVIDER_GL_EXT_occlusion_query_boolean,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        13725 /* "glEndQueryEXT" */,
        13725 /* "glEndQueryEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 13725 /* "glEndQueryEXT" */,
                                providers, entrypoints);
}

static PFNGLENDQUERYINDEXEDPROC
epoxy_glEndQueryIndexed_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_GL_ARB_transform_feedback3,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        13739 /* "glEndQueryIndexed" */,
        13739 /* "glEndQueryIndexed" */,
    };
    return gl_provider_resolver(entrypoint_strings + 13739 /* "glEndQueryIndexed" */,
                                providers, entrypoints);
}

static PFNGLENDTILINGQCOMPROC
epoxy_glEndTilingQCOM_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_QCOM_tiled_rendering, 13757 /* glEndTilingQCOM */);
}

static PFNGLENDTRANSFORMFEEDBACKPROC
epoxy_glEndTransformFeedback_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_EXT_transform_feedback,
        PROVIDER_GL_NV_transform_feedback,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        13773 /* "glEndTransformFeedback" */,
        13773 /* "glEndTransformFeedback" */,
        13796 /* "glEndTransformFeedbackEXT" */,
        13822 /* "glEndTransformFeedbackNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 13773 /* "glEndTransformFeedback" */,
                                providers, entrypoints);
}

static PFNGLENDTRANSFORMFEEDBACKEXTPROC
epoxy_glEndTransformFeedbackEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_transform_feedback,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_NV_transform_feedback,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        13796 /* "glEndTransformFeedbackEXT" */,
        13773 /* "glEndTransformFeedback" */,
        13773 /* "glEndTransformFeedback" */,
        13822 /* "glEndTransformFeedbackNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 13796 /* "glEndTransformFeedbackEXT" */,
                                providers, entrypoints);
}

static PFNGLENDTRANSFORMFEEDBACKNVPROC
epoxy_glEndTransformFeedbackNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_transform_feedback,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_EXT_transform_feedback,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        13822 /* "glEndTransformFeedbackNV" */,
        13773 /* "glEndTransformFeedback" */,
        13773 /* "glEndTransformFeedback" */,
        13796 /* "glEndTransformFeedbackEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 13822 /* "glEndTransformFeedbackNV" */,
                                providers, entrypoints);
}

static PFNGLENDVERTEXSHADEREXTPROC
epoxy_glEndVertexShaderEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_shader, 13847 /* glEndVertexShaderEXT */);
}

static PFNGLENDVIDEOCAPTURENVPROC
epoxy_glEndVideoCaptureNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_video_capture, 13868 /* glEndVideoCaptureNV */);
}

static PFNGLEVALCOORD1DPROC
epoxy_glEvalCoord1d_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 13888 /* glEvalCoord1d */);
}

static PFNGLEVALCOORD1DVPROC
epoxy_glEvalCoord1dv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 13902 /* glEvalCoord1dv */);
}

static PFNGLEVALCOORD1FPROC
epoxy_glEvalCoord1f_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 13917 /* glEvalCoord1f */);
}

static PFNGLEVALCOORD1FVPROC
epoxy_glEvalCoord1fv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 13931 /* glEvalCoord1fv */);
}

static PFNGLEVALCOORD1XOESPROC
epoxy_glEvalCoord1xOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 13946 /* glEvalCoord1xOES */);
}

static PFNGLEVALCOORD1XVOESPROC
epoxy_glEvalCoord1xvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 13963 /* glEvalCoord1xvOES */);
}

static PFNGLEVALCOORD2DPROC
epoxy_glEvalCoord2d_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 13981 /* glEvalCoord2d */);
}

static PFNGLEVALCOORD2DVPROC
epoxy_glEvalCoord2dv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 13995 /* glEvalCoord2dv */);
}

static PFNGLEVALCOORD2FPROC
epoxy_glEvalCoord2f_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 14010 /* glEvalCoord2f */);
}

static PFNGLEVALCOORD2FVPROC
epoxy_glEvalCoord2fv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 14024 /* glEvalCoord2fv */);
}

static PFNGLEVALCOORD2XOESPROC
epoxy_glEvalCoord2xOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 14039 /* glEvalCoord2xOES */);
}

static PFNGLEVALCOORD2XVOESPROC
epoxy_glEvalCoord2xvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 14056 /* glEvalCoord2xvOES */);
}

static PFNGLEVALMAPSNVPROC
epoxy_glEvalMapsNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_evaluators, 14074 /* glEvalMapsNV */);
}

static PFNGLEVALMESH1PROC
epoxy_glEvalMesh1_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 14087 /* glEvalMesh1 */);
}

static PFNGLEVALMESH2PROC
epoxy_glEvalMesh2_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 14099 /* glEvalMesh2 */);
}

static PFNGLEVALPOINT1PROC
epoxy_glEvalPoint1_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 14111 /* glEvalPoint1 */);
}

static PFNGLEVALPOINT2PROC
epoxy_glEvalPoint2_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 14124 /* glEvalPoint2 */);
}

static PFNGLEVALUATEDEPTHVALUESARBPROC
epoxy_glEvaluateDepthValuesARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_sample_locations, 14137 /* glEvaluateDepthValuesARB */);
}

static PFNGLEXECUTEPROGRAMNVPROC
epoxy_glExecuteProgramNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_program, 14162 /* glExecuteProgramNV */);
}

static PFNGLEXTGETBUFFERPOINTERVQCOMPROC
epoxy_glExtGetBufferPointervQCOM_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_QCOM_extended_get, 14181 /* glExtGetBufferPointervQCOM */);
}

static PFNGLEXTGETBUFFERSQCOMPROC
epoxy_glExtGetBuffersQCOM_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_QCOM_extended_get, 14208 /* glExtGetBuffersQCOM */);
}

static PFNGLEXTGETFRAMEBUFFERSQCOMPROC
epoxy_glExtGetFramebuffersQCOM_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_QCOM_extended_get, 14228 /* glExtGetFramebuffersQCOM */);
}

static PFNGLEXTGETPROGRAMBINARYSOURCEQCOMPROC
epoxy_glExtGetProgramBinarySourceQCOM_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_QCOM_extended_get2, 14253 /* glExtGetProgramBinarySourceQCOM */);
}

static PFNGLEXTGETPROGRAMSQCOMPROC
epoxy_glExtGetProgramsQCOM_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_QCOM_extended_get2, 14285 /* glExtGetProgramsQCOM */);
}

static PFNGLEXTGETRENDERBUFFERSQCOMPROC
epoxy_glExtGetRenderbuffersQCOM_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_QCOM_extended_get, 14306 /* glExtGetRenderbuffersQCOM */);
}

static PFNGLEXTGETSHADERSQCOMPROC
epoxy_glExtGetShadersQCOM_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_QCOM_extended_get2, 14332 /* glExtGetShadersQCOM */);
}

static PFNGLEXTGETTEXLEVELPARAMETERIVQCOMPROC
epoxy_glExtGetTexLevelParameterivQCOM_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_QCOM_extended_get, 14352 /* glExtGetTexLevelParameterivQCOM */);
}

static PFNGLEXTGETTEXSUBIMAGEQCOMPROC
epoxy_glExtGetTexSubImageQCOM_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_QCOM_extended_get, 14384 /* glExtGetTexSubImageQCOM */);
}

static PFNGLEXTGETTEXTURESQCOMPROC
epoxy_glExtGetTexturesQCOM_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_QCOM_extended_get, 14408 /* glExtGetTexturesQCOM */);
}

static PFNGLEXTISPROGRAMBINARYQCOMPROC
epoxy_glExtIsProgramBinaryQCOM_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_QCOM_extended_get2, 14429 /* glExtIsProgramBinaryQCOM */);
}

static PFNGLEXTTEXOBJECTSTATEOVERRIDEIQCOMPROC
epoxy_glExtTexObjectStateOverrideiQCOM_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_QCOM_extended_get, 14454 /* glExtTexObjectStateOverrideiQCOM */);
}

static PFNGLEXTRACTCOMPONENTEXTPROC
epoxy_glExtractComponentEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_shader, 14487 /* glExtractComponentEXT */);
}

static PFNGLFEEDBACKBUFFERPROC
epoxy_glFeedbackBuffer_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 14509 /* glFeedbackBuffer */);
}

static PFNGLFEEDBACKBUFFERXOESPROC
epoxy_glFeedbackBufferxOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 14526 /* glFeedbackBufferxOES */);
}

static PFNGLFENCESYNCPROC
epoxy_glFenceSync_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_2,
        PROVIDER_GL_ARB_sync,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_APPLE_sync,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        14547 /* "glFenceSync" */,
        14547 /* "glFenceSync" */,
        14547 /* "glFenceSync" */,
        14559 /* "glFenceSyncAPPLE" */,
    };
    return gl_provider_resolver(entrypoint_strings + 14547 /* "glFenceSync" */,
                                providers, entrypoints);
}

static PFNGLFENCESYNCAPPLEPROC
epoxy_glFenceSyncAPPLE_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_APPLE_sync,
        PROVIDER_Desktop_OpenGL_3_2,
        PROVIDER_GL_ARB_sync,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        14559 /* "glFenceSyncAPPLE" */,
        14547 /* "glFenceSync" */,
        14547 /* "glFenceSync" */,
        14547 /* "glFenceSync" */,
    };
    return gl_provider_resolver(entrypoint_strings + 14559 /* "glFenceSyncAPPLE" */,
                                providers, entrypoints);
}

static PFNGLFINALCOMBINERINPUTNVPROC
epoxy_glFinalCombinerInputNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_register_combiners, 14576 /* glFinalCombinerInputNV */);
}

static PFNGLFINISHPROC
epoxy_glFinish_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        14599 /* "glFinish" */,
        14599 /* "glFinish" */,
        14599 /* "glFinish" */,
    };
    return gl_provider_resolver(entrypoint_strings + 14599 /* "glFinish" */,
                                providers, entrypoints);
}

static PFNGLFINISHASYNCSGIXPROC
epoxy_glFinishAsyncSGIX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIX_async, 14608 /* glFinishAsyncSGIX */);
}

static PFNGLFINISHFENCEAPPLEPROC
epoxy_glFinishFenceAPPLE_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_APPLE_fence, 14626 /* glFinishFenceAPPLE */);
}

static PFNGLFINISHFENCENVPROC
epoxy_glFinishFenceNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_fence, 14645 /* glFinishFenceNV */);
}

static PFNGLFINISHOBJECTAPPLEPROC
epoxy_glFinishObjectAPPLE_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_APPLE_fence, 14661 /* glFinishObjectAPPLE */);
}

static PFNGLFINISHTEXTURESUNXPROC
epoxy_glFinishTextureSUNX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUNX_constant_data, 14681 /* glFinishTextureSUNX */);
}

static PFNGLFLUSHPROC
epoxy_glFlush_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        14701 /* "glFlush" */,
        14701 /* "glFlush" */,
        14701 /* "glFlush" */,
    };
    return gl_provider_resolver(entrypoint_strings + 14701 /* "glFlush" */,
                                providers, entrypoints);
}

static PFNGLFLUSHMAPPEDBUFFERRANGEPROC
epoxy_glFlushMappedBufferRange_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_map_buffer_range,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_APPLE_flush_buffer_range,
        PROVIDER_GL_EXT_map_buffer_range,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        14709 /* "glFlushMappedBufferRange" */,
        14709 /* "glFlushMappedBufferRange" */,
        14709 /* "glFlushMappedBufferRange" */,
        14734 /* "glFlushMappedBufferRangeAPPLE" */,
        14764 /* "glFlushMappedBufferRangeEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 14709 /* "glFlushMappedBufferRange" */,
                                providers, entrypoints);
}

static PFNGLFLUSHMAPPEDBUFFERRANGEAPPLEPROC
epoxy_glFlushMappedBufferRangeAPPLE_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_APPLE_flush_buffer_range,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_map_buffer_range,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_EXT_map_buffer_range,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        14734 /* "glFlushMappedBufferRangeAPPLE" */,
        14709 /* "glFlushMappedBufferRange" */,
        14709 /* "glFlushMappedBufferRange" */,
        14709 /* "glFlushMappedBufferRange" */,
        14764 /* "glFlushMappedBufferRangeEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 14734 /* "glFlushMappedBufferRangeAPPLE" */,
                                providers, entrypoints);
}

static PFNGLFLUSHMAPPEDBUFFERRANGEEXTPROC
epoxy_glFlushMappedBufferRangeEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_map_buffer_range,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_map_buffer_range,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_APPLE_flush_buffer_range,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        14764 /* "glFlushMappedBufferRangeEXT" */,
        14709 /* "glFlushMappedBufferRange" */,
        14709 /* "glFlushMappedBufferRange" */,
        14709 /* "glFlushMappedBufferRange" */,
        14734 /* "glFlushMappedBufferRangeAPPLE" */,
    };
    return gl_provider_resolver(entrypoint_strings + 14764 /* "glFlushMappedBufferRangeEXT" */,
                                providers, entrypoints);
}

static PFNGLFLUSHMAPPEDNAMEDBUFFERRANGEPROC
epoxy_glFlushMappedNamedBufferRange_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        14792 /* "glFlushMappedNamedBufferRange" */,
        14792 /* "glFlushMappedNamedBufferRange" */,
    };
    return gl_provider_resolver(entrypoint_strings + 14792 /* "glFlushMappedNamedBufferRange" */,
                                providers, entrypoints);
}

static PFNGLFLUSHMAPPEDNAMEDBUFFERRANGEEXTPROC
epoxy_glFlushMappedNamedBufferRangeEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 14822 /* glFlushMappedNamedBufferRangeEXT */);
}

static PFNGLFLUSHPIXELDATARANGENVPROC
epoxy_glFlushPixelDataRangeNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_pixel_data_range, 14855 /* glFlushPixelDataRangeNV */);
}

static PFNGLFLUSHRASTERSGIXPROC
epoxy_glFlushRasterSGIX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIX_flush_raster, 14879 /* glFlushRasterSGIX */);
}

static PFNGLFLUSHSTATICDATAIBMPROC
epoxy_glFlushStaticDataIBM_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_IBM_static_data, 14897 /* glFlushStaticDataIBM */);
}

static PFNGLFLUSHVERTEXARRAYRANGEAPPLEPROC
epoxy_glFlushVertexArrayRangeAPPLE_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_APPLE_vertex_array_range, 14918 /* glFlushVertexArrayRangeAPPLE */);
}

static PFNGLFLUSHVERTEXARRAYRANGENVPROC
epoxy_glFlushVertexArrayRangeNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_array_range, 14947 /* glFlushVertexArrayRangeNV */);
}

static PFNGLFOGCOORDFORMATNVPROC
epoxy_glFogCoordFormatNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_buffer_unified_memory, 14973 /* glFogCoordFormatNV */);
}

static PFNGLFOGCOORDPOINTERPROC
epoxy_glFogCoordPointer_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_EXT_fog_coord,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        14992 /* "glFogCoordPointer" */,
        15010 /* "glFogCoordPointerEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 14992 /* "glFogCoordPointer" */,
                                providers, entrypoints);
}

static PFNGLFOGCOORDPOINTEREXTPROC
epoxy_glFogCoordPointerEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_fog_coord,
        PROVIDER_Desktop_OpenGL_1_4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        15010 /* "glFogCoordPointerEXT" */,
        14992 /* "glFogCoordPointer" */,
    };
    return gl_provider_resolver(entrypoint_strings + 15010 /* "glFogCoordPointerEXT" */,
                                providers, entrypoints);
}

static PFNGLFOGCOORDPOINTERLISTIBMPROC
epoxy_glFogCoordPointerListIBM_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_IBM_vertex_array_lists, 15031 /* glFogCoordPointerListIBM */);
}

static PFNGLFOGCOORDDPROC
epoxy_glFogCoordd_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_EXT_fog_coord,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        15056 /* "glFogCoordd" */,
        15068 /* "glFogCoorddEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 15056 /* "glFogCoordd" */,
                                providers, entrypoints);
}

static PFNGLFOGCOORDDEXTPROC
epoxy_glFogCoorddEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_fog_coord,
        PROVIDER_Desktop_OpenGL_1_4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        15068 /* "glFogCoorddEXT" */,
        15056 /* "glFogCoordd" */,
    };
    return gl_provider_resolver(entrypoint_strings + 15068 /* "glFogCoorddEXT" */,
                                providers, entrypoints);
}

static PFNGLFOGCOORDDVPROC
epoxy_glFogCoorddv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_EXT_fog_coord,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        15083 /* "glFogCoorddv" */,
        15096 /* "glFogCoorddvEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 15083 /* "glFogCoorddv" */,
                                providers, entrypoints);
}

static PFNGLFOGCOORDDVEXTPROC
epoxy_glFogCoorddvEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_fog_coord,
        PROVIDER_Desktop_OpenGL_1_4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        15096 /* "glFogCoorddvEXT" */,
        15083 /* "glFogCoorddv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 15096 /* "glFogCoorddvEXT" */,
                                providers, entrypoints);
}

static PFNGLFOGCOORDFPROC
epoxy_glFogCoordf_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_EXT_fog_coord,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        15112 /* "glFogCoordf" */,
        15124 /* "glFogCoordfEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 15112 /* "glFogCoordf" */,
                                providers, entrypoints);
}

static PFNGLFOGCOORDFEXTPROC
epoxy_glFogCoordfEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_fog_coord,
        PROVIDER_Desktop_OpenGL_1_4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        15124 /* "glFogCoordfEXT" */,
        15112 /* "glFogCoordf" */,
    };
    return gl_provider_resolver(entrypoint_strings + 15124 /* "glFogCoordfEXT" */,
                                providers, entrypoints);
}

static PFNGLFOGCOORDFVPROC
epoxy_glFogCoordfv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_EXT_fog_coord,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        15139 /* "glFogCoordfv" */,
        15152 /* "glFogCoordfvEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 15139 /* "glFogCoordfv" */,
                                providers, entrypoints);
}

static PFNGLFOGCOORDFVEXTPROC
epoxy_glFogCoordfvEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_fog_coord,
        PROVIDER_Desktop_OpenGL_1_4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        15152 /* "glFogCoordfvEXT" */,
        15139 /* "glFogCoordfv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 15152 /* "glFogCoordfvEXT" */,
                                providers, entrypoints);
}

static PFNGLFOGCOORDHNVPROC
epoxy_glFogCoordhNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_half_float, 15168 /* glFogCoordhNV */);
}

static PFNGLFOGCOORDHVNVPROC
epoxy_glFogCoordhvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_half_float, 15182 /* glFogCoordhvNV */);
}

static PFNGLFOGFUNCSGISPROC
epoxy_glFogFuncSGIS_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIS_fog_function, 15197 /* glFogFuncSGIS */);
}

static PFNGLFOGFPROC
epoxy_glFogf_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        15211 /* "glFogf" */,
        15211 /* "glFogf" */,
    };
    return gl_provider_resolver(entrypoint_strings + 15211 /* "glFogf" */,
                                providers, entrypoints);
}

static PFNGLFOGFVPROC
epoxy_glFogfv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        15218 /* "glFogfv" */,
        15218 /* "glFogfv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 15218 /* "glFogfv" */,
                                providers, entrypoints);
}

static PFNGLFOGIPROC
epoxy_glFogi_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 15226 /* glFogi */);
}

static PFNGLFOGIVPROC
epoxy_glFogiv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 15233 /* glFogiv */);
}

static PFNGLFOGXPROC
epoxy_glFogx_resolver(void)
{
    return gl_single_resolver(PROVIDER_OpenGL_ES_1_0, 15241 /* glFogx */);
}

static PFNGLFOGXOESPROC
epoxy_glFogxOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 15248 /* glFogxOES */);
}

static PFNGLFOGXVPROC
epoxy_glFogxv_resolver(void)
{
    return gl_single_resolver(PROVIDER_OpenGL_ES_1_0, 15258 /* glFogxv */);
}

static PFNGLFOGXVOESPROC
epoxy_glFogxvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 15266 /* glFogxvOES */);
}

static PFNGLFRAGMENTCOLORMATERIALSGIXPROC
epoxy_glFragmentColorMaterialSGIX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIX_fragment_lighting, 15277 /* glFragmentColorMaterialSGIX */);
}

static PFNGLFRAGMENTCOVERAGECOLORNVPROC
epoxy_glFragmentCoverageColorNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_fragment_coverage_to_color, 15305 /* glFragmentCoverageColorNV */);
}

static PFNGLFRAGMENTLIGHTMODELFSGIXPROC
epoxy_glFragmentLightModelfSGIX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIX_fragment_lighting, 15331 /* glFragmentLightModelfSGIX */);
}

static PFNGLFRAGMENTLIGHTMODELFVSGIXPROC
epoxy_glFragmentLightModelfvSGIX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIX_fragment_lighting, 15357 /* glFragmentLightModelfvSGIX */);
}

static PFNGLFRAGMENTLIGHTMODELISGIXPROC
epoxy_glFragmentLightModeliSGIX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIX_fragment_lighting, 15384 /* glFragmentLightModeliSGIX */);
}

static PFNGLFRAGMENTLIGHTMODELIVSGIXPROC
epoxy_glFragmentLightModelivSGIX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIX_fragment_lighting, 15410 /* glFragmentLightModelivSGIX */);
}

static PFNGLFRAGMENTLIGHTFSGIXPROC
epoxy_glFragmentLightfSGIX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIX_fragment_lighting, 15437 /* glFragmentLightfSGIX */);
}

static PFNGLFRAGMENTLIGHTFVSGIXPROC
epoxy_glFragmentLightfvSGIX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIX_fragment_lighting, 15458 /* glFragmentLightfvSGIX */);
}

static PFNGLFRAGMENTLIGHTISGIXPROC
epoxy_glFragmentLightiSGIX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIX_fragment_lighting, 15480 /* glFragmentLightiSGIX */);
}

static PFNGLFRAGMENTLIGHTIVSGIXPROC
epoxy_glFragmentLightivSGIX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIX_fragment_lighting, 15501 /* glFragmentLightivSGIX */);
}

static PFNGLFRAGMENTMATERIALFSGIXPROC
epoxy_glFragmentMaterialfSGIX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIX_fragment_lighting, 15523 /* glFragmentMaterialfSGIX */);
}

static PFNGLFRAGMENTMATERIALFVSGIXPROC
epoxy_glFragmentMaterialfvSGIX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIX_fragment_lighting, 15547 /* glFragmentMaterialfvSGIX */);
}

static PFNGLFRAGMENTMATERIALISGIXPROC
epoxy_glFragmentMaterialiSGIX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIX_fragment_lighting, 15572 /* glFragmentMaterialiSGIX */);
}

static PFNGLFRAGMENTMATERIALIVSGIXPROC
epoxy_glFragmentMaterialivSGIX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIX_fragment_lighting, 15596 /* glFragmentMaterialivSGIX */);
}

static PFNGLFRAMETERMINATORGREMEDYPROC
epoxy_glFrameTerminatorGREMEDY_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_GREMEDY_frame_terminator, 15621 /* glFrameTerminatorGREMEDY */);
}

static PFNGLFRAMEZOOMSGIXPROC
epoxy_glFrameZoomSGIX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIX_framezoom, 15646 /* glFrameZoomSGIX */);
}

static PFNGLFRAMEBUFFERDRAWBUFFEREXTPROC
epoxy_glFramebufferDrawBufferEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 15662 /* glFramebufferDrawBufferEXT */);
}

static PFNGLFRAMEBUFFERDRAWBUFFERSEXTPROC
epoxy_glFramebufferDrawBuffersEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 15689 /* glFramebufferDrawBuffersEXT */);
}

static PFNGLFRAMEBUFFERFETCHBARRIEREXTPROC
epoxy_glFramebufferFetchBarrierEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_shader_framebuffer_fetch_non_coherent, 15717 /* glFramebufferFetchBarrierEXT */);
}

static PFNGLFRAMEBUFFERFETCHBARRIERQCOMPROC
epoxy_glFramebufferFetchBarrierQCOM_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_QCOM_shader_framebuffer_fetch_noncoherent, 15746 /* glFramebufferFetchBarrierQCOM */);
}

static PFNGLFRAMEBUFFERFOVEATIONCONFIGQCOMPROC
epoxy_glFramebufferFoveationConfigQCOM_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_QCOM_framebuffer_foveated, 15776 /* glFramebufferFoveationConfigQCOM */);
}

static PFNGLFRAMEBUFFERFOVEATIONPARAMETERSQCOMPROC
epoxy_glFramebufferFoveationParametersQCOM_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_QCOM_framebuffer_foveated, 15809 /* glFramebufferFoveationParametersQCOM */);
}

static PFNGLFRAMEBUFFERPARAMETERIPROC
epoxy_glFramebufferParameteri_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_ARB_framebuffer_no_attachments,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        15846 /* "glFramebufferParameteri" */,
        15846 /* "glFramebufferParameteri" */,
        15846 /* "glFramebufferParameteri" */,
    };
    return gl_provider_resolver(entrypoint_strings + 15846 /* "glFramebufferParameteri" */,
                                providers, entrypoints);
}

static PFNGLFRAMEBUFFERPARAMETERIMESAPROC
epoxy_glFramebufferParameteriMESA_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_MESA_framebuffer_flip_y, 15870 /* glFramebufferParameteriMESA */);
}

static PFNGLFRAMEBUFFERPIXELLOCALSTORAGESIZEEXTPROC
epoxy_glFramebufferPixelLocalStorageSizeEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_shader_pixel_local_storage2, 15898 /* glFramebufferPixelLocalStorageSizeEXT */);
}

static PFNGLFRAMEBUFFERREADBUFFEREXTPROC
epoxy_glFramebufferReadBufferEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 15936 /* glFramebufferReadBufferEXT */);
}

static PFNGLFRAMEBUFFERRENDERBUFFERPROC
epoxy_glFramebufferRenderbuffer_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_framebuffer_object,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_EXT_framebuffer_object,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        15963 /* "glFramebufferRenderbuffer" */,
        15963 /* "glFramebufferRenderbuffer" */,
        15963 /* "glFramebufferRenderbuffer" */,
        15989 /* "glFramebufferRenderbufferEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 15963 /* "glFramebufferRenderbuffer" */,
                                providers, entrypoints);
}

static PFNGLFRAMEBUFFERRENDERBUFFEREXTPROC
epoxy_glFramebufferRenderbufferEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_framebuffer_object,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_framebuffer_object,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        15989 /* "glFramebufferRenderbufferEXT" */,
        15963 /* "glFramebufferRenderbuffer" */,
        15963 /* "glFramebufferRenderbuffer" */,
        15963 /* "glFramebufferRenderbuffer" */,
    };
    return gl_provider_resolver(entrypoint_strings + 15989 /* "glFramebufferRenderbufferEXT" */,
                                providers, entrypoints);
}

static PFNGLFRAMEBUFFERRENDERBUFFEROESPROC
epoxy_glFramebufferRenderbufferOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_framebuffer_object, 16018 /* glFramebufferRenderbufferOES */);
}

static PFNGLFRAMEBUFFERSAMPLELOCATIONSFVARBPROC
epoxy_glFramebufferSampleLocationsfvARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_sample_locations, 16047 /* glFramebufferSampleLocationsfvARB */);
}

static PFNGLFRAMEBUFFERSAMPLELOCATIONSFVNVPROC
epoxy_glFramebufferSampleLocationsfvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_sample_locations, 16081 /* glFramebufferSampleLocationsfvNV */);
}

static PFNGLFRAMEBUFFERSAMPLEPOSITIONSFVAMDPROC
epoxy_glFramebufferSamplePositionsfvAMD_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_AMD_framebuffer_sample_positions, 16114 /* glFramebufferSamplePositionsfvAMD */);
}

static PFNGLFRAMEBUFFERTEXTUREPROC
epoxy_glFramebufferTexture_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_2,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_ARB_geometry_shader4,
        PROVIDER_GL_EXT_geometry_shader,
        PROVIDER_GL_NV_geometry_program4,
        PROVIDER_GL_OES_geometry_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        16148 /* "glFramebufferTexture" */,
        16148 /* "glFramebufferTexture" */,
        16478 /* "glFramebufferTextureARB" */,
        16502 /* "glFramebufferTextureEXT" */,
        16502 /* "glFramebufferTextureEXT" */,
        16782 /* "glFramebufferTextureOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 16148 /* "glFramebufferTexture" */,
                                providers, entrypoints);
}

static PFNGLFRAMEBUFFERTEXTURE1DPROC
epoxy_glFramebufferTexture1D_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_framebuffer_object,
        PROVIDER_GL_EXT_framebuffer_object,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        16169 /* "glFramebufferTexture1D" */,
        16169 /* "glFramebufferTexture1D" */,
        16192 /* "glFramebufferTexture1DEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 16169 /* "glFramebufferTexture1D" */,
                                providers, entrypoints);
}

static PFNGLFRAMEBUFFERTEXTURE1DEXTPROC
epoxy_glFramebufferTexture1DEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_framebuffer_object,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_framebuffer_object,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        16192 /* "glFramebufferTexture1DEXT" */,
        16169 /* "glFramebufferTexture1D" */,
        16169 /* "glFramebufferTexture1D" */,
    };
    return gl_provider_resolver(entrypoint_strings + 16192 /* "glFramebufferTexture1DEXT" */,
                                providers, entrypoints);
}

static PFNGLFRAMEBUFFERTEXTURE2DPROC
epoxy_glFramebufferTexture2D_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_framebuffer_object,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_EXT_framebuffer_object,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        16218 /* "glFramebufferTexture2D" */,
        16218 /* "glFramebufferTexture2D" */,
        16218 /* "glFramebufferTexture2D" */,
        16277 /* "glFramebufferTexture2DEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 16218 /* "glFramebufferTexture2D" */,
                                providers, entrypoints);
}

static PFNGLFRAMEBUFFERTEXTURE2DDOWNSAMPLEIMGPROC
epoxy_glFramebufferTexture2DDownsampleIMG_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_IMG_framebuffer_downsample, 16241 /* glFramebufferTexture2DDownsampleIMG */);
}

static PFNGLFRAMEBUFFERTEXTURE2DEXTPROC
epoxy_glFramebufferTexture2DEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_framebuffer_object,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_framebuffer_object,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        16277 /* "glFramebufferTexture2DEXT" */,
        16218 /* "glFramebufferTexture2D" */,
        16218 /* "glFramebufferTexture2D" */,
        16218 /* "glFramebufferTexture2D" */,
    };
    return gl_provider_resolver(entrypoint_strings + 16277 /* "glFramebufferTexture2DEXT" */,
                                providers, entrypoints);
}

static PFNGLFRAMEBUFFERTEXTURE2DMULTISAMPLEEXTPROC
epoxy_glFramebufferTexture2DMultisampleEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_multisampled_render_to_texture, 16303 /* glFramebufferTexture2DMultisampleEXT */);
}

static PFNGLFRAMEBUFFERTEXTURE2DMULTISAMPLEIMGPROC
epoxy_glFramebufferTexture2DMultisampleIMG_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_IMG_multisampled_render_to_texture, 16340 /* glFramebufferTexture2DMultisampleIMG */);
}

static PFNGLFRAMEBUFFERTEXTURE2DOESPROC
epoxy_glFramebufferTexture2DOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_framebuffer_object, 16377 /* glFramebufferTexture2DOES */);
}

static PFNGLFRAMEBUFFERTEXTURE3DPROC
epoxy_glFramebufferTexture3D_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_framebuffer_object,
        PROVIDER_GL_EXT_framebuffer_object,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        16403 /* "glFramebufferTexture3D" */,
        16403 /* "glFramebufferTexture3D" */,
        16426 /* "glFramebufferTexture3DEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 16403 /* "glFramebufferTexture3D" */,
                                providers, entrypoints);
}

static PFNGLFRAMEBUFFERTEXTURE3DEXTPROC
epoxy_glFramebufferTexture3DEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_framebuffer_object,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_framebuffer_object,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        16426 /* "glFramebufferTexture3DEXT" */,
        16403 /* "glFramebufferTexture3D" */,
        16403 /* "glFramebufferTexture3D" */,
    };
    return gl_provider_resolver(entrypoint_strings + 16426 /* "glFramebufferTexture3DEXT" */,
                                providers, entrypoints);
}

static PFNGLFRAMEBUFFERTEXTURE3DOESPROC
epoxy_glFramebufferTexture3DOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_texture_3D, 16452 /* glFramebufferTexture3DOES */);
}

static PFNGLFRAMEBUFFERTEXTUREARBPROC
epoxy_glFramebufferTextureARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_geometry_shader4,
        PROVIDER_Desktop_OpenGL_3_2,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_geometry_shader,
        PROVIDER_GL_NV_geometry_program4,
        PROVIDER_GL_OES_geometry_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        16478 /* "glFramebufferTextureARB" */,
        16148 /* "glFramebufferTexture" */,
        16148 /* "glFramebufferTexture" */,
        16502 /* "glFramebufferTextureEXT" */,
        16502 /* "glFramebufferTextureEXT" */,
        16782 /* "glFramebufferTextureOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 16478 /* "glFramebufferTextureARB" */,
                                providers, entrypoints);
}

static PFNGLFRAMEBUFFERTEXTUREEXTPROC
epoxy_glFramebufferTextureEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_geometry_shader,
        PROVIDER_GL_NV_geometry_program4,
        PROVIDER_Desktop_OpenGL_3_2,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_ARB_geometry_shader4,
        PROVIDER_GL_OES_geometry_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        16502 /* "glFramebufferTextureEXT" */,
        16502 /* "glFramebufferTextureEXT" */,
        16148 /* "glFramebufferTexture" */,
        16148 /* "glFramebufferTexture" */,
        16478 /* "glFramebufferTextureARB" */,
        16782 /* "glFramebufferTextureOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 16502 /* "glFramebufferTextureEXT" */,
                                providers, entrypoints);
}

static PFNGLFRAMEBUFFERTEXTUREFACEARBPROC
epoxy_glFramebufferTextureFaceARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_geometry_shader4,
        PROVIDER_GL_NV_geometry_program4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        16526 /* "glFramebufferTextureFaceARB" */,
        16554 /* "glFramebufferTextureFaceEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 16526 /* "glFramebufferTextureFaceARB" */,
                                providers, entrypoints);
}

static PFNGLFRAMEBUFFERTEXTUREFACEEXTPROC
epoxy_glFramebufferTextureFaceEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_geometry_program4,
        PROVIDER_GL_ARB_geometry_shader4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        16554 /* "glFramebufferTextureFaceEXT" */,
        16526 /* "glFramebufferTextureFaceARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 16554 /* "glFramebufferTextureFaceEXT" */,
                                providers, entrypoints);
}

static PFNGLFRAMEBUFFERTEXTURELAYERPROC
epoxy_glFramebufferTextureLayer_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_framebuffer_object,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_ARB_geometry_shader4,
        PROVIDER_GL_EXT_texture_array,
        PROVIDER_GL_NV_geometry_program4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        16582 /* "glFramebufferTextureLayer" */,
        16582 /* "glFramebufferTextureLayer" */,
        16582 /* "glFramebufferTextureLayer" */,
        16608 /* "glFramebufferTextureLayerARB" */,
        16676 /* "glFramebufferTextureLayerEXT" */,
        16676 /* "glFramebufferTextureLayerEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 16582 /* "glFramebufferTextureLayer" */,
                                providers, entrypoints);
}

static PFNGLFRAMEBUFFERTEXTURELAYERARBPROC
epoxy_glFramebufferTextureLayerARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_geometry_shader4,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_framebuffer_object,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_EXT_texture_array,
        PROVIDER_GL_NV_geometry_program4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        16608 /* "glFramebufferTextureLayerARB" */,
        16582 /* "glFramebufferTextureLayer" */,
        16582 /* "glFramebufferTextureLayer" */,
        16582 /* "glFramebufferTextureLayer" */,
        16676 /* "glFramebufferTextureLayerEXT" */,
        16676 /* "glFramebufferTextureLayerEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 16608 /* "glFramebufferTextureLayerARB" */,
                                providers, entrypoints);
}

static PFNGLFRAMEBUFFERTEXTURELAYERDOWNSAMPLEIMGPROC
epoxy_glFramebufferTextureLayerDownsampleIMG_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_IMG_framebuffer_downsample, 16637 /* glFramebufferTextureLayerDownsampleIMG */);
}

static PFNGLFRAMEBUFFERTEXTURELAYEREXTPROC
epoxy_glFramebufferTextureLayerEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_texture_array,
        PROVIDER_GL_NV_geometry_program4,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_framebuffer_object,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_ARB_geometry_shader4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        16676 /* "glFramebufferTextureLayerEXT" */,
        16676 /* "glFramebufferTextureLayerEXT" */,
        16582 /* "glFramebufferTextureLayer" */,
        16582 /* "glFramebufferTextureLayer" */,
        16582 /* "glFramebufferTextureLayer" */,
        16608 /* "glFramebufferTextureLayerARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 16676 /* "glFramebufferTextureLayerEXT" */,
                                providers, entrypoints);
}

static PFNGLFRAMEBUFFERTEXTUREMULTISAMPLEMULTIVIEWOVRPROC
epoxy_glFramebufferTextureMultisampleMultiviewOVR_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OVR_multiview_multisampled_render_to_texture, 16705 /* glFramebufferTextureMultisampleMultiviewOVR */);
}

static PFNGLFRAMEBUFFERTEXTUREMULTIVIEWOVRPROC
epoxy_glFramebufferTextureMultiviewOVR_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OVR_multiview, 16749 /* glFramebufferTextureMultiviewOVR */);
}

static PFNGLFRAMEBUFFERTEXTUREOESPROC
epoxy_glFramebufferTextureOES_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_OES_geometry_shader,
        PROVIDER_Desktop_OpenGL_3_2,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_ARB_geometry_shader4,
        PROVIDER_GL_EXT_geometry_shader,
        PROVIDER_GL_NV_geometry_program4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        16782 /* "glFramebufferTextureOES" */,
        16148 /* "glFramebufferTexture" */,
        16148 /* "glFramebufferTexture" */,
        16478 /* "glFramebufferTextureARB" */,
        16502 /* "glFramebufferTextureEXT" */,
        16502 /* "glFramebufferTextureEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 16782 /* "glFramebufferTextureOES" */,
                                providers, entrypoints);
}

static PFNGLFREEOBJECTBUFFERATIPROC
epoxy_glFreeObjectBufferATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_array_object, 16806 /* glFreeObjectBufferATI */);
}

static PFNGLFRONTFACEPROC
epoxy_glFrontFace_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        16828 /* "glFrontFace" */,
        16828 /* "glFrontFace" */,
        16828 /* "glFrontFace" */,
    };
    return gl_provider_resolver(entrypoint_strings + 16828 /* "glFrontFace" */,
                                providers, entrypoints);
}

static PFNGLFRUSTUMPROC
epoxy_glFrustum_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 16840 /* glFrustum */);
}

static PFNGLFRUSTUMFPROC
epoxy_glFrustumf_resolver(void)
{
    return gl_single_resolver(PROVIDER_OpenGL_ES_1_0, 16850 /* glFrustumf */);
}

static PFNGLFRUSTUMFOESPROC
epoxy_glFrustumfOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_single_precision, 16861 /* glFrustumfOES */);
}

static PFNGLFRUSTUMXPROC
epoxy_glFrustumx_resolver(void)
{
    return gl_single_resolver(PROVIDER_OpenGL_ES_1_0, 16875 /* glFrustumx */);
}

static PFNGLFRUSTUMXOESPROC
epoxy_glFrustumxOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 16886 /* glFrustumxOES */);
}

static PFNGLGENASYNCMARKERSSGIXPROC
epoxy_glGenAsyncMarkersSGIX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIX_async, 16900 /* glGenAsyncMarkersSGIX */);
}

static PFNGLGENBUFFERSPROC
epoxy_glGenBuffers_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_5,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_vertex_buffer_object,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        16922 /* "glGenBuffers" */,
        16922 /* "glGenBuffers" */,
        16922 /* "glGenBuffers" */,
        16935 /* "glGenBuffersARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 16922 /* "glGenBuffers" */,
                                providers, entrypoints);
}

static PFNGLGENBUFFERSARBPROC
epoxy_glGenBuffersARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_buffer_object,
        PROVIDER_Desktop_OpenGL_1_5,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        16935 /* "glGenBuffersARB" */,
        16922 /* "glGenBuffers" */,
        16922 /* "glGenBuffers" */,
        16922 /* "glGenBuffers" */,
    };
    return gl_provider_resolver(entrypoint_strings + 16935 /* "glGenBuffersARB" */,
                                providers, entrypoints);
}

static PFNGLGENFENCESAPPLEPROC
epoxy_glGenFencesAPPLE_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_APPLE_fence, 16951 /* glGenFencesAPPLE */);
}

static PFNGLGENFENCESNVPROC
epoxy_glGenFencesNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_fence, 16968 /* glGenFencesNV */);
}

static PFNGLGENFRAGMENTSHADERSATIPROC
epoxy_glGenFragmentShadersATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_fragment_shader, 16982 /* glGenFragmentShadersATI */);
}

static PFNGLGENFRAMEBUFFERSPROC
epoxy_glGenFramebuffers_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_framebuffer_object,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_EXT_framebuffer_object,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        17006 /* "glGenFramebuffers" */,
        17006 /* "glGenFramebuffers" */,
        17006 /* "glGenFramebuffers" */,
        17024 /* "glGenFramebuffersEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 17006 /* "glGenFramebuffers" */,
                                providers, entrypoints);
}

static PFNGLGENFRAMEBUFFERSEXTPROC
epoxy_glGenFramebuffersEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_framebuffer_object,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_framebuffer_object,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        17024 /* "glGenFramebuffersEXT" */,
        17006 /* "glGenFramebuffers" */,
        17006 /* "glGenFramebuffers" */,
        17006 /* "glGenFramebuffers" */,
    };
    return gl_provider_resolver(entrypoint_strings + 17024 /* "glGenFramebuffersEXT" */,
                                providers, entrypoints);
}

static PFNGLGENFRAMEBUFFERSOESPROC
epoxy_glGenFramebuffersOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_framebuffer_object, 17045 /* glGenFramebuffersOES */);
}

static PFNGLGENLISTSPROC
epoxy_glGenLists_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 17066 /* glGenLists */);
}

static PFNGLGENNAMESAMDPROC
epoxy_glGenNamesAMD_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_AMD_name_gen_delete, 17077 /* glGenNamesAMD */);
}

static PFNGLGENOCCLUSIONQUERIESNVPROC
epoxy_glGenOcclusionQueriesNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_occlusion_query, 17091 /* glGenOcclusionQueriesNV */);
}

static PFNGLGENPATHSNVPROC
epoxy_glGenPathsNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 17115 /* glGenPathsNV */);
}

static PFNGLGENPERFMONITORSAMDPROC
epoxy_glGenPerfMonitorsAMD_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_AMD_performance_monitor, 17128 /* glGenPerfMonitorsAMD */);
}

static PFNGLGENPROGRAMPIPELINESPROC
epoxy_glGenProgramPipelines_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        17149 /* "glGenProgramPipelines" */,
        17149 /* "glGenProgramPipelines" */,
        17149 /* "glGenProgramPipelines" */,
    };
    return gl_provider_resolver(entrypoint_strings + 17149 /* "glGenProgramPipelines" */,
                                providers, entrypoints);
}

static PFNGLGENPROGRAMPIPELINESEXTPROC
epoxy_glGenProgramPipelinesEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_separate_shader_objects, 17171 /* glGenProgramPipelinesEXT */);
}

static PFNGLGENPROGRAMSARBPROC
epoxy_glGenProgramsARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_fragment_program,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        17196 /* "glGenProgramsARB" */,
        17196 /* "glGenProgramsARB" */,
        17213 /* "glGenProgramsNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 17196 /* "glGenProgramsARB" */,
                                providers, entrypoints);
}

static PFNGLGENPROGRAMSNVPROC
epoxy_glGenProgramsNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program,
        PROVIDER_GL_ARB_fragment_program,
        PROVIDER_GL_ARB_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        17213 /* "glGenProgramsNV" */,
        17196 /* "glGenProgramsARB" */,
        17196 /* "glGenProgramsARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 17213 /* "glGenProgramsNV" */,
                                providers, entrypoints);
}

static PFNGLGENQUERIESPROC
epoxy_glGenQueries_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_5,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_ARB_occlusion_query,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        17229 /* "glGenQueries" */,
        17229 /* "glGenQueries" */,
        17242 /* "glGenQueriesARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 17229 /* "glGenQueries" */,
                                providers, entrypoints);
}

static PFNGLGENQUERIESARBPROC
epoxy_glGenQueriesARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_occlusion_query,
        PROVIDER_Desktop_OpenGL_1_5,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        17242 /* "glGenQueriesARB" */,
        17229 /* "glGenQueries" */,
        17229 /* "glGenQueries" */,
    };
    return gl_provider_resolver(entrypoint_strings + 17242 /* "glGenQueriesARB" */,
                                providers, entrypoints);
}

static PFNGLGENQUERIESEXTPROC
epoxy_glGenQueriesEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_disjoint_timer_query,
        PROVIDER_GL_EXT_occlusion_query_boolean,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        17258 /* "glGenQueriesEXT" */,
        17258 /* "glGenQueriesEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 17258 /* "glGenQueriesEXT" */,
                                providers, entrypoints);
}

static PFNGLGENQUERYRESOURCETAGNVPROC
epoxy_glGenQueryResourceTagNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_query_resource_tag, 17274 /* glGenQueryResourceTagNV */);
}

static PFNGLGENRENDERBUFFERSPROC
epoxy_glGenRenderbuffers_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_framebuffer_object,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_EXT_framebuffer_object,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        17298 /* "glGenRenderbuffers" */,
        17298 /* "glGenRenderbuffers" */,
        17298 /* "glGenRenderbuffers" */,
        17317 /* "glGenRenderbuffersEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 17298 /* "glGenRenderbuffers" */,
                                providers, entrypoints);
}

static PFNGLGENRENDERBUFFERSEXTPROC
epoxy_glGenRenderbuffersEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_framebuffer_object,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_framebuffer_object,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        17317 /* "glGenRenderbuffersEXT" */,
        17298 /* "glGenRenderbuffers" */,
        17298 /* "glGenRenderbuffers" */,
        17298 /* "glGenRenderbuffers" */,
    };
    return gl_provider_resolver(entrypoint_strings + 17317 /* "glGenRenderbuffersEXT" */,
                                providers, entrypoints);
}

static PFNGLGENRENDERBUFFERSOESPROC
epoxy_glGenRenderbuffersOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_framebuffer_object, 17339 /* glGenRenderbuffersOES */);
}

static PFNGLGENSAMPLERSPROC
epoxy_glGenSamplers_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_sampler_objects,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        17361 /* "glGenSamplers" */,
        17361 /* "glGenSamplers" */,
        17361 /* "glGenSamplers" */,
    };
    return gl_provider_resolver(entrypoint_strings + 17361 /* "glGenSamplers" */,
                                providers, entrypoints);
}

static PFNGLGENSEMAPHORESEXTPROC
epoxy_glGenSemaphoresEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_semaphore, 17375 /* glGenSemaphoresEXT */);
}

static PFNGLGENSYMBOLSEXTPROC
epoxy_glGenSymbolsEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_shader, 17394 /* glGenSymbolsEXT */);
}

static PFNGLGENTEXTURESPROC
epoxy_glGenTextures_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_1,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        17410 /* "glGenTextures" */,
        17410 /* "glGenTextures" */,
        17410 /* "glGenTextures" */,
    };
    return gl_provider_resolver(entrypoint_strings + 17410 /* "glGenTextures" */,
                                providers, entrypoints);
}

static PFNGLGENTEXTURESEXTPROC
epoxy_glGenTexturesEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_texture_object, 17424 /* glGenTexturesEXT */);
}

static PFNGLGENTRANSFORMFEEDBACKSPROC
epoxy_glGenTransformFeedbacks_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_GL_ARB_transform_feedback2,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_NV_transform_feedback2,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        17441 /* "glGenTransformFeedbacks" */,
        17441 /* "glGenTransformFeedbacks" */,
        17441 /* "glGenTransformFeedbacks" */,
        17465 /* "glGenTransformFeedbacksNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 17441 /* "glGenTransformFeedbacks" */,
                                providers, entrypoints);
}

static PFNGLGENTRANSFORMFEEDBACKSNVPROC
epoxy_glGenTransformFeedbacksNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_transform_feedback2,
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_GL_ARB_transform_feedback2,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        17465 /* "glGenTransformFeedbacksNV" */,
        17441 /* "glGenTransformFeedbacks" */,
        17441 /* "glGenTransformFeedbacks" */,
        17441 /* "glGenTransformFeedbacks" */,
    };
    return gl_provider_resolver(entrypoint_strings + 17465 /* "glGenTransformFeedbacksNV" */,
                                providers, entrypoints);
}

static PFNGLGENVERTEXARRAYSPROC
epoxy_glGenVertexArrays_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_vertex_array_object,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_APPLE_vertex_array_object,
        PROVIDER_GL_OES_vertex_array_object,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        17491 /* "glGenVertexArrays" */,
        17491 /* "glGenVertexArrays" */,
        17491 /* "glGenVertexArrays" */,
        17509 /* "glGenVertexArraysAPPLE" */,
        17532 /* "glGenVertexArraysOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 17491 /* "glGenVertexArrays" */,
                                providers, entrypoints);
}

static PFNGLGENVERTEXARRAYSAPPLEPROC
epoxy_glGenVertexArraysAPPLE_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_APPLE_vertex_array_object,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_vertex_array_object,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_OES_vertex_array_object,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        17509 /* "glGenVertexArraysAPPLE" */,
        17491 /* "glGenVertexArrays" */,
        17491 /* "glGenVertexArrays" */,
        17491 /* "glGenVertexArrays" */,
        17532 /* "glGenVertexArraysOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 17509 /* "glGenVertexArraysAPPLE" */,
                                providers, entrypoints);
}

static PFNGLGENVERTEXARRAYSOESPROC
epoxy_glGenVertexArraysOES_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_OES_vertex_array_object,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_vertex_array_object,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_APPLE_vertex_array_object,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        17532 /* "glGenVertexArraysOES" */,
        17491 /* "glGenVertexArrays" */,
        17491 /* "glGenVertexArrays" */,
        17491 /* "glGenVertexArrays" */,
        17509 /* "glGenVertexArraysAPPLE" */,
    };
    return gl_provider_resolver(entrypoint_strings + 17532 /* "glGenVertexArraysOES" */,
                                providers, entrypoints);
}

static PFNGLGENVERTEXSHADERSEXTPROC
epoxy_glGenVertexShadersEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_shader, 17553 /* glGenVertexShadersEXT */);
}

static PFNGLGENERATEMIPMAPPROC
epoxy_glGenerateMipmap_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_framebuffer_object,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_EXT_framebuffer_object,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        17575 /* "glGenerateMipmap" */,
        17575 /* "glGenerateMipmap" */,
        17575 /* "glGenerateMipmap" */,
        17592 /* "glGenerateMipmapEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 17575 /* "glGenerateMipmap" */,
                                providers, entrypoints);
}

static PFNGLGENERATEMIPMAPEXTPROC
epoxy_glGenerateMipmapEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_framebuffer_object,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_framebuffer_object,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        17592 /* "glGenerateMipmapEXT" */,
        17575 /* "glGenerateMipmap" */,
        17575 /* "glGenerateMipmap" */,
        17575 /* "glGenerateMipmap" */,
    };
    return gl_provider_resolver(entrypoint_strings + 17592 /* "glGenerateMipmapEXT" */,
                                providers, entrypoints);
}

static PFNGLGENERATEMIPMAPOESPROC
epoxy_glGenerateMipmapOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_framebuffer_object, 17612 /* glGenerateMipmapOES */);
}

static PFNGLGENERATEMULTITEXMIPMAPEXTPROC
epoxy_glGenerateMultiTexMipmapEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 17632 /* glGenerateMultiTexMipmapEXT */);
}

static PFNGLGENERATETEXTUREMIPMAPPROC
epoxy_glGenerateTextureMipmap_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        17660 /* "glGenerateTextureMipmap" */,
        17660 /* "glGenerateTextureMipmap" */,
    };
    return gl_provider_resolver(entrypoint_strings + 17660 /* "glGenerateTextureMipmap" */,
                                providers, entrypoints);
}

static PFNGLGENERATETEXTUREMIPMAPEXTPROC
epoxy_glGenerateTextureMipmapEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 17684 /* glGenerateTextureMipmapEXT */);
}

static PFNGLGETACTIVEATOMICCOUNTERBUFFERIVPROC
epoxy_glGetActiveAtomicCounterBufferiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_2,
        PROVIDER_GL_ARB_shader_atomic_counters,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        17711 /* "glGetActiveAtomicCounterBufferiv" */,
        17711 /* "glGetActiveAtomicCounterBufferiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 17711 /* "glGetActiveAtomicCounterBufferiv" */,
                                providers, entrypoints);
}

static PFNGLGETACTIVEATTRIBPROC
epoxy_glGetActiveAttrib_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_vertex_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        17744 /* "glGetActiveAttrib" */,
        17744 /* "glGetActiveAttrib" */,
        17762 /* "glGetActiveAttribARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 17744 /* "glGetActiveAttrib" */,
                                providers, entrypoints);
}

static PFNGLGETACTIVEATTRIBARBPROC
epoxy_glGetActiveAttribARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        17762 /* "glGetActiveAttribARB" */,
        17744 /* "glGetActiveAttrib" */,
        17744 /* "glGetActiveAttrib" */,
    };
    return gl_provider_resolver(entrypoint_strings + 17762 /* "glGetActiveAttribARB" */,
                                providers, entrypoints);
}

static PFNGLGETACTIVESUBROUTINENAMEPROC
epoxy_glGetActiveSubroutineName_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_GL_ARB_shader_subroutine,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        17783 /* "glGetActiveSubroutineName" */,
        17783 /* "glGetActiveSubroutineName" */,
    };
    return gl_provider_resolver(entrypoint_strings + 17783 /* "glGetActiveSubroutineName" */,
                                providers, entrypoints);
}

static PFNGLGETACTIVESUBROUTINEUNIFORMNAMEPROC
epoxy_glGetActiveSubroutineUniformName_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_GL_ARB_shader_subroutine,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        17809 /* "glGetActiveSubroutineUniformName" */,
        17809 /* "glGetActiveSubroutineUniformName" */,
    };
    return gl_provider_resolver(entrypoint_strings + 17809 /* "glGetActiveSubroutineUniformName" */,
                                providers, entrypoints);
}

static PFNGLGETACTIVESUBROUTINEUNIFORMIVPROC
epoxy_glGetActiveSubroutineUniformiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_GL_ARB_shader_subroutine,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        17842 /* "glGetActiveSubroutineUniformiv" */,
        17842 /* "glGetActiveSubroutineUniformiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 17842 /* "glGetActiveSubroutineUniformiv" */,
                                providers, entrypoints);
}

static PFNGLGETACTIVEUNIFORMPROC
epoxy_glGetActiveUniform_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        17873 /* "glGetActiveUniform" */,
        17873 /* "glGetActiveUniform" */,
        17892 /* "glGetActiveUniformARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 17873 /* "glGetActiveUniform" */,
                                providers, entrypoints);
}

static PFNGLGETACTIVEUNIFORMARBPROC
epoxy_glGetActiveUniformARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_shader_objects,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        17892 /* "glGetActiveUniformARB" */,
        17873 /* "glGetActiveUniform" */,
        17873 /* "glGetActiveUniform" */,
    };
    return gl_provider_resolver(entrypoint_strings + 17892 /* "glGetActiveUniformARB" */,
                                providers, entrypoints);
}

static PFNGLGETACTIVEUNIFORMBLOCKNAMEPROC
epoxy_glGetActiveUniformBlockName_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_1,
        PROVIDER_GL_ARB_uniform_buffer_object,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        17914 /* "glGetActiveUniformBlockName" */,
        17914 /* "glGetActiveUniformBlockName" */,
        17914 /* "glGetActiveUniformBlockName" */,
    };
    return gl_provider_resolver(entrypoint_strings + 17914 /* "glGetActiveUniformBlockName" */,
                                providers, entrypoints);
}

static PFNGLGETACTIVEUNIFORMBLOCKIVPROC
epoxy_glGetActiveUniformBlockiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_1,
        PROVIDER_GL_ARB_uniform_buffer_object,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        17942 /* "glGetActiveUniformBlockiv" */,
        17942 /* "glGetActiveUniformBlockiv" */,
        17942 /* "glGetActiveUniformBlockiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 17942 /* "glGetActiveUniformBlockiv" */,
                                providers, entrypoints);
}

static PFNGLGETACTIVEUNIFORMNAMEPROC
epoxy_glGetActiveUniformName_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_1,
        PROVIDER_GL_ARB_uniform_buffer_object,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        17968 /* "glGetActiveUniformName" */,
        17968 /* "glGetActiveUniformName" */,
    };
    return gl_provider_resolver(entrypoint_strings + 17968 /* "glGetActiveUniformName" */,
                                providers, entrypoints);
}

static PFNGLGETACTIVEUNIFORMSIVPROC
epoxy_glGetActiveUniformsiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_1,
        PROVIDER_GL_ARB_uniform_buffer_object,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        17991 /* "glGetActiveUniformsiv" */,
        17991 /* "glGetActiveUniformsiv" */,
        17991 /* "glGetActiveUniformsiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 17991 /* "glGetActiveUniformsiv" */,
                                providers, entrypoints);
}

static PFNGLGETACTIVEVARYINGNVPROC
epoxy_glGetActiveVaryingNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_transform_feedback, 18013 /* glGetActiveVaryingNV */);
}

static PFNGLGETARRAYOBJECTFVATIPROC
epoxy_glGetArrayObjectfvATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_array_object, 18034 /* glGetArrayObjectfvATI */);
}

static PFNGLGETARRAYOBJECTIVATIPROC
epoxy_glGetArrayObjectivATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_array_object, 18056 /* glGetArrayObjectivATI */);
}

static PFNGLGETATTACHEDOBJECTSARBPROC
epoxy_glGetAttachedObjectsARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_shader_objects, 18078 /* glGetAttachedObjectsARB */);
}

static PFNGLGETATTACHEDSHADERSPROC
epoxy_glGetAttachedShaders_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        18102 /* "glGetAttachedShaders" */,
        18102 /* "glGetAttachedShaders" */,
    };
    return gl_provider_resolver(entrypoint_strings + 18102 /* "glGetAttachedShaders" */,
                                providers, entrypoints);
}

static PFNGLGETATTRIBLOCATIONPROC
epoxy_glGetAttribLocation_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_vertex_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        18123 /* "glGetAttribLocation" */,
        18123 /* "glGetAttribLocation" */,
        18143 /* "glGetAttribLocationARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 18123 /* "glGetAttribLocation" */,
                                providers, entrypoints);
}

static PFNGLGETATTRIBLOCATIONARBPROC
epoxy_glGetAttribLocationARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        18143 /* "glGetAttribLocationARB" */,
        18123 /* "glGetAttribLocation" */,
        18123 /* "glGetAttribLocation" */,
    };
    return gl_provider_resolver(entrypoint_strings + 18143 /* "glGetAttribLocationARB" */,
                                providers, entrypoints);
}

static PFNGLGETBOOLEANINDEXEDVEXTPROC
epoxy_glGetBooleanIndexedvEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_draw_buffers2,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        18166 /* "glGetBooleanIndexedvEXT" */,
        18166 /* "glGetBooleanIndexedvEXT" */,
        18190 /* "glGetBooleani_v" */,
        18190 /* "glGetBooleani_v" */,
    };
    return gl_provider_resolver(entrypoint_strings + 18166 /* "glGetBooleanIndexedvEXT" */,
                                providers, entrypoints);
}

static PFNGLGETBOOLEANI_VPROC
epoxy_glGetBooleani_v_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_1,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_draw_buffers2,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        18190 /* "glGetBooleani_v" */,
        18190 /* "glGetBooleani_v" */,
        18166 /* "glGetBooleanIndexedvEXT" */,
        18166 /* "glGetBooleanIndexedvEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 18190 /* "glGetBooleani_v" */,
                                providers, entrypoints);
}

static PFNGLGETBOOLEANVPROC
epoxy_glGetBooleanv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        18206 /* "glGetBooleanv" */,
        18206 /* "glGetBooleanv" */,
        18206 /* "glGetBooleanv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 18206 /* "glGetBooleanv" */,
                                providers, entrypoints);
}

static PFNGLGETBUFFERPARAMETERI64VPROC
epoxy_glGetBufferParameteri64v_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_2,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        18220 /* "glGetBufferParameteri64v" */,
        18220 /* "glGetBufferParameteri64v" */,
    };
    return gl_provider_resolver(entrypoint_strings + 18220 /* "glGetBufferParameteri64v" */,
                                providers, entrypoints);
}

static PFNGLGETBUFFERPARAMETERIVPROC
epoxy_glGetBufferParameteriv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_5,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_vertex_buffer_object,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        18245 /* "glGetBufferParameteriv" */,
        18245 /* "glGetBufferParameteriv" */,
        18245 /* "glGetBufferParameteriv" */,
        18268 /* "glGetBufferParameterivARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 18245 /* "glGetBufferParameteriv" */,
                                providers, entrypoints);
}

static PFNGLGETBUFFERPARAMETERIVARBPROC
epoxy_glGetBufferParameterivARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_buffer_object,
        PROVIDER_Desktop_OpenGL_1_5,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        18268 /* "glGetBufferParameterivARB" */,
        18245 /* "glGetBufferParameteriv" */,
        18245 /* "glGetBufferParameteriv" */,
        18245 /* "glGetBufferParameteriv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 18268 /* "glGetBufferParameterivARB" */,
                                providers, entrypoints);
}

static PFNGLGETBUFFERPARAMETERUI64VNVPROC
epoxy_glGetBufferParameterui64vNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_shader_buffer_load, 18294 /* glGetBufferParameterui64vNV */);
}

static PFNGLGETBUFFERPOINTERVPROC
epoxy_glGetBufferPointerv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_5,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_ARB_vertex_buffer_object,
        PROVIDER_GL_OES_mapbuffer,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        18322 /* "glGetBufferPointerv" */,
        18322 /* "glGetBufferPointerv" */,
        18342 /* "glGetBufferPointervARB" */,
        18365 /* "glGetBufferPointervOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 18322 /* "glGetBufferPointerv" */,
                                providers, entrypoints);
}

static PFNGLGETBUFFERPOINTERVARBPROC
epoxy_glGetBufferPointervARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_buffer_object,
        PROVIDER_Desktop_OpenGL_1_5,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_OES_mapbuffer,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        18342 /* "glGetBufferPointervARB" */,
        18322 /* "glGetBufferPointerv" */,
        18322 /* "glGetBufferPointerv" */,
        18365 /* "glGetBufferPointervOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 18342 /* "glGetBufferPointervARB" */,
                                providers, entrypoints);
}

static PFNGLGETBUFFERPOINTERVOESPROC
epoxy_glGetBufferPointervOES_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_OES_mapbuffer,
        PROVIDER_Desktop_OpenGL_1_5,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_ARB_vertex_buffer_object,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        18365 /* "glGetBufferPointervOES" */,
        18322 /* "glGetBufferPointerv" */,
        18322 /* "glGetBufferPointerv" */,
        18342 /* "glGetBufferPointervARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 18365 /* "glGetBufferPointervOES" */,
                                providers, entrypoints);
}

static PFNGLGETBUFFERSUBDATAPROC
epoxy_glGetBufferSubData_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_5,
        PROVIDER_GL_ARB_vertex_buffer_object,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        18388 /* "glGetBufferSubData" */,
        18407 /* "glGetBufferSubDataARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 18388 /* "glGetBufferSubData" */,
                                providers, entrypoints);
}

static PFNGLGETBUFFERSUBDATAARBPROC
epoxy_glGetBufferSubDataARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_buffer_object,
        PROVIDER_Desktop_OpenGL_1_5,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        18407 /* "glGetBufferSubDataARB" */,
        18388 /* "glGetBufferSubData" */,
    };
    return gl_provider_resolver(entrypoint_strings + 18407 /* "glGetBufferSubDataARB" */,
                                providers, entrypoints);
}

static PFNGLGETCLIPPLANEPROC
epoxy_glGetClipPlane_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 18429 /* glGetClipPlane */);
}

static PFNGLGETCLIPPLANEFPROC
epoxy_glGetClipPlanef_resolver(void)
{
    return gl_single_resolver(PROVIDER_OpenGL_ES_1_0, 18444 /* glGetClipPlanef */);
}

static PFNGLGETCLIPPLANEFOESPROC
epoxy_glGetClipPlanefOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_single_precision, 18460 /* glGetClipPlanefOES */);
}

static PFNGLGETCLIPPLANEXPROC
epoxy_glGetClipPlanex_resolver(void)
{
    return gl_single_resolver(PROVIDER_OpenGL_ES_1_0, 18479 /* glGetClipPlanex */);
}

static PFNGLGETCLIPPLANEXOESPROC
epoxy_glGetClipPlanexOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 18495 /* glGetClipPlanexOES */);
}

static PFNGLGETCOLORTABLEPROC
epoxy_glGetColorTable_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_imaging,
        PROVIDER_GL_EXT_paletted_texture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        18514 /* "glGetColorTable" */,
        18530 /* "glGetColorTableEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 18514 /* "glGetColorTable" */,
                                providers, entrypoints);
}

static PFNGLGETCOLORTABLEEXTPROC
epoxy_glGetColorTableEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_paletted_texture,
        PROVIDER_GL_ARB_imaging,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        18530 /* "glGetColorTableEXT" */,
        18514 /* "glGetColorTable" */,
    };
    return gl_provider_resolver(entrypoint_strings + 18530 /* "glGetColorTableEXT" */,
                                providers, entrypoints);
}

static PFNGLGETCOLORTABLEPARAMETERFVPROC
epoxy_glGetColorTableParameterfv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_imaging,
        PROVIDER_GL_EXT_paletted_texture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        18549 /* "glGetColorTableParameterfv" */,
        18576 /* "glGetColorTableParameterfvEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 18549 /* "glGetColorTableParameterfv" */,
                                providers, entrypoints);
}

static PFNGLGETCOLORTABLEPARAMETERFVEXTPROC
epoxy_glGetColorTableParameterfvEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_paletted_texture,
        PROVIDER_GL_ARB_imaging,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        18576 /* "glGetColorTableParameterfvEXT" */,
        18549 /* "glGetColorTableParameterfv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 18576 /* "glGetColorTableParameterfvEXT" */,
                                providers, entrypoints);
}

static PFNGLGETCOLORTABLEPARAMETERFVSGIPROC
epoxy_glGetColorTableParameterfvSGI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGI_color_table, 18606 /* glGetColorTableParameterfvSGI */);
}

static PFNGLGETCOLORTABLEPARAMETERIVPROC
epoxy_glGetColorTableParameteriv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_imaging,
        PROVIDER_GL_EXT_paletted_texture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        18636 /* "glGetColorTableParameteriv" */,
        18663 /* "glGetColorTableParameterivEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 18636 /* "glGetColorTableParameteriv" */,
                                providers, entrypoints);
}

static PFNGLGETCOLORTABLEPARAMETERIVEXTPROC
epoxy_glGetColorTableParameterivEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_paletted_texture,
        PROVIDER_GL_ARB_imaging,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        18663 /* "glGetColorTableParameterivEXT" */,
        18636 /* "glGetColorTableParameteriv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 18663 /* "glGetColorTableParameterivEXT" */,
                                providers, entrypoints);
}

static PFNGLGETCOLORTABLEPARAMETERIVSGIPROC
epoxy_glGetColorTableParameterivSGI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGI_color_table, 18693 /* glGetColorTableParameterivSGI */);
}

static PFNGLGETCOLORTABLESGIPROC
epoxy_glGetColorTableSGI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGI_color_table, 18723 /* glGetColorTableSGI */);
}

static PFNGLGETCOMBINERINPUTPARAMETERFVNVPROC
epoxy_glGetCombinerInputParameterfvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_register_combiners, 18742 /* glGetCombinerInputParameterfvNV */);
}

static PFNGLGETCOMBINERINPUTPARAMETERIVNVPROC
epoxy_glGetCombinerInputParameterivNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_register_combiners, 18774 /* glGetCombinerInputParameterivNV */);
}

static PFNGLGETCOMBINEROUTPUTPARAMETERFVNVPROC
epoxy_glGetCombinerOutputParameterfvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_register_combiners, 18806 /* glGetCombinerOutputParameterfvNV */);
}

static PFNGLGETCOMBINEROUTPUTPARAMETERIVNVPROC
epoxy_glGetCombinerOutputParameterivNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_register_combiners, 18839 /* glGetCombinerOutputParameterivNV */);
}

static PFNGLGETCOMBINERSTAGEPARAMETERFVNVPROC
epoxy_glGetCombinerStageParameterfvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_register_combiners2, 18872 /* glGetCombinerStageParameterfvNV */);
}

static PFNGLGETCOMMANDHEADERNVPROC
epoxy_glGetCommandHeaderNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_command_list, 18904 /* glGetCommandHeaderNV */);
}

static PFNGLGETCOMPRESSEDMULTITEXIMAGEEXTPROC
epoxy_glGetCompressedMultiTexImageEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 18925 /* glGetCompressedMultiTexImageEXT */);
}

static PFNGLGETCOMPRESSEDTEXIMAGEPROC
epoxy_glGetCompressedTexImage_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_GL_ARB_texture_compression,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        18957 /* "glGetCompressedTexImage" */,
        18981 /* "glGetCompressedTexImageARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 18957 /* "glGetCompressedTexImage" */,
                                providers, entrypoints);
}

static PFNGLGETCOMPRESSEDTEXIMAGEARBPROC
epoxy_glGetCompressedTexImageARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_texture_compression,
        PROVIDER_Desktop_OpenGL_1_3,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        18981 /* "glGetCompressedTexImageARB" */,
        18957 /* "glGetCompressedTexImage" */,
    };
    return gl_provider_resolver(entrypoint_strings + 18981 /* "glGetCompressedTexImageARB" */,
                                providers, entrypoints);
}

static PFNGLGETCOMPRESSEDTEXTUREIMAGEPROC
epoxy_glGetCompressedTextureImage_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        19008 /* "glGetCompressedTextureImage" */,
        19008 /* "glGetCompressedTextureImage" */,
    };
    return gl_provider_resolver(entrypoint_strings + 19008 /* "glGetCompressedTextureImage" */,
                                providers, entrypoints);
}

static PFNGLGETCOMPRESSEDTEXTUREIMAGEEXTPROC
epoxy_glGetCompressedTextureImageEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 19036 /* glGetCompressedTextureImageEXT */);
}

static PFNGLGETCOMPRESSEDTEXTURESUBIMAGEPROC
epoxy_glGetCompressedTextureSubImage_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_get_texture_sub_image,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        19067 /* "glGetCompressedTextureSubImage" */,
        19067 /* "glGetCompressedTextureSubImage" */,
    };
    return gl_provider_resolver(entrypoint_strings + 19067 /* "glGetCompressedTextureSubImage" */,
                                providers, entrypoints);
}

static PFNGLGETCONVOLUTIONFILTERPROC
epoxy_glGetConvolutionFilter_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_imaging, 19098 /* glGetConvolutionFilter */);
}

static PFNGLGETCONVOLUTIONFILTEREXTPROC
epoxy_glGetConvolutionFilterEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_convolution, 19121 /* glGetConvolutionFilterEXT */);
}

static PFNGLGETCONVOLUTIONPARAMETERFVPROC
epoxy_glGetConvolutionParameterfv_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_imaging, 19147 /* glGetConvolutionParameterfv */);
}

static PFNGLGETCONVOLUTIONPARAMETERFVEXTPROC
epoxy_glGetConvolutionParameterfvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_convolution, 19175 /* glGetConvolutionParameterfvEXT */);
}

static PFNGLGETCONVOLUTIONPARAMETERIVPROC
epoxy_glGetConvolutionParameteriv_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_imaging, 19206 /* glGetConvolutionParameteriv */);
}

static PFNGLGETCONVOLUTIONPARAMETERIVEXTPROC
epoxy_glGetConvolutionParameterivEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_convolution, 19234 /* glGetConvolutionParameterivEXT */);
}

static PFNGLGETCONVOLUTIONPARAMETERXVOESPROC
epoxy_glGetConvolutionParameterxvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 19265 /* glGetConvolutionParameterxvOES */);
}

static PFNGLGETCOVERAGEMODULATIONTABLENVPROC
epoxy_glGetCoverageModulationTableNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_framebuffer_mixed_samples, 19296 /* glGetCoverageModulationTableNV */);
}

static PFNGLGETDEBUGMESSAGELOGPROC
epoxy_glGetDebugMessageLog_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_KHR_debug,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_ARB_debug_output,
        PROVIDER_GL_KHR_debug,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        19327 /* "glGetDebugMessageLog" */,
        19327 /* "glGetDebugMessageLog" */,
        19327 /* "glGetDebugMessageLog" */,
        19372 /* "glGetDebugMessageLogARB" */,
        19396 /* "glGetDebugMessageLogKHR" */,
    };
    return gl_provider_resolver(entrypoint_strings + 19327 /* "glGetDebugMessageLog" */,
                                providers, entrypoints);
}

static PFNGLGETDEBUGMESSAGELOGAMDPROC
epoxy_glGetDebugMessageLogAMD_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_AMD_debug_output, 19348 /* glGetDebugMessageLogAMD */);
}

static PFNGLGETDEBUGMESSAGELOGARBPROC
epoxy_glGetDebugMessageLogARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_debug_output,
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_KHR_debug,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_KHR_debug,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        19372 /* "glGetDebugMessageLogARB" */,
        19327 /* "glGetDebugMessageLog" */,
        19327 /* "glGetDebugMessageLog" */,
        19327 /* "glGetDebugMessageLog" */,
        19396 /* "glGetDebugMessageLogKHR" */,
    };
    return gl_provider_resolver(entrypoint_strings + 19372 /* "glGetDebugMessageLogARB" */,
                                providers, entrypoints);
}

static PFNGLGETDEBUGMESSAGELOGKHRPROC
epoxy_glGetDebugMessageLogKHR_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_KHR_debug,
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_KHR_debug,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_ARB_debug_output,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        19396 /* "glGetDebugMessageLogKHR" */,
        19327 /* "glGetDebugMessageLog" */,
        19327 /* "glGetDebugMessageLog" */,
        19327 /* "glGetDebugMessageLog" */,
        19372 /* "glGetDebugMessageLogARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 19396 /* "glGetDebugMessageLogKHR" */,
                                providers, entrypoints);
}

static PFNGLGETDETAILTEXFUNCSGISPROC
epoxy_glGetDetailTexFuncSGIS_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIS_detail_texture, 19420 /* glGetDetailTexFuncSGIS */);
}

static PFNGLGETDOUBLEINDEXEDVEXTPROC
epoxy_glGetDoubleIndexedvEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_viewport_array,
        PROVIDER_GL_EXT_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        19443 /* "glGetDoubleIndexedvEXT" */,
        19466 /* "glGetDoublei_v" */,
        19466 /* "glGetDoublei_v" */,
        19481 /* "glGetDoublei_vEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 19443 /* "glGetDoubleIndexedvEXT" */,
                                providers, entrypoints);
}

static PFNGLGETDOUBLEI_VPROC
epoxy_glGetDoublei_v_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_viewport_array,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        19466 /* "glGetDoublei_v" */,
        19466 /* "glGetDoublei_v" */,
        19443 /* "glGetDoubleIndexedvEXT" */,
        19481 /* "glGetDoublei_vEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 19466 /* "glGetDoublei_v" */,
                                providers, entrypoints);
}

static PFNGLGETDOUBLEI_VEXTPROC
epoxy_glGetDoublei_vEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_viewport_array,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        19481 /* "glGetDoublei_vEXT" */,
        19443 /* "glGetDoubleIndexedvEXT" */,
        19466 /* "glGetDoublei_v" */,
        19466 /* "glGetDoublei_v" */,
    };
    return gl_provider_resolver(entrypoint_strings + 19481 /* "glGetDoublei_vEXT" */,
                                providers, entrypoints);
}

static PFNGLGETDOUBLEVPROC
epoxy_glGetDoublev_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 19499 /* glGetDoublev */);
}

static PFNGLGETDRIVERCONTROLSTRINGQCOMPROC
epoxy_glGetDriverControlStringQCOM_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_QCOM_driver_control, 19512 /* glGetDriverControlStringQCOM */);
}

static PFNGLGETDRIVERCONTROLSQCOMPROC
epoxy_glGetDriverControlsQCOM_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_QCOM_driver_control, 19541 /* glGetDriverControlsQCOM */);
}

static PFNGLGETERRORPROC
epoxy_glGetError_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        19565 /* "glGetError" */,
        19565 /* "glGetError" */,
        19565 /* "glGetError" */,
    };
    return gl_provider_resolver(entrypoint_strings + 19565 /* "glGetError" */,
                                providers, entrypoints);
}

static PFNGLGETFENCEIVNVPROC
epoxy_glGetFenceivNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_fence, 19576 /* glGetFenceivNV */);
}

static PFNGLGETFINALCOMBINERINPUTPARAMETERFVNVPROC
epoxy_glGetFinalCombinerInputParameterfvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_register_combiners, 19591 /* glGetFinalCombinerInputParameterfvNV */);
}

static PFNGLGETFINALCOMBINERINPUTPARAMETERIVNVPROC
epoxy_glGetFinalCombinerInputParameterivNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_register_combiners, 19628 /* glGetFinalCombinerInputParameterivNV */);
}

static PFNGLGETFIRSTPERFQUERYIDINTELPROC
epoxy_glGetFirstPerfQueryIdINTEL_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_INTEL_performance_query, 19665 /* glGetFirstPerfQueryIdINTEL */);
}

static PFNGLGETFIXEDVPROC
epoxy_glGetFixedv_resolver(void)
{
    return gl_single_resolver(PROVIDER_OpenGL_ES_1_0, 19692 /* glGetFixedv */);
}

static PFNGLGETFIXEDVOESPROC
epoxy_glGetFixedvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 19704 /* glGetFixedvOES */);
}

static PFNGLGETFLOATINDEXEDVEXTPROC
epoxy_glGetFloatIndexedvEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_viewport_array,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_NV_viewport_array,
        PROVIDER_GL_OES_viewport_array,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        19719 /* "glGetFloatIndexedvEXT" */,
        19741 /* "glGetFloati_v" */,
        19741 /* "glGetFloati_v" */,
        19755 /* "glGetFloati_vEXT" */,
        19772 /* "glGetFloati_vNV" */,
        19788 /* "glGetFloati_vOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 19719 /* "glGetFloatIndexedvEXT" */,
                                providers, entrypoints);
}

static PFNGLGETFLOATI_VPROC
epoxy_glGetFloati_v_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_viewport_array,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_NV_viewport_array,
        PROVIDER_GL_OES_viewport_array,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        19741 /* "glGetFloati_v" */,
        19741 /* "glGetFloati_v" */,
        19719 /* "glGetFloatIndexedvEXT" */,
        19755 /* "glGetFloati_vEXT" */,
        19772 /* "glGetFloati_vNV" */,
        19788 /* "glGetFloati_vOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 19741 /* "glGetFloati_v" */,
                                providers, entrypoints);
}

static PFNGLGETFLOATI_VEXTPROC
epoxy_glGetFloati_vEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_viewport_array,
        PROVIDER_GL_NV_viewport_array,
        PROVIDER_GL_OES_viewport_array,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        19755 /* "glGetFloati_vEXT" */,
        19719 /* "glGetFloatIndexedvEXT" */,
        19741 /* "glGetFloati_v" */,
        19741 /* "glGetFloati_v" */,
        19772 /* "glGetFloati_vNV" */,
        19788 /* "glGetFloati_vOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 19755 /* "glGetFloati_vEXT" */,
                                providers, entrypoints);
}

static PFNGLGETFLOATI_VNVPROC
epoxy_glGetFloati_vNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_viewport_array,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_viewport_array,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_OES_viewport_array,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        19772 /* "glGetFloati_vNV" */,
        19719 /* "glGetFloatIndexedvEXT" */,
        19741 /* "glGetFloati_v" */,
        19741 /* "glGetFloati_v" */,
        19755 /* "glGetFloati_vEXT" */,
        19788 /* "glGetFloati_vOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 19772 /* "glGetFloati_vNV" */,
                                providers, entrypoints);
}

static PFNGLGETFLOATI_VOESPROC
epoxy_glGetFloati_vOES_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_OES_viewport_array,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_viewport_array,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_NV_viewport_array,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        19788 /* "glGetFloati_vOES" */,
        19719 /* "glGetFloatIndexedvEXT" */,
        19741 /* "glGetFloati_v" */,
        19741 /* "glGetFloati_v" */,
        19755 /* "glGetFloati_vEXT" */,
        19772 /* "glGetFloati_vNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 19788 /* "glGetFloati_vOES" */,
                                providers, entrypoints);
}

static PFNGLGETFLOATVPROC
epoxy_glGetFloatv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        19805 /* "glGetFloatv" */,
        19805 /* "glGetFloatv" */,
        19805 /* "glGetFloatv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 19805 /* "glGetFloatv" */,
                                providers, entrypoints);
}

static PFNGLGETFOGFUNCSGISPROC
epoxy_glGetFogFuncSGIS_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIS_fog_function, 19817 /* glGetFogFuncSGIS */);
}

static PFNGLGETFRAGDATAINDEXPROC
epoxy_glGetFragDataIndex_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_blend_func_extended,
        PROVIDER_GL_EXT_blend_func_extended,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        19834 /* "glGetFragDataIndex" */,
        19834 /* "glGetFragDataIndex" */,
        19853 /* "glGetFragDataIndexEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 19834 /* "glGetFragDataIndex" */,
                                providers, entrypoints);
}

static PFNGLGETFRAGDATAINDEXEXTPROC
epoxy_glGetFragDataIndexEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_blend_func_extended,
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_blend_func_extended,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        19853 /* "glGetFragDataIndexEXT" */,
        19834 /* "glGetFragDataIndex" */,
        19834 /* "glGetFragDataIndex" */,
    };
    return gl_provider_resolver(entrypoint_strings + 19853 /* "glGetFragDataIndexEXT" */,
                                providers, entrypoints);
}

static PFNGLGETFRAGDATALOCATIONPROC
epoxy_glGetFragDataLocation_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_EXT_gpu_shader4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        19875 /* "glGetFragDataLocation" */,
        19875 /* "glGetFragDataLocation" */,
        19897 /* "glGetFragDataLocationEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 19875 /* "glGetFragDataLocation" */,
                                providers, entrypoints);
}

static PFNGLGETFRAGDATALOCATIONEXTPROC
epoxy_glGetFragDataLocationEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_gpu_shader4,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        19897 /* "glGetFragDataLocationEXT" */,
        19875 /* "glGetFragDataLocation" */,
        19875 /* "glGetFragDataLocation" */,
    };
    return gl_provider_resolver(entrypoint_strings + 19897 /* "glGetFragDataLocationEXT" */,
                                providers, entrypoints);
}

static PFNGLGETFRAGMENTLIGHTFVSGIXPROC
epoxy_glGetFragmentLightfvSGIX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIX_fragment_lighting, 19922 /* glGetFragmentLightfvSGIX */);
}

static PFNGLGETFRAGMENTLIGHTIVSGIXPROC
epoxy_glGetFragmentLightivSGIX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIX_fragment_lighting, 19947 /* glGetFragmentLightivSGIX */);
}

static PFNGLGETFRAGMENTMATERIALFVSGIXPROC
epoxy_glGetFragmentMaterialfvSGIX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIX_fragment_lighting, 19972 /* glGetFragmentMaterialfvSGIX */);
}

static PFNGLGETFRAGMENTMATERIALIVSGIXPROC
epoxy_glGetFragmentMaterialivSGIX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIX_fragment_lighting, 20000 /* glGetFragmentMaterialivSGIX */);
}

static PFNGLGETFRAMEBUFFERATTACHMENTPARAMETERIVPROC
epoxy_glGetFramebufferAttachmentParameteriv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_framebuffer_object,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_EXT_framebuffer_object,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        20028 /* "glGetFramebufferAttachmentParameteriv" */,
        20028 /* "glGetFramebufferAttachmentParameteriv" */,
        20028 /* "glGetFramebufferAttachmentParameteriv" */,
        20066 /* "glGetFramebufferAttachmentParameterivEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 20028 /* "glGetFramebufferAttachmentParameteriv" */,
                                providers, entrypoints);
}

static PFNGLGETFRAMEBUFFERATTACHMENTPARAMETERIVEXTPROC
epoxy_glGetFramebufferAttachmentParameterivEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_framebuffer_object,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_framebuffer_object,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        20066 /* "glGetFramebufferAttachmentParameterivEXT" */,
        20028 /* "glGetFramebufferAttachmentParameteriv" */,
        20028 /* "glGetFramebufferAttachmentParameteriv" */,
        20028 /* "glGetFramebufferAttachmentParameteriv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 20066 /* "glGetFramebufferAttachmentParameterivEXT" */,
                                providers, entrypoints);
}

static PFNGLGETFRAMEBUFFERATTACHMENTPARAMETERIVOESPROC
epoxy_glGetFramebufferAttachmentParameterivOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_framebuffer_object, 20107 /* glGetFramebufferAttachmentParameterivOES */);
}

static PFNGLGETFRAMEBUFFERPARAMETERFVAMDPROC
epoxy_glGetFramebufferParameterfvAMD_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_AMD_framebuffer_sample_positions, 20148 /* glGetFramebufferParameterfvAMD */);
}

static PFNGLGETFRAMEBUFFERPARAMETERIVPROC
epoxy_glGetFramebufferParameteriv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_ARB_framebuffer_no_attachments,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        20179 /* "glGetFramebufferParameteriv" */,
        20179 /* "glGetFramebufferParameteriv" */,
        20179 /* "glGetFramebufferParameteriv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 20179 /* "glGetFramebufferParameteriv" */,
                                providers, entrypoints);
}

static PFNGLGETFRAMEBUFFERPARAMETERIVEXTPROC
epoxy_glGetFramebufferParameterivEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 20207 /* glGetFramebufferParameterivEXT */);
}

static PFNGLGETFRAMEBUFFERPARAMETERIVMESAPROC
epoxy_glGetFramebufferParameterivMESA_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_MESA_framebuffer_flip_y, 20238 /* glGetFramebufferParameterivMESA */);
}

static PFNGLGETFRAMEBUFFERPIXELLOCALSTORAGESIZEEXTPROC
epoxy_glGetFramebufferPixelLocalStorageSizeEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_shader_pixel_local_storage2, 20270 /* glGetFramebufferPixelLocalStorageSizeEXT */);
}

static PFNGLGETGRAPHICSRESETSTATUSPROC
epoxy_glGetGraphicsResetStatus_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_KHR_robustness,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_robustness,
        PROVIDER_GL_KHR_robustness,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        20311 /* "glGetGraphicsResetStatus" */,
        20311 /* "glGetGraphicsResetStatus" */,
        20311 /* "glGetGraphicsResetStatus" */,
        20364 /* "glGetGraphicsResetStatusEXT" */,
        20392 /* "glGetGraphicsResetStatusKHR" */,
    };
    return gl_provider_resolver(entrypoint_strings + 20311 /* "glGetGraphicsResetStatus" */,
                                providers, entrypoints);
}

static PFNGLGETGRAPHICSRESETSTATUSARBPROC
epoxy_glGetGraphicsResetStatusARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_robustness, 20336 /* glGetGraphicsResetStatusARB */);
}

static PFNGLGETGRAPHICSRESETSTATUSEXTPROC
epoxy_glGetGraphicsResetStatusEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_robustness,
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_KHR_robustness,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_KHR_robustness,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        20364 /* "glGetGraphicsResetStatusEXT" */,
        20311 /* "glGetGraphicsResetStatus" */,
        20311 /* "glGetGraphicsResetStatus" */,
        20311 /* "glGetGraphicsResetStatus" */,
        20392 /* "glGetGraphicsResetStatusKHR" */,
    };
    return gl_provider_resolver(entrypoint_strings + 20364 /* "glGetGraphicsResetStatusEXT" */,
                                providers, entrypoints);
}

static PFNGLGETGRAPHICSRESETSTATUSKHRPROC
epoxy_glGetGraphicsResetStatusKHR_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_KHR_robustness,
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_KHR_robustness,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_robustness,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        20392 /* "glGetGraphicsResetStatusKHR" */,
        20311 /* "glGetGraphicsResetStatus" */,
        20311 /* "glGetGraphicsResetStatus" */,
        20311 /* "glGetGraphicsResetStatus" */,
        20364 /* "glGetGraphicsResetStatusEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 20392 /* "glGetGraphicsResetStatusKHR" */,
                                providers, entrypoints);
}

static PFNGLGETHANDLEARBPROC
epoxy_glGetHandleARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_shader_objects, 20420 /* glGetHandleARB */);
}

static PFNGLGETHISTOGRAMPROC
epoxy_glGetHistogram_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_imaging, 20435 /* glGetHistogram */);
}

static PFNGLGETHISTOGRAMEXTPROC
epoxy_glGetHistogramEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_histogram, 20450 /* glGetHistogramEXT */);
}

static PFNGLGETHISTOGRAMPARAMETERFVPROC
epoxy_glGetHistogramParameterfv_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_imaging, 20468 /* glGetHistogramParameterfv */);
}

static PFNGLGETHISTOGRAMPARAMETERFVEXTPROC
epoxy_glGetHistogramParameterfvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_histogram, 20494 /* glGetHistogramParameterfvEXT */);
}

static PFNGLGETHISTOGRAMPARAMETERIVPROC
epoxy_glGetHistogramParameteriv_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_imaging, 20523 /* glGetHistogramParameteriv */);
}

static PFNGLGETHISTOGRAMPARAMETERIVEXTPROC
epoxy_glGetHistogramParameterivEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_histogram, 20549 /* glGetHistogramParameterivEXT */);
}

static PFNGLGETHISTOGRAMPARAMETERXVOESPROC
epoxy_glGetHistogramParameterxvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 20578 /* glGetHistogramParameterxvOES */);
}

static PFNGLGETIMAGEHANDLEARBPROC
epoxy_glGetImageHandleARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_bindless_texture, 20607 /* glGetImageHandleARB */);
}

static PFNGLGETIMAGEHANDLENVPROC
epoxy_glGetImageHandleNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_bindless_texture, 20627 /* glGetImageHandleNV */);
}

static PFNGLGETIMAGETRANSFORMPARAMETERFVHPPROC
epoxy_glGetImageTransformParameterfvHP_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_HP_image_transform, 20646 /* glGetImageTransformParameterfvHP */);
}

static PFNGLGETIMAGETRANSFORMPARAMETERIVHPPROC
epoxy_glGetImageTransformParameterivHP_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_HP_image_transform, 20679 /* glGetImageTransformParameterivHP */);
}

static PFNGLGETINFOLOGARBPROC
epoxy_glGetInfoLogARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_shader_objects, 20712 /* glGetInfoLogARB */);
}

static PFNGLGETINSTRUMENTSSGIXPROC
epoxy_glGetInstrumentsSGIX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIX_instruments, 20728 /* glGetInstrumentsSGIX */);
}

static PFNGLGETINTEGER64I_VPROC
epoxy_glGetInteger64i_v_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_2,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        20749 /* "glGetInteger64i_v" */,
        20749 /* "glGetInteger64i_v" */,
    };
    return gl_provider_resolver(entrypoint_strings + 20749 /* "glGetInteger64i_v" */,
                                providers, entrypoints);
}

static PFNGLGETINTEGER64VPROC
epoxy_glGetInteger64v_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_2,
        PROVIDER_GL_ARB_sync,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_APPLE_sync,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        20767 /* "glGetInteger64v" */,
        20767 /* "glGetInteger64v" */,
        20767 /* "glGetInteger64v" */,
        20783 /* "glGetInteger64vAPPLE" */,
    };
    return gl_provider_resolver(entrypoint_strings + 20767 /* "glGetInteger64v" */,
                                providers, entrypoints);
}

static PFNGLGETINTEGER64VAPPLEPROC
epoxy_glGetInteger64vAPPLE_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_APPLE_sync,
        PROVIDER_Desktop_OpenGL_3_2,
        PROVIDER_GL_ARB_sync,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        20783 /* "glGetInteger64vAPPLE" */,
        20767 /* "glGetInteger64v" */,
        20767 /* "glGetInteger64v" */,
        20767 /* "glGetInteger64v" */,
    };
    return gl_provider_resolver(entrypoint_strings + 20783 /* "glGetInteger64vAPPLE" */,
                                providers, entrypoints);
}

static PFNGLGETINTEGERINDEXEDVEXTPROC
epoxy_glGetIntegerIndexedvEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_draw_buffers2,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_Desktop_OpenGL_3_1,
        PROVIDER_GL_ARB_uniform_buffer_object,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        20804 /* "glGetIntegerIndexedvEXT" */,
        20804 /* "glGetIntegerIndexedvEXT" */,
        20828 /* "glGetIntegeri_v" */,
        20828 /* "glGetIntegeri_v" */,
        20828 /* "glGetIntegeri_v" */,
        20828 /* "glGetIntegeri_v" */,
    };
    return gl_provider_resolver(entrypoint_strings + 20804 /* "glGetIntegerIndexedvEXT" */,
                                providers, entrypoints);
}

static PFNGLGETINTEGERI_VPROC
epoxy_glGetIntegeri_v_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_Desktop_OpenGL_3_1,
        PROVIDER_GL_ARB_uniform_buffer_object,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_draw_buffers2,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        20828 /* "glGetIntegeri_v" */,
        20828 /* "glGetIntegeri_v" */,
        20828 /* "glGetIntegeri_v" */,
        20828 /* "glGetIntegeri_v" */,
        20804 /* "glGetIntegerIndexedvEXT" */,
        20804 /* "glGetIntegerIndexedvEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 20828 /* "glGetIntegeri_v" */,
                                providers, entrypoints);
}

static PFNGLGETINTEGERI_VEXTPROC
epoxy_glGetIntegeri_vEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_multiview_draw_buffers, 20844 /* glGetIntegeri_vEXT */);
}

static PFNGLGETINTEGERUI64I_VNVPROC
epoxy_glGetIntegerui64i_vNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_buffer_unified_memory, 20863 /* glGetIntegerui64i_vNV */);
}

static PFNGLGETINTEGERUI64VNVPROC
epoxy_glGetIntegerui64vNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_shader_buffer_load, 20885 /* glGetIntegerui64vNV */);
}

static PFNGLGETINTEGERVPROC
epoxy_glGetIntegerv_resolver(void)
{
    return gl_single_resolver(PROVIDER_always_present, 20905 /* glGetIntegerv */);
}

static PFNGLGETINTERNALFORMATSAMPLEIVNVPROC
epoxy_glGetInternalformatSampleivNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_internalformat_sample_query, 20919 /* glGetInternalformatSampleivNV */);
}

static PFNGLGETINTERNALFORMATI64VPROC
epoxy_glGetInternalformati64v_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_ARB_internalformat_query2,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        20949 /* "glGetInternalformati64v" */,
        20949 /* "glGetInternalformati64v" */,
    };
    return gl_provider_resolver(entrypoint_strings + 20949 /* "glGetInternalformati64v" */,
                                providers, entrypoints);
}

static PFNGLGETINTERNALFORMATIVPROC
epoxy_glGetInternalformativ_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_2,
        PROVIDER_GL_ARB_internalformat_query,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        20973 /* "glGetInternalformativ" */,
        20973 /* "glGetInternalformativ" */,
        20973 /* "glGetInternalformativ" */,
    };
    return gl_provider_resolver(entrypoint_strings + 20973 /* "glGetInternalformativ" */,
                                providers, entrypoints);
}

static PFNGLGETINVARIANTBOOLEANVEXTPROC
epoxy_glGetInvariantBooleanvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_shader, 20995 /* glGetInvariantBooleanvEXT */);
}

static PFNGLGETINVARIANTFLOATVEXTPROC
epoxy_glGetInvariantFloatvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_shader, 21021 /* glGetInvariantFloatvEXT */);
}

static PFNGLGETINVARIANTINTEGERVEXTPROC
epoxy_glGetInvariantIntegervEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_shader, 21045 /* glGetInvariantIntegervEXT */);
}

static PFNGLGETLIGHTFVPROC
epoxy_glGetLightfv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        21071 /* "glGetLightfv" */,
        21071 /* "glGetLightfv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 21071 /* "glGetLightfv" */,
                                providers, entrypoints);
}

static PFNGLGETLIGHTIVPROC
epoxy_glGetLightiv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 21084 /* glGetLightiv */);
}

static PFNGLGETLIGHTXOESPROC
epoxy_glGetLightxOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 21097 /* glGetLightxOES */);
}

static PFNGLGETLIGHTXVPROC
epoxy_glGetLightxv_resolver(void)
{
    return gl_single_resolver(PROVIDER_OpenGL_ES_1_0, 21112 /* glGetLightxv */);
}

static PFNGLGETLIGHTXVOESPROC
epoxy_glGetLightxvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 21125 /* glGetLightxvOES */);
}

static PFNGLGETLISTPARAMETERFVSGIXPROC
epoxy_glGetListParameterfvSGIX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIX_list_priority, 21141 /* glGetListParameterfvSGIX */);
}

static PFNGLGETLISTPARAMETERIVSGIXPROC
epoxy_glGetListParameterivSGIX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIX_list_priority, 21166 /* glGetListParameterivSGIX */);
}

static PFNGLGETLOCALCONSTANTBOOLEANVEXTPROC
epoxy_glGetLocalConstantBooleanvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_shader, 21191 /* glGetLocalConstantBooleanvEXT */);
}

static PFNGLGETLOCALCONSTANTFLOATVEXTPROC
epoxy_glGetLocalConstantFloatvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_shader, 21221 /* glGetLocalConstantFloatvEXT */);
}

static PFNGLGETLOCALCONSTANTINTEGERVEXTPROC
epoxy_glGetLocalConstantIntegervEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_shader, 21249 /* glGetLocalConstantIntegervEXT */);
}

static PFNGLGETMAPATTRIBPARAMETERFVNVPROC
epoxy_glGetMapAttribParameterfvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_evaluators, 21279 /* glGetMapAttribParameterfvNV */);
}

static PFNGLGETMAPATTRIBPARAMETERIVNVPROC
epoxy_glGetMapAttribParameterivNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_evaluators, 21307 /* glGetMapAttribParameterivNV */);
}

static PFNGLGETMAPCONTROLPOINTSNVPROC
epoxy_glGetMapControlPointsNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_evaluators, 21335 /* glGetMapControlPointsNV */);
}

static PFNGLGETMAPPARAMETERFVNVPROC
epoxy_glGetMapParameterfvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_evaluators, 21359 /* glGetMapParameterfvNV */);
}

static PFNGLGETMAPPARAMETERIVNVPROC
epoxy_glGetMapParameterivNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_evaluators, 21381 /* glGetMapParameterivNV */);
}

static PFNGLGETMAPDVPROC
epoxy_glGetMapdv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 21403 /* glGetMapdv */);
}

static PFNGLGETMAPFVPROC
epoxy_glGetMapfv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 21414 /* glGetMapfv */);
}

static PFNGLGETMAPIVPROC
epoxy_glGetMapiv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 21425 /* glGetMapiv */);
}

static PFNGLGETMAPXVOESPROC
epoxy_glGetMapxvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 21436 /* glGetMapxvOES */);
}

static PFNGLGETMATERIALFVPROC
epoxy_glGetMaterialfv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        21450 /* "glGetMaterialfv" */,
        21450 /* "glGetMaterialfv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 21450 /* "glGetMaterialfv" */,
                                providers, entrypoints);
}

static PFNGLGETMATERIALIVPROC
epoxy_glGetMaterialiv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 21466 /* glGetMaterialiv */);
}

static PFNGLGETMATERIALXOESPROC
epoxy_glGetMaterialxOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 21482 /* glGetMaterialxOES */);
}

static PFNGLGETMATERIALXVPROC
epoxy_glGetMaterialxv_resolver(void)
{
    return gl_single_resolver(PROVIDER_OpenGL_ES_1_0, 21500 /* glGetMaterialxv */);
}

static PFNGLGETMATERIALXVOESPROC
epoxy_glGetMaterialxvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 21516 /* glGetMaterialxvOES */);
}

static PFNGLGETMEMORYOBJECTDETACHEDRESOURCESUIVNVPROC
epoxy_glGetMemoryObjectDetachedResourcesuivNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_memory_attachment, 21535 /* glGetMemoryObjectDetachedResourcesuivNV */);
}

static PFNGLGETMEMORYOBJECTPARAMETERIVEXTPROC
epoxy_glGetMemoryObjectParameterivEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_memory_object, 21575 /* glGetMemoryObjectParameterivEXT */);
}

static PFNGLGETMINMAXPROC
epoxy_glGetMinmax_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_imaging, 21607 /* glGetMinmax */);
}

static PFNGLGETMINMAXEXTPROC
epoxy_glGetMinmaxEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_histogram, 21619 /* glGetMinmaxEXT */);
}

static PFNGLGETMINMAXPARAMETERFVPROC
epoxy_glGetMinmaxParameterfv_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_imaging, 21634 /* glGetMinmaxParameterfv */);
}

static PFNGLGETMINMAXPARAMETERFVEXTPROC
epoxy_glGetMinmaxParameterfvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_histogram, 21657 /* glGetMinmaxParameterfvEXT */);
}

static PFNGLGETMINMAXPARAMETERIVPROC
epoxy_glGetMinmaxParameteriv_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_imaging, 21683 /* glGetMinmaxParameteriv */);
}

static PFNGLGETMINMAXPARAMETERIVEXTPROC
epoxy_glGetMinmaxParameterivEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_histogram, 21706 /* glGetMinmaxParameterivEXT */);
}

static PFNGLGETMULTITEXENVFVEXTPROC
epoxy_glGetMultiTexEnvfvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 21732 /* glGetMultiTexEnvfvEXT */);
}

static PFNGLGETMULTITEXENVIVEXTPROC
epoxy_glGetMultiTexEnvivEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 21754 /* glGetMultiTexEnvivEXT */);
}

static PFNGLGETMULTITEXGENDVEXTPROC
epoxy_glGetMultiTexGendvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 21776 /* glGetMultiTexGendvEXT */);
}

static PFNGLGETMULTITEXGENFVEXTPROC
epoxy_glGetMultiTexGenfvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 21798 /* glGetMultiTexGenfvEXT */);
}

static PFNGLGETMULTITEXGENIVEXTPROC
epoxy_glGetMultiTexGenivEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 21820 /* glGetMultiTexGenivEXT */);
}

static PFNGLGETMULTITEXIMAGEEXTPROC
epoxy_glGetMultiTexImageEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 21842 /* glGetMultiTexImageEXT */);
}

static PFNGLGETMULTITEXLEVELPARAMETERFVEXTPROC
epoxy_glGetMultiTexLevelParameterfvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 21864 /* glGetMultiTexLevelParameterfvEXT */);
}

static PFNGLGETMULTITEXLEVELPARAMETERIVEXTPROC
epoxy_glGetMultiTexLevelParameterivEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 21897 /* glGetMultiTexLevelParameterivEXT */);
}

static PFNGLGETMULTITEXPARAMETERIIVEXTPROC
epoxy_glGetMultiTexParameterIivEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 21930 /* glGetMultiTexParameterIivEXT */);
}

static PFNGLGETMULTITEXPARAMETERIUIVEXTPROC
epoxy_glGetMultiTexParameterIuivEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 21959 /* glGetMultiTexParameterIuivEXT */);
}

static PFNGLGETMULTITEXPARAMETERFVEXTPROC
epoxy_glGetMultiTexParameterfvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 21989 /* glGetMultiTexParameterfvEXT */);
}

static PFNGLGETMULTITEXPARAMETERIVEXTPROC
epoxy_glGetMultiTexParameterivEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 22017 /* glGetMultiTexParameterivEXT */);
}

static PFNGLGETMULTISAMPLEFVPROC
epoxy_glGetMultisamplefv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_2,
        PROVIDER_GL_ARB_texture_multisample,
        PROVIDER_OpenGL_ES_3_1,
        PROVIDER_GL_NV_explicit_multisample,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        22045 /* "glGetMultisamplefv" */,
        22045 /* "glGetMultisamplefv" */,
        22045 /* "glGetMultisamplefv" */,
        22064 /* "glGetMultisamplefvNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 22045 /* "glGetMultisamplefv" */,
                                providers, entrypoints);
}

static PFNGLGETMULTISAMPLEFVNVPROC
epoxy_glGetMultisamplefvNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_explicit_multisample,
        PROVIDER_Desktop_OpenGL_3_2,
        PROVIDER_GL_ARB_texture_multisample,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        22064 /* "glGetMultisamplefvNV" */,
        22045 /* "glGetMultisamplefv" */,
        22045 /* "glGetMultisamplefv" */,
        22045 /* "glGetMultisamplefv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 22064 /* "glGetMultisamplefvNV" */,
                                providers, entrypoints);
}

static PFNGLGETNAMEDBUFFERPARAMETERI64VPROC
epoxy_glGetNamedBufferParameteri64v_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        22085 /* "glGetNamedBufferParameteri64v" */,
        22085 /* "glGetNamedBufferParameteri64v" */,
    };
    return gl_provider_resolver(entrypoint_strings + 22085 /* "glGetNamedBufferParameteri64v" */,
                                providers, entrypoints);
}

static PFNGLGETNAMEDBUFFERPARAMETERIVPROC
epoxy_glGetNamedBufferParameteriv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        22115 /* "glGetNamedBufferParameteriv" */,
        22115 /* "glGetNamedBufferParameteriv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 22115 /* "glGetNamedBufferParameteriv" */,
                                providers, entrypoints);
}

static PFNGLGETNAMEDBUFFERPARAMETERIVEXTPROC
epoxy_glGetNamedBufferParameterivEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 22143 /* glGetNamedBufferParameterivEXT */);
}

static PFNGLGETNAMEDBUFFERPARAMETERUI64VNVPROC
epoxy_glGetNamedBufferParameterui64vNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_shader_buffer_load, 22174 /* glGetNamedBufferParameterui64vNV */);
}

static PFNGLGETNAMEDBUFFERPOINTERVPROC
epoxy_glGetNamedBufferPointerv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        22207 /* "glGetNamedBufferPointerv" */,
        22207 /* "glGetNamedBufferPointerv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 22207 /* "glGetNamedBufferPointerv" */,
                                providers, entrypoints);
}

static PFNGLGETNAMEDBUFFERPOINTERVEXTPROC
epoxy_glGetNamedBufferPointervEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 22232 /* glGetNamedBufferPointervEXT */);
}

static PFNGLGETNAMEDBUFFERSUBDATAPROC
epoxy_glGetNamedBufferSubData_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        22260 /* "glGetNamedBufferSubData" */,
        22260 /* "glGetNamedBufferSubData" */,
    };
    return gl_provider_resolver(entrypoint_strings + 22260 /* "glGetNamedBufferSubData" */,
                                providers, entrypoints);
}

static PFNGLGETNAMEDBUFFERSUBDATAEXTPROC
epoxy_glGetNamedBufferSubDataEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 22284 /* glGetNamedBufferSubDataEXT */);
}

static PFNGLGETNAMEDFRAMEBUFFERATTACHMENTPARAMETERIVPROC
epoxy_glGetNamedFramebufferAttachmentParameteriv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        22311 /* "glGetNamedFramebufferAttachmentParameteriv" */,
        22311 /* "glGetNamedFramebufferAttachmentParameteriv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 22311 /* "glGetNamedFramebufferAttachmentParameteriv" */,
                                providers, entrypoints);
}

static PFNGLGETNAMEDFRAMEBUFFERATTACHMENTPARAMETERIVEXTPROC
epoxy_glGetNamedFramebufferAttachmentParameterivEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 22354 /* glGetNamedFramebufferAttachmentParameterivEXT */);
}

static PFNGLGETNAMEDFRAMEBUFFERPARAMETERFVAMDPROC
epoxy_glGetNamedFramebufferParameterfvAMD_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_AMD_framebuffer_sample_positions, 22400 /* glGetNamedFramebufferParameterfvAMD */);
}

static PFNGLGETNAMEDFRAMEBUFFERPARAMETERIVPROC
epoxy_glGetNamedFramebufferParameteriv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        22436 /* "glGetNamedFramebufferParameteriv" */,
        22436 /* "glGetNamedFramebufferParameteriv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 22436 /* "glGetNamedFramebufferParameteriv" */,
                                providers, entrypoints);
}

static PFNGLGETNAMEDFRAMEBUFFERPARAMETERIVEXTPROC
epoxy_glGetNamedFramebufferParameterivEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 22469 /* glGetNamedFramebufferParameterivEXT */);
}

static PFNGLGETNAMEDPROGRAMLOCALPARAMETERIIVEXTPROC
epoxy_glGetNamedProgramLocalParameterIivEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 22505 /* glGetNamedProgramLocalParameterIivEXT */);
}

static PFNGLGETNAMEDPROGRAMLOCALPARAMETERIUIVEXTPROC
epoxy_glGetNamedProgramLocalParameterIuivEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 22543 /* glGetNamedProgramLocalParameterIuivEXT */);
}

static PFNGLGETNAMEDPROGRAMLOCALPARAMETERDVEXTPROC
epoxy_glGetNamedProgramLocalParameterdvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 22582 /* glGetNamedProgramLocalParameterdvEXT */);
}

static PFNGLGETNAMEDPROGRAMLOCALPARAMETERFVEXTPROC
epoxy_glGetNamedProgramLocalParameterfvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 22619 /* glGetNamedProgramLocalParameterfvEXT */);
}

static PFNGLGETNAMEDPROGRAMSTRINGEXTPROC
epoxy_glGetNamedProgramStringEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 22656 /* glGetNamedProgramStringEXT */);
}

static PFNGLGETNAMEDPROGRAMIVEXTPROC
epoxy_glGetNamedProgramivEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 22683 /* glGetNamedProgramivEXT */);
}

static PFNGLGETNAMEDRENDERBUFFERPARAMETERIVPROC
epoxy_glGetNamedRenderbufferParameteriv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        22706 /* "glGetNamedRenderbufferParameteriv" */,
        22706 /* "glGetNamedRenderbufferParameteriv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 22706 /* "glGetNamedRenderbufferParameteriv" */,
                                providers, entrypoints);
}

static PFNGLGETNAMEDRENDERBUFFERPARAMETERIVEXTPROC
epoxy_glGetNamedRenderbufferParameterivEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 22740 /* glGetNamedRenderbufferParameterivEXT */);
}

static PFNGLGETNAMEDSTRINGARBPROC
epoxy_glGetNamedStringARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_shading_language_include, 22777 /* glGetNamedStringARB */);
}

static PFNGLGETNAMEDSTRINGIVARBPROC
epoxy_glGetNamedStringivARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_shading_language_include, 22797 /* glGetNamedStringivARB */);
}

static PFNGLGETNEXTPERFQUERYIDINTELPROC
epoxy_glGetNextPerfQueryIdINTEL_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_INTEL_performance_query, 22819 /* glGetNextPerfQueryIdINTEL */);
}

static PFNGLGETOBJECTBUFFERFVATIPROC
epoxy_glGetObjectBufferfvATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_array_object, 22845 /* glGetObjectBufferfvATI */);
}

static PFNGLGETOBJECTBUFFERIVATIPROC
epoxy_glGetObjectBufferivATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_array_object, 22868 /* glGetObjectBufferivATI */);
}

static PFNGLGETOBJECTLABELPROC
epoxy_glGetObjectLabel_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_KHR_debug,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_KHR_debug,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        22891 /* "glGetObjectLabel" */,
        22891 /* "glGetObjectLabel" */,
        22891 /* "glGetObjectLabel" */,
        22928 /* "glGetObjectLabelKHR" */,
    };
    return gl_provider_resolver(entrypoint_strings + 22891 /* "glGetObjectLabel" */,
                                providers, entrypoints);
}

static PFNGLGETOBJECTLABELEXTPROC
epoxy_glGetObjectLabelEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_debug_label, 22908 /* glGetObjectLabelEXT */);
}

static PFNGLGETOBJECTLABELKHRPROC
epoxy_glGetObjectLabelKHR_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_KHR_debug,
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_KHR_debug,
        PROVIDER_OpenGL_ES_3_2,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        22928 /* "glGetObjectLabelKHR" */,
        22891 /* "glGetObjectLabel" */,
        22891 /* "glGetObjectLabel" */,
        22891 /* "glGetObjectLabel" */,
    };
    return gl_provider_resolver(entrypoint_strings + 22928 /* "glGetObjectLabelKHR" */,
                                providers, entrypoints);
}

static PFNGLGETOBJECTPARAMETERFVARBPROC
epoxy_glGetObjectParameterfvARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_shader_objects, 22948 /* glGetObjectParameterfvARB */);
}

static PFNGLGETOBJECTPARAMETERIVAPPLEPROC
epoxy_glGetObjectParameterivAPPLE_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_APPLE_object_purgeable, 22974 /* glGetObjectParameterivAPPLE */);
}

static PFNGLGETOBJECTPARAMETERIVARBPROC
epoxy_glGetObjectParameterivARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_shader_objects, 23002 /* glGetObjectParameterivARB */);
}

static PFNGLGETOBJECTPTRLABELPROC
epoxy_glGetObjectPtrLabel_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_KHR_debug,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_KHR_debug,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        23028 /* "glGetObjectPtrLabel" */,
        23028 /* "glGetObjectPtrLabel" */,
        23028 /* "glGetObjectPtrLabel" */,
        23048 /* "glGetObjectPtrLabelKHR" */,
    };
    return gl_provider_resolver(entrypoint_strings + 23028 /* "glGetObjectPtrLabel" */,
                                providers, entrypoints);
}

static PFNGLGETOBJECTPTRLABELKHRPROC
epoxy_glGetObjectPtrLabelKHR_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_KHR_debug,
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_KHR_debug,
        PROVIDER_OpenGL_ES_3_2,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        23048 /* "glGetObjectPtrLabelKHR" */,
        23028 /* "glGetObjectPtrLabel" */,
        23028 /* "glGetObjectPtrLabel" */,
        23028 /* "glGetObjectPtrLabel" */,
    };
    return gl_provider_resolver(entrypoint_strings + 23048 /* "glGetObjectPtrLabelKHR" */,
                                providers, entrypoints);
}

static PFNGLGETOCCLUSIONQUERYIVNVPROC
epoxy_glGetOcclusionQueryivNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_occlusion_query, 23071 /* glGetOcclusionQueryivNV */);
}

static PFNGLGETOCCLUSIONQUERYUIVNVPROC
epoxy_glGetOcclusionQueryuivNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_occlusion_query, 23095 /* glGetOcclusionQueryuivNV */);
}

static PFNGLGETPATHCOLORGENFVNVPROC
epoxy_glGetPathColorGenfvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 23120 /* glGetPathColorGenfvNV */);
}

static PFNGLGETPATHCOLORGENIVNVPROC
epoxy_glGetPathColorGenivNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 23142 /* glGetPathColorGenivNV */);
}

static PFNGLGETPATHCOMMANDSNVPROC
epoxy_glGetPathCommandsNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 23164 /* glGetPathCommandsNV */);
}

static PFNGLGETPATHCOORDSNVPROC
epoxy_glGetPathCoordsNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 23184 /* glGetPathCoordsNV */);
}

static PFNGLGETPATHDASHARRAYNVPROC
epoxy_glGetPathDashArrayNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 23202 /* glGetPathDashArrayNV */);
}

static PFNGLGETPATHLENGTHNVPROC
epoxy_glGetPathLengthNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 23223 /* glGetPathLengthNV */);
}

static PFNGLGETPATHMETRICRANGENVPROC
epoxy_glGetPathMetricRangeNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 23241 /* glGetPathMetricRangeNV */);
}

static PFNGLGETPATHMETRICSNVPROC
epoxy_glGetPathMetricsNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 23264 /* glGetPathMetricsNV */);
}

static PFNGLGETPATHPARAMETERFVNVPROC
epoxy_glGetPathParameterfvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 23283 /* glGetPathParameterfvNV */);
}

static PFNGLGETPATHPARAMETERIVNVPROC
epoxy_glGetPathParameterivNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 23306 /* glGetPathParameterivNV */);
}

static PFNGLGETPATHSPACINGNVPROC
epoxy_glGetPathSpacingNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 23329 /* glGetPathSpacingNV */);
}

static PFNGLGETPATHTEXGENFVNVPROC
epoxy_glGetPathTexGenfvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 23348 /* glGetPathTexGenfvNV */);
}

static PFNGLGETPATHTEXGENIVNVPROC
epoxy_glGetPathTexGenivNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 23368 /* glGetPathTexGenivNV */);
}

static PFNGLGETPERFCOUNTERINFOINTELPROC
epoxy_glGetPerfCounterInfoINTEL_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_INTEL_performance_query, 23388 /* glGetPerfCounterInfoINTEL */);
}

static PFNGLGETPERFMONITORCOUNTERDATAAMDPROC
epoxy_glGetPerfMonitorCounterDataAMD_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_AMD_performance_monitor, 23414 /* glGetPerfMonitorCounterDataAMD */);
}

static PFNGLGETPERFMONITORCOUNTERINFOAMDPROC
epoxy_glGetPerfMonitorCounterInfoAMD_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_AMD_performance_monitor, 23445 /* glGetPerfMonitorCounterInfoAMD */);
}

static PFNGLGETPERFMONITORCOUNTERSTRINGAMDPROC
epoxy_glGetPerfMonitorCounterStringAMD_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_AMD_performance_monitor, 23476 /* glGetPerfMonitorCounterStringAMD */);
}

static PFNGLGETPERFMONITORCOUNTERSAMDPROC
epoxy_glGetPerfMonitorCountersAMD_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_AMD_performance_monitor, 23509 /* glGetPerfMonitorCountersAMD */);
}

static PFNGLGETPERFMONITORGROUPSTRINGAMDPROC
epoxy_glGetPerfMonitorGroupStringAMD_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_AMD_performance_monitor, 23537 /* glGetPerfMonitorGroupStringAMD */);
}

static PFNGLGETPERFMONITORGROUPSAMDPROC
epoxy_glGetPerfMonitorGroupsAMD_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_AMD_performance_monitor, 23568 /* glGetPerfMonitorGroupsAMD */);
}

static PFNGLGETPERFQUERYDATAINTELPROC
epoxy_glGetPerfQueryDataINTEL_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_INTEL_performance_query, 23594 /* glGetPerfQueryDataINTEL */);
}

static PFNGLGETPERFQUERYIDBYNAMEINTELPROC
epoxy_glGetPerfQueryIdByNameINTEL_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_INTEL_performance_query, 23618 /* glGetPerfQueryIdByNameINTEL */);
}

static PFNGLGETPERFQUERYINFOINTELPROC
epoxy_glGetPerfQueryInfoINTEL_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_INTEL_performance_query, 23646 /* glGetPerfQueryInfoINTEL */);
}

static PFNGLGETPIXELMAPFVPROC
epoxy_glGetPixelMapfv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 23670 /* glGetPixelMapfv */);
}

static PFNGLGETPIXELMAPUIVPROC
epoxy_glGetPixelMapuiv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 23686 /* glGetPixelMapuiv */);
}

static PFNGLGETPIXELMAPUSVPROC
epoxy_glGetPixelMapusv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 23703 /* glGetPixelMapusv */);
}

static PFNGLGETPIXELMAPXVPROC
epoxy_glGetPixelMapxv_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 23720 /* glGetPixelMapxv */);
}

static PFNGLGETPIXELTEXGENPARAMETERFVSGISPROC
epoxy_glGetPixelTexGenParameterfvSGIS_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIS_pixel_texture, 23736 /* glGetPixelTexGenParameterfvSGIS */);
}

static PFNGLGETPIXELTEXGENPARAMETERIVSGISPROC
epoxy_glGetPixelTexGenParameterivSGIS_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIS_pixel_texture, 23768 /* glGetPixelTexGenParameterivSGIS */);
}

static PFNGLGETPIXELTRANSFORMPARAMETERFVEXTPROC
epoxy_glGetPixelTransformParameterfvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_pixel_transform, 23800 /* glGetPixelTransformParameterfvEXT */);
}

static PFNGLGETPIXELTRANSFORMPARAMETERIVEXTPROC
epoxy_glGetPixelTransformParameterivEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_pixel_transform, 23834 /* glGetPixelTransformParameterivEXT */);
}

static PFNGLGETPOINTERINDEXEDVEXTPROC
epoxy_glGetPointerIndexedvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 23868 /* glGetPointerIndexedvEXT */);
}

static PFNGLGETPOINTERI_VEXTPROC
epoxy_glGetPointeri_vEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 23892 /* glGetPointeri_vEXT */);
}

static PFNGLGETPOINTERVPROC
epoxy_glGetPointerv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_1,
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_KHR_debug,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_vertex_array,
        PROVIDER_GL_KHR_debug,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        23911 /* "glGetPointerv" */,
        23911 /* "glGetPointerv" */,
        23911 /* "glGetPointerv" */,
        23911 /* "glGetPointerv" */,
        23911 /* "glGetPointerv" */,
        23925 /* "glGetPointervEXT" */,
        23942 /* "glGetPointervKHR" */,
    };
    return gl_provider_resolver(entrypoint_strings + 23911 /* "glGetPointerv" */,
                                providers, entrypoints);
}

static PFNGLGETPOINTERVEXTPROC
epoxy_glGetPointervEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_vertex_array,
        PROVIDER_Desktop_OpenGL_1_1,
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_KHR_debug,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_KHR_debug,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        23925 /* "glGetPointervEXT" */,
        23911 /* "glGetPointerv" */,
        23911 /* "glGetPointerv" */,
        23911 /* "glGetPointerv" */,
        23911 /* "glGetPointerv" */,
        23911 /* "glGetPointerv" */,
        23942 /* "glGetPointervKHR" */,
    };
    return gl_provider_resolver(entrypoint_strings + 23925 /* "glGetPointervEXT" */,
                                providers, entrypoints);
}

static PFNGLGETPOINTERVKHRPROC
epoxy_glGetPointervKHR_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_KHR_debug,
        PROVIDER_Desktop_OpenGL_1_1,
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_KHR_debug,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_vertex_array,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        23942 /* "glGetPointervKHR" */,
        23911 /* "glGetPointerv" */,
        23911 /* "glGetPointerv" */,
        23911 /* "glGetPointerv" */,
        23911 /* "glGetPointerv" */,
        23911 /* "glGetPointerv" */,
        23925 /* "glGetPointervEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 23942 /* "glGetPointervKHR" */,
                                providers, entrypoints);
}

static PFNGLGETPOLYGONSTIPPLEPROC
epoxy_glGetPolygonStipple_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 23959 /* glGetPolygonStipple */);
}

static PFNGLGETPROGRAMBINARYPROC
epoxy_glGetProgramBinary_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_get_program_binary,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_OES_get_program_binary,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        23979 /* "glGetProgramBinary" */,
        23979 /* "glGetProgramBinary" */,
        23979 /* "glGetProgramBinary" */,
        23998 /* "glGetProgramBinaryOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 23979 /* "glGetProgramBinary" */,
                                providers, entrypoints);
}

static PFNGLGETPROGRAMBINARYOESPROC
epoxy_glGetProgramBinaryOES_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_OES_get_program_binary,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_get_program_binary,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        23998 /* "glGetProgramBinaryOES" */,
        23979 /* "glGetProgramBinary" */,
        23979 /* "glGetProgramBinary" */,
        23979 /* "glGetProgramBinary" */,
    };
    return gl_provider_resolver(entrypoint_strings + 23998 /* "glGetProgramBinaryOES" */,
                                providers, entrypoints);
}

static PFNGLGETPROGRAMENVPARAMETERIIVNVPROC
epoxy_glGetProgramEnvParameterIivNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_gpu_program4, 24020 /* glGetProgramEnvParameterIivNV */);
}

static PFNGLGETPROGRAMENVPARAMETERIUIVNVPROC
epoxy_glGetProgramEnvParameterIuivNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_gpu_program4, 24050 /* glGetProgramEnvParameterIuivNV */);
}

static PFNGLGETPROGRAMENVPARAMETERDVARBPROC
epoxy_glGetProgramEnvParameterdvARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_fragment_program,
        PROVIDER_GL_ARB_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        24081 /* "glGetProgramEnvParameterdvARB" */,
        24081 /* "glGetProgramEnvParameterdvARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 24081 /* "glGetProgramEnvParameterdvARB" */,
                                providers, entrypoints);
}

static PFNGLGETPROGRAMENVPARAMETERFVARBPROC
epoxy_glGetProgramEnvParameterfvARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_fragment_program,
        PROVIDER_GL_ARB_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        24111 /* "glGetProgramEnvParameterfvARB" */,
        24111 /* "glGetProgramEnvParameterfvARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 24111 /* "glGetProgramEnvParameterfvARB" */,
                                providers, entrypoints);
}

static PFNGLGETPROGRAMINFOLOGPROC
epoxy_glGetProgramInfoLog_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        24141 /* "glGetProgramInfoLog" */,
        24141 /* "glGetProgramInfoLog" */,
    };
    return gl_provider_resolver(entrypoint_strings + 24141 /* "glGetProgramInfoLog" */,
                                providers, entrypoints);
}

static PFNGLGETPROGRAMINTERFACEIVPROC
epoxy_glGetProgramInterfaceiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_ARB_program_interface_query,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        24161 /* "glGetProgramInterfaceiv" */,
        24161 /* "glGetProgramInterfaceiv" */,
        24161 /* "glGetProgramInterfaceiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 24161 /* "glGetProgramInterfaceiv" */,
                                providers, entrypoints);
}

static PFNGLGETPROGRAMLOCALPARAMETERIIVNVPROC
epoxy_glGetProgramLocalParameterIivNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_gpu_program4, 24185 /* glGetProgramLocalParameterIivNV */);
}

static PFNGLGETPROGRAMLOCALPARAMETERIUIVNVPROC
epoxy_glGetProgramLocalParameterIuivNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_gpu_program4, 24217 /* glGetProgramLocalParameterIuivNV */);
}

static PFNGLGETPROGRAMLOCALPARAMETERDVARBPROC
epoxy_glGetProgramLocalParameterdvARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_fragment_program,
        PROVIDER_GL_ARB_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        24250 /* "glGetProgramLocalParameterdvARB" */,
        24250 /* "glGetProgramLocalParameterdvARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 24250 /* "glGetProgramLocalParameterdvARB" */,
                                providers, entrypoints);
}

static PFNGLGETPROGRAMLOCALPARAMETERFVARBPROC
epoxy_glGetProgramLocalParameterfvARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_fragment_program,
        PROVIDER_GL_ARB_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        24282 /* "glGetProgramLocalParameterfvARB" */,
        24282 /* "glGetProgramLocalParameterfvARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 24282 /* "glGetProgramLocalParameterfvARB" */,
                                providers, entrypoints);
}

static PFNGLGETPROGRAMNAMEDPARAMETERDVNVPROC
epoxy_glGetProgramNamedParameterdvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_fragment_program, 24314 /* glGetProgramNamedParameterdvNV */);
}

static PFNGLGETPROGRAMNAMEDPARAMETERFVNVPROC
epoxy_glGetProgramNamedParameterfvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_fragment_program, 24345 /* glGetProgramNamedParameterfvNV */);
}

static PFNGLGETPROGRAMPARAMETERDVNVPROC
epoxy_glGetProgramParameterdvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_program, 24376 /* glGetProgramParameterdvNV */);
}

static PFNGLGETPROGRAMPARAMETERFVNVPROC
epoxy_glGetProgramParameterfvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_program, 24402 /* glGetProgramParameterfvNV */);
}

static PFNGLGETPROGRAMPIPELINEINFOLOGPROC
epoxy_glGetProgramPipelineInfoLog_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        24428 /* "glGetProgramPipelineInfoLog" */,
        24428 /* "glGetProgramPipelineInfoLog" */,
        24428 /* "glGetProgramPipelineInfoLog" */,
    };
    return gl_provider_resolver(entrypoint_strings + 24428 /* "glGetProgramPipelineInfoLog" */,
                                providers, entrypoints);
}

static PFNGLGETPROGRAMPIPELINEINFOLOGEXTPROC
epoxy_glGetProgramPipelineInfoLogEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_separate_shader_objects, 24456 /* glGetProgramPipelineInfoLogEXT */);
}

static PFNGLGETPROGRAMPIPELINEIVPROC
epoxy_glGetProgramPipelineiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        24487 /* "glGetProgramPipelineiv" */,
        24487 /* "glGetProgramPipelineiv" */,
        24487 /* "glGetProgramPipelineiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 24487 /* "glGetProgramPipelineiv" */,
                                providers, entrypoints);
}

static PFNGLGETPROGRAMPIPELINEIVEXTPROC
epoxy_glGetProgramPipelineivEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_separate_shader_objects, 24510 /* glGetProgramPipelineivEXT */);
}

static PFNGLGETPROGRAMRESOURCEINDEXPROC
epoxy_glGetProgramResourceIndex_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_ARB_program_interface_query,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        24536 /* "glGetProgramResourceIndex" */,
        24536 /* "glGetProgramResourceIndex" */,
        24536 /* "glGetProgramResourceIndex" */,
    };
    return gl_provider_resolver(entrypoint_strings + 24536 /* "glGetProgramResourceIndex" */,
                                providers, entrypoints);
}

static PFNGLGETPROGRAMRESOURCELOCATIONPROC
epoxy_glGetProgramResourceLocation_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_ARB_program_interface_query,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        24562 /* "glGetProgramResourceLocation" */,
        24562 /* "glGetProgramResourceLocation" */,
        24562 /* "glGetProgramResourceLocation" */,
    };
    return gl_provider_resolver(entrypoint_strings + 24562 /* "glGetProgramResourceLocation" */,
                                providers, entrypoints);
}

static PFNGLGETPROGRAMRESOURCELOCATIONINDEXPROC
epoxy_glGetProgramResourceLocationIndex_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_ARB_program_interface_query,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        24591 /* "glGetProgramResourceLocationIndex" */,
        24591 /* "glGetProgramResourceLocationIndex" */,
    };
    return gl_provider_resolver(entrypoint_strings + 24591 /* "glGetProgramResourceLocationIndex" */,
                                providers, entrypoints);
}

static PFNGLGETPROGRAMRESOURCELOCATIONINDEXEXTPROC
epoxy_glGetProgramResourceLocationIndexEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_blend_func_extended, 24625 /* glGetProgramResourceLocationIndexEXT */);
}

static PFNGLGETPROGRAMRESOURCENAMEPROC
epoxy_glGetProgramResourceName_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_ARB_program_interface_query,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        24662 /* "glGetProgramResourceName" */,
        24662 /* "glGetProgramResourceName" */,
        24662 /* "glGetProgramResourceName" */,
    };
    return gl_provider_resolver(entrypoint_strings + 24662 /* "glGetProgramResourceName" */,
                                providers, entrypoints);
}

static PFNGLGETPROGRAMRESOURCEFVNVPROC
epoxy_glGetProgramResourcefvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 24687 /* glGetProgramResourcefvNV */);
}

static PFNGLGETPROGRAMRESOURCEIVPROC
epoxy_glGetProgramResourceiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_ARB_program_interface_query,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        24712 /* "glGetProgramResourceiv" */,
        24712 /* "glGetProgramResourceiv" */,
        24712 /* "glGetProgramResourceiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 24712 /* "glGetProgramResourceiv" */,
                                providers, entrypoints);
}

static PFNGLGETPROGRAMSTAGEIVPROC
epoxy_glGetProgramStageiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_GL_ARB_shader_subroutine,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        24735 /* "glGetProgramStageiv" */,
        24735 /* "glGetProgramStageiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 24735 /* "glGetProgramStageiv" */,
                                providers, entrypoints);
}

static PFNGLGETPROGRAMSTRINGARBPROC
epoxy_glGetProgramStringARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_fragment_program,
        PROVIDER_GL_ARB_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        24755 /* "glGetProgramStringARB" */,
        24755 /* "glGetProgramStringARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 24755 /* "glGetProgramStringARB" */,
                                providers, entrypoints);
}

static PFNGLGETPROGRAMSTRINGNVPROC
epoxy_glGetProgramStringNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_program, 24777 /* glGetProgramStringNV */);
}

static PFNGLGETPROGRAMSUBROUTINEPARAMETERUIVNVPROC
epoxy_glGetProgramSubroutineParameteruivNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_gpu_program5, 24798 /* glGetProgramSubroutineParameteruivNV */);
}

static PFNGLGETPROGRAMIVPROC
epoxy_glGetProgramiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        24835 /* "glGetProgramiv" */,
        24835 /* "glGetProgramiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 24835 /* "glGetProgramiv" */,
                                providers, entrypoints);
}

static PFNGLGETPROGRAMIVARBPROC
epoxy_glGetProgramivARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_fragment_program,
        PROVIDER_GL_ARB_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        24850 /* "glGetProgramivARB" */,
        24850 /* "glGetProgramivARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 24850 /* "glGetProgramivARB" */,
                                providers, entrypoints);
}

static PFNGLGETPROGRAMIVNVPROC
epoxy_glGetProgramivNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_program, 24868 /* glGetProgramivNV */);
}

static PFNGLGETQUERYBUFFEROBJECTI64VPROC
epoxy_glGetQueryBufferObjecti64v_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        24885 /* "glGetQueryBufferObjecti64v" */,
        24885 /* "glGetQueryBufferObjecti64v" */,
    };
    return gl_provider_resolver(entrypoint_strings + 24885 /* "glGetQueryBufferObjecti64v" */,
                                providers, entrypoints);
}

static PFNGLGETQUERYBUFFEROBJECTIVPROC
epoxy_glGetQueryBufferObjectiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        24912 /* "glGetQueryBufferObjectiv" */,
        24912 /* "glGetQueryBufferObjectiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 24912 /* "glGetQueryBufferObjectiv" */,
                                providers, entrypoints);
}

static PFNGLGETQUERYBUFFEROBJECTUI64VPROC
epoxy_glGetQueryBufferObjectui64v_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        24937 /* "glGetQueryBufferObjectui64v" */,
        24937 /* "glGetQueryBufferObjectui64v" */,
    };
    return gl_provider_resolver(entrypoint_strings + 24937 /* "glGetQueryBufferObjectui64v" */,
                                providers, entrypoints);
}

static PFNGLGETQUERYBUFFEROBJECTUIVPROC
epoxy_glGetQueryBufferObjectuiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        24965 /* "glGetQueryBufferObjectuiv" */,
        24965 /* "glGetQueryBufferObjectuiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 24965 /* "glGetQueryBufferObjectuiv" */,
                                providers, entrypoints);
}

static PFNGLGETQUERYINDEXEDIVPROC
epoxy_glGetQueryIndexediv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_GL_ARB_transform_feedback3,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        24991 /* "glGetQueryIndexediv" */,
        24991 /* "glGetQueryIndexediv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 24991 /* "glGetQueryIndexediv" */,
                                providers, entrypoints);
}

static PFNGLGETQUERYOBJECTI64VPROC
epoxy_glGetQueryObjecti64v_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_timer_query,
        PROVIDER_GL_EXT_disjoint_timer_query,
        PROVIDER_GL_EXT_timer_query,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        25011 /* "glGetQueryObjecti64v" */,
        25011 /* "glGetQueryObjecti64v" */,
        25032 /* "glGetQueryObjecti64vEXT" */,
        25032 /* "glGetQueryObjecti64vEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 25011 /* "glGetQueryObjecti64v" */,
                                providers, entrypoints);
}

static PFNGLGETQUERYOBJECTI64VEXTPROC
epoxy_glGetQueryObjecti64vEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_disjoint_timer_query,
        PROVIDER_GL_EXT_timer_query,
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_timer_query,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        25032 /* "glGetQueryObjecti64vEXT" */,
        25032 /* "glGetQueryObjecti64vEXT" */,
        25011 /* "glGetQueryObjecti64v" */,
        25011 /* "glGetQueryObjecti64v" */,
    };
    return gl_provider_resolver(entrypoint_strings + 25032 /* "glGetQueryObjecti64vEXT" */,
                                providers, entrypoints);
}

static PFNGLGETQUERYOBJECTIVPROC
epoxy_glGetQueryObjectiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_5,
        PROVIDER_GL_ARB_occlusion_query,
        PROVIDER_GL_EXT_disjoint_timer_query,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        25056 /* "glGetQueryObjectiv" */,
        25075 /* "glGetQueryObjectivARB" */,
        25097 /* "glGetQueryObjectivEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 25056 /* "glGetQueryObjectiv" */,
                                providers, entrypoints);
}

static PFNGLGETQUERYOBJECTIVARBPROC
epoxy_glGetQueryObjectivARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_occlusion_query,
        PROVIDER_Desktop_OpenGL_1_5,
        PROVIDER_GL_EXT_disjoint_timer_query,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        25075 /* "glGetQueryObjectivARB" */,
        25056 /* "glGetQueryObjectiv" */,
        25097 /* "glGetQueryObjectivEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 25075 /* "glGetQueryObjectivARB" */,
                                providers, entrypoints);
}

static PFNGLGETQUERYOBJECTIVEXTPROC
epoxy_glGetQueryObjectivEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_disjoint_timer_query,
        PROVIDER_Desktop_OpenGL_1_5,
        PROVIDER_GL_ARB_occlusion_query,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        25097 /* "glGetQueryObjectivEXT" */,
        25056 /* "glGetQueryObjectiv" */,
        25075 /* "glGetQueryObjectivARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 25097 /* "glGetQueryObjectivEXT" */,
                                providers, entrypoints);
}

static PFNGLGETQUERYOBJECTUI64VPROC
epoxy_glGetQueryObjectui64v_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_timer_query,
        PROVIDER_GL_EXT_disjoint_timer_query,
        PROVIDER_GL_EXT_timer_query,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        25119 /* "glGetQueryObjectui64v" */,
        25119 /* "glGetQueryObjectui64v" */,
        25141 /* "glGetQueryObjectui64vEXT" */,
        25141 /* "glGetQueryObjectui64vEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 25119 /* "glGetQueryObjectui64v" */,
                                providers, entrypoints);
}

static PFNGLGETQUERYOBJECTUI64VEXTPROC
epoxy_glGetQueryObjectui64vEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_disjoint_timer_query,
        PROVIDER_GL_EXT_timer_query,
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_timer_query,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        25141 /* "glGetQueryObjectui64vEXT" */,
        25141 /* "glGetQueryObjectui64vEXT" */,
        25119 /* "glGetQueryObjectui64v" */,
        25119 /* "glGetQueryObjectui64v" */,
    };
    return gl_provider_resolver(entrypoint_strings + 25141 /* "glGetQueryObjectui64vEXT" */,
                                providers, entrypoints);
}

static PFNGLGETQUERYOBJECTUIVPROC
epoxy_glGetQueryObjectuiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_5,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_ARB_occlusion_query,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        25166 /* "glGetQueryObjectuiv" */,
        25166 /* "glGetQueryObjectuiv" */,
        25186 /* "glGetQueryObjectuivARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 25166 /* "glGetQueryObjectuiv" */,
                                providers, entrypoints);
}

static PFNGLGETQUERYOBJECTUIVARBPROC
epoxy_glGetQueryObjectuivARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_occlusion_query,
        PROVIDER_Desktop_OpenGL_1_5,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        25186 /* "glGetQueryObjectuivARB" */,
        25166 /* "glGetQueryObjectuiv" */,
        25166 /* "glGetQueryObjectuiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 25186 /* "glGetQueryObjectuivARB" */,
                                providers, entrypoints);
}

static PFNGLGETQUERYOBJECTUIVEXTPROC
epoxy_glGetQueryObjectuivEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_disjoint_timer_query,
        PROVIDER_GL_EXT_occlusion_query_boolean,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        25209 /* "glGetQueryObjectuivEXT" */,
        25209 /* "glGetQueryObjectuivEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 25209 /* "glGetQueryObjectuivEXT" */,
                                providers, entrypoints);
}

static PFNGLGETQUERYIVPROC
epoxy_glGetQueryiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_5,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_ARB_occlusion_query,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        25232 /* "glGetQueryiv" */,
        25232 /* "glGetQueryiv" */,
        25245 /* "glGetQueryivARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 25232 /* "glGetQueryiv" */,
                                providers, entrypoints);
}

static PFNGLGETQUERYIVARBPROC
epoxy_glGetQueryivARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_occlusion_query,
        PROVIDER_Desktop_OpenGL_1_5,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        25245 /* "glGetQueryivARB" */,
        25232 /* "glGetQueryiv" */,
        25232 /* "glGetQueryiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 25245 /* "glGetQueryivARB" */,
                                providers, entrypoints);
}

static PFNGLGETQUERYIVEXTPROC
epoxy_glGetQueryivEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_disjoint_timer_query,
        PROVIDER_GL_EXT_occlusion_query_boolean,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        25261 /* "glGetQueryivEXT" */,
        25261 /* "glGetQueryivEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 25261 /* "glGetQueryivEXT" */,
                                providers, entrypoints);
}

static PFNGLGETRENDERBUFFERPARAMETERIVPROC
epoxy_glGetRenderbufferParameteriv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_framebuffer_object,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_EXT_framebuffer_object,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        25277 /* "glGetRenderbufferParameteriv" */,
        25277 /* "glGetRenderbufferParameteriv" */,
        25277 /* "glGetRenderbufferParameteriv" */,
        25306 /* "glGetRenderbufferParameterivEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 25277 /* "glGetRenderbufferParameteriv" */,
                                providers, entrypoints);
}

static PFNGLGETRENDERBUFFERPARAMETERIVEXTPROC
epoxy_glGetRenderbufferParameterivEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_framebuffer_object,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_framebuffer_object,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        25306 /* "glGetRenderbufferParameterivEXT" */,
        25277 /* "glGetRenderbufferParameteriv" */,
        25277 /* "glGetRenderbufferParameteriv" */,
        25277 /* "glGetRenderbufferParameteriv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 25306 /* "glGetRenderbufferParameterivEXT" */,
                                providers, entrypoints);
}

static PFNGLGETRENDERBUFFERPARAMETERIVOESPROC
epoxy_glGetRenderbufferParameterivOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_framebuffer_object, 25338 /* glGetRenderbufferParameterivOES */);
}

static PFNGLGETSAMPLERPARAMETERIIVPROC
epoxy_glGetSamplerParameterIiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_sampler_objects,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_texture_border_clamp,
        PROVIDER_GL_OES_texture_border_clamp,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        25370 /* "glGetSamplerParameterIiv" */,
        25370 /* "glGetSamplerParameterIiv" */,
        25370 /* "glGetSamplerParameterIiv" */,
        25395 /* "glGetSamplerParameterIivEXT" */,
        25423 /* "glGetSamplerParameterIivOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 25370 /* "glGetSamplerParameterIiv" */,
                                providers, entrypoints);
}

static PFNGLGETSAMPLERPARAMETERIIVEXTPROC
epoxy_glGetSamplerParameterIivEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_texture_border_clamp,
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_sampler_objects,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_OES_texture_border_clamp,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        25395 /* "glGetSamplerParameterIivEXT" */,
        25370 /* "glGetSamplerParameterIiv" */,
        25370 /* "glGetSamplerParameterIiv" */,
        25370 /* "glGetSamplerParameterIiv" */,
        25423 /* "glGetSamplerParameterIivOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 25395 /* "glGetSamplerParameterIivEXT" */,
                                providers, entrypoints);
}

static PFNGLGETSAMPLERPARAMETERIIVOESPROC
epoxy_glGetSamplerParameterIivOES_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_OES_texture_border_clamp,
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_sampler_objects,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_texture_border_clamp,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        25423 /* "glGetSamplerParameterIivOES" */,
        25370 /* "glGetSamplerParameterIiv" */,
        25370 /* "glGetSamplerParameterIiv" */,
        25370 /* "glGetSamplerParameterIiv" */,
        25395 /* "glGetSamplerParameterIivEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 25423 /* "glGetSamplerParameterIivOES" */,
                                providers, entrypoints);
}

static PFNGLGETSAMPLERPARAMETERIUIVPROC
epoxy_glGetSamplerParameterIuiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_sampler_objects,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_texture_border_clamp,
        PROVIDER_GL_OES_texture_border_clamp,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        25451 /* "glGetSamplerParameterIuiv" */,
        25451 /* "glGetSamplerParameterIuiv" */,
        25451 /* "glGetSamplerParameterIuiv" */,
        25477 /* "glGetSamplerParameterIuivEXT" */,
        25506 /* "glGetSamplerParameterIuivOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 25451 /* "glGetSamplerParameterIuiv" */,
                                providers, entrypoints);
}

static PFNGLGETSAMPLERPARAMETERIUIVEXTPROC
epoxy_glGetSamplerParameterIuivEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_texture_border_clamp,
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_sampler_objects,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_OES_texture_border_clamp,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        25477 /* "glGetSamplerParameterIuivEXT" */,
        25451 /* "glGetSamplerParameterIuiv" */,
        25451 /* "glGetSamplerParameterIuiv" */,
        25451 /* "glGetSamplerParameterIuiv" */,
        25506 /* "glGetSamplerParameterIuivOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 25477 /* "glGetSamplerParameterIuivEXT" */,
                                providers, entrypoints);
}

static PFNGLGETSAMPLERPARAMETERIUIVOESPROC
epoxy_glGetSamplerParameterIuivOES_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_OES_texture_border_clamp,
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_sampler_objects,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_texture_border_clamp,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        25506 /* "glGetSamplerParameterIuivOES" */,
        25451 /* "glGetSamplerParameterIuiv" */,
        25451 /* "glGetSamplerParameterIuiv" */,
        25451 /* "glGetSamplerParameterIuiv" */,
        25477 /* "glGetSamplerParameterIuivEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 25506 /* "glGetSamplerParameterIuivOES" */,
                                providers, entrypoints);
}

static PFNGLGETSAMPLERPARAMETERFVPROC
epoxy_glGetSamplerParameterfv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_sampler_objects,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        25535 /* "glGetSamplerParameterfv" */,
        25535 /* "glGetSamplerParameterfv" */,
        25535 /* "glGetSamplerParameterfv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 25535 /* "glGetSamplerParameterfv" */,
                                providers, entrypoints);
}

static PFNGLGETSAMPLERPARAMETERIVPROC
epoxy_glGetSamplerParameteriv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_sampler_objects,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        25559 /* "glGetSamplerParameteriv" */,
        25559 /* "glGetSamplerParameteriv" */,
        25559 /* "glGetSamplerParameteriv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 25559 /* "glGetSamplerParameteriv" */,
                                providers, entrypoints);
}

static PFNGLGETSEMAPHOREPARAMETERUI64VEXTPROC
epoxy_glGetSemaphoreParameterui64vEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_semaphore, 25583 /* glGetSemaphoreParameterui64vEXT */);
}

static PFNGLGETSEPARABLEFILTERPROC
epoxy_glGetSeparableFilter_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_imaging, 25615 /* glGetSeparableFilter */);
}

static PFNGLGETSEPARABLEFILTEREXTPROC
epoxy_glGetSeparableFilterEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_convolution, 25636 /* glGetSeparableFilterEXT */);
}

static PFNGLGETSHADERINFOLOGPROC
epoxy_glGetShaderInfoLog_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        25660 /* "glGetShaderInfoLog" */,
        25660 /* "glGetShaderInfoLog" */,
    };
    return gl_provider_resolver(entrypoint_strings + 25660 /* "glGetShaderInfoLog" */,
                                providers, entrypoints);
}

static PFNGLGETSHADERPRECISIONFORMATPROC
epoxy_glGetShaderPrecisionFormat_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_ES2_compatibility,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        25679 /* "glGetShaderPrecisionFormat" */,
        25679 /* "glGetShaderPrecisionFormat" */,
        25679 /* "glGetShaderPrecisionFormat" */,
    };
    return gl_provider_resolver(entrypoint_strings + 25679 /* "glGetShaderPrecisionFormat" */,
                                providers, entrypoints);
}

static PFNGLGETSHADERSOURCEPROC
epoxy_glGetShaderSource_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        25706 /* "glGetShaderSource" */,
        25706 /* "glGetShaderSource" */,
        25724 /* "glGetShaderSourceARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 25706 /* "glGetShaderSource" */,
                                providers, entrypoints);
}

static PFNGLGETSHADERSOURCEARBPROC
epoxy_glGetShaderSourceARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_shader_objects,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        25724 /* "glGetShaderSourceARB" */,
        25706 /* "glGetShaderSource" */,
        25706 /* "glGetShaderSource" */,
    };
    return gl_provider_resolver(entrypoint_strings + 25724 /* "glGetShaderSourceARB" */,
                                providers, entrypoints);
}

static PFNGLGETSHADERIVPROC
epoxy_glGetShaderiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        25745 /* "glGetShaderiv" */,
        25745 /* "glGetShaderiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 25745 /* "glGetShaderiv" */,
                                providers, entrypoints);
}

static PFNGLGETSHADINGRATEIMAGEPALETTENVPROC
epoxy_glGetShadingRateImagePaletteNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_shading_rate_image, 25759 /* glGetShadingRateImagePaletteNV */);
}

static PFNGLGETSHADINGRATESAMPLELOCATIONIVNVPROC
epoxy_glGetShadingRateSampleLocationivNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_shading_rate_image, 25790 /* glGetShadingRateSampleLocationivNV */);
}

static PFNGLGETSHARPENTEXFUNCSGISPROC
epoxy_glGetSharpenTexFuncSGIS_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIS_sharpen_texture, 25825 /* glGetSharpenTexFuncSGIS */);
}

static PFNGLGETSTAGEINDEXNVPROC
epoxy_glGetStageIndexNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_command_list, 25849 /* glGetStageIndexNV */);
}

static PFNGLGETSTRINGPROC
epoxy_glGetString_resolver(void)
{
    return gl_single_resolver(PROVIDER_always_present, 25867 /* glGetString */);
}

static PFNGLGETSTRINGIPROC
epoxy_glGetStringi_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        25879 /* "glGetStringi" */,
        25879 /* "glGetStringi" */,
    };
    return gl_provider_resolver(entrypoint_strings + 25879 /* "glGetStringi" */,
                                providers, entrypoints);
}

static PFNGLGETSUBROUTINEINDEXPROC
epoxy_glGetSubroutineIndex_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_GL_ARB_shader_subroutine,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        25892 /* "glGetSubroutineIndex" */,
        25892 /* "glGetSubroutineIndex" */,
    };
    return gl_provider_resolver(entrypoint_strings + 25892 /* "glGetSubroutineIndex" */,
                                providers, entrypoints);
}

static PFNGLGETSUBROUTINEUNIFORMLOCATIONPROC
epoxy_glGetSubroutineUniformLocation_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_GL_ARB_shader_subroutine,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        25913 /* "glGetSubroutineUniformLocation" */,
        25913 /* "glGetSubroutineUniformLocation" */,
    };
    return gl_provider_resolver(entrypoint_strings + 25913 /* "glGetSubroutineUniformLocation" */,
                                providers, entrypoints);
}

static PFNGLGETSYNCIVPROC
epoxy_glGetSynciv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_2,
        PROVIDER_GL_ARB_sync,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_APPLE_sync,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        25944 /* "glGetSynciv" */,
        25944 /* "glGetSynciv" */,
        25944 /* "glGetSynciv" */,
        25956 /* "glGetSyncivAPPLE" */,
    };
    return gl_provider_resolver(entrypoint_strings + 25944 /* "glGetSynciv" */,
                                providers, entrypoints);
}

static PFNGLGETSYNCIVAPPLEPROC
epoxy_glGetSyncivAPPLE_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_APPLE_sync,
        PROVIDER_Desktop_OpenGL_3_2,
        PROVIDER_GL_ARB_sync,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        25956 /* "glGetSyncivAPPLE" */,
        25944 /* "glGetSynciv" */,
        25944 /* "glGetSynciv" */,
        25944 /* "glGetSynciv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 25956 /* "glGetSyncivAPPLE" */,
                                providers, entrypoints);
}

static PFNGLGETTEXBUMPPARAMETERFVATIPROC
epoxy_glGetTexBumpParameterfvATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_envmap_bumpmap, 25973 /* glGetTexBumpParameterfvATI */);
}

static PFNGLGETTEXBUMPPARAMETERIVATIPROC
epoxy_glGetTexBumpParameterivATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_envmap_bumpmap, 26000 /* glGetTexBumpParameterivATI */);
}

static PFNGLGETTEXENVFVPROC
epoxy_glGetTexEnvfv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        26027 /* "glGetTexEnvfv" */,
        26027 /* "glGetTexEnvfv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 26027 /* "glGetTexEnvfv" */,
                                providers, entrypoints);
}

static PFNGLGETTEXENVIVPROC
epoxy_glGetTexEnviv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        26041 /* "glGetTexEnviv" */,
        26041 /* "glGetTexEnviv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 26041 /* "glGetTexEnviv" */,
                                providers, entrypoints);
}

static PFNGLGETTEXENVXVPROC
epoxy_glGetTexEnvxv_resolver(void)
{
    return gl_single_resolver(PROVIDER_OpenGL_ES_1_0, 26055 /* glGetTexEnvxv */);
}

static PFNGLGETTEXENVXVOESPROC
epoxy_glGetTexEnvxvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 26069 /* glGetTexEnvxvOES */);
}

static PFNGLGETTEXFILTERFUNCSGISPROC
epoxy_glGetTexFilterFuncSGIS_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIS_texture_filter4, 26086 /* glGetTexFilterFuncSGIS */);
}

static PFNGLGETTEXGENDVPROC
epoxy_glGetTexGendv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 26109 /* glGetTexGendv */);
}

static PFNGLGETTEXGENFVPROC
epoxy_glGetTexGenfv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 26123 /* glGetTexGenfv */);
}

static PFNGLGETTEXGENFVOESPROC
epoxy_glGetTexGenfvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_texture_cube_map, 26137 /* glGetTexGenfvOES */);
}

static PFNGLGETTEXGENIVPROC
epoxy_glGetTexGeniv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 26154 /* glGetTexGeniv */);
}

static PFNGLGETTEXGENIVOESPROC
epoxy_glGetTexGenivOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_texture_cube_map, 26168 /* glGetTexGenivOES */);
}

static PFNGLGETTEXGENXVOESPROC
epoxy_glGetTexGenxvOES_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_OES_fixed_point,
        PROVIDER_GL_OES_texture_cube_map,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        26185 /* "glGetTexGenxvOES" */,
        26185 /* "glGetTexGenxvOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 26185 /* "glGetTexGenxvOES" */,
                                providers, entrypoints);
}

static PFNGLGETTEXIMAGEPROC
epoxy_glGetTexImage_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 26202 /* glGetTexImage */);
}

static PFNGLGETTEXLEVELPARAMETERFVPROC
epoxy_glGetTexLevelParameterfv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        26216 /* "glGetTexLevelParameterfv" */,
        26216 /* "glGetTexLevelParameterfv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 26216 /* "glGetTexLevelParameterfv" */,
                                providers, entrypoints);
}

static PFNGLGETTEXLEVELPARAMETERIVPROC
epoxy_glGetTexLevelParameteriv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        26241 /* "glGetTexLevelParameteriv" */,
        26241 /* "glGetTexLevelParameteriv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 26241 /* "glGetTexLevelParameteriv" */,
                                providers, entrypoints);
}

static PFNGLGETTEXLEVELPARAMETERXVOESPROC
epoxy_glGetTexLevelParameterxvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 26266 /* glGetTexLevelParameterxvOES */);
}

static PFNGLGETTEXPARAMETERIIVPROC
epoxy_glGetTexParameterIiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_texture_border_clamp,
        PROVIDER_GL_EXT_texture_integer,
        PROVIDER_GL_OES_texture_border_clamp,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        26294 /* "glGetTexParameterIiv" */,
        26294 /* "glGetTexParameterIiv" */,
        26315 /* "glGetTexParameterIivEXT" */,
        26315 /* "glGetTexParameterIivEXT" */,
        26339 /* "glGetTexParameterIivOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 26294 /* "glGetTexParameterIiv" */,
                                providers, entrypoints);
}

static PFNGLGETTEXPARAMETERIIVEXTPROC
epoxy_glGetTexParameterIivEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_texture_border_clamp,
        PROVIDER_GL_EXT_texture_integer,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_OES_texture_border_clamp,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        26315 /* "glGetTexParameterIivEXT" */,
        26315 /* "glGetTexParameterIivEXT" */,
        26294 /* "glGetTexParameterIiv" */,
        26294 /* "glGetTexParameterIiv" */,
        26339 /* "glGetTexParameterIivOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 26315 /* "glGetTexParameterIivEXT" */,
                                providers, entrypoints);
}

static PFNGLGETTEXPARAMETERIIVOESPROC
epoxy_glGetTexParameterIivOES_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_OES_texture_border_clamp,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_texture_border_clamp,
        PROVIDER_GL_EXT_texture_integer,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        26339 /* "glGetTexParameterIivOES" */,
        26294 /* "glGetTexParameterIiv" */,
        26294 /* "glGetTexParameterIiv" */,
        26315 /* "glGetTexParameterIivEXT" */,
        26315 /* "glGetTexParameterIivEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 26339 /* "glGetTexParameterIivOES" */,
                                providers, entrypoints);
}

static PFNGLGETTEXPARAMETERIUIVPROC
epoxy_glGetTexParameterIuiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_texture_border_clamp,
        PROVIDER_GL_EXT_texture_integer,
        PROVIDER_GL_OES_texture_border_clamp,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        26363 /* "glGetTexParameterIuiv" */,
        26363 /* "glGetTexParameterIuiv" */,
        26385 /* "glGetTexParameterIuivEXT" */,
        26385 /* "glGetTexParameterIuivEXT" */,
        26410 /* "glGetTexParameterIuivOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 26363 /* "glGetTexParameterIuiv" */,
                                providers, entrypoints);
}

static PFNGLGETTEXPARAMETERIUIVEXTPROC
epoxy_glGetTexParameterIuivEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_texture_border_clamp,
        PROVIDER_GL_EXT_texture_integer,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_OES_texture_border_clamp,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        26385 /* "glGetTexParameterIuivEXT" */,
        26385 /* "glGetTexParameterIuivEXT" */,
        26363 /* "glGetTexParameterIuiv" */,
        26363 /* "glGetTexParameterIuiv" */,
        26410 /* "glGetTexParameterIuivOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 26385 /* "glGetTexParameterIuivEXT" */,
                                providers, entrypoints);
}

static PFNGLGETTEXPARAMETERIUIVOESPROC
epoxy_glGetTexParameterIuivOES_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_OES_texture_border_clamp,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_texture_border_clamp,
        PROVIDER_GL_EXT_texture_integer,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        26410 /* "glGetTexParameterIuivOES" */,
        26363 /* "glGetTexParameterIuiv" */,
        26363 /* "glGetTexParameterIuiv" */,
        26385 /* "glGetTexParameterIuivEXT" */,
        26385 /* "glGetTexParameterIuivEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 26410 /* "glGetTexParameterIuivOES" */,
                                providers, entrypoints);
}

static PFNGLGETTEXPARAMETERPOINTERVAPPLEPROC
epoxy_glGetTexParameterPointervAPPLE_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_APPLE_texture_range, 26435 /* glGetTexParameterPointervAPPLE */);
}

static PFNGLGETTEXPARAMETERFVPROC
epoxy_glGetTexParameterfv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        26466 /* "glGetTexParameterfv" */,
        26466 /* "glGetTexParameterfv" */,
        26466 /* "glGetTexParameterfv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 26466 /* "glGetTexParameterfv" */,
                                providers, entrypoints);
}

static PFNGLGETTEXPARAMETERIVPROC
epoxy_glGetTexParameteriv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        26486 /* "glGetTexParameteriv" */,
        26486 /* "glGetTexParameteriv" */,
        26486 /* "glGetTexParameteriv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 26486 /* "glGetTexParameteriv" */,
                                providers, entrypoints);
}

static PFNGLGETTEXPARAMETERXVPROC
epoxy_glGetTexParameterxv_resolver(void)
{
    return gl_single_resolver(PROVIDER_OpenGL_ES_1_0, 26506 /* glGetTexParameterxv */);
}

static PFNGLGETTEXPARAMETERXVOESPROC
epoxy_glGetTexParameterxvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 26526 /* glGetTexParameterxvOES */);
}

static PFNGLGETTEXTUREHANDLEARBPROC
epoxy_glGetTextureHandleARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_bindless_texture,
        PROVIDER_GL_IMG_bindless_texture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        26549 /* "glGetTextureHandleARB" */,
        26571 /* "glGetTextureHandleIMG" */,
    };
    return gl_provider_resolver(entrypoint_strings + 26549 /* "glGetTextureHandleARB" */,
                                providers, entrypoints);
}

static PFNGLGETTEXTUREHANDLEIMGPROC
epoxy_glGetTextureHandleIMG_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_IMG_bindless_texture,
        PROVIDER_GL_ARB_bindless_texture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        26571 /* "glGetTextureHandleIMG" */,
        26549 /* "glGetTextureHandleARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 26571 /* "glGetTextureHandleIMG" */,
                                providers, entrypoints);
}

static PFNGLGETTEXTUREHANDLENVPROC
epoxy_glGetTextureHandleNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_bindless_texture, 26593 /* glGetTextureHandleNV */);
}

static PFNGLGETTEXTUREIMAGEPROC
epoxy_glGetTextureImage_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        26614 /* "glGetTextureImage" */,
        26614 /* "glGetTextureImage" */,
    };
    return gl_provider_resolver(entrypoint_strings + 26614 /* "glGetTextureImage" */,
                                providers, entrypoints);
}

static PFNGLGETTEXTUREIMAGEEXTPROC
epoxy_glGetTextureImageEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 26632 /* glGetTextureImageEXT */);
}

static PFNGLGETTEXTURELEVELPARAMETERFVPROC
epoxy_glGetTextureLevelParameterfv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        26653 /* "glGetTextureLevelParameterfv" */,
        26653 /* "glGetTextureLevelParameterfv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 26653 /* "glGetTextureLevelParameterfv" */,
                                providers, entrypoints);
}

static PFNGLGETTEXTURELEVELPARAMETERFVEXTPROC
epoxy_glGetTextureLevelParameterfvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 26682 /* glGetTextureLevelParameterfvEXT */);
}

static PFNGLGETTEXTURELEVELPARAMETERIVPROC
epoxy_glGetTextureLevelParameteriv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        26714 /* "glGetTextureLevelParameteriv" */,
        26714 /* "glGetTextureLevelParameteriv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 26714 /* "glGetTextureLevelParameteriv" */,
                                providers, entrypoints);
}

static PFNGLGETTEXTURELEVELPARAMETERIVEXTPROC
epoxy_glGetTextureLevelParameterivEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 26743 /* glGetTextureLevelParameterivEXT */);
}

static PFNGLGETTEXTUREPARAMETERIIVPROC
epoxy_glGetTextureParameterIiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        26775 /* "glGetTextureParameterIiv" */,
        26775 /* "glGetTextureParameterIiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 26775 /* "glGetTextureParameterIiv" */,
                                providers, entrypoints);
}

static PFNGLGETTEXTUREPARAMETERIIVEXTPROC
epoxy_glGetTextureParameterIivEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 26800 /* glGetTextureParameterIivEXT */);
}

static PFNGLGETTEXTUREPARAMETERIUIVPROC
epoxy_glGetTextureParameterIuiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        26828 /* "glGetTextureParameterIuiv" */,
        26828 /* "glGetTextureParameterIuiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 26828 /* "glGetTextureParameterIuiv" */,
                                providers, entrypoints);
}

static PFNGLGETTEXTUREPARAMETERIUIVEXTPROC
epoxy_glGetTextureParameterIuivEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 26854 /* glGetTextureParameterIuivEXT */);
}

static PFNGLGETTEXTUREPARAMETERFVPROC
epoxy_glGetTextureParameterfv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        26883 /* "glGetTextureParameterfv" */,
        26883 /* "glGetTextureParameterfv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 26883 /* "glGetTextureParameterfv" */,
                                providers, entrypoints);
}

static PFNGLGETTEXTUREPARAMETERFVEXTPROC
epoxy_glGetTextureParameterfvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 26907 /* glGetTextureParameterfvEXT */);
}

static PFNGLGETTEXTUREPARAMETERIVPROC
epoxy_glGetTextureParameteriv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        26934 /* "glGetTextureParameteriv" */,
        26934 /* "glGetTextureParameteriv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 26934 /* "glGetTextureParameteriv" */,
                                providers, entrypoints);
}

static PFNGLGETTEXTUREPARAMETERIVEXTPROC
epoxy_glGetTextureParameterivEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 26958 /* glGetTextureParameterivEXT */);
}

static PFNGLGETTEXTURESAMPLERHANDLEARBPROC
epoxy_glGetTextureSamplerHandleARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_bindless_texture,
        PROVIDER_GL_IMG_bindless_texture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        26985 /* "glGetTextureSamplerHandleARB" */,
        27014 /* "glGetTextureSamplerHandleIMG" */,
    };
    return gl_provider_resolver(entrypoint_strings + 26985 /* "glGetTextureSamplerHandleARB" */,
                                providers, entrypoints);
}

static PFNGLGETTEXTURESAMPLERHANDLEIMGPROC
epoxy_glGetTextureSamplerHandleIMG_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_IMG_bindless_texture,
        PROVIDER_GL_ARB_bindless_texture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        27014 /* "glGetTextureSamplerHandleIMG" */,
        26985 /* "glGetTextureSamplerHandleARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 27014 /* "glGetTextureSamplerHandleIMG" */,
                                providers, entrypoints);
}

static PFNGLGETTEXTURESAMPLERHANDLENVPROC
epoxy_glGetTextureSamplerHandleNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_bindless_texture, 27043 /* glGetTextureSamplerHandleNV */);
}

static PFNGLGETTEXTURESUBIMAGEPROC
epoxy_glGetTextureSubImage_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_get_texture_sub_image,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        27071 /* "glGetTextureSubImage" */,
        27071 /* "glGetTextureSubImage" */,
    };
    return gl_provider_resolver(entrypoint_strings + 27071 /* "glGetTextureSubImage" */,
                                providers, entrypoints);
}

static PFNGLGETTRACKMATRIXIVNVPROC
epoxy_glGetTrackMatrixivNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_program, 27092 /* glGetTrackMatrixivNV */);
}

static PFNGLGETTRANSFORMFEEDBACKVARYINGPROC
epoxy_glGetTransformFeedbackVarying_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_EXT_transform_feedback,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        27113 /* "glGetTransformFeedbackVarying" */,
        27113 /* "glGetTransformFeedbackVarying" */,
        27143 /* "glGetTransformFeedbackVaryingEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 27113 /* "glGetTransformFeedbackVarying" */,
                                providers, entrypoints);
}

static PFNGLGETTRANSFORMFEEDBACKVARYINGEXTPROC
epoxy_glGetTransformFeedbackVaryingEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_transform_feedback,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        27143 /* "glGetTransformFeedbackVaryingEXT" */,
        27113 /* "glGetTransformFeedbackVarying" */,
        27113 /* "glGetTransformFeedbackVarying" */,
    };
    return gl_provider_resolver(entrypoint_strings + 27143 /* "glGetTransformFeedbackVaryingEXT" */,
                                providers, entrypoints);
}

static PFNGLGETTRANSFORMFEEDBACKVARYINGNVPROC
epoxy_glGetTransformFeedbackVaryingNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_transform_feedback, 27176 /* glGetTransformFeedbackVaryingNV */);
}

static PFNGLGETTRANSFORMFEEDBACKI64_VPROC
epoxy_glGetTransformFeedbacki64_v_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        27208 /* "glGetTransformFeedbacki64_v" */,
        27208 /* "glGetTransformFeedbacki64_v" */,
    };
    return gl_provider_resolver(entrypoint_strings + 27208 /* "glGetTransformFeedbacki64_v" */,
                                providers, entrypoints);
}

static PFNGLGETTRANSFORMFEEDBACKI_VPROC
epoxy_glGetTransformFeedbacki_v_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        27236 /* "glGetTransformFeedbacki_v" */,
        27236 /* "glGetTransformFeedbacki_v" */,
    };
    return gl_provider_resolver(entrypoint_strings + 27236 /* "glGetTransformFeedbacki_v" */,
                                providers, entrypoints);
}

static PFNGLGETTRANSFORMFEEDBACKIVPROC
epoxy_glGetTransformFeedbackiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        27262 /* "glGetTransformFeedbackiv" */,
        27262 /* "glGetTransformFeedbackiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 27262 /* "glGetTransformFeedbackiv" */,
                                providers, entrypoints);
}

static PFNGLGETTRANSLATEDSHADERSOURCEANGLEPROC
epoxy_glGetTranslatedShaderSourceANGLE_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ANGLE_translated_shader_source, 27287 /* glGetTranslatedShaderSourceANGLE */);
}

static PFNGLGETUNIFORMBLOCKINDEXPROC
epoxy_glGetUniformBlockIndex_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_1,
        PROVIDER_GL_ARB_uniform_buffer_object,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        27320 /* "glGetUniformBlockIndex" */,
        27320 /* "glGetUniformBlockIndex" */,
        27320 /* "glGetUniformBlockIndex" */,
    };
    return gl_provider_resolver(entrypoint_strings + 27320 /* "glGetUniformBlockIndex" */,
                                providers, entrypoints);
}

static PFNGLGETUNIFORMBUFFERSIZEEXTPROC
epoxy_glGetUniformBufferSizeEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_bindable_uniform, 27343 /* glGetUniformBufferSizeEXT */);
}

static PFNGLGETUNIFORMINDICESPROC
epoxy_glGetUniformIndices_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_1,
        PROVIDER_GL_ARB_uniform_buffer_object,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        27369 /* "glGetUniformIndices" */,
        27369 /* "glGetUniformIndices" */,
        27369 /* "glGetUniformIndices" */,
    };
    return gl_provider_resolver(entrypoint_strings + 27369 /* "glGetUniformIndices" */,
                                providers, entrypoints);
}

static PFNGLGETUNIFORMLOCATIONPROC
epoxy_glGetUniformLocation_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        27389 /* "glGetUniformLocation" */,
        27389 /* "glGetUniformLocation" */,
        27410 /* "glGetUniformLocationARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 27389 /* "glGetUniformLocation" */,
                                providers, entrypoints);
}

static PFNGLGETUNIFORMLOCATIONARBPROC
epoxy_glGetUniformLocationARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_shader_objects,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        27410 /* "glGetUniformLocationARB" */,
        27389 /* "glGetUniformLocation" */,
        27389 /* "glGetUniformLocation" */,
    };
    return gl_provider_resolver(entrypoint_strings + 27410 /* "glGetUniformLocationARB" */,
                                providers, entrypoints);
}

static PFNGLGETUNIFORMOFFSETEXTPROC
epoxy_glGetUniformOffsetEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_bindable_uniform, 27434 /* glGetUniformOffsetEXT */);
}

static PFNGLGETUNIFORMSUBROUTINEUIVPROC
epoxy_glGetUniformSubroutineuiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_GL_ARB_shader_subroutine,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        27456 /* "glGetUniformSubroutineuiv" */,
        27456 /* "glGetUniformSubroutineuiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 27456 /* "glGetUniformSubroutineuiv" */,
                                providers, entrypoints);
}

static PFNGLGETUNIFORMDVPROC
epoxy_glGetUniformdv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_GL_ARB_gpu_shader_fp64,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        27482 /* "glGetUniformdv" */,
        27482 /* "glGetUniformdv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 27482 /* "glGetUniformdv" */,
                                providers, entrypoints);
}

static PFNGLGETUNIFORMFVPROC
epoxy_glGetUniformfv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        27497 /* "glGetUniformfv" */,
        27497 /* "glGetUniformfv" */,
        27512 /* "glGetUniformfvARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 27497 /* "glGetUniformfv" */,
                                providers, entrypoints);
}

static PFNGLGETUNIFORMFVARBPROC
epoxy_glGetUniformfvARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_shader_objects,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        27512 /* "glGetUniformfvARB" */,
        27497 /* "glGetUniformfv" */,
        27497 /* "glGetUniformfv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 27512 /* "glGetUniformfvARB" */,
                                providers, entrypoints);
}

static PFNGLGETUNIFORMI64VARBPROC
epoxy_glGetUniformi64vARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_gpu_shader_int64, 27530 /* glGetUniformi64vARB */);
}

static PFNGLGETUNIFORMI64VNVPROC
epoxy_glGetUniformi64vNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_AMD_gpu_shader_int64,
        PROVIDER_GL_NV_gpu_shader5,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        27550 /* "glGetUniformi64vNV" */,
        27550 /* "glGetUniformi64vNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 27550 /* "glGetUniformi64vNV" */,
                                providers, entrypoints);
}

static PFNGLGETUNIFORMIVPROC
epoxy_glGetUniformiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        27569 /* "glGetUniformiv" */,
        27569 /* "glGetUniformiv" */,
        27584 /* "glGetUniformivARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 27569 /* "glGetUniformiv" */,
                                providers, entrypoints);
}

static PFNGLGETUNIFORMIVARBPROC
epoxy_glGetUniformivARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_shader_objects,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        27584 /* "glGetUniformivARB" */,
        27569 /* "glGetUniformiv" */,
        27569 /* "glGetUniformiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 27584 /* "glGetUniformivARB" */,
                                providers, entrypoints);
}

static PFNGLGETUNIFORMUI64VARBPROC
epoxy_glGetUniformui64vARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_gpu_shader_int64, 27602 /* glGetUniformui64vARB */);
}

static PFNGLGETUNIFORMUI64VNVPROC
epoxy_glGetUniformui64vNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_AMD_gpu_shader_int64,
        PROVIDER_GL_NV_shader_buffer_load,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        27623 /* "glGetUniformui64vNV" */,
        27623 /* "glGetUniformui64vNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 27623 /* "glGetUniformui64vNV" */,
                                providers, entrypoints);
}

static PFNGLGETUNIFORMUIVPROC
epoxy_glGetUniformuiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_EXT_gpu_shader4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        27643 /* "glGetUniformuiv" */,
        27643 /* "glGetUniformuiv" */,
        27659 /* "glGetUniformuivEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 27643 /* "glGetUniformuiv" */,
                                providers, entrypoints);
}

static PFNGLGETUNIFORMUIVEXTPROC
epoxy_glGetUniformuivEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_gpu_shader4,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        27659 /* "glGetUniformuivEXT" */,
        27643 /* "glGetUniformuiv" */,
        27643 /* "glGetUniformuiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 27659 /* "glGetUniformuivEXT" */,
                                providers, entrypoints);
}

static PFNGLGETUNSIGNEDBYTEI_VEXTPROC
epoxy_glGetUnsignedBytei_vEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_memory_object,
        PROVIDER_GL_EXT_semaphore,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        27678 /* "glGetUnsignedBytei_vEXT" */,
        27678 /* "glGetUnsignedBytei_vEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 27678 /* "glGetUnsignedBytei_vEXT" */,
                                providers, entrypoints);
}

static PFNGLGETUNSIGNEDBYTEVEXTPROC
epoxy_glGetUnsignedBytevEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_memory_object,
        PROVIDER_GL_EXT_semaphore,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        27702 /* "glGetUnsignedBytevEXT" */,
        27702 /* "glGetUnsignedBytevEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 27702 /* "glGetUnsignedBytevEXT" */,
                                providers, entrypoints);
}

static PFNGLGETVARIANTARRAYOBJECTFVATIPROC
epoxy_glGetVariantArrayObjectfvATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_array_object, 27724 /* glGetVariantArrayObjectfvATI */);
}

static PFNGLGETVARIANTARRAYOBJECTIVATIPROC
epoxy_glGetVariantArrayObjectivATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_array_object, 27753 /* glGetVariantArrayObjectivATI */);
}

static PFNGLGETVARIANTBOOLEANVEXTPROC
epoxy_glGetVariantBooleanvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_shader, 27782 /* glGetVariantBooleanvEXT */);
}

static PFNGLGETVARIANTFLOATVEXTPROC
epoxy_glGetVariantFloatvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_shader, 27806 /* glGetVariantFloatvEXT */);
}

static PFNGLGETVARIANTINTEGERVEXTPROC
epoxy_glGetVariantIntegervEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_shader, 27828 /* glGetVariantIntegervEXT */);
}

static PFNGLGETVARIANTPOINTERVEXTPROC
epoxy_glGetVariantPointervEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_shader, 27852 /* glGetVariantPointervEXT */);
}

static PFNGLGETVARYINGLOCATIONNVPROC
epoxy_glGetVaryingLocationNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_transform_feedback, 27876 /* glGetVaryingLocationNV */);
}

static PFNGLGETVERTEXARRAYINDEXED64IVPROC
epoxy_glGetVertexArrayIndexed64iv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        27899 /* "glGetVertexArrayIndexed64iv" */,
        27899 /* "glGetVertexArrayIndexed64iv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 27899 /* "glGetVertexArrayIndexed64iv" */,
                                providers, entrypoints);
}

static PFNGLGETVERTEXARRAYINDEXEDIVPROC
epoxy_glGetVertexArrayIndexediv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        27927 /* "glGetVertexArrayIndexediv" */,
        27927 /* "glGetVertexArrayIndexediv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 27927 /* "glGetVertexArrayIndexediv" */,
                                providers, entrypoints);
}

static PFNGLGETVERTEXARRAYINTEGERI_VEXTPROC
epoxy_glGetVertexArrayIntegeri_vEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 27953 /* glGetVertexArrayIntegeri_vEXT */);
}

static PFNGLGETVERTEXARRAYINTEGERVEXTPROC
epoxy_glGetVertexArrayIntegervEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 27983 /* glGetVertexArrayIntegervEXT */);
}

static PFNGLGETVERTEXARRAYPOINTERI_VEXTPROC
epoxy_glGetVertexArrayPointeri_vEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 28011 /* glGetVertexArrayPointeri_vEXT */);
}

static PFNGLGETVERTEXARRAYPOINTERVEXTPROC
epoxy_glGetVertexArrayPointervEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 28041 /* glGetVertexArrayPointervEXT */);
}

static PFNGLGETVERTEXARRAYIVPROC
epoxy_glGetVertexArrayiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        28069 /* "glGetVertexArrayiv" */,
        28069 /* "glGetVertexArrayiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 28069 /* "glGetVertexArrayiv" */,
                                providers, entrypoints);
}

static PFNGLGETVERTEXATTRIBARRAYOBJECTFVATIPROC
epoxy_glGetVertexAttribArrayObjectfvATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_attrib_array_object, 28088 /* glGetVertexAttribArrayObjectfvATI */);
}

static PFNGLGETVERTEXATTRIBARRAYOBJECTIVATIPROC
epoxy_glGetVertexAttribArrayObjectivATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_attrib_array_object, 28122 /* glGetVertexAttribArrayObjectivATI */);
}

static PFNGLGETVERTEXATTRIBIIVPROC
epoxy_glGetVertexAttribIiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_NV_vertex_program4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        28156 /* "glGetVertexAttribIiv" */,
        28156 /* "glGetVertexAttribIiv" */,
        28177 /* "glGetVertexAttribIivEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 28156 /* "glGetVertexAttribIiv" */,
                                providers, entrypoints);
}

static PFNGLGETVERTEXATTRIBIIVEXTPROC
epoxy_glGetVertexAttribIivEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program4,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        28177 /* "glGetVertexAttribIivEXT" */,
        28156 /* "glGetVertexAttribIiv" */,
        28156 /* "glGetVertexAttribIiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 28177 /* "glGetVertexAttribIivEXT" */,
                                providers, entrypoints);
}

static PFNGLGETVERTEXATTRIBIUIVPROC
epoxy_glGetVertexAttribIuiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_NV_vertex_program4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        28201 /* "glGetVertexAttribIuiv" */,
        28201 /* "glGetVertexAttribIuiv" */,
        28223 /* "glGetVertexAttribIuivEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 28201 /* "glGetVertexAttribIuiv" */,
                                providers, entrypoints);
}

static PFNGLGETVERTEXATTRIBIUIVEXTPROC
epoxy_glGetVertexAttribIuivEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program4,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        28223 /* "glGetVertexAttribIuivEXT" */,
        28201 /* "glGetVertexAttribIuiv" */,
        28201 /* "glGetVertexAttribIuiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 28223 /* "glGetVertexAttribIuivEXT" */,
                                providers, entrypoints);
}

static PFNGLGETVERTEXATTRIBLDVPROC
epoxy_glGetVertexAttribLdv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_vertex_attrib_64bit,
        PROVIDER_GL_EXT_vertex_attrib_64bit,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        28248 /* "glGetVertexAttribLdv" */,
        28248 /* "glGetVertexAttribLdv" */,
        28269 /* "glGetVertexAttribLdvEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 28248 /* "glGetVertexAttribLdv" */,
                                providers, entrypoints);
}

static PFNGLGETVERTEXATTRIBLDVEXTPROC
epoxy_glGetVertexAttribLdvEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_vertex_attrib_64bit,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_vertex_attrib_64bit,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        28269 /* "glGetVertexAttribLdvEXT" */,
        28248 /* "glGetVertexAttribLdv" */,
        28248 /* "glGetVertexAttribLdv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 28269 /* "glGetVertexAttribLdvEXT" */,
                                providers, entrypoints);
}

static PFNGLGETVERTEXATTRIBLI64VNVPROC
epoxy_glGetVertexAttribLi64vNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_attrib_integer_64bit, 28293 /* glGetVertexAttribLi64vNV */);
}

static PFNGLGETVERTEXATTRIBLUI64VARBPROC
epoxy_glGetVertexAttribLui64vARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_bindless_texture, 28318 /* glGetVertexAttribLui64vARB */);
}

static PFNGLGETVERTEXATTRIBLUI64VNVPROC
epoxy_glGetVertexAttribLui64vNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_attrib_integer_64bit, 28345 /* glGetVertexAttribLui64vNV */);
}

static PFNGLGETVERTEXATTRIBPOINTERVPROC
epoxy_glGetVertexAttribPointerv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        28371 /* "glGetVertexAttribPointerv" */,
        28371 /* "glGetVertexAttribPointerv" */,
        28397 /* "glGetVertexAttribPointervARB" */,
        28397 /* "glGetVertexAttribPointervARB" */,
        28426 /* "glGetVertexAttribPointervNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 28371 /* "glGetVertexAttribPointerv" */,
                                providers, entrypoints);
}

static PFNGLGETVERTEXATTRIBPOINTERVARBPROC
epoxy_glGetVertexAttribPointervARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        28397 /* "glGetVertexAttribPointervARB" */,
        28397 /* "glGetVertexAttribPointervARB" */,
        28371 /* "glGetVertexAttribPointerv" */,
        28371 /* "glGetVertexAttribPointerv" */,
        28426 /* "glGetVertexAttribPointervNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 28397 /* "glGetVertexAttribPointervARB" */,
                                providers, entrypoints);
}

static PFNGLGETVERTEXATTRIBPOINTERVNVPROC
epoxy_glGetVertexAttribPointervNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        28426 /* "glGetVertexAttribPointervNV" */,
        28371 /* "glGetVertexAttribPointerv" */,
        28371 /* "glGetVertexAttribPointerv" */,
        28397 /* "glGetVertexAttribPointervARB" */,
        28397 /* "glGetVertexAttribPointervARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 28426 /* "glGetVertexAttribPointervNV" */,
                                providers, entrypoints);
}

static PFNGLGETVERTEXATTRIBDVPROC
epoxy_glGetVertexAttribdv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        28454 /* "glGetVertexAttribdv" */,
        28474 /* "glGetVertexAttribdvARB" */,
        28474 /* "glGetVertexAttribdvARB" */,
        28497 /* "glGetVertexAttribdvNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 28454 /* "glGetVertexAttribdv" */,
                                providers, entrypoints);
}

static PFNGLGETVERTEXATTRIBDVARBPROC
epoxy_glGetVertexAttribdvARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        28474 /* "glGetVertexAttribdvARB" */,
        28474 /* "glGetVertexAttribdvARB" */,
        28454 /* "glGetVertexAttribdv" */,
        28497 /* "glGetVertexAttribdvNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 28474 /* "glGetVertexAttribdvARB" */,
                                providers, entrypoints);
}

static PFNGLGETVERTEXATTRIBDVNVPROC
epoxy_glGetVertexAttribdvNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        28497 /* "glGetVertexAttribdvNV" */,
        28454 /* "glGetVertexAttribdv" */,
        28474 /* "glGetVertexAttribdvARB" */,
        28474 /* "glGetVertexAttribdvARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 28497 /* "glGetVertexAttribdvNV" */,
                                providers, entrypoints);
}

static PFNGLGETVERTEXATTRIBFVPROC
epoxy_glGetVertexAttribfv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        28519 /* "glGetVertexAttribfv" */,
        28519 /* "glGetVertexAttribfv" */,
        28539 /* "glGetVertexAttribfvARB" */,
        28539 /* "glGetVertexAttribfvARB" */,
        28562 /* "glGetVertexAttribfvNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 28519 /* "glGetVertexAttribfv" */,
                                providers, entrypoints);
}

static PFNGLGETVERTEXATTRIBFVARBPROC
epoxy_glGetVertexAttribfvARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        28539 /* "glGetVertexAttribfvARB" */,
        28539 /* "glGetVertexAttribfvARB" */,
        28519 /* "glGetVertexAttribfv" */,
        28519 /* "glGetVertexAttribfv" */,
        28562 /* "glGetVertexAttribfvNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 28539 /* "glGetVertexAttribfvARB" */,
                                providers, entrypoints);
}

static PFNGLGETVERTEXATTRIBFVNVPROC
epoxy_glGetVertexAttribfvNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        28562 /* "glGetVertexAttribfvNV" */,
        28519 /* "glGetVertexAttribfv" */,
        28519 /* "glGetVertexAttribfv" */,
        28539 /* "glGetVertexAttribfvARB" */,
        28539 /* "glGetVertexAttribfvARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 28562 /* "glGetVertexAttribfvNV" */,
                                providers, entrypoints);
}

static PFNGLGETVERTEXATTRIBIVPROC
epoxy_glGetVertexAttribiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        28584 /* "glGetVertexAttribiv" */,
        28584 /* "glGetVertexAttribiv" */,
        28604 /* "glGetVertexAttribivARB" */,
        28604 /* "glGetVertexAttribivARB" */,
        28627 /* "glGetVertexAttribivNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 28584 /* "glGetVertexAttribiv" */,
                                providers, entrypoints);
}

static PFNGLGETVERTEXATTRIBIVARBPROC
epoxy_glGetVertexAttribivARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        28604 /* "glGetVertexAttribivARB" */,
        28604 /* "glGetVertexAttribivARB" */,
        28584 /* "glGetVertexAttribiv" */,
        28584 /* "glGetVertexAttribiv" */,
        28627 /* "glGetVertexAttribivNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 28604 /* "glGetVertexAttribivARB" */,
                                providers, entrypoints);
}

static PFNGLGETVERTEXATTRIBIVNVPROC
epoxy_glGetVertexAttribivNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        28627 /* "glGetVertexAttribivNV" */,
        28584 /* "glGetVertexAttribiv" */,
        28584 /* "glGetVertexAttribiv" */,
        28604 /* "glGetVertexAttribivARB" */,
        28604 /* "glGetVertexAttribivARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 28627 /* "glGetVertexAttribivNV" */,
                                providers, entrypoints);
}

static PFNGLGETVIDEOCAPTURESTREAMDVNVPROC
epoxy_glGetVideoCaptureStreamdvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_video_capture, 28649 /* glGetVideoCaptureStreamdvNV */);
}

static PFNGLGETVIDEOCAPTURESTREAMFVNVPROC
epoxy_glGetVideoCaptureStreamfvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_video_capture, 28677 /* glGetVideoCaptureStreamfvNV */);
}

static PFNGLGETVIDEOCAPTURESTREAMIVNVPROC
epoxy_glGetVideoCaptureStreamivNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_video_capture, 28705 /* glGetVideoCaptureStreamivNV */);
}

static PFNGLGETVIDEOCAPTUREIVNVPROC
epoxy_glGetVideoCaptureivNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_video_capture, 28733 /* glGetVideoCaptureivNV */);
}

static PFNGLGETVIDEOI64VNVPROC
epoxy_glGetVideoi64vNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_present_video, 28755 /* glGetVideoi64vNV */);
}

static PFNGLGETVIDEOIVNVPROC
epoxy_glGetVideoivNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_present_video, 28772 /* glGetVideoivNV */);
}

static PFNGLGETVIDEOUI64VNVPROC
epoxy_glGetVideoui64vNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_present_video, 28787 /* glGetVideoui64vNV */);
}

static PFNGLGETVIDEOUIVNVPROC
epoxy_glGetVideouivNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_present_video, 28805 /* glGetVideouivNV */);
}

static PFNGLGETVKPROCADDRNVPROC
epoxy_glGetVkProcAddrNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_draw_vulkan_image, 28821 /* glGetVkProcAddrNV */);
}

static PFNGLGETNCOLORTABLEPROC
epoxy_glGetnColorTable_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_4_5, 28839 /* glGetnColorTable */);
}

static PFNGLGETNCOLORTABLEARBPROC
epoxy_glGetnColorTableARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_robustness, 28856 /* glGetnColorTableARB */);
}

static PFNGLGETNCOMPRESSEDTEXIMAGEPROC
epoxy_glGetnCompressedTexImage_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_4_5, 28876 /* glGetnCompressedTexImage */);
}

static PFNGLGETNCOMPRESSEDTEXIMAGEARBPROC
epoxy_glGetnCompressedTexImageARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_robustness, 28901 /* glGetnCompressedTexImageARB */);
}

static PFNGLGETNCONVOLUTIONFILTERPROC
epoxy_glGetnConvolutionFilter_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_4_5, 28929 /* glGetnConvolutionFilter */);
}

static PFNGLGETNCONVOLUTIONFILTERARBPROC
epoxy_glGetnConvolutionFilterARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_robustness, 28953 /* glGetnConvolutionFilterARB */);
}

static PFNGLGETNHISTOGRAMPROC
epoxy_glGetnHistogram_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_4_5, 28980 /* glGetnHistogram */);
}

static PFNGLGETNHISTOGRAMARBPROC
epoxy_glGetnHistogramARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_robustness, 28996 /* glGetnHistogramARB */);
}

static PFNGLGETNMAPDVPROC
epoxy_glGetnMapdv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_4_5, 29015 /* glGetnMapdv */);
}

static PFNGLGETNMAPDVARBPROC
epoxy_glGetnMapdvARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_robustness, 29027 /* glGetnMapdvARB */);
}

static PFNGLGETNMAPFVPROC
epoxy_glGetnMapfv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_4_5, 29042 /* glGetnMapfv */);
}

static PFNGLGETNMAPFVARBPROC
epoxy_glGetnMapfvARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_robustness, 29054 /* glGetnMapfvARB */);
}

static PFNGLGETNMAPIVPROC
epoxy_glGetnMapiv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_4_5, 29069 /* glGetnMapiv */);
}

static PFNGLGETNMAPIVARBPROC
epoxy_glGetnMapivARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_robustness, 29081 /* glGetnMapivARB */);
}

static PFNGLGETNMINMAXPROC
epoxy_glGetnMinmax_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_4_5, 29096 /* glGetnMinmax */);
}

static PFNGLGETNMINMAXARBPROC
epoxy_glGetnMinmaxARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_robustness, 29109 /* glGetnMinmaxARB */);
}

static PFNGLGETNPIXELMAPFVPROC
epoxy_glGetnPixelMapfv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_4_5, 29125 /* glGetnPixelMapfv */);
}

static PFNGLGETNPIXELMAPFVARBPROC
epoxy_glGetnPixelMapfvARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_robustness, 29142 /* glGetnPixelMapfvARB */);
}

static PFNGLGETNPIXELMAPUIVPROC
epoxy_glGetnPixelMapuiv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_4_5, 29162 /* glGetnPixelMapuiv */);
}

static PFNGLGETNPIXELMAPUIVARBPROC
epoxy_glGetnPixelMapuivARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_robustness, 29180 /* glGetnPixelMapuivARB */);
}

static PFNGLGETNPIXELMAPUSVPROC
epoxy_glGetnPixelMapusv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_4_5, 29201 /* glGetnPixelMapusv */);
}

static PFNGLGETNPIXELMAPUSVARBPROC
epoxy_glGetnPixelMapusvARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_robustness, 29219 /* glGetnPixelMapusvARB */);
}

static PFNGLGETNPOLYGONSTIPPLEPROC
epoxy_glGetnPolygonStipple_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_4_5, 29240 /* glGetnPolygonStipple */);
}

static PFNGLGETNPOLYGONSTIPPLEARBPROC
epoxy_glGetnPolygonStippleARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_robustness, 29261 /* glGetnPolygonStippleARB */);
}

static PFNGLGETNSEPARABLEFILTERPROC
epoxy_glGetnSeparableFilter_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_4_5, 29285 /* glGetnSeparableFilter */);
}

static PFNGLGETNSEPARABLEFILTERARBPROC
epoxy_glGetnSeparableFilterARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_robustness, 29307 /* glGetnSeparableFilterARB */);
}

static PFNGLGETNTEXIMAGEPROC
epoxy_glGetnTexImage_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_4_5, 29332 /* glGetnTexImage */);
}

static PFNGLGETNTEXIMAGEARBPROC
epoxy_glGetnTexImageARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_robustness, 29347 /* glGetnTexImageARB */);
}

static PFNGLGETNUNIFORMDVPROC
epoxy_glGetnUniformdv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_4_5, 29365 /* glGetnUniformdv */);
}

static PFNGLGETNUNIFORMDVARBPROC
epoxy_glGetnUniformdvARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_robustness, 29381 /* glGetnUniformdvARB */);
}

static PFNGLGETNUNIFORMFVPROC
epoxy_glGetnUniformfv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_KHR_robustness,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_robustness,
        PROVIDER_GL_KHR_robustness,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        29400 /* "glGetnUniformfv" */,
        29400 /* "glGetnUniformfv" */,
        29400 /* "glGetnUniformfv" */,
        29435 /* "glGetnUniformfvEXT" */,
        29454 /* "glGetnUniformfvKHR" */,
    };
    return gl_provider_resolver(entrypoint_strings + 29400 /* "glGetnUniformfv" */,
                                providers, entrypoints);
}

static PFNGLGETNUNIFORMFVARBPROC
epoxy_glGetnUniformfvARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_robustness, 29416 /* glGetnUniformfvARB */);
}

static PFNGLGETNUNIFORMFVEXTPROC
epoxy_glGetnUniformfvEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_robustness,
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_KHR_robustness,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_KHR_robustness,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        29435 /* "glGetnUniformfvEXT" */,
        29400 /* "glGetnUniformfv" */,
        29400 /* "glGetnUniformfv" */,
        29400 /* "glGetnUniformfv" */,
        29454 /* "glGetnUniformfvKHR" */,
    };
    return gl_provider_resolver(entrypoint_strings + 29435 /* "glGetnUniformfvEXT" */,
                                providers, entrypoints);
}

static PFNGLGETNUNIFORMFVKHRPROC
epoxy_glGetnUniformfvKHR_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_KHR_robustness,
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_KHR_robustness,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_robustness,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        29454 /* "glGetnUniformfvKHR" */,
        29400 /* "glGetnUniformfv" */,
        29400 /* "glGetnUniformfv" */,
        29400 /* "glGetnUniformfv" */,
        29435 /* "glGetnUniformfvEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 29454 /* "glGetnUniformfvKHR" */,
                                providers, entrypoints);
}

static PFNGLGETNUNIFORMI64VARBPROC
epoxy_glGetnUniformi64vARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_gpu_shader_int64, 29473 /* glGetnUniformi64vARB */);
}

static PFNGLGETNUNIFORMIVPROC
epoxy_glGetnUniformiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_KHR_robustness,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_robustness,
        PROVIDER_GL_KHR_robustness,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        29494 /* "glGetnUniformiv" */,
        29494 /* "glGetnUniformiv" */,
        29494 /* "glGetnUniformiv" */,
        29529 /* "glGetnUniformivEXT" */,
        29548 /* "glGetnUniformivKHR" */,
    };
    return gl_provider_resolver(entrypoint_strings + 29494 /* "glGetnUniformiv" */,
                                providers, entrypoints);
}

static PFNGLGETNUNIFORMIVARBPROC
epoxy_glGetnUniformivARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_robustness, 29510 /* glGetnUniformivARB */);
}

static PFNGLGETNUNIFORMIVEXTPROC
epoxy_glGetnUniformivEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_robustness,
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_KHR_robustness,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_KHR_robustness,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        29529 /* "glGetnUniformivEXT" */,
        29494 /* "glGetnUniformiv" */,
        29494 /* "glGetnUniformiv" */,
        29494 /* "glGetnUniformiv" */,
        29548 /* "glGetnUniformivKHR" */,
    };
    return gl_provider_resolver(entrypoint_strings + 29529 /* "glGetnUniformivEXT" */,
                                providers, entrypoints);
}

static PFNGLGETNUNIFORMIVKHRPROC
epoxy_glGetnUniformivKHR_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_KHR_robustness,
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_KHR_robustness,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_robustness,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        29548 /* "glGetnUniformivKHR" */,
        29494 /* "glGetnUniformiv" */,
        29494 /* "glGetnUniformiv" */,
        29494 /* "glGetnUniformiv" */,
        29529 /* "glGetnUniformivEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 29548 /* "glGetnUniformivKHR" */,
                                providers, entrypoints);
}

static PFNGLGETNUNIFORMUI64VARBPROC
epoxy_glGetnUniformui64vARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_gpu_shader_int64, 29567 /* glGetnUniformui64vARB */);
}

static PFNGLGETNUNIFORMUIVPROC
epoxy_glGetnUniformuiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_KHR_robustness,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_KHR_robustness,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        29589 /* "glGetnUniformuiv" */,
        29589 /* "glGetnUniformuiv" */,
        29589 /* "glGetnUniformuiv" */,
        29626 /* "glGetnUniformuivKHR" */,
    };
    return gl_provider_resolver(entrypoint_strings + 29589 /* "glGetnUniformuiv" */,
                                providers, entrypoints);
}

static PFNGLGETNUNIFORMUIVARBPROC
epoxy_glGetnUniformuivARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_robustness, 29606 /* glGetnUniformuivARB */);
}

static PFNGLGETNUNIFORMUIVKHRPROC
epoxy_glGetnUniformuivKHR_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_KHR_robustness,
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_KHR_robustness,
        PROVIDER_OpenGL_ES_3_2,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        29626 /* "glGetnUniformuivKHR" */,
        29589 /* "glGetnUniformuiv" */,
        29589 /* "glGetnUniformuiv" */,
        29589 /* "glGetnUniformuiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 29626 /* "glGetnUniformuivKHR" */,
                                providers, entrypoints);
}

static PFNGLGLOBALALPHAFACTORBSUNPROC
epoxy_glGlobalAlphaFactorbSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_global_alpha, 29646 /* glGlobalAlphaFactorbSUN */);
}

static PFNGLGLOBALALPHAFACTORDSUNPROC
epoxy_glGlobalAlphaFactordSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_global_alpha, 29670 /* glGlobalAlphaFactordSUN */);
}

static PFNGLGLOBALALPHAFACTORFSUNPROC
epoxy_glGlobalAlphaFactorfSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_global_alpha, 29694 /* glGlobalAlphaFactorfSUN */);
}

static PFNGLGLOBALALPHAFACTORISUNPROC
epoxy_glGlobalAlphaFactoriSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_global_alpha, 29718 /* glGlobalAlphaFactoriSUN */);
}

static PFNGLGLOBALALPHAFACTORSSUNPROC
epoxy_glGlobalAlphaFactorsSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_global_alpha, 29742 /* glGlobalAlphaFactorsSUN */);
}

static PFNGLGLOBALALPHAFACTORUBSUNPROC
epoxy_glGlobalAlphaFactorubSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_global_alpha, 29766 /* glGlobalAlphaFactorubSUN */);
}

static PFNGLGLOBALALPHAFACTORUISUNPROC
epoxy_glGlobalAlphaFactoruiSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_global_alpha, 29791 /* glGlobalAlphaFactoruiSUN */);
}

static PFNGLGLOBALALPHAFACTORUSSUNPROC
epoxy_glGlobalAlphaFactorusSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_global_alpha, 29816 /* glGlobalAlphaFactorusSUN */);
}

static PFNGLHINTPROC
epoxy_glHint_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        29841 /* "glHint" */,
        29841 /* "glHint" */,
        29841 /* "glHint" */,
    };
    return gl_provider_resolver(entrypoint_strings + 29841 /* "glHint" */,
                                providers, entrypoints);
}

static PFNGLHINTPGIPROC
epoxy_glHintPGI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_PGI_misc_hints, 29848 /* glHintPGI */);
}

static PFNGLHISTOGRAMPROC
epoxy_glHistogram_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_imaging,
        PROVIDER_GL_EXT_histogram,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        29858 /* "glHistogram" */,
        29870 /* "glHistogramEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 29858 /* "glHistogram" */,
                                providers, entrypoints);
}

static PFNGLHISTOGRAMEXTPROC
epoxy_glHistogramEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_histogram,
        PROVIDER_GL_ARB_imaging,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        29870 /* "glHistogramEXT" */,
        29858 /* "glHistogram" */,
    };
    return gl_provider_resolver(entrypoint_strings + 29870 /* "glHistogramEXT" */,
                                providers, entrypoints);
}

static PFNGLIGLOOINTERFACESGIXPROC
epoxy_glIglooInterfaceSGIX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIX_igloo_interface, 29885 /* glIglooInterfaceSGIX */);
}

static PFNGLIMAGETRANSFORMPARAMETERFHPPROC
epoxy_glImageTransformParameterfHP_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_HP_image_transform, 29906 /* glImageTransformParameterfHP */);
}

static PFNGLIMAGETRANSFORMPARAMETERFVHPPROC
epoxy_glImageTransformParameterfvHP_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_HP_image_transform, 29935 /* glImageTransformParameterfvHP */);
}

static PFNGLIMAGETRANSFORMPARAMETERIHPPROC
epoxy_glImageTransformParameteriHP_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_HP_image_transform, 29965 /* glImageTransformParameteriHP */);
}

static PFNGLIMAGETRANSFORMPARAMETERIVHPPROC
epoxy_glImageTransformParameterivHP_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_HP_image_transform, 29994 /* glImageTransformParameterivHP */);
}

static PFNGLIMPORTMEMORYFDEXTPROC
epoxy_glImportMemoryFdEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_memory_object_fd, 30024 /* glImportMemoryFdEXT */);
}

static PFNGLIMPORTMEMORYWIN32HANDLEEXTPROC
epoxy_glImportMemoryWin32HandleEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_memory_object_win32, 30044 /* glImportMemoryWin32HandleEXT */);
}

static PFNGLIMPORTMEMORYWIN32NAMEEXTPROC
epoxy_glImportMemoryWin32NameEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_memory_object_win32, 30073 /* glImportMemoryWin32NameEXT */);
}

static PFNGLIMPORTSEMAPHOREFDEXTPROC
epoxy_glImportSemaphoreFdEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_semaphore_fd, 30100 /* glImportSemaphoreFdEXT */);
}

static PFNGLIMPORTSEMAPHOREWIN32HANDLEEXTPROC
epoxy_glImportSemaphoreWin32HandleEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_semaphore_win32, 30123 /* glImportSemaphoreWin32HandleEXT */);
}

static PFNGLIMPORTSEMAPHOREWIN32NAMEEXTPROC
epoxy_glImportSemaphoreWin32NameEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_semaphore_win32, 30155 /* glImportSemaphoreWin32NameEXT */);
}

static PFNGLIMPORTSYNCEXTPROC
epoxy_glImportSyncEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_x11_sync_object, 30185 /* glImportSyncEXT */);
}

static PFNGLINDEXFORMATNVPROC
epoxy_glIndexFormatNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_buffer_unified_memory, 30201 /* glIndexFormatNV */);
}

static PFNGLINDEXFUNCEXTPROC
epoxy_glIndexFuncEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_index_func, 30217 /* glIndexFuncEXT */);
}

static PFNGLINDEXMASKPROC
epoxy_glIndexMask_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 30232 /* glIndexMask */);
}

static PFNGLINDEXMATERIALEXTPROC
epoxy_glIndexMaterialEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_index_material, 30244 /* glIndexMaterialEXT */);
}

static PFNGLINDEXPOINTERPROC
epoxy_glIndexPointer_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_1, 30263 /* glIndexPointer */);
}

static PFNGLINDEXPOINTEREXTPROC
epoxy_glIndexPointerEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_array, 30278 /* glIndexPointerEXT */);
}

static PFNGLINDEXPOINTERLISTIBMPROC
epoxy_glIndexPointerListIBM_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_IBM_vertex_array_lists, 30296 /* glIndexPointerListIBM */);
}

static PFNGLINDEXDPROC
epoxy_glIndexd_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 30318 /* glIndexd */);
}

static PFNGLINDEXDVPROC
epoxy_glIndexdv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 30327 /* glIndexdv */);
}

static PFNGLINDEXFPROC
epoxy_glIndexf_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 30337 /* glIndexf */);
}

static PFNGLINDEXFVPROC
epoxy_glIndexfv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 30346 /* glIndexfv */);
}

static PFNGLINDEXIPROC
epoxy_glIndexi_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 30356 /* glIndexi */);
}

static PFNGLINDEXIVPROC
epoxy_glIndexiv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 30365 /* glIndexiv */);
}

static PFNGLINDEXSPROC
epoxy_glIndexs_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 30375 /* glIndexs */);
}

static PFNGLINDEXSVPROC
epoxy_glIndexsv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 30384 /* glIndexsv */);
}

static PFNGLINDEXUBPROC
epoxy_glIndexub_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_1, 30394 /* glIndexub */);
}

static PFNGLINDEXUBVPROC
epoxy_glIndexubv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_1, 30404 /* glIndexubv */);
}

static PFNGLINDEXXOESPROC
epoxy_glIndexxOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 30415 /* glIndexxOES */);
}

static PFNGLINDEXXVOESPROC
epoxy_glIndexxvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 30427 /* glIndexxvOES */);
}

static PFNGLINITNAMESPROC
epoxy_glInitNames_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 30440 /* glInitNames */);
}

static PFNGLINSERTCOMPONENTEXTPROC
epoxy_glInsertComponentEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_shader, 30452 /* glInsertComponentEXT */);
}

static PFNGLINSERTEVENTMARKEREXTPROC
epoxy_glInsertEventMarkerEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_debug_marker, 30473 /* glInsertEventMarkerEXT */);
}

static PFNGLINSTRUMENTSBUFFERSGIXPROC
epoxy_glInstrumentsBufferSGIX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIX_instruments, 30496 /* glInstrumentsBufferSGIX */);
}

static PFNGLINTERLEAVEDARRAYSPROC
epoxy_glInterleavedArrays_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_1, 30520 /* glInterleavedArrays */);
}

static PFNGLINTERPOLATEPATHSNVPROC
epoxy_glInterpolatePathsNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 30540 /* glInterpolatePathsNV */);
}

static PFNGLINVALIDATEBUFFERDATAPROC
epoxy_glInvalidateBufferData_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_ARB_invalidate_subdata,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        30561 /* "glInvalidateBufferData" */,
        30561 /* "glInvalidateBufferData" */,
    };
    return gl_provider_resolver(entrypoint_strings + 30561 /* "glInvalidateBufferData" */,
                                providers, entrypoints);
}

static PFNGLINVALIDATEBUFFERSUBDATAPROC
epoxy_glInvalidateBufferSubData_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_ARB_invalidate_subdata,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        30584 /* "glInvalidateBufferSubData" */,
        30584 /* "glInvalidateBufferSubData" */,
    };
    return gl_provider_resolver(entrypoint_strings + 30584 /* "glInvalidateBufferSubData" */,
                                providers, entrypoints);
}

static PFNGLINVALIDATEFRAMEBUFFERPROC
epoxy_glInvalidateFramebuffer_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_ARB_invalidate_subdata,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        30610 /* "glInvalidateFramebuffer" */,
        30610 /* "glInvalidateFramebuffer" */,
        30610 /* "glInvalidateFramebuffer" */,
    };
    return gl_provider_resolver(entrypoint_strings + 30610 /* "glInvalidateFramebuffer" */,
                                providers, entrypoints);
}

static PFNGLINVALIDATENAMEDFRAMEBUFFERDATAPROC
epoxy_glInvalidateNamedFramebufferData_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        30634 /* "glInvalidateNamedFramebufferData" */,
        30634 /* "glInvalidateNamedFramebufferData" */,
    };
    return gl_provider_resolver(entrypoint_strings + 30634 /* "glInvalidateNamedFramebufferData" */,
                                providers, entrypoints);
}

static PFNGLINVALIDATENAMEDFRAMEBUFFERSUBDATAPROC
epoxy_glInvalidateNamedFramebufferSubData_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        30667 /* "glInvalidateNamedFramebufferSubData" */,
        30667 /* "glInvalidateNamedFramebufferSubData" */,
    };
    return gl_provider_resolver(entrypoint_strings + 30667 /* "glInvalidateNamedFramebufferSubData" */,
                                providers, entrypoints);
}

static PFNGLINVALIDATESUBFRAMEBUFFERPROC
epoxy_glInvalidateSubFramebuffer_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_ARB_invalidate_subdata,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        30703 /* "glInvalidateSubFramebuffer" */,
        30703 /* "glInvalidateSubFramebuffer" */,
        30703 /* "glInvalidateSubFramebuffer" */,
    };
    return gl_provider_resolver(entrypoint_strings + 30703 /* "glInvalidateSubFramebuffer" */,
                                providers, entrypoints);
}

static PFNGLINVALIDATETEXIMAGEPROC
epoxy_glInvalidateTexImage_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_ARB_invalidate_subdata,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        30730 /* "glInvalidateTexImage" */,
        30730 /* "glInvalidateTexImage" */,
    };
    return gl_provider_resolver(entrypoint_strings + 30730 /* "glInvalidateTexImage" */,
                                providers, entrypoints);
}

static PFNGLINVALIDATETEXSUBIMAGEPROC
epoxy_glInvalidateTexSubImage_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_ARB_invalidate_subdata,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        30751 /* "glInvalidateTexSubImage" */,
        30751 /* "glInvalidateTexSubImage" */,
    };
    return gl_provider_resolver(entrypoint_strings + 30751 /* "glInvalidateTexSubImage" */,
                                providers, entrypoints);
}

static PFNGLISASYNCMARKERSGIXPROC
epoxy_glIsAsyncMarkerSGIX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIX_async, 30775 /* glIsAsyncMarkerSGIX */);
}

static PFNGLISBUFFERPROC
epoxy_glIsBuffer_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_5,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_vertex_buffer_object,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        30795 /* "glIsBuffer" */,
        30795 /* "glIsBuffer" */,
        30795 /* "glIsBuffer" */,
        30806 /* "glIsBufferARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 30795 /* "glIsBuffer" */,
                                providers, entrypoints);
}

static PFNGLISBUFFERARBPROC
epoxy_glIsBufferARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_buffer_object,
        PROVIDER_Desktop_OpenGL_1_5,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        30806 /* "glIsBufferARB" */,
        30795 /* "glIsBuffer" */,
        30795 /* "glIsBuffer" */,
        30795 /* "glIsBuffer" */,
    };
    return gl_provider_resolver(entrypoint_strings + 30806 /* "glIsBufferARB" */,
                                providers, entrypoints);
}

static PFNGLISBUFFERRESIDENTNVPROC
epoxy_glIsBufferResidentNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_shader_buffer_load, 30820 /* glIsBufferResidentNV */);
}

static PFNGLISCOMMANDLISTNVPROC
epoxy_glIsCommandListNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_command_list, 30841 /* glIsCommandListNV */);
}

static PFNGLISENABLEDPROC
epoxy_glIsEnabled_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        30859 /* "glIsEnabled" */,
        30859 /* "glIsEnabled" */,
        30859 /* "glIsEnabled" */,
    };
    return gl_provider_resolver(entrypoint_strings + 30859 /* "glIsEnabled" */,
                                providers, entrypoints);
}

static PFNGLISENABLEDINDEXEDEXTPROC
epoxy_glIsEnabledIndexedEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_draw_buffers2,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_draw_buffers_indexed,
        PROVIDER_GL_NV_viewport_array,
        PROVIDER_GL_OES_draw_buffers_indexed,
        PROVIDER_GL_OES_viewport_array,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        30871 /* "glIsEnabledIndexedEXT" */,
        30871 /* "glIsEnabledIndexedEXT" */,
        30893 /* "glIsEnabledi" */,
        30893 /* "glIsEnabledi" */,
        30906 /* "glIsEnablediEXT" */,
        30922 /* "glIsEnablediNV" */,
        30937 /* "glIsEnablediOES" */,
        30937 /* "glIsEnablediOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 30871 /* "glIsEnabledIndexedEXT" */,
                                providers, entrypoints);
}

static PFNGLISENABLEDIPROC
epoxy_glIsEnabledi_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_draw_buffers2,
        PROVIDER_GL_EXT_draw_buffers_indexed,
        PROVIDER_GL_NV_viewport_array,
        PROVIDER_GL_OES_draw_buffers_indexed,
        PROVIDER_GL_OES_viewport_array,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        30893 /* "glIsEnabledi" */,
        30893 /* "glIsEnabledi" */,
        30871 /* "glIsEnabledIndexedEXT" */,
        30871 /* "glIsEnabledIndexedEXT" */,
        30906 /* "glIsEnablediEXT" */,
        30922 /* "glIsEnablediNV" */,
        30937 /* "glIsEnablediOES" */,
        30937 /* "glIsEnablediOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 30893 /* "glIsEnabledi" */,
                                providers, entrypoints);
}

static PFNGLISENABLEDIEXTPROC
epoxy_glIsEnablediEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_draw_buffers_indexed,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_draw_buffers2,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_NV_viewport_array,
        PROVIDER_GL_OES_draw_buffers_indexed,
        PROVIDER_GL_OES_viewport_array,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        30906 /* "glIsEnablediEXT" */,
        30871 /* "glIsEnabledIndexedEXT" */,
        30871 /* "glIsEnabledIndexedEXT" */,
        30893 /* "glIsEnabledi" */,
        30893 /* "glIsEnabledi" */,
        30922 /* "glIsEnablediNV" */,
        30937 /* "glIsEnablediOES" */,
        30937 /* "glIsEnablediOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 30906 /* "glIsEnablediEXT" */,
                                providers, entrypoints);
}

static PFNGLISENABLEDINVPROC
epoxy_glIsEnablediNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_viewport_array,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_draw_buffers2,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_draw_buffers_indexed,
        PROVIDER_GL_OES_draw_buffers_indexed,
        PROVIDER_GL_OES_viewport_array,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        30922 /* "glIsEnablediNV" */,
        30871 /* "glIsEnabledIndexedEXT" */,
        30871 /* "glIsEnabledIndexedEXT" */,
        30893 /* "glIsEnabledi" */,
        30893 /* "glIsEnabledi" */,
        30906 /* "glIsEnablediEXT" */,
        30937 /* "glIsEnablediOES" */,
        30937 /* "glIsEnablediOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 30922 /* "glIsEnablediNV" */,
                                providers, entrypoints);
}

static PFNGLISENABLEDIOESPROC
epoxy_glIsEnablediOES_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_OES_draw_buffers_indexed,
        PROVIDER_GL_OES_viewport_array,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_draw_buffers2,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_draw_buffers_indexed,
        PROVIDER_GL_NV_viewport_array,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        30937 /* "glIsEnablediOES" */,
        30937 /* "glIsEnablediOES" */,
        30871 /* "glIsEnabledIndexedEXT" */,
        30871 /* "glIsEnabledIndexedEXT" */,
        30893 /* "glIsEnabledi" */,
        30893 /* "glIsEnabledi" */,
        30906 /* "glIsEnablediEXT" */,
        30922 /* "glIsEnablediNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 30937 /* "glIsEnablediOES" */,
                                providers, entrypoints);
}

static PFNGLISFENCEAPPLEPROC
epoxy_glIsFenceAPPLE_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_APPLE_fence, 30953 /* glIsFenceAPPLE */);
}

static PFNGLISFENCENVPROC
epoxy_glIsFenceNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_fence, 30968 /* glIsFenceNV */);
}

static PFNGLISFRAMEBUFFERPROC
epoxy_glIsFramebuffer_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_framebuffer_object,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_EXT_framebuffer_object,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        30980 /* "glIsFramebuffer" */,
        30980 /* "glIsFramebuffer" */,
        30980 /* "glIsFramebuffer" */,
        30996 /* "glIsFramebufferEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 30980 /* "glIsFramebuffer" */,
                                providers, entrypoints);
}

static PFNGLISFRAMEBUFFEREXTPROC
epoxy_glIsFramebufferEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_framebuffer_object,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_framebuffer_object,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        30996 /* "glIsFramebufferEXT" */,
        30980 /* "glIsFramebuffer" */,
        30980 /* "glIsFramebuffer" */,
        30980 /* "glIsFramebuffer" */,
    };
    return gl_provider_resolver(entrypoint_strings + 30996 /* "glIsFramebufferEXT" */,
                                providers, entrypoints);
}

static PFNGLISFRAMEBUFFEROESPROC
epoxy_glIsFramebufferOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_framebuffer_object, 31015 /* glIsFramebufferOES */);
}

static PFNGLISIMAGEHANDLERESIDENTARBPROC
epoxy_glIsImageHandleResidentARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_bindless_texture, 31034 /* glIsImageHandleResidentARB */);
}

static PFNGLISIMAGEHANDLERESIDENTNVPROC
epoxy_glIsImageHandleResidentNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_bindless_texture, 31061 /* glIsImageHandleResidentNV */);
}

static PFNGLISLISTPROC
epoxy_glIsList_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 31087 /* glIsList */);
}

static PFNGLISMEMORYOBJECTEXTPROC
epoxy_glIsMemoryObjectEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_memory_object, 31096 /* glIsMemoryObjectEXT */);
}

static PFNGLISNAMEAMDPROC
epoxy_glIsNameAMD_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_AMD_name_gen_delete, 31116 /* glIsNameAMD */);
}

static PFNGLISNAMEDBUFFERRESIDENTNVPROC
epoxy_glIsNamedBufferResidentNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_shader_buffer_load, 31128 /* glIsNamedBufferResidentNV */);
}

static PFNGLISNAMEDSTRINGARBPROC
epoxy_glIsNamedStringARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_shading_language_include, 31154 /* glIsNamedStringARB */);
}

static PFNGLISOBJECTBUFFERATIPROC
epoxy_glIsObjectBufferATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_array_object, 31173 /* glIsObjectBufferATI */);
}

static PFNGLISOCCLUSIONQUERYNVPROC
epoxy_glIsOcclusionQueryNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_occlusion_query, 31193 /* glIsOcclusionQueryNV */);
}

static PFNGLISPATHNVPROC
epoxy_glIsPathNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 31214 /* glIsPathNV */);
}

static PFNGLISPOINTINFILLPATHNVPROC
epoxy_glIsPointInFillPathNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 31225 /* glIsPointInFillPathNV */);
}

static PFNGLISPOINTINSTROKEPATHNVPROC
epoxy_glIsPointInStrokePathNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 31247 /* glIsPointInStrokePathNV */);
}

static PFNGLISPROGRAMPROC
epoxy_glIsProgram_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        31271 /* "glIsProgram" */,
        31271 /* "glIsProgram" */,
    };
    return gl_provider_resolver(entrypoint_strings + 31271 /* "glIsProgram" */,
                                providers, entrypoints);
}

static PFNGLISPROGRAMARBPROC
epoxy_glIsProgramARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_fragment_program,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        31283 /* "glIsProgramARB" */,
        31283 /* "glIsProgramARB" */,
        31298 /* "glIsProgramNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 31283 /* "glIsProgramARB" */,
                                providers, entrypoints);
}

static PFNGLISPROGRAMNVPROC
epoxy_glIsProgramNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program,
        PROVIDER_GL_ARB_fragment_program,
        PROVIDER_GL_ARB_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        31298 /* "glIsProgramNV" */,
        31283 /* "glIsProgramARB" */,
        31283 /* "glIsProgramARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 31298 /* "glIsProgramNV" */,
                                providers, entrypoints);
}

static PFNGLISPROGRAMPIPELINEPROC
epoxy_glIsProgramPipeline_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        31312 /* "glIsProgramPipeline" */,
        31312 /* "glIsProgramPipeline" */,
        31312 /* "glIsProgramPipeline" */,
    };
    return gl_provider_resolver(entrypoint_strings + 31312 /* "glIsProgramPipeline" */,
                                providers, entrypoints);
}

static PFNGLISPROGRAMPIPELINEEXTPROC
epoxy_glIsProgramPipelineEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_separate_shader_objects, 31332 /* glIsProgramPipelineEXT */);
}

static PFNGLISQUERYPROC
epoxy_glIsQuery_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_5,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_ARB_occlusion_query,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        31355 /* "glIsQuery" */,
        31355 /* "glIsQuery" */,
        31365 /* "glIsQueryARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 31355 /* "glIsQuery" */,
                                providers, entrypoints);
}

static PFNGLISQUERYARBPROC
epoxy_glIsQueryARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_occlusion_query,
        PROVIDER_Desktop_OpenGL_1_5,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        31365 /* "glIsQueryARB" */,
        31355 /* "glIsQuery" */,
        31355 /* "glIsQuery" */,
    };
    return gl_provider_resolver(entrypoint_strings + 31365 /* "glIsQueryARB" */,
                                providers, entrypoints);
}

static PFNGLISQUERYEXTPROC
epoxy_glIsQueryEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_disjoint_timer_query,
        PROVIDER_GL_EXT_occlusion_query_boolean,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        31378 /* "glIsQueryEXT" */,
        31378 /* "glIsQueryEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 31378 /* "glIsQueryEXT" */,
                                providers, entrypoints);
}

static PFNGLISRENDERBUFFERPROC
epoxy_glIsRenderbuffer_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_framebuffer_object,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_EXT_framebuffer_object,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        31391 /* "glIsRenderbuffer" */,
        31391 /* "glIsRenderbuffer" */,
        31391 /* "glIsRenderbuffer" */,
        31408 /* "glIsRenderbufferEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 31391 /* "glIsRenderbuffer" */,
                                providers, entrypoints);
}

static PFNGLISRENDERBUFFEREXTPROC
epoxy_glIsRenderbufferEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_framebuffer_object,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_framebuffer_object,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        31408 /* "glIsRenderbufferEXT" */,
        31391 /* "glIsRenderbuffer" */,
        31391 /* "glIsRenderbuffer" */,
        31391 /* "glIsRenderbuffer" */,
    };
    return gl_provider_resolver(entrypoint_strings + 31408 /* "glIsRenderbufferEXT" */,
                                providers, entrypoints);
}

static PFNGLISRENDERBUFFEROESPROC
epoxy_glIsRenderbufferOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_framebuffer_object, 31428 /* glIsRenderbufferOES */);
}

static PFNGLISSAMPLERPROC
epoxy_glIsSampler_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_sampler_objects,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        31448 /* "glIsSampler" */,
        31448 /* "glIsSampler" */,
        31448 /* "glIsSampler" */,
    };
    return gl_provider_resolver(entrypoint_strings + 31448 /* "glIsSampler" */,
                                providers, entrypoints);
}

static PFNGLISSEMAPHOREEXTPROC
epoxy_glIsSemaphoreEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_semaphore, 31460 /* glIsSemaphoreEXT */);
}

static PFNGLISSHADERPROC
epoxy_glIsShader_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        31477 /* "glIsShader" */,
        31477 /* "glIsShader" */,
    };
    return gl_provider_resolver(entrypoint_strings + 31477 /* "glIsShader" */,
                                providers, entrypoints);
}

static PFNGLISSTATENVPROC
epoxy_glIsStateNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_command_list, 31488 /* glIsStateNV */);
}

static PFNGLISSYNCPROC
epoxy_glIsSync_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_2,
        PROVIDER_GL_ARB_sync,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_APPLE_sync,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        31500 /* "glIsSync" */,
        31500 /* "glIsSync" */,
        31500 /* "glIsSync" */,
        31509 /* "glIsSyncAPPLE" */,
    };
    return gl_provider_resolver(entrypoint_strings + 31500 /* "glIsSync" */,
                                providers, entrypoints);
}

static PFNGLISSYNCAPPLEPROC
epoxy_glIsSyncAPPLE_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_APPLE_sync,
        PROVIDER_Desktop_OpenGL_3_2,
        PROVIDER_GL_ARB_sync,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        31509 /* "glIsSyncAPPLE" */,
        31500 /* "glIsSync" */,
        31500 /* "glIsSync" */,
        31500 /* "glIsSync" */,
    };
    return gl_provider_resolver(entrypoint_strings + 31509 /* "glIsSyncAPPLE" */,
                                providers, entrypoints);
}

static PFNGLISTEXTUREPROC
epoxy_glIsTexture_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_1,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        31523 /* "glIsTexture" */,
        31523 /* "glIsTexture" */,
        31523 /* "glIsTexture" */,
    };
    return gl_provider_resolver(entrypoint_strings + 31523 /* "glIsTexture" */,
                                providers, entrypoints);
}

static PFNGLISTEXTUREEXTPROC
epoxy_glIsTextureEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_texture_object, 31535 /* glIsTextureEXT */);
}

static PFNGLISTEXTUREHANDLERESIDENTARBPROC
epoxy_glIsTextureHandleResidentARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_bindless_texture, 31550 /* glIsTextureHandleResidentARB */);
}

static PFNGLISTEXTUREHANDLERESIDENTNVPROC
epoxy_glIsTextureHandleResidentNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_bindless_texture, 31579 /* glIsTextureHandleResidentNV */);
}

static PFNGLISTRANSFORMFEEDBACKPROC
epoxy_glIsTransformFeedback_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_GL_ARB_transform_feedback2,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_NV_transform_feedback2,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        31607 /* "glIsTransformFeedback" */,
        31607 /* "glIsTransformFeedback" */,
        31607 /* "glIsTransformFeedback" */,
        31629 /* "glIsTransformFeedbackNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 31607 /* "glIsTransformFeedback" */,
                                providers, entrypoints);
}

static PFNGLISTRANSFORMFEEDBACKNVPROC
epoxy_glIsTransformFeedbackNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_transform_feedback2,
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_GL_ARB_transform_feedback2,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        31629 /* "glIsTransformFeedbackNV" */,
        31607 /* "glIsTransformFeedback" */,
        31607 /* "glIsTransformFeedback" */,
        31607 /* "glIsTransformFeedback" */,
    };
    return gl_provider_resolver(entrypoint_strings + 31629 /* "glIsTransformFeedbackNV" */,
                                providers, entrypoints);
}

static PFNGLISVARIANTENABLEDEXTPROC
epoxy_glIsVariantEnabledEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_shader, 31653 /* glIsVariantEnabledEXT */);
}

static PFNGLISVERTEXARRAYPROC
epoxy_glIsVertexArray_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_vertex_array_object,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_APPLE_vertex_array_object,
        PROVIDER_GL_OES_vertex_array_object,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        31675 /* "glIsVertexArray" */,
        31675 /* "glIsVertexArray" */,
        31675 /* "glIsVertexArray" */,
        31691 /* "glIsVertexArrayAPPLE" */,
        31712 /* "glIsVertexArrayOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 31675 /* "glIsVertexArray" */,
                                providers, entrypoints);
}

static PFNGLISVERTEXARRAYAPPLEPROC
epoxy_glIsVertexArrayAPPLE_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_APPLE_vertex_array_object,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_vertex_array_object,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_OES_vertex_array_object,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        31691 /* "glIsVertexArrayAPPLE" */,
        31675 /* "glIsVertexArray" */,
        31675 /* "glIsVertexArray" */,
        31675 /* "glIsVertexArray" */,
        31712 /* "glIsVertexArrayOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 31691 /* "glIsVertexArrayAPPLE" */,
                                providers, entrypoints);
}

static PFNGLISVERTEXARRAYOESPROC
epoxy_glIsVertexArrayOES_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_OES_vertex_array_object,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_vertex_array_object,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_APPLE_vertex_array_object,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        31712 /* "glIsVertexArrayOES" */,
        31675 /* "glIsVertexArray" */,
        31675 /* "glIsVertexArray" */,
        31675 /* "glIsVertexArray" */,
        31691 /* "glIsVertexArrayAPPLE" */,
    };
    return gl_provider_resolver(entrypoint_strings + 31712 /* "glIsVertexArrayOES" */,
                                providers, entrypoints);
}

static PFNGLISVERTEXATTRIBENABLEDAPPLEPROC
epoxy_glIsVertexAttribEnabledAPPLE_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_APPLE_vertex_program_evaluators, 31731 /* glIsVertexAttribEnabledAPPLE */);
}

static PFNGLLGPUCOPYIMAGESUBDATANVXPROC
epoxy_glLGPUCopyImageSubDataNVX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NVX_linked_gpu_multicast, 31760 /* glLGPUCopyImageSubDataNVX */);
}

static PFNGLLGPUINTERLOCKNVXPROC
epoxy_glLGPUInterlockNVX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NVX_linked_gpu_multicast, 31786 /* glLGPUInterlockNVX */);
}

static PFNGLLGPUNAMEDBUFFERSUBDATANVXPROC
epoxy_glLGPUNamedBufferSubDataNVX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NVX_linked_gpu_multicast, 31805 /* glLGPUNamedBufferSubDataNVX */);
}

static PFNGLLABELOBJECTEXTPROC
epoxy_glLabelObjectEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_debug_label, 31833 /* glLabelObjectEXT */);
}

static PFNGLLIGHTENVISGIXPROC
epoxy_glLightEnviSGIX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIX_fragment_lighting, 31850 /* glLightEnviSGIX */);
}

static PFNGLLIGHTMODELFPROC
epoxy_glLightModelf_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        31866 /* "glLightModelf" */,
        31866 /* "glLightModelf" */,
    };
    return gl_provider_resolver(entrypoint_strings + 31866 /* "glLightModelf" */,
                                providers, entrypoints);
}

static PFNGLLIGHTMODELFVPROC
epoxy_glLightModelfv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        31880 /* "glLightModelfv" */,
        31880 /* "glLightModelfv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 31880 /* "glLightModelfv" */,
                                providers, entrypoints);
}

static PFNGLLIGHTMODELIPROC
epoxy_glLightModeli_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 31895 /* glLightModeli */);
}

static PFNGLLIGHTMODELIVPROC
epoxy_glLightModeliv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 31909 /* glLightModeliv */);
}

static PFNGLLIGHTMODELXPROC
epoxy_glLightModelx_resolver(void)
{
    return gl_single_resolver(PROVIDER_OpenGL_ES_1_0, 31924 /* glLightModelx */);
}

static PFNGLLIGHTMODELXOESPROC
epoxy_glLightModelxOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 31938 /* glLightModelxOES */);
}

static PFNGLLIGHTMODELXVPROC
epoxy_glLightModelxv_resolver(void)
{
    return gl_single_resolver(PROVIDER_OpenGL_ES_1_0, 31955 /* glLightModelxv */);
}

static PFNGLLIGHTMODELXVOESPROC
epoxy_glLightModelxvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 31970 /* glLightModelxvOES */);
}

static PFNGLLIGHTFPROC
epoxy_glLightf_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        31988 /* "glLightf" */,
        31988 /* "glLightf" */,
    };
    return gl_provider_resolver(entrypoint_strings + 31988 /* "glLightf" */,
                                providers, entrypoints);
}

static PFNGLLIGHTFVPROC
epoxy_glLightfv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        31997 /* "glLightfv" */,
        31997 /* "glLightfv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 31997 /* "glLightfv" */,
                                providers, entrypoints);
}

static PFNGLLIGHTIPROC
epoxy_glLighti_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 32007 /* glLighti */);
}

static PFNGLLIGHTIVPROC
epoxy_glLightiv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 32016 /* glLightiv */);
}

static PFNGLLIGHTXPROC
epoxy_glLightx_resolver(void)
{
    return gl_single_resolver(PROVIDER_OpenGL_ES_1_0, 32026 /* glLightx */);
}

static PFNGLLIGHTXOESPROC
epoxy_glLightxOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 32035 /* glLightxOES */);
}

static PFNGLLIGHTXVPROC
epoxy_glLightxv_resolver(void)
{
    return gl_single_resolver(PROVIDER_OpenGL_ES_1_0, 32047 /* glLightxv */);
}

static PFNGLLIGHTXVOESPROC
epoxy_glLightxvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 32057 /* glLightxvOES */);
}

static PFNGLLINESTIPPLEPROC
epoxy_glLineStipple_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 32070 /* glLineStipple */);
}

static PFNGLLINEWIDTHPROC
epoxy_glLineWidth_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        32084 /* "glLineWidth" */,
        32084 /* "glLineWidth" */,
        32084 /* "glLineWidth" */,
    };
    return gl_provider_resolver(entrypoint_strings + 32084 /* "glLineWidth" */,
                                providers, entrypoints);
}

static PFNGLLINEWIDTHXPROC
epoxy_glLineWidthx_resolver(void)
{
    return gl_single_resolver(PROVIDER_OpenGL_ES_1_0, 32096 /* glLineWidthx */);
}

static PFNGLLINEWIDTHXOESPROC
epoxy_glLineWidthxOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 32109 /* glLineWidthxOES */);
}

static PFNGLLINKPROGRAMPROC
epoxy_glLinkProgram_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        32125 /* "glLinkProgram" */,
        32125 /* "glLinkProgram" */,
        32139 /* "glLinkProgramARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 32125 /* "glLinkProgram" */,
                                providers, entrypoints);
}

static PFNGLLINKPROGRAMARBPROC
epoxy_glLinkProgramARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_shader_objects,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        32139 /* "glLinkProgramARB" */,
        32125 /* "glLinkProgram" */,
        32125 /* "glLinkProgram" */,
    };
    return gl_provider_resolver(entrypoint_strings + 32139 /* "glLinkProgramARB" */,
                                providers, entrypoints);
}

static PFNGLLISTBASEPROC
epoxy_glListBase_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 32156 /* glListBase */);
}

static PFNGLLISTDRAWCOMMANDSSTATESCLIENTNVPROC
epoxy_glListDrawCommandsStatesClientNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_command_list, 32167 /* glListDrawCommandsStatesClientNV */);
}

static PFNGLLISTPARAMETERFSGIXPROC
epoxy_glListParameterfSGIX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIX_list_priority, 32200 /* glListParameterfSGIX */);
}

static PFNGLLISTPARAMETERFVSGIXPROC
epoxy_glListParameterfvSGIX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIX_list_priority, 32221 /* glListParameterfvSGIX */);
}

static PFNGLLISTPARAMETERISGIXPROC
epoxy_glListParameteriSGIX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIX_list_priority, 32243 /* glListParameteriSGIX */);
}

static PFNGLLISTPARAMETERIVSGIXPROC
epoxy_glListParameterivSGIX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIX_list_priority, 32264 /* glListParameterivSGIX */);
}

static PFNGLLOADIDENTITYPROC
epoxy_glLoadIdentity_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        32286 /* "glLoadIdentity" */,
        32286 /* "glLoadIdentity" */,
    };
    return gl_provider_resolver(entrypoint_strings + 32286 /* "glLoadIdentity" */,
                                providers, entrypoints);
}

static PFNGLLOADIDENTITYDEFORMATIONMAPSGIXPROC
epoxy_glLoadIdentityDeformationMapSGIX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIX_polynomial_ffd, 32301 /* glLoadIdentityDeformationMapSGIX */);
}

static PFNGLLOADMATRIXDPROC
epoxy_glLoadMatrixd_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 32334 /* glLoadMatrixd */);
}

static PFNGLLOADMATRIXFPROC
epoxy_glLoadMatrixf_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        32348 /* "glLoadMatrixf" */,
        32348 /* "glLoadMatrixf" */,
    };
    return gl_provider_resolver(entrypoint_strings + 32348 /* "glLoadMatrixf" */,
                                providers, entrypoints);
}

static PFNGLLOADMATRIXXPROC
epoxy_glLoadMatrixx_resolver(void)
{
    return gl_single_resolver(PROVIDER_OpenGL_ES_1_0, 32362 /* glLoadMatrixx */);
}

static PFNGLLOADMATRIXXOESPROC
epoxy_glLoadMatrixxOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 32376 /* glLoadMatrixxOES */);
}

static PFNGLLOADNAMEPROC
epoxy_glLoadName_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 32393 /* glLoadName */);
}

static PFNGLLOADPALETTEFROMMODELVIEWMATRIXOESPROC
epoxy_glLoadPaletteFromModelViewMatrixOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_matrix_palette, 32404 /* glLoadPaletteFromModelViewMatrixOES */);
}

static PFNGLLOADPROGRAMNVPROC
epoxy_glLoadProgramNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_program, 32440 /* glLoadProgramNV */);
}

static PFNGLLOADTRANSPOSEMATRIXDPROC
epoxy_glLoadTransposeMatrixd_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_GL_ARB_transpose_matrix,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        32456 /* "glLoadTransposeMatrixd" */,
        32479 /* "glLoadTransposeMatrixdARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 32456 /* "glLoadTransposeMatrixd" */,
                                providers, entrypoints);
}

static PFNGLLOADTRANSPOSEMATRIXDARBPROC
epoxy_glLoadTransposeMatrixdARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_transpose_matrix,
        PROVIDER_Desktop_OpenGL_1_3,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        32479 /* "glLoadTransposeMatrixdARB" */,
        32456 /* "glLoadTransposeMatrixd" */,
    };
    return gl_provider_resolver(entrypoint_strings + 32479 /* "glLoadTransposeMatrixdARB" */,
                                providers, entrypoints);
}

static PFNGLLOADTRANSPOSEMATRIXFPROC
epoxy_glLoadTransposeMatrixf_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_GL_ARB_transpose_matrix,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        32505 /* "glLoadTransposeMatrixf" */,
        32528 /* "glLoadTransposeMatrixfARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 32505 /* "glLoadTransposeMatrixf" */,
                                providers, entrypoints);
}

static PFNGLLOADTRANSPOSEMATRIXFARBPROC
epoxy_glLoadTransposeMatrixfARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_transpose_matrix,
        PROVIDER_Desktop_OpenGL_1_3,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        32528 /* "glLoadTransposeMatrixfARB" */,
        32505 /* "glLoadTransposeMatrixf" */,
    };
    return gl_provider_resolver(entrypoint_strings + 32528 /* "glLoadTransposeMatrixfARB" */,
                                providers, entrypoints);
}

static PFNGLLOADTRANSPOSEMATRIXXOESPROC
epoxy_glLoadTransposeMatrixxOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 32554 /* glLoadTransposeMatrixxOES */);
}

static PFNGLLOCKARRAYSEXTPROC
epoxy_glLockArraysEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_compiled_vertex_array, 32580 /* glLockArraysEXT */);
}

static PFNGLLOGICOPPROC
epoxy_glLogicOp_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        32596 /* "glLogicOp" */,
        32596 /* "glLogicOp" */,
    };
    return gl_provider_resolver(entrypoint_strings + 32596 /* "glLogicOp" */,
                                providers, entrypoints);
}

static PFNGLMAKEBUFFERNONRESIDENTNVPROC
epoxy_glMakeBufferNonResidentNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_shader_buffer_load, 32606 /* glMakeBufferNonResidentNV */);
}

static PFNGLMAKEBUFFERRESIDENTNVPROC
epoxy_glMakeBufferResidentNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_shader_buffer_load, 32632 /* glMakeBufferResidentNV */);
}

static PFNGLMAKEIMAGEHANDLENONRESIDENTARBPROC
epoxy_glMakeImageHandleNonResidentARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_bindless_texture, 32655 /* glMakeImageHandleNonResidentARB */);
}

static PFNGLMAKEIMAGEHANDLENONRESIDENTNVPROC
epoxy_glMakeImageHandleNonResidentNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_bindless_texture, 32687 /* glMakeImageHandleNonResidentNV */);
}

static PFNGLMAKEIMAGEHANDLERESIDENTARBPROC
epoxy_glMakeImageHandleResidentARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_bindless_texture, 32718 /* glMakeImageHandleResidentARB */);
}

static PFNGLMAKEIMAGEHANDLERESIDENTNVPROC
epoxy_glMakeImageHandleResidentNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_bindless_texture, 32747 /* glMakeImageHandleResidentNV */);
}

static PFNGLMAKENAMEDBUFFERNONRESIDENTNVPROC
epoxy_glMakeNamedBufferNonResidentNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_shader_buffer_load, 32775 /* glMakeNamedBufferNonResidentNV */);
}

static PFNGLMAKENAMEDBUFFERRESIDENTNVPROC
epoxy_glMakeNamedBufferResidentNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_shader_buffer_load, 32806 /* glMakeNamedBufferResidentNV */);
}

static PFNGLMAKETEXTUREHANDLENONRESIDENTARBPROC
epoxy_glMakeTextureHandleNonResidentARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_bindless_texture, 32834 /* glMakeTextureHandleNonResidentARB */);
}

static PFNGLMAKETEXTUREHANDLENONRESIDENTNVPROC
epoxy_glMakeTextureHandleNonResidentNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_bindless_texture, 32868 /* glMakeTextureHandleNonResidentNV */);
}

static PFNGLMAKETEXTUREHANDLERESIDENTARBPROC
epoxy_glMakeTextureHandleResidentARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_bindless_texture, 32901 /* glMakeTextureHandleResidentARB */);
}

static PFNGLMAKETEXTUREHANDLERESIDENTNVPROC
epoxy_glMakeTextureHandleResidentNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_bindless_texture, 32932 /* glMakeTextureHandleResidentNV */);
}

static PFNGLMAP1DPROC
epoxy_glMap1d_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 32962 /* glMap1d */);
}

static PFNGLMAP1FPROC
epoxy_glMap1f_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 32970 /* glMap1f */);
}

static PFNGLMAP1XOESPROC
epoxy_glMap1xOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 32978 /* glMap1xOES */);
}

static PFNGLMAP2DPROC
epoxy_glMap2d_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 32989 /* glMap2d */);
}

static PFNGLMAP2FPROC
epoxy_glMap2f_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 32997 /* glMap2f */);
}

static PFNGLMAP2XOESPROC
epoxy_glMap2xOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 33005 /* glMap2xOES */);
}

static PFNGLMAPBUFFERPROC
epoxy_glMapBuffer_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_5,
        PROVIDER_GL_ARB_vertex_buffer_object,
        PROVIDER_GL_OES_mapbuffer,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        33016 /* "glMapBuffer" */,
        33028 /* "glMapBufferARB" */,
        33043 /* "glMapBufferOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 33016 /* "glMapBuffer" */,
                                providers, entrypoints);
}

static PFNGLMAPBUFFERARBPROC
epoxy_glMapBufferARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_buffer_object,
        PROVIDER_Desktop_OpenGL_1_5,
        PROVIDER_GL_OES_mapbuffer,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        33028 /* "glMapBufferARB" */,
        33016 /* "glMapBuffer" */,
        33043 /* "glMapBufferOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 33028 /* "glMapBufferARB" */,
                                providers, entrypoints);
}

static PFNGLMAPBUFFEROESPROC
epoxy_glMapBufferOES_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_OES_mapbuffer,
        PROVIDER_Desktop_OpenGL_1_5,
        PROVIDER_GL_ARB_vertex_buffer_object,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        33043 /* "glMapBufferOES" */,
        33016 /* "glMapBuffer" */,
        33028 /* "glMapBufferARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 33043 /* "glMapBufferOES" */,
                                providers, entrypoints);
}

static PFNGLMAPBUFFERRANGEPROC
epoxy_glMapBufferRange_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_map_buffer_range,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_EXT_map_buffer_range,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        33058 /* "glMapBufferRange" */,
        33058 /* "glMapBufferRange" */,
        33058 /* "glMapBufferRange" */,
        33075 /* "glMapBufferRangeEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 33058 /* "glMapBufferRange" */,
                                providers, entrypoints);
}

static PFNGLMAPBUFFERRANGEEXTPROC
epoxy_glMapBufferRangeEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_map_buffer_range,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_map_buffer_range,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        33075 /* "glMapBufferRangeEXT" */,
        33058 /* "glMapBufferRange" */,
        33058 /* "glMapBufferRange" */,
        33058 /* "glMapBufferRange" */,
    };
    return gl_provider_resolver(entrypoint_strings + 33075 /* "glMapBufferRangeEXT" */,
                                providers, entrypoints);
}

static PFNGLMAPCONTROLPOINTSNVPROC
epoxy_glMapControlPointsNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_evaluators, 33095 /* glMapControlPointsNV */);
}

static PFNGLMAPGRID1DPROC
epoxy_glMapGrid1d_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 33116 /* glMapGrid1d */);
}

static PFNGLMAPGRID1FPROC
epoxy_glMapGrid1f_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 33128 /* glMapGrid1f */);
}

static PFNGLMAPGRID1XOESPROC
epoxy_glMapGrid1xOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 33140 /* glMapGrid1xOES */);
}

static PFNGLMAPGRID2DPROC
epoxy_glMapGrid2d_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 33155 /* glMapGrid2d */);
}

static PFNGLMAPGRID2FPROC
epoxy_glMapGrid2f_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 33167 /* glMapGrid2f */);
}

static PFNGLMAPGRID2XOESPROC
epoxy_glMapGrid2xOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 33179 /* glMapGrid2xOES */);
}

static PFNGLMAPNAMEDBUFFERPROC
epoxy_glMapNamedBuffer_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        33194 /* "glMapNamedBuffer" */,
        33194 /* "glMapNamedBuffer" */,
    };
    return gl_provider_resolver(entrypoint_strings + 33194 /* "glMapNamedBuffer" */,
                                providers, entrypoints);
}

static PFNGLMAPNAMEDBUFFEREXTPROC
epoxy_glMapNamedBufferEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 33211 /* glMapNamedBufferEXT */);
}

static PFNGLMAPNAMEDBUFFERRANGEPROC
epoxy_glMapNamedBufferRange_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        33231 /* "glMapNamedBufferRange" */,
        33231 /* "glMapNamedBufferRange" */,
    };
    return gl_provider_resolver(entrypoint_strings + 33231 /* "glMapNamedBufferRange" */,
                                providers, entrypoints);
}

static PFNGLMAPNAMEDBUFFERRANGEEXTPROC
epoxy_glMapNamedBufferRangeEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 33253 /* glMapNamedBufferRangeEXT */);
}

static PFNGLMAPOBJECTBUFFERATIPROC
epoxy_glMapObjectBufferATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_map_object_buffer, 33278 /* glMapObjectBufferATI */);
}

static PFNGLMAPPARAMETERFVNVPROC
epoxy_glMapParameterfvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_evaluators, 33299 /* glMapParameterfvNV */);
}

static PFNGLMAPPARAMETERIVNVPROC
epoxy_glMapParameterivNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_evaluators, 33318 /* glMapParameterivNV */);
}

static PFNGLMAPTEXTURE2DINTELPROC
epoxy_glMapTexture2DINTEL_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_INTEL_map_texture, 33337 /* glMapTexture2DINTEL */);
}

static PFNGLMAPVERTEXATTRIB1DAPPLEPROC
epoxy_glMapVertexAttrib1dAPPLE_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_APPLE_vertex_program_evaluators, 33357 /* glMapVertexAttrib1dAPPLE */);
}

static PFNGLMAPVERTEXATTRIB1FAPPLEPROC
epoxy_glMapVertexAttrib1fAPPLE_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_APPLE_vertex_program_evaluators, 33382 /* glMapVertexAttrib1fAPPLE */);
}

static PFNGLMAPVERTEXATTRIB2DAPPLEPROC
epoxy_glMapVertexAttrib2dAPPLE_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_APPLE_vertex_program_evaluators, 33407 /* glMapVertexAttrib2dAPPLE */);
}

static PFNGLMAPVERTEXATTRIB2FAPPLEPROC
epoxy_glMapVertexAttrib2fAPPLE_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_APPLE_vertex_program_evaluators, 33432 /* glMapVertexAttrib2fAPPLE */);
}

static PFNGLMATERIALFPROC
epoxy_glMaterialf_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        33457 /* "glMaterialf" */,
        33457 /* "glMaterialf" */,
    };
    return gl_provider_resolver(entrypoint_strings + 33457 /* "glMaterialf" */,
                                providers, entrypoints);
}

static PFNGLMATERIALFVPROC
epoxy_glMaterialfv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        33469 /* "glMaterialfv" */,
        33469 /* "glMaterialfv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 33469 /* "glMaterialfv" */,
                                providers, entrypoints);
}

static PFNGLMATERIALIPROC
epoxy_glMateriali_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 33482 /* glMateriali */);
}

static PFNGLMATERIALIVPROC
epoxy_glMaterialiv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 33494 /* glMaterialiv */);
}

static PFNGLMATERIALXPROC
epoxy_glMaterialx_resolver(void)
{
    return gl_single_resolver(PROVIDER_OpenGL_ES_1_0, 33507 /* glMaterialx */);
}

static PFNGLMATERIALXOESPROC
epoxy_glMaterialxOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 33519 /* glMaterialxOES */);
}

static PFNGLMATERIALXVPROC
epoxy_glMaterialxv_resolver(void)
{
    return gl_single_resolver(PROVIDER_OpenGL_ES_1_0, 33534 /* glMaterialxv */);
}

static PFNGLMATERIALXVOESPROC
epoxy_glMaterialxvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 33547 /* glMaterialxvOES */);
}

static PFNGLMATRIXFRUSTUMEXTPROC
epoxy_glMatrixFrustumEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_NV_path_rendering,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        33563 /* "glMatrixFrustumEXT" */,
        33563 /* "glMatrixFrustumEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 33563 /* "glMatrixFrustumEXT" */,
                                providers, entrypoints);
}

static PFNGLMATRIXINDEXPOINTERARBPROC
epoxy_glMatrixIndexPointerARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_matrix_palette, 33582 /* glMatrixIndexPointerARB */);
}

static PFNGLMATRIXINDEXPOINTEROESPROC
epoxy_glMatrixIndexPointerOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_matrix_palette, 33606 /* glMatrixIndexPointerOES */);
}

static PFNGLMATRIXINDEXUBVARBPROC
epoxy_glMatrixIndexubvARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_matrix_palette, 33630 /* glMatrixIndexubvARB */);
}

static PFNGLMATRIXINDEXUIVARBPROC
epoxy_glMatrixIndexuivARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_matrix_palette, 33650 /* glMatrixIndexuivARB */);
}

static PFNGLMATRIXINDEXUSVARBPROC
epoxy_glMatrixIndexusvARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_matrix_palette, 33670 /* glMatrixIndexusvARB */);
}

static PFNGLMATRIXLOAD3X2FNVPROC
epoxy_glMatrixLoad3x2fNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 33690 /* glMatrixLoad3x2fNV */);
}

static PFNGLMATRIXLOAD3X3FNVPROC
epoxy_glMatrixLoad3x3fNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 33709 /* glMatrixLoad3x3fNV */);
}

static PFNGLMATRIXLOADIDENTITYEXTPROC
epoxy_glMatrixLoadIdentityEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_NV_path_rendering,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        33728 /* "glMatrixLoadIdentityEXT" */,
        33728 /* "glMatrixLoadIdentityEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 33728 /* "glMatrixLoadIdentityEXT" */,
                                providers, entrypoints);
}

static PFNGLMATRIXLOADTRANSPOSE3X3FNVPROC
epoxy_glMatrixLoadTranspose3x3fNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 33752 /* glMatrixLoadTranspose3x3fNV */);
}

static PFNGLMATRIXLOADTRANSPOSEDEXTPROC
epoxy_glMatrixLoadTransposedEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_NV_path_rendering,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        33780 /* "glMatrixLoadTransposedEXT" */,
        33780 /* "glMatrixLoadTransposedEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 33780 /* "glMatrixLoadTransposedEXT" */,
                                providers, entrypoints);
}

static PFNGLMATRIXLOADTRANSPOSEFEXTPROC
epoxy_glMatrixLoadTransposefEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_NV_path_rendering,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        33806 /* "glMatrixLoadTransposefEXT" */,
        33806 /* "glMatrixLoadTransposefEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 33806 /* "glMatrixLoadTransposefEXT" */,
                                providers, entrypoints);
}

static PFNGLMATRIXLOADDEXTPROC
epoxy_glMatrixLoaddEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_NV_path_rendering,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        33832 /* "glMatrixLoaddEXT" */,
        33832 /* "glMatrixLoaddEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 33832 /* "glMatrixLoaddEXT" */,
                                providers, entrypoints);
}

static PFNGLMATRIXLOADFEXTPROC
epoxy_glMatrixLoadfEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_NV_path_rendering,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        33849 /* "glMatrixLoadfEXT" */,
        33849 /* "glMatrixLoadfEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 33849 /* "glMatrixLoadfEXT" */,
                                providers, entrypoints);
}

static PFNGLMATRIXMODEPROC
epoxy_glMatrixMode_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        33866 /* "glMatrixMode" */,
        33866 /* "glMatrixMode" */,
    };
    return gl_provider_resolver(entrypoint_strings + 33866 /* "glMatrixMode" */,
                                providers, entrypoints);
}

static PFNGLMATRIXMULT3X2FNVPROC
epoxy_glMatrixMult3x2fNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 33879 /* glMatrixMult3x2fNV */);
}

static PFNGLMATRIXMULT3X3FNVPROC
epoxy_glMatrixMult3x3fNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 33898 /* glMatrixMult3x3fNV */);
}

static PFNGLMATRIXMULTTRANSPOSE3X3FNVPROC
epoxy_glMatrixMultTranspose3x3fNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 33917 /* glMatrixMultTranspose3x3fNV */);
}

static PFNGLMATRIXMULTTRANSPOSEDEXTPROC
epoxy_glMatrixMultTransposedEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_NV_path_rendering,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        33945 /* "glMatrixMultTransposedEXT" */,
        33945 /* "glMatrixMultTransposedEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 33945 /* "glMatrixMultTransposedEXT" */,
                                providers, entrypoints);
}

static PFNGLMATRIXMULTTRANSPOSEFEXTPROC
epoxy_glMatrixMultTransposefEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_NV_path_rendering,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        33971 /* "glMatrixMultTransposefEXT" */,
        33971 /* "glMatrixMultTransposefEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 33971 /* "glMatrixMultTransposefEXT" */,
                                providers, entrypoints);
}

static PFNGLMATRIXMULTDEXTPROC
epoxy_glMatrixMultdEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_NV_path_rendering,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        33997 /* "glMatrixMultdEXT" */,
        33997 /* "glMatrixMultdEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 33997 /* "glMatrixMultdEXT" */,
                                providers, entrypoints);
}

static PFNGLMATRIXMULTFEXTPROC
epoxy_glMatrixMultfEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_NV_path_rendering,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        34014 /* "glMatrixMultfEXT" */,
        34014 /* "glMatrixMultfEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 34014 /* "glMatrixMultfEXT" */,
                                providers, entrypoints);
}

static PFNGLMATRIXORTHOEXTPROC
epoxy_glMatrixOrthoEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_NV_path_rendering,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        34031 /* "glMatrixOrthoEXT" */,
        34031 /* "glMatrixOrthoEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 34031 /* "glMatrixOrthoEXT" */,
                                providers, entrypoints);
}

static PFNGLMATRIXPOPEXTPROC
epoxy_glMatrixPopEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_NV_path_rendering,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        34048 /* "glMatrixPopEXT" */,
        34048 /* "glMatrixPopEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 34048 /* "glMatrixPopEXT" */,
                                providers, entrypoints);
}

static PFNGLMATRIXPUSHEXTPROC
epoxy_glMatrixPushEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_NV_path_rendering,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        34063 /* "glMatrixPushEXT" */,
        34063 /* "glMatrixPushEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 34063 /* "glMatrixPushEXT" */,
                                providers, entrypoints);
}

static PFNGLMATRIXROTATEDEXTPROC
epoxy_glMatrixRotatedEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_NV_path_rendering,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        34079 /* "glMatrixRotatedEXT" */,
        34079 /* "glMatrixRotatedEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 34079 /* "glMatrixRotatedEXT" */,
                                providers, entrypoints);
}

static PFNGLMATRIXROTATEFEXTPROC
epoxy_glMatrixRotatefEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_NV_path_rendering,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        34098 /* "glMatrixRotatefEXT" */,
        34098 /* "glMatrixRotatefEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 34098 /* "glMatrixRotatefEXT" */,
                                providers, entrypoints);
}

static PFNGLMATRIXSCALEDEXTPROC
epoxy_glMatrixScaledEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_NV_path_rendering,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        34117 /* "glMatrixScaledEXT" */,
        34117 /* "glMatrixScaledEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 34117 /* "glMatrixScaledEXT" */,
                                providers, entrypoints);
}

static PFNGLMATRIXSCALEFEXTPROC
epoxy_glMatrixScalefEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_NV_path_rendering,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        34135 /* "glMatrixScalefEXT" */,
        34135 /* "glMatrixScalefEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 34135 /* "glMatrixScalefEXT" */,
                                providers, entrypoints);
}

static PFNGLMATRIXTRANSLATEDEXTPROC
epoxy_glMatrixTranslatedEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_NV_path_rendering,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        34153 /* "glMatrixTranslatedEXT" */,
        34153 /* "glMatrixTranslatedEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 34153 /* "glMatrixTranslatedEXT" */,
                                providers, entrypoints);
}

static PFNGLMATRIXTRANSLATEFEXTPROC
epoxy_glMatrixTranslatefEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_NV_path_rendering,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        34175 /* "glMatrixTranslatefEXT" */,
        34175 /* "glMatrixTranslatefEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 34175 /* "glMatrixTranslatefEXT" */,
                                providers, entrypoints);
}

static PFNGLMAXSHADERCOMPILERTHREADSARBPROC
epoxy_glMaxShaderCompilerThreadsARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_parallel_shader_compile,
        PROVIDER_GL_KHR_parallel_shader_compile,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        34197 /* "glMaxShaderCompilerThreadsARB" */,
        34227 /* "glMaxShaderCompilerThreadsKHR" */,
    };
    return gl_provider_resolver(entrypoint_strings + 34197 /* "glMaxShaderCompilerThreadsARB" */,
                                providers, entrypoints);
}

static PFNGLMAXSHADERCOMPILERTHREADSKHRPROC
epoxy_glMaxShaderCompilerThreadsKHR_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_KHR_parallel_shader_compile,
        PROVIDER_GL_ARB_parallel_shader_compile,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        34227 /* "glMaxShaderCompilerThreadsKHR" */,
        34197 /* "glMaxShaderCompilerThreadsARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 34227 /* "glMaxShaderCompilerThreadsKHR" */,
                                providers, entrypoints);
}

static PFNGLMEMORYBARRIERPROC
epoxy_glMemoryBarrier_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_2,
        PROVIDER_GL_ARB_shader_image_load_store,
        PROVIDER_OpenGL_ES_3_1,
        PROVIDER_GL_EXT_shader_image_load_store,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        34257 /* "glMemoryBarrier" */,
        34257 /* "glMemoryBarrier" */,
        34257 /* "glMemoryBarrier" */,
        34297 /* "glMemoryBarrierEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 34257 /* "glMemoryBarrier" */,
                                providers, entrypoints);
}

static PFNGLMEMORYBARRIERBYREGIONPROC
epoxy_glMemoryBarrierByRegion_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_ES3_1_compatibility,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        34273 /* "glMemoryBarrierByRegion" */,
        34273 /* "glMemoryBarrierByRegion" */,
        34273 /* "glMemoryBarrierByRegion" */,
    };
    return gl_provider_resolver(entrypoint_strings + 34273 /* "glMemoryBarrierByRegion" */,
                                providers, entrypoints);
}

static PFNGLMEMORYBARRIEREXTPROC
epoxy_glMemoryBarrierEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_shader_image_load_store,
        PROVIDER_Desktop_OpenGL_4_2,
        PROVIDER_GL_ARB_shader_image_load_store,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        34297 /* "glMemoryBarrierEXT" */,
        34257 /* "glMemoryBarrier" */,
        34257 /* "glMemoryBarrier" */,
        34257 /* "glMemoryBarrier" */,
    };
    return gl_provider_resolver(entrypoint_strings + 34297 /* "glMemoryBarrierEXT" */,
                                providers, entrypoints);
}

static PFNGLMEMORYOBJECTPARAMETERIVEXTPROC
epoxy_glMemoryObjectParameterivEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_memory_object, 34316 /* glMemoryObjectParameterivEXT */);
}

static PFNGLMINSAMPLESHADINGPROC
epoxy_glMinSampleShading_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_ARB_sample_shading,
        PROVIDER_GL_OES_sample_shading,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        34345 /* "glMinSampleShading" */,
        34345 /* "glMinSampleShading" */,
        34364 /* "glMinSampleShadingARB" */,
        34386 /* "glMinSampleShadingOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 34345 /* "glMinSampleShading" */,
                                providers, entrypoints);
}

static PFNGLMINSAMPLESHADINGARBPROC
epoxy_glMinSampleShadingARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_sample_shading,
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_OES_sample_shading,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        34364 /* "glMinSampleShadingARB" */,
        34345 /* "glMinSampleShading" */,
        34345 /* "glMinSampleShading" */,
        34386 /* "glMinSampleShadingOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 34364 /* "glMinSampleShadingARB" */,
                                providers, entrypoints);
}

static PFNGLMINSAMPLESHADINGOESPROC
epoxy_glMinSampleShadingOES_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_OES_sample_shading,
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_ARB_sample_shading,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        34386 /* "glMinSampleShadingOES" */,
        34345 /* "glMinSampleShading" */,
        34345 /* "glMinSampleShading" */,
        34364 /* "glMinSampleShadingARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 34386 /* "glMinSampleShadingOES" */,
                                providers, entrypoints);
}

static PFNGLMINMAXPROC
epoxy_glMinmax_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_imaging,
        PROVIDER_GL_EXT_histogram,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        34408 /* "glMinmax" */,
        34417 /* "glMinmaxEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 34408 /* "glMinmax" */,
                                providers, entrypoints);
}

static PFNGLMINMAXEXTPROC
epoxy_glMinmaxEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_histogram,
        PROVIDER_GL_ARB_imaging,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        34417 /* "glMinmaxEXT" */,
        34408 /* "glMinmax" */,
    };
    return gl_provider_resolver(entrypoint_strings + 34417 /* "glMinmaxEXT" */,
                                providers, entrypoints);
}

static PFNGLMULTMATRIXDPROC
epoxy_glMultMatrixd_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 34429 /* glMultMatrixd */);
}

static PFNGLMULTMATRIXFPROC
epoxy_glMultMatrixf_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        34443 /* "glMultMatrixf" */,
        34443 /* "glMultMatrixf" */,
    };
    return gl_provider_resolver(entrypoint_strings + 34443 /* "glMultMatrixf" */,
                                providers, entrypoints);
}

static PFNGLMULTMATRIXXPROC
epoxy_glMultMatrixx_resolver(void)
{
    return gl_single_resolver(PROVIDER_OpenGL_ES_1_0, 34457 /* glMultMatrixx */);
}

static PFNGLMULTMATRIXXOESPROC
epoxy_glMultMatrixxOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 34471 /* glMultMatrixxOES */);
}

static PFNGLMULTTRANSPOSEMATRIXDPROC
epoxy_glMultTransposeMatrixd_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_GL_ARB_transpose_matrix,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        34488 /* "glMultTransposeMatrixd" */,
        34511 /* "glMultTransposeMatrixdARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 34488 /* "glMultTransposeMatrixd" */,
                                providers, entrypoints);
}

static PFNGLMULTTRANSPOSEMATRIXDARBPROC
epoxy_glMultTransposeMatrixdARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_transpose_matrix,
        PROVIDER_Desktop_OpenGL_1_3,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        34511 /* "glMultTransposeMatrixdARB" */,
        34488 /* "glMultTransposeMatrixd" */,
    };
    return gl_provider_resolver(entrypoint_strings + 34511 /* "glMultTransposeMatrixdARB" */,
                                providers, entrypoints);
}

static PFNGLMULTTRANSPOSEMATRIXFPROC
epoxy_glMultTransposeMatrixf_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_GL_ARB_transpose_matrix,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        34537 /* "glMultTransposeMatrixf" */,
        34560 /* "glMultTransposeMatrixfARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 34537 /* "glMultTransposeMatrixf" */,
                                providers, entrypoints);
}

static PFNGLMULTTRANSPOSEMATRIXFARBPROC
epoxy_glMultTransposeMatrixfARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_transpose_matrix,
        PROVIDER_Desktop_OpenGL_1_3,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        34560 /* "glMultTransposeMatrixfARB" */,
        34537 /* "glMultTransposeMatrixf" */,
    };
    return gl_provider_resolver(entrypoint_strings + 34560 /* "glMultTransposeMatrixfARB" */,
                                providers, entrypoints);
}

static PFNGLMULTTRANSPOSEMATRIXXOESPROC
epoxy_glMultTransposeMatrixxOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 34586 /* glMultTransposeMatrixxOES */);
}

static PFNGLMULTIDRAWARRAYSPROC
epoxy_glMultiDrawArrays_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_EXT_multi_draw_arrays,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        34612 /* "glMultiDrawArrays" */,
        34630 /* "glMultiDrawArraysEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 34612 /* "glMultiDrawArrays" */,
                                providers, entrypoints);
}

static PFNGLMULTIDRAWARRAYSEXTPROC
epoxy_glMultiDrawArraysEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_multi_draw_arrays,
        PROVIDER_Desktop_OpenGL_1_4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        34630 /* "glMultiDrawArraysEXT" */,
        34612 /* "glMultiDrawArrays" */,
    };
    return gl_provider_resolver(entrypoint_strings + 34630 /* "glMultiDrawArraysEXT" */,
                                providers, entrypoints);
}

static PFNGLMULTIDRAWARRAYSINDIRECTPROC
epoxy_glMultiDrawArraysIndirect_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_ARB_multi_draw_indirect,
        PROVIDER_GL_AMD_multi_draw_indirect,
        PROVIDER_GL_EXT_multi_draw_indirect,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        34651 /* "glMultiDrawArraysIndirect" */,
        34651 /* "glMultiDrawArraysIndirect" */,
        34677 /* "glMultiDrawArraysIndirectAMD" */,
        34848 /* "glMultiDrawArraysIndirectEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 34651 /* "glMultiDrawArraysIndirect" */,
                                providers, entrypoints);
}

static PFNGLMULTIDRAWARRAYSINDIRECTAMDPROC
epoxy_glMultiDrawArraysIndirectAMD_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_AMD_multi_draw_indirect,
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_ARB_multi_draw_indirect,
        PROVIDER_GL_EXT_multi_draw_indirect,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        34677 /* "glMultiDrawArraysIndirectAMD" */,
        34651 /* "glMultiDrawArraysIndirect" */,
        34651 /* "glMultiDrawArraysIndirect" */,
        34848 /* "glMultiDrawArraysIndirectEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 34677 /* "glMultiDrawArraysIndirectAMD" */,
                                providers, entrypoints);
}

static PFNGLMULTIDRAWARRAYSINDIRECTBINDLESSCOUNTNVPROC
epoxy_glMultiDrawArraysIndirectBindlessCountNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_bindless_multi_draw_indirect_count, 34706 /* glMultiDrawArraysIndirectBindlessCountNV */);
}

static PFNGLMULTIDRAWARRAYSINDIRECTBINDLESSNVPROC
epoxy_glMultiDrawArraysIndirectBindlessNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_bindless_multi_draw_indirect, 34747 /* glMultiDrawArraysIndirectBindlessNV */);
}

static PFNGLMULTIDRAWARRAYSINDIRECTCOUNTPROC
epoxy_glMultiDrawArraysIndirectCount_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_6,
        PROVIDER_GL_ARB_indirect_parameters,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        34783 /* "glMultiDrawArraysIndirectCount" */,
        34814 /* "glMultiDrawArraysIndirectCountARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 34783 /* "glMultiDrawArraysIndirectCount" */,
                                providers, entrypoints);
}

static PFNGLMULTIDRAWARRAYSINDIRECTCOUNTARBPROC
epoxy_glMultiDrawArraysIndirectCountARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_indirect_parameters,
        PROVIDER_Desktop_OpenGL_4_6,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        34814 /* "glMultiDrawArraysIndirectCountARB" */,
        34783 /* "glMultiDrawArraysIndirectCount" */,
    };
    return gl_provider_resolver(entrypoint_strings + 34814 /* "glMultiDrawArraysIndirectCountARB" */,
                                providers, entrypoints);
}

static PFNGLMULTIDRAWARRAYSINDIRECTEXTPROC
epoxy_glMultiDrawArraysIndirectEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_multi_draw_indirect,
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_ARB_multi_draw_indirect,
        PROVIDER_GL_AMD_multi_draw_indirect,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        34848 /* "glMultiDrawArraysIndirectEXT" */,
        34651 /* "glMultiDrawArraysIndirect" */,
        34651 /* "glMultiDrawArraysIndirect" */,
        34677 /* "glMultiDrawArraysIndirectAMD" */,
    };
    return gl_provider_resolver(entrypoint_strings + 34848 /* "glMultiDrawArraysIndirectEXT" */,
                                providers, entrypoints);
}

static PFNGLMULTIDRAWELEMENTARRAYAPPLEPROC
epoxy_glMultiDrawElementArrayAPPLE_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_APPLE_element_array, 34877 /* glMultiDrawElementArrayAPPLE */);
}

static PFNGLMULTIDRAWELEMENTSPROC
epoxy_glMultiDrawElements_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_EXT_multi_draw_arrays,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        34906 /* "glMultiDrawElements" */,
        34989 /* "glMultiDrawElementsEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 34906 /* "glMultiDrawElements" */,
                                providers, entrypoints);
}

static PFNGLMULTIDRAWELEMENTSBASEVERTEXPROC
epoxy_glMultiDrawElementsBaseVertex_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_2,
        PROVIDER_GL_ARB_draw_elements_base_vertex,
        PROVIDER_GL_EXT_draw_elements_base_vertex,
        PROVIDER_GL_OES_draw_elements_base_vertex,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        34926 /* "glMultiDrawElementsBaseVertex" */,
        34926 /* "glMultiDrawElementsBaseVertex" */,
        34956 /* "glMultiDrawElementsBaseVertexEXT" */,
        34956 /* "glMultiDrawElementsBaseVertexEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 34926 /* "glMultiDrawElementsBaseVertex" */,
                                providers, entrypoints);
}

static PFNGLMULTIDRAWELEMENTSBASEVERTEXEXTPROC
epoxy_glMultiDrawElementsBaseVertexEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_draw_elements_base_vertex,
        PROVIDER_GL_OES_draw_elements_base_vertex,
        PROVIDER_Desktop_OpenGL_3_2,
        PROVIDER_GL_ARB_draw_elements_base_vertex,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        34956 /* "glMultiDrawElementsBaseVertexEXT" */,
        34956 /* "glMultiDrawElementsBaseVertexEXT" */,
        34926 /* "glMultiDrawElementsBaseVertex" */,
        34926 /* "glMultiDrawElementsBaseVertex" */,
    };
    return gl_provider_resolver(entrypoint_strings + 34956 /* "glMultiDrawElementsBaseVertexEXT" */,
                                providers, entrypoints);
}

static PFNGLMULTIDRAWELEMENTSEXTPROC
epoxy_glMultiDrawElementsEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_multi_draw_arrays,
        PROVIDER_Desktop_OpenGL_1_4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        34989 /* "glMultiDrawElementsEXT" */,
        34906 /* "glMultiDrawElements" */,
    };
    return gl_provider_resolver(entrypoint_strings + 34989 /* "glMultiDrawElementsEXT" */,
                                providers, entrypoints);
}

static PFNGLMULTIDRAWELEMENTSINDIRECTPROC
epoxy_glMultiDrawElementsIndirect_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_ARB_multi_draw_indirect,
        PROVIDER_GL_AMD_multi_draw_indirect,
        PROVIDER_GL_EXT_multi_draw_indirect,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        35012 /* "glMultiDrawElementsIndirect" */,
        35012 /* "glMultiDrawElementsIndirect" */,
        35040 /* "glMultiDrawElementsIndirectAMD" */,
        35221 /* "glMultiDrawElementsIndirectEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 35012 /* "glMultiDrawElementsIndirect" */,
                                providers, entrypoints);
}

static PFNGLMULTIDRAWELEMENTSINDIRECTAMDPROC
epoxy_glMultiDrawElementsIndirectAMD_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_AMD_multi_draw_indirect,
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_ARB_multi_draw_indirect,
        PROVIDER_GL_EXT_multi_draw_indirect,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        35040 /* "glMultiDrawElementsIndirectAMD" */,
        35012 /* "glMultiDrawElementsIndirect" */,
        35012 /* "glMultiDrawElementsIndirect" */,
        35221 /* "glMultiDrawElementsIndirectEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 35040 /* "glMultiDrawElementsIndirectAMD" */,
                                providers, entrypoints);
}

static PFNGLMULTIDRAWELEMENTSINDIRECTBINDLESSCOUNTNVPROC
epoxy_glMultiDrawElementsIndirectBindlessCountNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_bindless_multi_draw_indirect_count, 35071 /* glMultiDrawElementsIndirectBindlessCountNV */);
}

static PFNGLMULTIDRAWELEMENTSINDIRECTBINDLESSNVPROC
epoxy_glMultiDrawElementsIndirectBindlessNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_bindless_multi_draw_indirect, 35114 /* glMultiDrawElementsIndirectBindlessNV */);
}

static PFNGLMULTIDRAWELEMENTSINDIRECTCOUNTPROC
epoxy_glMultiDrawElementsIndirectCount_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_6,
        PROVIDER_GL_ARB_indirect_parameters,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        35152 /* "glMultiDrawElementsIndirectCount" */,
        35185 /* "glMultiDrawElementsIndirectCountARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 35152 /* "glMultiDrawElementsIndirectCount" */,
                                providers, entrypoints);
}

static PFNGLMULTIDRAWELEMENTSINDIRECTCOUNTARBPROC
epoxy_glMultiDrawElementsIndirectCountARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_indirect_parameters,
        PROVIDER_Desktop_OpenGL_4_6,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        35185 /* "glMultiDrawElementsIndirectCountARB" */,
        35152 /* "glMultiDrawElementsIndirectCount" */,
    };
    return gl_provider_resolver(entrypoint_strings + 35185 /* "glMultiDrawElementsIndirectCountARB" */,
                                providers, entrypoints);
}

static PFNGLMULTIDRAWELEMENTSINDIRECTEXTPROC
epoxy_glMultiDrawElementsIndirectEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_multi_draw_indirect,
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_ARB_multi_draw_indirect,
        PROVIDER_GL_AMD_multi_draw_indirect,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        35221 /* "glMultiDrawElementsIndirectEXT" */,
        35012 /* "glMultiDrawElementsIndirect" */,
        35012 /* "glMultiDrawElementsIndirect" */,
        35040 /* "glMultiDrawElementsIndirectAMD" */,
    };
    return gl_provider_resolver(entrypoint_strings + 35221 /* "glMultiDrawElementsIndirectEXT" */,
                                providers, entrypoints);
}

static PFNGLMULTIDRAWMESHTASKSINDIRECTCOUNTNVPROC
epoxy_glMultiDrawMeshTasksIndirectCountNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_mesh_shader, 35252 /* glMultiDrawMeshTasksIndirectCountNV */);
}

static PFNGLMULTIDRAWMESHTASKSINDIRECTNVPROC
epoxy_glMultiDrawMeshTasksIndirectNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_mesh_shader, 35288 /* glMultiDrawMeshTasksIndirectNV */);
}

static PFNGLMULTIDRAWRANGEELEMENTARRAYAPPLEPROC
epoxy_glMultiDrawRangeElementArrayAPPLE_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_APPLE_element_array, 35319 /* glMultiDrawRangeElementArrayAPPLE */);
}

static PFNGLMULTIMODEDRAWARRAYSIBMPROC
epoxy_glMultiModeDrawArraysIBM_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_IBM_multimode_draw_arrays, 35353 /* glMultiModeDrawArraysIBM */);
}

static PFNGLMULTIMODEDRAWELEMENTSIBMPROC
epoxy_glMultiModeDrawElementsIBM_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_IBM_multimode_draw_arrays, 35378 /* glMultiModeDrawElementsIBM */);
}

static PFNGLMULTITEXBUFFEREXTPROC
epoxy_glMultiTexBufferEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 35405 /* glMultiTexBufferEXT */);
}

static PFNGLMULTITEXCOORD1BOESPROC
epoxy_glMultiTexCoord1bOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_byte_coordinates, 35425 /* glMultiTexCoord1bOES */);
}

static PFNGLMULTITEXCOORD1BVOESPROC
epoxy_glMultiTexCoord1bvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_byte_coordinates, 35446 /* glMultiTexCoord1bvOES */);
}

static PFNGLMULTITEXCOORD1DPROC
epoxy_glMultiTexCoord1d_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_GL_ARB_multitexture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        35468 /* "glMultiTexCoord1d" */,
        35486 /* "glMultiTexCoord1dARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 35468 /* "glMultiTexCoord1d" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD1DARBPROC
epoxy_glMultiTexCoord1dARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_multitexture,
        PROVIDER_Desktop_OpenGL_1_3,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        35486 /* "glMultiTexCoord1dARB" */,
        35468 /* "glMultiTexCoord1d" */,
    };
    return gl_provider_resolver(entrypoint_strings + 35486 /* "glMultiTexCoord1dARB" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD1DVPROC
epoxy_glMultiTexCoord1dv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_GL_ARB_multitexture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        35507 /* "glMultiTexCoord1dv" */,
        35526 /* "glMultiTexCoord1dvARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 35507 /* "glMultiTexCoord1dv" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD1DVARBPROC
epoxy_glMultiTexCoord1dvARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_multitexture,
        PROVIDER_Desktop_OpenGL_1_3,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        35526 /* "glMultiTexCoord1dvARB" */,
        35507 /* "glMultiTexCoord1dv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 35526 /* "glMultiTexCoord1dvARB" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD1FPROC
epoxy_glMultiTexCoord1f_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_GL_ARB_multitexture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        35548 /* "glMultiTexCoord1f" */,
        35566 /* "glMultiTexCoord1fARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 35548 /* "glMultiTexCoord1f" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD1FARBPROC
epoxy_glMultiTexCoord1fARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_multitexture,
        PROVIDER_Desktop_OpenGL_1_3,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        35566 /* "glMultiTexCoord1fARB" */,
        35548 /* "glMultiTexCoord1f" */,
    };
    return gl_provider_resolver(entrypoint_strings + 35566 /* "glMultiTexCoord1fARB" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD1FVPROC
epoxy_glMultiTexCoord1fv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_GL_ARB_multitexture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        35587 /* "glMultiTexCoord1fv" */,
        35606 /* "glMultiTexCoord1fvARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 35587 /* "glMultiTexCoord1fv" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD1FVARBPROC
epoxy_glMultiTexCoord1fvARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_multitexture,
        PROVIDER_Desktop_OpenGL_1_3,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        35606 /* "glMultiTexCoord1fvARB" */,
        35587 /* "glMultiTexCoord1fv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 35606 /* "glMultiTexCoord1fvARB" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD1HNVPROC
epoxy_glMultiTexCoord1hNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_half_float, 35628 /* glMultiTexCoord1hNV */);
}

static PFNGLMULTITEXCOORD1HVNVPROC
epoxy_glMultiTexCoord1hvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_half_float, 35648 /* glMultiTexCoord1hvNV */);
}

static PFNGLMULTITEXCOORD1IPROC
epoxy_glMultiTexCoord1i_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_GL_ARB_multitexture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        35669 /* "glMultiTexCoord1i" */,
        35687 /* "glMultiTexCoord1iARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 35669 /* "glMultiTexCoord1i" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD1IARBPROC
epoxy_glMultiTexCoord1iARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_multitexture,
        PROVIDER_Desktop_OpenGL_1_3,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        35687 /* "glMultiTexCoord1iARB" */,
        35669 /* "glMultiTexCoord1i" */,
    };
    return gl_provider_resolver(entrypoint_strings + 35687 /* "glMultiTexCoord1iARB" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD1IVPROC
epoxy_glMultiTexCoord1iv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_GL_ARB_multitexture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        35708 /* "glMultiTexCoord1iv" */,
        35727 /* "glMultiTexCoord1ivARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 35708 /* "glMultiTexCoord1iv" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD1IVARBPROC
epoxy_glMultiTexCoord1ivARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_multitexture,
        PROVIDER_Desktop_OpenGL_1_3,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        35727 /* "glMultiTexCoord1ivARB" */,
        35708 /* "glMultiTexCoord1iv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 35727 /* "glMultiTexCoord1ivARB" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD1SPROC
epoxy_glMultiTexCoord1s_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_GL_ARB_multitexture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        35749 /* "glMultiTexCoord1s" */,
        35767 /* "glMultiTexCoord1sARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 35749 /* "glMultiTexCoord1s" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD1SARBPROC
epoxy_glMultiTexCoord1sARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_multitexture,
        PROVIDER_Desktop_OpenGL_1_3,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        35767 /* "glMultiTexCoord1sARB" */,
        35749 /* "glMultiTexCoord1s" */,
    };
    return gl_provider_resolver(entrypoint_strings + 35767 /* "glMultiTexCoord1sARB" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD1SVPROC
epoxy_glMultiTexCoord1sv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_GL_ARB_multitexture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        35788 /* "glMultiTexCoord1sv" */,
        35807 /* "glMultiTexCoord1svARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 35788 /* "glMultiTexCoord1sv" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD1SVARBPROC
epoxy_glMultiTexCoord1svARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_multitexture,
        PROVIDER_Desktop_OpenGL_1_3,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        35807 /* "glMultiTexCoord1svARB" */,
        35788 /* "glMultiTexCoord1sv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 35807 /* "glMultiTexCoord1svARB" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD1XOESPROC
epoxy_glMultiTexCoord1xOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 35829 /* glMultiTexCoord1xOES */);
}

static PFNGLMULTITEXCOORD1XVOESPROC
epoxy_glMultiTexCoord1xvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 35850 /* glMultiTexCoord1xvOES */);
}

static PFNGLMULTITEXCOORD2BOESPROC
epoxy_glMultiTexCoord2bOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_byte_coordinates, 35872 /* glMultiTexCoord2bOES */);
}

static PFNGLMULTITEXCOORD2BVOESPROC
epoxy_glMultiTexCoord2bvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_byte_coordinates, 35893 /* glMultiTexCoord2bvOES */);
}

static PFNGLMULTITEXCOORD2DPROC
epoxy_glMultiTexCoord2d_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_GL_ARB_multitexture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        35915 /* "glMultiTexCoord2d" */,
        35933 /* "glMultiTexCoord2dARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 35915 /* "glMultiTexCoord2d" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD2DARBPROC
epoxy_glMultiTexCoord2dARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_multitexture,
        PROVIDER_Desktop_OpenGL_1_3,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        35933 /* "glMultiTexCoord2dARB" */,
        35915 /* "glMultiTexCoord2d" */,
    };
    return gl_provider_resolver(entrypoint_strings + 35933 /* "glMultiTexCoord2dARB" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD2DVPROC
epoxy_glMultiTexCoord2dv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_GL_ARB_multitexture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        35954 /* "glMultiTexCoord2dv" */,
        35973 /* "glMultiTexCoord2dvARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 35954 /* "glMultiTexCoord2dv" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD2DVARBPROC
epoxy_glMultiTexCoord2dvARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_multitexture,
        PROVIDER_Desktop_OpenGL_1_3,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        35973 /* "glMultiTexCoord2dvARB" */,
        35954 /* "glMultiTexCoord2dv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 35973 /* "glMultiTexCoord2dvARB" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD2FPROC
epoxy_glMultiTexCoord2f_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_GL_ARB_multitexture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        35995 /* "glMultiTexCoord2f" */,
        36013 /* "glMultiTexCoord2fARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 35995 /* "glMultiTexCoord2f" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD2FARBPROC
epoxy_glMultiTexCoord2fARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_multitexture,
        PROVIDER_Desktop_OpenGL_1_3,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        36013 /* "glMultiTexCoord2fARB" */,
        35995 /* "glMultiTexCoord2f" */,
    };
    return gl_provider_resolver(entrypoint_strings + 36013 /* "glMultiTexCoord2fARB" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD2FVPROC
epoxy_glMultiTexCoord2fv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_GL_ARB_multitexture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        36034 /* "glMultiTexCoord2fv" */,
        36053 /* "glMultiTexCoord2fvARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 36034 /* "glMultiTexCoord2fv" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD2FVARBPROC
epoxy_glMultiTexCoord2fvARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_multitexture,
        PROVIDER_Desktop_OpenGL_1_3,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        36053 /* "glMultiTexCoord2fvARB" */,
        36034 /* "glMultiTexCoord2fv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 36053 /* "glMultiTexCoord2fvARB" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD2HNVPROC
epoxy_glMultiTexCoord2hNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_half_float, 36075 /* glMultiTexCoord2hNV */);
}

static PFNGLMULTITEXCOORD2HVNVPROC
epoxy_glMultiTexCoord2hvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_half_float, 36095 /* glMultiTexCoord2hvNV */);
}

static PFNGLMULTITEXCOORD2IPROC
epoxy_glMultiTexCoord2i_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_GL_ARB_multitexture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        36116 /* "glMultiTexCoord2i" */,
        36134 /* "glMultiTexCoord2iARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 36116 /* "glMultiTexCoord2i" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD2IARBPROC
epoxy_glMultiTexCoord2iARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_multitexture,
        PROVIDER_Desktop_OpenGL_1_3,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        36134 /* "glMultiTexCoord2iARB" */,
        36116 /* "glMultiTexCoord2i" */,
    };
    return gl_provider_resolver(entrypoint_strings + 36134 /* "glMultiTexCoord2iARB" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD2IVPROC
epoxy_glMultiTexCoord2iv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_GL_ARB_multitexture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        36155 /* "glMultiTexCoord2iv" */,
        36174 /* "glMultiTexCoord2ivARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 36155 /* "glMultiTexCoord2iv" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD2IVARBPROC
epoxy_glMultiTexCoord2ivARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_multitexture,
        PROVIDER_Desktop_OpenGL_1_3,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        36174 /* "glMultiTexCoord2ivARB" */,
        36155 /* "glMultiTexCoord2iv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 36174 /* "glMultiTexCoord2ivARB" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD2SPROC
epoxy_glMultiTexCoord2s_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_GL_ARB_multitexture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        36196 /* "glMultiTexCoord2s" */,
        36214 /* "glMultiTexCoord2sARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 36196 /* "glMultiTexCoord2s" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD2SARBPROC
epoxy_glMultiTexCoord2sARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_multitexture,
        PROVIDER_Desktop_OpenGL_1_3,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        36214 /* "glMultiTexCoord2sARB" */,
        36196 /* "glMultiTexCoord2s" */,
    };
    return gl_provider_resolver(entrypoint_strings + 36214 /* "glMultiTexCoord2sARB" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD2SVPROC
epoxy_glMultiTexCoord2sv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_GL_ARB_multitexture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        36235 /* "glMultiTexCoord2sv" */,
        36254 /* "glMultiTexCoord2svARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 36235 /* "glMultiTexCoord2sv" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD2SVARBPROC
epoxy_glMultiTexCoord2svARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_multitexture,
        PROVIDER_Desktop_OpenGL_1_3,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        36254 /* "glMultiTexCoord2svARB" */,
        36235 /* "glMultiTexCoord2sv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 36254 /* "glMultiTexCoord2svARB" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD2XOESPROC
epoxy_glMultiTexCoord2xOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 36276 /* glMultiTexCoord2xOES */);
}

static PFNGLMULTITEXCOORD2XVOESPROC
epoxy_glMultiTexCoord2xvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 36297 /* glMultiTexCoord2xvOES */);
}

static PFNGLMULTITEXCOORD3BOESPROC
epoxy_glMultiTexCoord3bOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_byte_coordinates, 36319 /* glMultiTexCoord3bOES */);
}

static PFNGLMULTITEXCOORD3BVOESPROC
epoxy_glMultiTexCoord3bvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_byte_coordinates, 36340 /* glMultiTexCoord3bvOES */);
}

static PFNGLMULTITEXCOORD3DPROC
epoxy_glMultiTexCoord3d_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_GL_ARB_multitexture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        36362 /* "glMultiTexCoord3d" */,
        36380 /* "glMultiTexCoord3dARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 36362 /* "glMultiTexCoord3d" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD3DARBPROC
epoxy_glMultiTexCoord3dARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_multitexture,
        PROVIDER_Desktop_OpenGL_1_3,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        36380 /* "glMultiTexCoord3dARB" */,
        36362 /* "glMultiTexCoord3d" */,
    };
    return gl_provider_resolver(entrypoint_strings + 36380 /* "glMultiTexCoord3dARB" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD3DVPROC
epoxy_glMultiTexCoord3dv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_GL_ARB_multitexture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        36401 /* "glMultiTexCoord3dv" */,
        36420 /* "glMultiTexCoord3dvARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 36401 /* "glMultiTexCoord3dv" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD3DVARBPROC
epoxy_glMultiTexCoord3dvARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_multitexture,
        PROVIDER_Desktop_OpenGL_1_3,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        36420 /* "glMultiTexCoord3dvARB" */,
        36401 /* "glMultiTexCoord3dv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 36420 /* "glMultiTexCoord3dvARB" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD3FPROC
epoxy_glMultiTexCoord3f_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_GL_ARB_multitexture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        36442 /* "glMultiTexCoord3f" */,
        36460 /* "glMultiTexCoord3fARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 36442 /* "glMultiTexCoord3f" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD3FARBPROC
epoxy_glMultiTexCoord3fARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_multitexture,
        PROVIDER_Desktop_OpenGL_1_3,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        36460 /* "glMultiTexCoord3fARB" */,
        36442 /* "glMultiTexCoord3f" */,
    };
    return gl_provider_resolver(entrypoint_strings + 36460 /* "glMultiTexCoord3fARB" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD3FVPROC
epoxy_glMultiTexCoord3fv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_GL_ARB_multitexture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        36481 /* "glMultiTexCoord3fv" */,
        36500 /* "glMultiTexCoord3fvARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 36481 /* "glMultiTexCoord3fv" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD3FVARBPROC
epoxy_glMultiTexCoord3fvARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_multitexture,
        PROVIDER_Desktop_OpenGL_1_3,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        36500 /* "glMultiTexCoord3fvARB" */,
        36481 /* "glMultiTexCoord3fv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 36500 /* "glMultiTexCoord3fvARB" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD3HNVPROC
epoxy_glMultiTexCoord3hNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_half_float, 36522 /* glMultiTexCoord3hNV */);
}

static PFNGLMULTITEXCOORD3HVNVPROC
epoxy_glMultiTexCoord3hvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_half_float, 36542 /* glMultiTexCoord3hvNV */);
}

static PFNGLMULTITEXCOORD3IPROC
epoxy_glMultiTexCoord3i_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_GL_ARB_multitexture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        36563 /* "glMultiTexCoord3i" */,
        36581 /* "glMultiTexCoord3iARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 36563 /* "glMultiTexCoord3i" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD3IARBPROC
epoxy_glMultiTexCoord3iARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_multitexture,
        PROVIDER_Desktop_OpenGL_1_3,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        36581 /* "glMultiTexCoord3iARB" */,
        36563 /* "glMultiTexCoord3i" */,
    };
    return gl_provider_resolver(entrypoint_strings + 36581 /* "glMultiTexCoord3iARB" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD3IVPROC
epoxy_glMultiTexCoord3iv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_GL_ARB_multitexture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        36602 /* "glMultiTexCoord3iv" */,
        36621 /* "glMultiTexCoord3ivARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 36602 /* "glMultiTexCoord3iv" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD3IVARBPROC
epoxy_glMultiTexCoord3ivARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_multitexture,
        PROVIDER_Desktop_OpenGL_1_3,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        36621 /* "glMultiTexCoord3ivARB" */,
        36602 /* "glMultiTexCoord3iv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 36621 /* "glMultiTexCoord3ivARB" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD3SPROC
epoxy_glMultiTexCoord3s_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_GL_ARB_multitexture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        36643 /* "glMultiTexCoord3s" */,
        36661 /* "glMultiTexCoord3sARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 36643 /* "glMultiTexCoord3s" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD3SARBPROC
epoxy_glMultiTexCoord3sARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_multitexture,
        PROVIDER_Desktop_OpenGL_1_3,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        36661 /* "glMultiTexCoord3sARB" */,
        36643 /* "glMultiTexCoord3s" */,
    };
    return gl_provider_resolver(entrypoint_strings + 36661 /* "glMultiTexCoord3sARB" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD3SVPROC
epoxy_glMultiTexCoord3sv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_GL_ARB_multitexture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        36682 /* "glMultiTexCoord3sv" */,
        36701 /* "glMultiTexCoord3svARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 36682 /* "glMultiTexCoord3sv" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD3SVARBPROC
epoxy_glMultiTexCoord3svARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_multitexture,
        PROVIDER_Desktop_OpenGL_1_3,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        36701 /* "glMultiTexCoord3svARB" */,
        36682 /* "glMultiTexCoord3sv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 36701 /* "glMultiTexCoord3svARB" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD3XOESPROC
epoxy_glMultiTexCoord3xOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 36723 /* glMultiTexCoord3xOES */);
}

static PFNGLMULTITEXCOORD3XVOESPROC
epoxy_glMultiTexCoord3xvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 36744 /* glMultiTexCoord3xvOES */);
}

static PFNGLMULTITEXCOORD4BOESPROC
epoxy_glMultiTexCoord4bOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_byte_coordinates, 36766 /* glMultiTexCoord4bOES */);
}

static PFNGLMULTITEXCOORD4BVOESPROC
epoxy_glMultiTexCoord4bvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_byte_coordinates, 36787 /* glMultiTexCoord4bvOES */);
}

static PFNGLMULTITEXCOORD4DPROC
epoxy_glMultiTexCoord4d_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_GL_ARB_multitexture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        36809 /* "glMultiTexCoord4d" */,
        36827 /* "glMultiTexCoord4dARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 36809 /* "glMultiTexCoord4d" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD4DARBPROC
epoxy_glMultiTexCoord4dARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_multitexture,
        PROVIDER_Desktop_OpenGL_1_3,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        36827 /* "glMultiTexCoord4dARB" */,
        36809 /* "glMultiTexCoord4d" */,
    };
    return gl_provider_resolver(entrypoint_strings + 36827 /* "glMultiTexCoord4dARB" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD4DVPROC
epoxy_glMultiTexCoord4dv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_GL_ARB_multitexture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        36848 /* "glMultiTexCoord4dv" */,
        36867 /* "glMultiTexCoord4dvARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 36848 /* "glMultiTexCoord4dv" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD4DVARBPROC
epoxy_glMultiTexCoord4dvARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_multitexture,
        PROVIDER_Desktop_OpenGL_1_3,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        36867 /* "glMultiTexCoord4dvARB" */,
        36848 /* "glMultiTexCoord4dv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 36867 /* "glMultiTexCoord4dvARB" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD4FPROC
epoxy_glMultiTexCoord4f_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_GL_ARB_multitexture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        36889 /* "glMultiTexCoord4f" */,
        36889 /* "glMultiTexCoord4f" */,
        36907 /* "glMultiTexCoord4fARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 36889 /* "glMultiTexCoord4f" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD4FARBPROC
epoxy_glMultiTexCoord4fARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_multitexture,
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_OpenGL_ES_1_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        36907 /* "glMultiTexCoord4fARB" */,
        36889 /* "glMultiTexCoord4f" */,
        36889 /* "glMultiTexCoord4f" */,
    };
    return gl_provider_resolver(entrypoint_strings + 36907 /* "glMultiTexCoord4fARB" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD4FVPROC
epoxy_glMultiTexCoord4fv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_GL_ARB_multitexture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        36928 /* "glMultiTexCoord4fv" */,
        36947 /* "glMultiTexCoord4fvARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 36928 /* "glMultiTexCoord4fv" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD4FVARBPROC
epoxy_glMultiTexCoord4fvARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_multitexture,
        PROVIDER_Desktop_OpenGL_1_3,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        36947 /* "glMultiTexCoord4fvARB" */,
        36928 /* "glMultiTexCoord4fv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 36947 /* "glMultiTexCoord4fvARB" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD4HNVPROC
epoxy_glMultiTexCoord4hNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_half_float, 36969 /* glMultiTexCoord4hNV */);
}

static PFNGLMULTITEXCOORD4HVNVPROC
epoxy_glMultiTexCoord4hvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_half_float, 36989 /* glMultiTexCoord4hvNV */);
}

static PFNGLMULTITEXCOORD4IPROC
epoxy_glMultiTexCoord4i_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_GL_ARB_multitexture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        37010 /* "glMultiTexCoord4i" */,
        37028 /* "glMultiTexCoord4iARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 37010 /* "glMultiTexCoord4i" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD4IARBPROC
epoxy_glMultiTexCoord4iARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_multitexture,
        PROVIDER_Desktop_OpenGL_1_3,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        37028 /* "glMultiTexCoord4iARB" */,
        37010 /* "glMultiTexCoord4i" */,
    };
    return gl_provider_resolver(entrypoint_strings + 37028 /* "glMultiTexCoord4iARB" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD4IVPROC
epoxy_glMultiTexCoord4iv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_GL_ARB_multitexture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        37049 /* "glMultiTexCoord4iv" */,
        37068 /* "glMultiTexCoord4ivARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 37049 /* "glMultiTexCoord4iv" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD4IVARBPROC
epoxy_glMultiTexCoord4ivARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_multitexture,
        PROVIDER_Desktop_OpenGL_1_3,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        37068 /* "glMultiTexCoord4ivARB" */,
        37049 /* "glMultiTexCoord4iv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 37068 /* "glMultiTexCoord4ivARB" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD4SPROC
epoxy_glMultiTexCoord4s_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_GL_ARB_multitexture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        37090 /* "glMultiTexCoord4s" */,
        37108 /* "glMultiTexCoord4sARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 37090 /* "glMultiTexCoord4s" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD4SARBPROC
epoxy_glMultiTexCoord4sARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_multitexture,
        PROVIDER_Desktop_OpenGL_1_3,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        37108 /* "glMultiTexCoord4sARB" */,
        37090 /* "glMultiTexCoord4s" */,
    };
    return gl_provider_resolver(entrypoint_strings + 37108 /* "glMultiTexCoord4sARB" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD4SVPROC
epoxy_glMultiTexCoord4sv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_GL_ARB_multitexture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        37129 /* "glMultiTexCoord4sv" */,
        37148 /* "glMultiTexCoord4svARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 37129 /* "glMultiTexCoord4sv" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD4SVARBPROC
epoxy_glMultiTexCoord4svARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_multitexture,
        PROVIDER_Desktop_OpenGL_1_3,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        37148 /* "glMultiTexCoord4svARB" */,
        37129 /* "glMultiTexCoord4sv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 37148 /* "glMultiTexCoord4svARB" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORD4XPROC
epoxy_glMultiTexCoord4x_resolver(void)
{
    return gl_single_resolver(PROVIDER_OpenGL_ES_1_0, 37170 /* glMultiTexCoord4x */);
}

static PFNGLMULTITEXCOORD4XOESPROC
epoxy_glMultiTexCoord4xOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 37188 /* glMultiTexCoord4xOES */);
}

static PFNGLMULTITEXCOORD4XVOESPROC
epoxy_glMultiTexCoord4xvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 37209 /* glMultiTexCoord4xvOES */);
}

static PFNGLMULTITEXCOORDP1UIPROC
epoxy_glMultiTexCoordP1ui_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_vertex_type_2_10_10_10_rev,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        37231 /* "glMultiTexCoordP1ui" */,
        37231 /* "glMultiTexCoordP1ui" */,
    };
    return gl_provider_resolver(entrypoint_strings + 37231 /* "glMultiTexCoordP1ui" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORDP1UIVPROC
epoxy_glMultiTexCoordP1uiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_vertex_type_2_10_10_10_rev,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        37251 /* "glMultiTexCoordP1uiv" */,
        37251 /* "glMultiTexCoordP1uiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 37251 /* "glMultiTexCoordP1uiv" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORDP2UIPROC
epoxy_glMultiTexCoordP2ui_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_vertex_type_2_10_10_10_rev,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        37272 /* "glMultiTexCoordP2ui" */,
        37272 /* "glMultiTexCoordP2ui" */,
    };
    return gl_provider_resolver(entrypoint_strings + 37272 /* "glMultiTexCoordP2ui" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORDP2UIVPROC
epoxy_glMultiTexCoordP2uiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_vertex_type_2_10_10_10_rev,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        37292 /* "glMultiTexCoordP2uiv" */,
        37292 /* "glMultiTexCoordP2uiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 37292 /* "glMultiTexCoordP2uiv" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORDP3UIPROC
epoxy_glMultiTexCoordP3ui_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_vertex_type_2_10_10_10_rev,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        37313 /* "glMultiTexCoordP3ui" */,
        37313 /* "glMultiTexCoordP3ui" */,
    };
    return gl_provider_resolver(entrypoint_strings + 37313 /* "glMultiTexCoordP3ui" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORDP3UIVPROC
epoxy_glMultiTexCoordP3uiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_vertex_type_2_10_10_10_rev,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        37333 /* "glMultiTexCoordP3uiv" */,
        37333 /* "glMultiTexCoordP3uiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 37333 /* "glMultiTexCoordP3uiv" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORDP4UIPROC
epoxy_glMultiTexCoordP4ui_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_vertex_type_2_10_10_10_rev,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        37354 /* "glMultiTexCoordP4ui" */,
        37354 /* "glMultiTexCoordP4ui" */,
    };
    return gl_provider_resolver(entrypoint_strings + 37354 /* "glMultiTexCoordP4ui" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORDP4UIVPROC
epoxy_glMultiTexCoordP4uiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_vertex_type_2_10_10_10_rev,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        37374 /* "glMultiTexCoordP4uiv" */,
        37374 /* "glMultiTexCoordP4uiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 37374 /* "glMultiTexCoordP4uiv" */,
                                providers, entrypoints);
}

static PFNGLMULTITEXCOORDPOINTEREXTPROC
epoxy_glMultiTexCoordPointerEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 37395 /* glMultiTexCoordPointerEXT */);
}

static PFNGLMULTITEXENVFEXTPROC
epoxy_glMultiTexEnvfEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 37421 /* glMultiTexEnvfEXT */);
}

static PFNGLMULTITEXENVFVEXTPROC
epoxy_glMultiTexEnvfvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 37439 /* glMultiTexEnvfvEXT */);
}

static PFNGLMULTITEXENVIEXTPROC
epoxy_glMultiTexEnviEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 37458 /* glMultiTexEnviEXT */);
}

static PFNGLMULTITEXENVIVEXTPROC
epoxy_glMultiTexEnvivEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 37476 /* glMultiTexEnvivEXT */);
}

static PFNGLMULTITEXGENDEXTPROC
epoxy_glMultiTexGendEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 37495 /* glMultiTexGendEXT */);
}

static PFNGLMULTITEXGENDVEXTPROC
epoxy_glMultiTexGendvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 37513 /* glMultiTexGendvEXT */);
}

static PFNGLMULTITEXGENFEXTPROC
epoxy_glMultiTexGenfEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 37532 /* glMultiTexGenfEXT */);
}

static PFNGLMULTITEXGENFVEXTPROC
epoxy_glMultiTexGenfvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 37550 /* glMultiTexGenfvEXT */);
}

static PFNGLMULTITEXGENIEXTPROC
epoxy_glMultiTexGeniEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 37569 /* glMultiTexGeniEXT */);
}

static PFNGLMULTITEXGENIVEXTPROC
epoxy_glMultiTexGenivEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 37587 /* glMultiTexGenivEXT */);
}

static PFNGLMULTITEXIMAGE1DEXTPROC
epoxy_glMultiTexImage1DEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 37606 /* glMultiTexImage1DEXT */);
}

static PFNGLMULTITEXIMAGE2DEXTPROC
epoxy_glMultiTexImage2DEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 37627 /* glMultiTexImage2DEXT */);
}

static PFNGLMULTITEXIMAGE3DEXTPROC
epoxy_glMultiTexImage3DEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 37648 /* glMultiTexImage3DEXT */);
}

static PFNGLMULTITEXPARAMETERIIVEXTPROC
epoxy_glMultiTexParameterIivEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 37669 /* glMultiTexParameterIivEXT */);
}

static PFNGLMULTITEXPARAMETERIUIVEXTPROC
epoxy_glMultiTexParameterIuivEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 37695 /* glMultiTexParameterIuivEXT */);
}

static PFNGLMULTITEXPARAMETERFEXTPROC
epoxy_glMultiTexParameterfEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 37722 /* glMultiTexParameterfEXT */);
}

static PFNGLMULTITEXPARAMETERFVEXTPROC
epoxy_glMultiTexParameterfvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 37746 /* glMultiTexParameterfvEXT */);
}

static PFNGLMULTITEXPARAMETERIEXTPROC
epoxy_glMultiTexParameteriEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 37771 /* glMultiTexParameteriEXT */);
}

static PFNGLMULTITEXPARAMETERIVEXTPROC
epoxy_glMultiTexParameterivEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 37795 /* glMultiTexParameterivEXT */);
}

static PFNGLMULTITEXRENDERBUFFEREXTPROC
epoxy_glMultiTexRenderbufferEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 37820 /* glMultiTexRenderbufferEXT */);
}

static PFNGLMULTITEXSUBIMAGE1DEXTPROC
epoxy_glMultiTexSubImage1DEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 37846 /* glMultiTexSubImage1DEXT */);
}

static PFNGLMULTITEXSUBIMAGE2DEXTPROC
epoxy_glMultiTexSubImage2DEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 37870 /* glMultiTexSubImage2DEXT */);
}

static PFNGLMULTITEXSUBIMAGE3DEXTPROC
epoxy_glMultiTexSubImage3DEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 37894 /* glMultiTexSubImage3DEXT */);
}

static PFNGLMULTICASTBARRIERNVPROC
epoxy_glMulticastBarrierNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_gpu_multicast, 37918 /* glMulticastBarrierNV */);
}

static PFNGLMULTICASTBLITFRAMEBUFFERNVPROC
epoxy_glMulticastBlitFramebufferNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_gpu_multicast, 37939 /* glMulticastBlitFramebufferNV */);
}

static PFNGLMULTICASTBUFFERSUBDATANVPROC
epoxy_glMulticastBufferSubDataNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_gpu_multicast, 37968 /* glMulticastBufferSubDataNV */);
}

static PFNGLMULTICASTCOPYBUFFERSUBDATANVPROC
epoxy_glMulticastCopyBufferSubDataNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_gpu_multicast, 37995 /* glMulticastCopyBufferSubDataNV */);
}

static PFNGLMULTICASTCOPYIMAGESUBDATANVPROC
epoxy_glMulticastCopyImageSubDataNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_gpu_multicast, 38026 /* glMulticastCopyImageSubDataNV */);
}

static PFNGLMULTICASTFRAMEBUFFERSAMPLELOCATIONSFVNVPROC
epoxy_glMulticastFramebufferSampleLocationsfvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_gpu_multicast, 38056 /* glMulticastFramebufferSampleLocationsfvNV */);
}

static PFNGLMULTICASTGETQUERYOBJECTI64VNVPROC
epoxy_glMulticastGetQueryObjecti64vNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_gpu_multicast, 38098 /* glMulticastGetQueryObjecti64vNV */);
}

static PFNGLMULTICASTGETQUERYOBJECTIVNVPROC
epoxy_glMulticastGetQueryObjectivNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_gpu_multicast, 38130 /* glMulticastGetQueryObjectivNV */);
}

static PFNGLMULTICASTGETQUERYOBJECTUI64VNVPROC
epoxy_glMulticastGetQueryObjectui64vNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_gpu_multicast, 38160 /* glMulticastGetQueryObjectui64vNV */);
}

static PFNGLMULTICASTGETQUERYOBJECTUIVNVPROC
epoxy_glMulticastGetQueryObjectuivNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_gpu_multicast, 38193 /* glMulticastGetQueryObjectuivNV */);
}

static PFNGLMULTICASTSCISSORARRAYVNVXPROC
epoxy_glMulticastScissorArrayvNVX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NVX_gpu_multicast2, 38224 /* glMulticastScissorArrayvNVX */);
}

static PFNGLMULTICASTVIEWPORTARRAYVNVXPROC
epoxy_glMulticastViewportArrayvNVX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NVX_gpu_multicast2, 38252 /* glMulticastViewportArrayvNVX */);
}

static PFNGLMULTICASTVIEWPORTPOSITIONWSCALENVXPROC
epoxy_glMulticastViewportPositionWScaleNVX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NVX_gpu_multicast2, 38281 /* glMulticastViewportPositionWScaleNVX */);
}

static PFNGLMULTICASTWAITSYNCNVPROC
epoxy_glMulticastWaitSyncNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_gpu_multicast, 38318 /* glMulticastWaitSyncNV */);
}

static PFNGLNAMEDBUFFERATTACHMEMORYNVPROC
epoxy_glNamedBufferAttachMemoryNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_memory_attachment, 38340 /* glNamedBufferAttachMemoryNV */);
}

static PFNGLNAMEDBUFFERDATAPROC
epoxy_glNamedBufferData_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        38368 /* "glNamedBufferData" */,
        38368 /* "glNamedBufferData" */,
    };
    return gl_provider_resolver(entrypoint_strings + 38368 /* "glNamedBufferData" */,
                                providers, entrypoints);
}

static PFNGLNAMEDBUFFERDATAEXTPROC
epoxy_glNamedBufferDataEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 38386 /* glNamedBufferDataEXT */);
}

static PFNGLNAMEDBUFFERPAGECOMMITMENTARBPROC
epoxy_glNamedBufferPageCommitmentARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_sparse_buffer, 38407 /* glNamedBufferPageCommitmentARB */);
}

static PFNGLNAMEDBUFFERPAGECOMMITMENTEXTPROC
epoxy_glNamedBufferPageCommitmentEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_sparse_buffer, 38438 /* glNamedBufferPageCommitmentEXT */);
}

static PFNGLNAMEDBUFFERSTORAGEPROC
epoxy_glNamedBufferStorage_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        PROVIDER_GL_EXT_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        38469 /* "glNamedBufferStorage" */,
        38469 /* "glNamedBufferStorage" */,
        38490 /* "glNamedBufferStorageEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 38469 /* "glNamedBufferStorage" */,
                                providers, entrypoints);
}

static PFNGLNAMEDBUFFERSTORAGEEXTPROC
epoxy_glNamedBufferStorageEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        38490 /* "glNamedBufferStorageEXT" */,
        38469 /* "glNamedBufferStorage" */,
        38469 /* "glNamedBufferStorage" */,
    };
    return gl_provider_resolver(entrypoint_strings + 38490 /* "glNamedBufferStorageEXT" */,
                                providers, entrypoints);
}

static PFNGLNAMEDBUFFERSTORAGEEXTERNALEXTPROC
epoxy_glNamedBufferStorageExternalEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_external_buffer, 38514 /* glNamedBufferStorageExternalEXT */);
}

static PFNGLNAMEDBUFFERSTORAGEMEMEXTPROC
epoxy_glNamedBufferStorageMemEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_memory_object, 38546 /* glNamedBufferStorageMemEXT */);
}

static PFNGLNAMEDBUFFERSUBDATAPROC
epoxy_glNamedBufferSubData_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        PROVIDER_GL_EXT_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        38573 /* "glNamedBufferSubData" */,
        38573 /* "glNamedBufferSubData" */,
        38594 /* "glNamedBufferSubDataEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 38573 /* "glNamedBufferSubData" */,
                                providers, entrypoints);
}

static PFNGLNAMEDBUFFERSUBDATAEXTPROC
epoxy_glNamedBufferSubDataEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        38594 /* "glNamedBufferSubDataEXT" */,
        38573 /* "glNamedBufferSubData" */,
        38573 /* "glNamedBufferSubData" */,
    };
    return gl_provider_resolver(entrypoint_strings + 38594 /* "glNamedBufferSubDataEXT" */,
                                providers, entrypoints);
}

static PFNGLNAMEDCOPYBUFFERSUBDATAEXTPROC
epoxy_glNamedCopyBufferSubDataEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 38618 /* glNamedCopyBufferSubDataEXT */);
}

static PFNGLNAMEDFRAMEBUFFERDRAWBUFFERPROC
epoxy_glNamedFramebufferDrawBuffer_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        38646 /* "glNamedFramebufferDrawBuffer" */,
        38646 /* "glNamedFramebufferDrawBuffer" */,
    };
    return gl_provider_resolver(entrypoint_strings + 38646 /* "glNamedFramebufferDrawBuffer" */,
                                providers, entrypoints);
}

static PFNGLNAMEDFRAMEBUFFERDRAWBUFFERSPROC
epoxy_glNamedFramebufferDrawBuffers_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        38675 /* "glNamedFramebufferDrawBuffers" */,
        38675 /* "glNamedFramebufferDrawBuffers" */,
    };
    return gl_provider_resolver(entrypoint_strings + 38675 /* "glNamedFramebufferDrawBuffers" */,
                                providers, entrypoints);
}

static PFNGLNAMEDFRAMEBUFFERPARAMETERIPROC
epoxy_glNamedFramebufferParameteri_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        38705 /* "glNamedFramebufferParameteri" */,
        38705 /* "glNamedFramebufferParameteri" */,
    };
    return gl_provider_resolver(entrypoint_strings + 38705 /* "glNamedFramebufferParameteri" */,
                                providers, entrypoints);
}

static PFNGLNAMEDFRAMEBUFFERPARAMETERIEXTPROC
epoxy_glNamedFramebufferParameteriEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 38734 /* glNamedFramebufferParameteriEXT */);
}

static PFNGLNAMEDFRAMEBUFFERREADBUFFERPROC
epoxy_glNamedFramebufferReadBuffer_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        38766 /* "glNamedFramebufferReadBuffer" */,
        38766 /* "glNamedFramebufferReadBuffer" */,
    };
    return gl_provider_resolver(entrypoint_strings + 38766 /* "glNamedFramebufferReadBuffer" */,
                                providers, entrypoints);
}

static PFNGLNAMEDFRAMEBUFFERRENDERBUFFERPROC
epoxy_glNamedFramebufferRenderbuffer_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        38795 /* "glNamedFramebufferRenderbuffer" */,
        38795 /* "glNamedFramebufferRenderbuffer" */,
    };
    return gl_provider_resolver(entrypoint_strings + 38795 /* "glNamedFramebufferRenderbuffer" */,
                                providers, entrypoints);
}

static PFNGLNAMEDFRAMEBUFFERRENDERBUFFEREXTPROC
epoxy_glNamedFramebufferRenderbufferEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 38826 /* glNamedFramebufferRenderbufferEXT */);
}

static PFNGLNAMEDFRAMEBUFFERSAMPLELOCATIONSFVARBPROC
epoxy_glNamedFramebufferSampleLocationsfvARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_sample_locations, 38860 /* glNamedFramebufferSampleLocationsfvARB */);
}

static PFNGLNAMEDFRAMEBUFFERSAMPLELOCATIONSFVNVPROC
epoxy_glNamedFramebufferSampleLocationsfvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_sample_locations, 38899 /* glNamedFramebufferSampleLocationsfvNV */);
}

static PFNGLNAMEDFRAMEBUFFERSAMPLEPOSITIONSFVAMDPROC
epoxy_glNamedFramebufferSamplePositionsfvAMD_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_AMD_framebuffer_sample_positions, 38937 /* glNamedFramebufferSamplePositionsfvAMD */);
}

static PFNGLNAMEDFRAMEBUFFERTEXTUREPROC
epoxy_glNamedFramebufferTexture_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        38976 /* "glNamedFramebufferTexture" */,
        38976 /* "glNamedFramebufferTexture" */,
    };
    return gl_provider_resolver(entrypoint_strings + 38976 /* "glNamedFramebufferTexture" */,
                                providers, entrypoints);
}

static PFNGLNAMEDFRAMEBUFFERTEXTURE1DEXTPROC
epoxy_glNamedFramebufferTexture1DEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 39002 /* glNamedFramebufferTexture1DEXT */);
}

static PFNGLNAMEDFRAMEBUFFERTEXTURE2DEXTPROC
epoxy_glNamedFramebufferTexture2DEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 39033 /* glNamedFramebufferTexture2DEXT */);
}

static PFNGLNAMEDFRAMEBUFFERTEXTURE3DEXTPROC
epoxy_glNamedFramebufferTexture3DEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 39064 /* glNamedFramebufferTexture3DEXT */);
}

static PFNGLNAMEDFRAMEBUFFERTEXTUREEXTPROC
epoxy_glNamedFramebufferTextureEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 39095 /* glNamedFramebufferTextureEXT */);
}

static PFNGLNAMEDFRAMEBUFFERTEXTUREFACEEXTPROC
epoxy_glNamedFramebufferTextureFaceEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 39124 /* glNamedFramebufferTextureFaceEXT */);
}

static PFNGLNAMEDFRAMEBUFFERTEXTURELAYERPROC
epoxy_glNamedFramebufferTextureLayer_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        39157 /* "glNamedFramebufferTextureLayer" */,
        39157 /* "glNamedFramebufferTextureLayer" */,
    };
    return gl_provider_resolver(entrypoint_strings + 39157 /* "glNamedFramebufferTextureLayer" */,
                                providers, entrypoints);
}

static PFNGLNAMEDFRAMEBUFFERTEXTURELAYEREXTPROC
epoxy_glNamedFramebufferTextureLayerEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 39188 /* glNamedFramebufferTextureLayerEXT */);
}

static PFNGLNAMEDPROGRAMLOCALPARAMETER4DEXTPROC
epoxy_glNamedProgramLocalParameter4dEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 39222 /* glNamedProgramLocalParameter4dEXT */);
}

static PFNGLNAMEDPROGRAMLOCALPARAMETER4DVEXTPROC
epoxy_glNamedProgramLocalParameter4dvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 39256 /* glNamedProgramLocalParameter4dvEXT */);
}

static PFNGLNAMEDPROGRAMLOCALPARAMETER4FEXTPROC
epoxy_glNamedProgramLocalParameter4fEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 39291 /* glNamedProgramLocalParameter4fEXT */);
}

static PFNGLNAMEDPROGRAMLOCALPARAMETER4FVEXTPROC
epoxy_glNamedProgramLocalParameter4fvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 39325 /* glNamedProgramLocalParameter4fvEXT */);
}

static PFNGLNAMEDPROGRAMLOCALPARAMETERI4IEXTPROC
epoxy_glNamedProgramLocalParameterI4iEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 39360 /* glNamedProgramLocalParameterI4iEXT */);
}

static PFNGLNAMEDPROGRAMLOCALPARAMETERI4IVEXTPROC
epoxy_glNamedProgramLocalParameterI4ivEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 39395 /* glNamedProgramLocalParameterI4ivEXT */);
}

static PFNGLNAMEDPROGRAMLOCALPARAMETERI4UIEXTPROC
epoxy_glNamedProgramLocalParameterI4uiEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 39431 /* glNamedProgramLocalParameterI4uiEXT */);
}

static PFNGLNAMEDPROGRAMLOCALPARAMETERI4UIVEXTPROC
epoxy_glNamedProgramLocalParameterI4uivEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 39467 /* glNamedProgramLocalParameterI4uivEXT */);
}

static PFNGLNAMEDPROGRAMLOCALPARAMETERS4FVEXTPROC
epoxy_glNamedProgramLocalParameters4fvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 39504 /* glNamedProgramLocalParameters4fvEXT */);
}

static PFNGLNAMEDPROGRAMLOCALPARAMETERSI4IVEXTPROC
epoxy_glNamedProgramLocalParametersI4ivEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 39540 /* glNamedProgramLocalParametersI4ivEXT */);
}

static PFNGLNAMEDPROGRAMLOCALPARAMETERSI4UIVEXTPROC
epoxy_glNamedProgramLocalParametersI4uivEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 39577 /* glNamedProgramLocalParametersI4uivEXT */);
}

static PFNGLNAMEDPROGRAMSTRINGEXTPROC
epoxy_glNamedProgramStringEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 39615 /* glNamedProgramStringEXT */);
}

static PFNGLNAMEDRENDERBUFFERSTORAGEPROC
epoxy_glNamedRenderbufferStorage_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        39639 /* "glNamedRenderbufferStorage" */,
        39639 /* "glNamedRenderbufferStorage" */,
    };
    return gl_provider_resolver(entrypoint_strings + 39639 /* "glNamedRenderbufferStorage" */,
                                providers, entrypoints);
}

static PFNGLNAMEDRENDERBUFFERSTORAGEEXTPROC
epoxy_glNamedRenderbufferStorageEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 39666 /* glNamedRenderbufferStorageEXT */);
}

static PFNGLNAMEDRENDERBUFFERSTORAGEMULTISAMPLEPROC
epoxy_glNamedRenderbufferStorageMultisample_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        39696 /* "glNamedRenderbufferStorageMultisample" */,
        39696 /* "glNamedRenderbufferStorageMultisample" */,
    };
    return gl_provider_resolver(entrypoint_strings + 39696 /* "glNamedRenderbufferStorageMultisample" */,
                                providers, entrypoints);
}

static PFNGLNAMEDRENDERBUFFERSTORAGEMULTISAMPLEADVANCEDAMDPROC
epoxy_glNamedRenderbufferStorageMultisampleAdvancedAMD_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_AMD_framebuffer_multisample_advanced, 39734 /* glNamedRenderbufferStorageMultisampleAdvancedAMD */);
}

static PFNGLNAMEDRENDERBUFFERSTORAGEMULTISAMPLECOVERAGEEXTPROC
epoxy_glNamedRenderbufferStorageMultisampleCoverageEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 39783 /* glNamedRenderbufferStorageMultisampleCoverageEXT */);
}

static PFNGLNAMEDRENDERBUFFERSTORAGEMULTISAMPLEEXTPROC
epoxy_glNamedRenderbufferStorageMultisampleEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 39832 /* glNamedRenderbufferStorageMultisampleEXT */);
}

static PFNGLNAMEDSTRINGARBPROC
epoxy_glNamedStringARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_shading_language_include, 39873 /* glNamedStringARB */);
}

static PFNGLNEWLISTPROC
epoxy_glNewList_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 39890 /* glNewList */);
}

static PFNGLNEWOBJECTBUFFERATIPROC
epoxy_glNewObjectBufferATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_array_object, 39900 /* glNewObjectBufferATI */);
}

static PFNGLNORMAL3BPROC
epoxy_glNormal3b_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 39921 /* glNormal3b */);
}

static PFNGLNORMAL3BVPROC
epoxy_glNormal3bv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 39932 /* glNormal3bv */);
}

static PFNGLNORMAL3DPROC
epoxy_glNormal3d_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 39944 /* glNormal3d */);
}

static PFNGLNORMAL3DVPROC
epoxy_glNormal3dv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 39955 /* glNormal3dv */);
}

static PFNGLNORMAL3FPROC
epoxy_glNormal3f_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        39967 /* "glNormal3f" */,
        39967 /* "glNormal3f" */,
    };
    return gl_provider_resolver(entrypoint_strings + 39967 /* "glNormal3f" */,
                                providers, entrypoints);
}

static PFNGLNORMAL3FVERTEX3FSUNPROC
epoxy_glNormal3fVertex3fSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_vertex, 39978 /* glNormal3fVertex3fSUN */);
}

static PFNGLNORMAL3FVERTEX3FVSUNPROC
epoxy_glNormal3fVertex3fvSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_vertex, 40000 /* glNormal3fVertex3fvSUN */);
}

static PFNGLNORMAL3FVPROC
epoxy_glNormal3fv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 40023 /* glNormal3fv */);
}

static PFNGLNORMAL3HNVPROC
epoxy_glNormal3hNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_half_float, 40035 /* glNormal3hNV */);
}

static PFNGLNORMAL3HVNVPROC
epoxy_glNormal3hvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_half_float, 40048 /* glNormal3hvNV */);
}

static PFNGLNORMAL3IPROC
epoxy_glNormal3i_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 40062 /* glNormal3i */);
}

static PFNGLNORMAL3IVPROC
epoxy_glNormal3iv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 40073 /* glNormal3iv */);
}

static PFNGLNORMAL3SPROC
epoxy_glNormal3s_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 40085 /* glNormal3s */);
}

static PFNGLNORMAL3SVPROC
epoxy_glNormal3sv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 40096 /* glNormal3sv */);
}

static PFNGLNORMAL3XPROC
epoxy_glNormal3x_resolver(void)
{
    return gl_single_resolver(PROVIDER_OpenGL_ES_1_0, 40108 /* glNormal3x */);
}

static PFNGLNORMAL3XOESPROC
epoxy_glNormal3xOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 40119 /* glNormal3xOES */);
}

static PFNGLNORMAL3XVOESPROC
epoxy_glNormal3xvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 40133 /* glNormal3xvOES */);
}

static PFNGLNORMALFORMATNVPROC
epoxy_glNormalFormatNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_buffer_unified_memory, 40148 /* glNormalFormatNV */);
}

static PFNGLNORMALP3UIPROC
epoxy_glNormalP3ui_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_vertex_type_2_10_10_10_rev,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        40165 /* "glNormalP3ui" */,
        40165 /* "glNormalP3ui" */,
    };
    return gl_provider_resolver(entrypoint_strings + 40165 /* "glNormalP3ui" */,
                                providers, entrypoints);
}

static PFNGLNORMALP3UIVPROC
epoxy_glNormalP3uiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_vertex_type_2_10_10_10_rev,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        40178 /* "glNormalP3uiv" */,
        40178 /* "glNormalP3uiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 40178 /* "glNormalP3uiv" */,
                                providers, entrypoints);
}

static PFNGLNORMALPOINTERPROC
epoxy_glNormalPointer_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_1,
        PROVIDER_OpenGL_ES_1_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        40192 /* "glNormalPointer" */,
        40192 /* "glNormalPointer" */,
    };
    return gl_provider_resolver(entrypoint_strings + 40192 /* "glNormalPointer" */,
                                providers, entrypoints);
}

static PFNGLNORMALPOINTEREXTPROC
epoxy_glNormalPointerEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_array, 40208 /* glNormalPointerEXT */);
}

static PFNGLNORMALPOINTERLISTIBMPROC
epoxy_glNormalPointerListIBM_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_IBM_vertex_array_lists, 40227 /* glNormalPointerListIBM */);
}

static PFNGLNORMALPOINTERVINTELPROC
epoxy_glNormalPointervINTEL_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_INTEL_parallel_arrays, 40250 /* glNormalPointervINTEL */);
}

static PFNGLNORMALSTREAM3BATIPROC
epoxy_glNormalStream3bATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_streams, 40272 /* glNormalStream3bATI */);
}

static PFNGLNORMALSTREAM3BVATIPROC
epoxy_glNormalStream3bvATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_streams, 40292 /* glNormalStream3bvATI */);
}

static PFNGLNORMALSTREAM3DATIPROC
epoxy_glNormalStream3dATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_streams, 40313 /* glNormalStream3dATI */);
}

static PFNGLNORMALSTREAM3DVATIPROC
epoxy_glNormalStream3dvATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_streams, 40333 /* glNormalStream3dvATI */);
}

static PFNGLNORMALSTREAM3FATIPROC
epoxy_glNormalStream3fATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_streams, 40354 /* glNormalStream3fATI */);
}

static PFNGLNORMALSTREAM3FVATIPROC
epoxy_glNormalStream3fvATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_streams, 40374 /* glNormalStream3fvATI */);
}

static PFNGLNORMALSTREAM3IATIPROC
epoxy_glNormalStream3iATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_streams, 40395 /* glNormalStream3iATI */);
}

static PFNGLNORMALSTREAM3IVATIPROC
epoxy_glNormalStream3ivATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_streams, 40415 /* glNormalStream3ivATI */);
}

static PFNGLNORMALSTREAM3SATIPROC
epoxy_glNormalStream3sATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_streams, 40436 /* glNormalStream3sATI */);
}

static PFNGLNORMALSTREAM3SVATIPROC
epoxy_glNormalStream3svATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_streams, 40456 /* glNormalStream3svATI */);
}

static PFNGLOBJECTLABELPROC
epoxy_glObjectLabel_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_KHR_debug,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_KHR_debug,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        40477 /* "glObjectLabel" */,
        40477 /* "glObjectLabel" */,
        40477 /* "glObjectLabel" */,
        40491 /* "glObjectLabelKHR" */,
    };
    return gl_provider_resolver(entrypoint_strings + 40477 /* "glObjectLabel" */,
                                providers, entrypoints);
}

static PFNGLOBJECTLABELKHRPROC
epoxy_glObjectLabelKHR_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_KHR_debug,
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_KHR_debug,
        PROVIDER_OpenGL_ES_3_2,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        40491 /* "glObjectLabelKHR" */,
        40477 /* "glObjectLabel" */,
        40477 /* "glObjectLabel" */,
        40477 /* "glObjectLabel" */,
    };
    return gl_provider_resolver(entrypoint_strings + 40491 /* "glObjectLabelKHR" */,
                                providers, entrypoints);
}

static PFNGLOBJECTPTRLABELPROC
epoxy_glObjectPtrLabel_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_KHR_debug,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_KHR_debug,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        40508 /* "glObjectPtrLabel" */,
        40508 /* "glObjectPtrLabel" */,
        40508 /* "glObjectPtrLabel" */,
        40525 /* "glObjectPtrLabelKHR" */,
    };
    return gl_provider_resolver(entrypoint_strings + 40508 /* "glObjectPtrLabel" */,
                                providers, entrypoints);
}

static PFNGLOBJECTPTRLABELKHRPROC
epoxy_glObjectPtrLabelKHR_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_KHR_debug,
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_KHR_debug,
        PROVIDER_OpenGL_ES_3_2,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        40525 /* "glObjectPtrLabelKHR" */,
        40508 /* "glObjectPtrLabel" */,
        40508 /* "glObjectPtrLabel" */,
        40508 /* "glObjectPtrLabel" */,
    };
    return gl_provider_resolver(entrypoint_strings + 40525 /* "glObjectPtrLabelKHR" */,
                                providers, entrypoints);
}

static PFNGLOBJECTPURGEABLEAPPLEPROC
epoxy_glObjectPurgeableAPPLE_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_APPLE_object_purgeable, 40545 /* glObjectPurgeableAPPLE */);
}

static PFNGLOBJECTUNPURGEABLEAPPLEPROC
epoxy_glObjectUnpurgeableAPPLE_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_APPLE_object_purgeable, 40568 /* glObjectUnpurgeableAPPLE */);
}

static PFNGLORTHOPROC
epoxy_glOrtho_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 40593 /* glOrtho */);
}

static PFNGLORTHOFPROC
epoxy_glOrthof_resolver(void)
{
    return gl_single_resolver(PROVIDER_OpenGL_ES_1_0, 40601 /* glOrthof */);
}

static PFNGLORTHOFOESPROC
epoxy_glOrthofOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_single_precision, 40610 /* glOrthofOES */);
}

static PFNGLORTHOXPROC
epoxy_glOrthox_resolver(void)
{
    return gl_single_resolver(PROVIDER_OpenGL_ES_1_0, 40622 /* glOrthox */);
}

static PFNGLORTHOXOESPROC
epoxy_glOrthoxOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 40631 /* glOrthoxOES */);
}

static PFNGLPNTRIANGLESFATIPROC
epoxy_glPNTrianglesfATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_pn_triangles, 40643 /* glPNTrianglesfATI */);
}

static PFNGLPNTRIANGLESIATIPROC
epoxy_glPNTrianglesiATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_pn_triangles, 40661 /* glPNTrianglesiATI */);
}

static PFNGLPASSTEXCOORDATIPROC
epoxy_glPassTexCoordATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_fragment_shader, 40679 /* glPassTexCoordATI */);
}

static PFNGLPASSTHROUGHPROC
epoxy_glPassThrough_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 40697 /* glPassThrough */);
}

static PFNGLPASSTHROUGHXOESPROC
epoxy_glPassThroughxOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 40711 /* glPassThroughxOES */);
}

static PFNGLPATCHPARAMETERFVPROC
epoxy_glPatchParameterfv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_GL_ARB_tessellation_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        40729 /* "glPatchParameterfv" */,
        40729 /* "glPatchParameterfv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 40729 /* "glPatchParameterfv" */,
                                providers, entrypoints);
}

static PFNGLPATCHPARAMETERIPROC
epoxy_glPatchParameteri_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_GL_ARB_tessellation_shader,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_tessellation_shader,
        PROVIDER_GL_OES_tessellation_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        40748 /* "glPatchParameteri" */,
        40748 /* "glPatchParameteri" */,
        40748 /* "glPatchParameteri" */,
        40766 /* "glPatchParameteriEXT" */,
        40787 /* "glPatchParameteriOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 40748 /* "glPatchParameteri" */,
                                providers, entrypoints);
}

static PFNGLPATCHPARAMETERIEXTPROC
epoxy_glPatchParameteriEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_tessellation_shader,
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_GL_ARB_tessellation_shader,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_OES_tessellation_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        40766 /* "glPatchParameteriEXT" */,
        40748 /* "glPatchParameteri" */,
        40748 /* "glPatchParameteri" */,
        40748 /* "glPatchParameteri" */,
        40787 /* "glPatchParameteriOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 40766 /* "glPatchParameteriEXT" */,
                                providers, entrypoints);
}

static PFNGLPATCHPARAMETERIOESPROC
epoxy_glPatchParameteriOES_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_OES_tessellation_shader,
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_GL_ARB_tessellation_shader,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_tessellation_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        40787 /* "glPatchParameteriOES" */,
        40748 /* "glPatchParameteri" */,
        40748 /* "glPatchParameteri" */,
        40748 /* "glPatchParameteri" */,
        40766 /* "glPatchParameteriEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 40787 /* "glPatchParameteriOES" */,
                                providers, entrypoints);
}

static PFNGLPATHCOLORGENNVPROC
epoxy_glPathColorGenNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 40808 /* glPathColorGenNV */);
}

static PFNGLPATHCOMMANDSNVPROC
epoxy_glPathCommandsNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 40825 /* glPathCommandsNV */);
}

static PFNGLPATHCOORDSNVPROC
epoxy_glPathCoordsNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 40842 /* glPathCoordsNV */);
}

static PFNGLPATHCOVERDEPTHFUNCNVPROC
epoxy_glPathCoverDepthFuncNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 40857 /* glPathCoverDepthFuncNV */);
}

static PFNGLPATHDASHARRAYNVPROC
epoxy_glPathDashArrayNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 40880 /* glPathDashArrayNV */);
}

static PFNGLPATHFOGGENNVPROC
epoxy_glPathFogGenNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 40898 /* glPathFogGenNV */);
}

static PFNGLPATHGLYPHINDEXARRAYNVPROC
epoxy_glPathGlyphIndexArrayNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 40913 /* glPathGlyphIndexArrayNV */);
}

static PFNGLPATHGLYPHINDEXRANGENVPROC
epoxy_glPathGlyphIndexRangeNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 40937 /* glPathGlyphIndexRangeNV */);
}

static PFNGLPATHGLYPHRANGENVPROC
epoxy_glPathGlyphRangeNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 40961 /* glPathGlyphRangeNV */);
}

static PFNGLPATHGLYPHSNVPROC
epoxy_glPathGlyphsNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 40980 /* glPathGlyphsNV */);
}

static PFNGLPATHMEMORYGLYPHINDEXARRAYNVPROC
epoxy_glPathMemoryGlyphIndexArrayNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 40995 /* glPathMemoryGlyphIndexArrayNV */);
}

static PFNGLPATHPARAMETERFNVPROC
epoxy_glPathParameterfNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 41025 /* glPathParameterfNV */);
}

static PFNGLPATHPARAMETERFVNVPROC
epoxy_glPathParameterfvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 41044 /* glPathParameterfvNV */);
}

static PFNGLPATHPARAMETERINVPROC
epoxy_glPathParameteriNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 41064 /* glPathParameteriNV */);
}

static PFNGLPATHPARAMETERIVNVPROC
epoxy_glPathParameterivNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 41083 /* glPathParameterivNV */);
}

static PFNGLPATHSTENCILDEPTHOFFSETNVPROC
epoxy_glPathStencilDepthOffsetNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 41103 /* glPathStencilDepthOffsetNV */);
}

static PFNGLPATHSTENCILFUNCNVPROC
epoxy_glPathStencilFuncNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 41130 /* glPathStencilFuncNV */);
}

static PFNGLPATHSTRINGNVPROC
epoxy_glPathStringNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 41150 /* glPathStringNV */);
}

static PFNGLPATHSUBCOMMANDSNVPROC
epoxy_glPathSubCommandsNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 41165 /* glPathSubCommandsNV */);
}

static PFNGLPATHSUBCOORDSNVPROC
epoxy_glPathSubCoordsNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 41185 /* glPathSubCoordsNV */);
}

static PFNGLPATHTEXGENNVPROC
epoxy_glPathTexGenNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 41203 /* glPathTexGenNV */);
}

static PFNGLPAUSETRANSFORMFEEDBACKPROC
epoxy_glPauseTransformFeedback_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_GL_ARB_transform_feedback2,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_NV_transform_feedback2,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        41218 /* "glPauseTransformFeedback" */,
        41218 /* "glPauseTransformFeedback" */,
        41218 /* "glPauseTransformFeedback" */,
        41243 /* "glPauseTransformFeedbackNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 41218 /* "glPauseTransformFeedback" */,
                                providers, entrypoints);
}

static PFNGLPAUSETRANSFORMFEEDBACKNVPROC
epoxy_glPauseTransformFeedbackNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_transform_feedback2,
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_GL_ARB_transform_feedback2,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        41243 /* "glPauseTransformFeedbackNV" */,
        41218 /* "glPauseTransformFeedback" */,
        41218 /* "glPauseTransformFeedback" */,
        41218 /* "glPauseTransformFeedback" */,
    };
    return gl_provider_resolver(entrypoint_strings + 41243 /* "glPauseTransformFeedbackNV" */,
                                providers, entrypoints);
}

static PFNGLPIXELDATARANGENVPROC
epoxy_glPixelDataRangeNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_pixel_data_range, 41270 /* glPixelDataRangeNV */);
}

static PFNGLPIXELMAPFVPROC
epoxy_glPixelMapfv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 41289 /* glPixelMapfv */);
}

static PFNGLPIXELMAPUIVPROC
epoxy_glPixelMapuiv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 41302 /* glPixelMapuiv */);
}

static PFNGLPIXELMAPUSVPROC
epoxy_glPixelMapusv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 41316 /* glPixelMapusv */);
}

static PFNGLPIXELMAPXPROC
epoxy_glPixelMapx_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 41330 /* glPixelMapx */);
}

static PFNGLPIXELSTOREFPROC
epoxy_glPixelStoref_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 41342 /* glPixelStoref */);
}

static PFNGLPIXELSTOREIPROC
epoxy_glPixelStorei_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        41356 /* "glPixelStorei" */,
        41356 /* "glPixelStorei" */,
        41356 /* "glPixelStorei" */,
    };
    return gl_provider_resolver(entrypoint_strings + 41356 /* "glPixelStorei" */,
                                providers, entrypoints);
}

static PFNGLPIXELSTOREXPROC
epoxy_glPixelStorex_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 41370 /* glPixelStorex */);
}

static PFNGLPIXELTEXGENPARAMETERFSGISPROC
epoxy_glPixelTexGenParameterfSGIS_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIS_pixel_texture, 41384 /* glPixelTexGenParameterfSGIS */);
}

static PFNGLPIXELTEXGENPARAMETERFVSGISPROC
epoxy_glPixelTexGenParameterfvSGIS_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIS_pixel_texture, 41412 /* glPixelTexGenParameterfvSGIS */);
}

static PFNGLPIXELTEXGENPARAMETERISGISPROC
epoxy_glPixelTexGenParameteriSGIS_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIS_pixel_texture, 41441 /* glPixelTexGenParameteriSGIS */);
}

static PFNGLPIXELTEXGENPARAMETERIVSGISPROC
epoxy_glPixelTexGenParameterivSGIS_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIS_pixel_texture, 41469 /* glPixelTexGenParameterivSGIS */);
}

static PFNGLPIXELTEXGENSGIXPROC
epoxy_glPixelTexGenSGIX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIX_pixel_texture, 41498 /* glPixelTexGenSGIX */);
}

static PFNGLPIXELTRANSFERFPROC
epoxy_glPixelTransferf_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 41516 /* glPixelTransferf */);
}

static PFNGLPIXELTRANSFERIPROC
epoxy_glPixelTransferi_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 41533 /* glPixelTransferi */);
}

static PFNGLPIXELTRANSFERXOESPROC
epoxy_glPixelTransferxOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 41550 /* glPixelTransferxOES */);
}

static PFNGLPIXELTRANSFORMPARAMETERFEXTPROC
epoxy_glPixelTransformParameterfEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_pixel_transform, 41570 /* glPixelTransformParameterfEXT */);
}

static PFNGLPIXELTRANSFORMPARAMETERFVEXTPROC
epoxy_glPixelTransformParameterfvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_pixel_transform, 41600 /* glPixelTransformParameterfvEXT */);
}

static PFNGLPIXELTRANSFORMPARAMETERIEXTPROC
epoxy_glPixelTransformParameteriEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_pixel_transform, 41631 /* glPixelTransformParameteriEXT */);
}

static PFNGLPIXELTRANSFORMPARAMETERIVEXTPROC
epoxy_glPixelTransformParameterivEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_pixel_transform, 41661 /* glPixelTransformParameterivEXT */);
}

static PFNGLPIXELZOOMPROC
epoxy_glPixelZoom_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 41692 /* glPixelZoom */);
}

static PFNGLPIXELZOOMXOESPROC
epoxy_glPixelZoomxOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 41704 /* glPixelZoomxOES */);
}

static PFNGLPOINTALONGPATHNVPROC
epoxy_glPointAlongPathNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 41720 /* glPointAlongPathNV */);
}

static PFNGLPOINTPARAMETERFPROC
epoxy_glPointParameterf_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_GL_ARB_point_parameters,
        PROVIDER_GL_EXT_point_parameters,
        PROVIDER_GL_SGIS_point_parameters,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        41739 /* "glPointParameterf" */,
        41739 /* "glPointParameterf" */,
        41757 /* "glPointParameterfARB" */,
        41778 /* "glPointParameterfEXT" */,
        41799 /* "glPointParameterfSGIS" */,
    };
    return gl_provider_resolver(entrypoint_strings + 41739 /* "glPointParameterf" */,
                                providers, entrypoints);
}

static PFNGLPOINTPARAMETERFARBPROC
epoxy_glPointParameterfARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_point_parameters,
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_GL_EXT_point_parameters,
        PROVIDER_GL_SGIS_point_parameters,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        41757 /* "glPointParameterfARB" */,
        41739 /* "glPointParameterf" */,
        41739 /* "glPointParameterf" */,
        41778 /* "glPointParameterfEXT" */,
        41799 /* "glPointParameterfSGIS" */,
    };
    return gl_provider_resolver(entrypoint_strings + 41757 /* "glPointParameterfARB" */,
                                providers, entrypoints);
}

static PFNGLPOINTPARAMETERFEXTPROC
epoxy_glPointParameterfEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_point_parameters,
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_GL_ARB_point_parameters,
        PROVIDER_GL_SGIS_point_parameters,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        41778 /* "glPointParameterfEXT" */,
        41739 /* "glPointParameterf" */,
        41739 /* "glPointParameterf" */,
        41757 /* "glPointParameterfARB" */,
        41799 /* "glPointParameterfSGIS" */,
    };
    return gl_provider_resolver(entrypoint_strings + 41778 /* "glPointParameterfEXT" */,
                                providers, entrypoints);
}

static PFNGLPOINTPARAMETERFSGISPROC
epoxy_glPointParameterfSGIS_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_SGIS_point_parameters,
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_GL_ARB_point_parameters,
        PROVIDER_GL_EXT_point_parameters,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        41799 /* "glPointParameterfSGIS" */,
        41739 /* "glPointParameterf" */,
        41739 /* "glPointParameterf" */,
        41757 /* "glPointParameterfARB" */,
        41778 /* "glPointParameterfEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 41799 /* "glPointParameterfSGIS" */,
                                providers, entrypoints);
}

static PFNGLPOINTPARAMETERFVPROC
epoxy_glPointParameterfv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_GL_ARB_point_parameters,
        PROVIDER_GL_EXT_point_parameters,
        PROVIDER_GL_SGIS_point_parameters,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        41821 /* "glPointParameterfv" */,
        41821 /* "glPointParameterfv" */,
        41840 /* "glPointParameterfvARB" */,
        41862 /* "glPointParameterfvEXT" */,
        41884 /* "glPointParameterfvSGIS" */,
    };
    return gl_provider_resolver(entrypoint_strings + 41821 /* "glPointParameterfv" */,
                                providers, entrypoints);
}

static PFNGLPOINTPARAMETERFVARBPROC
epoxy_glPointParameterfvARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_point_parameters,
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_GL_EXT_point_parameters,
        PROVIDER_GL_SGIS_point_parameters,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        41840 /* "glPointParameterfvARB" */,
        41821 /* "glPointParameterfv" */,
        41821 /* "glPointParameterfv" */,
        41862 /* "glPointParameterfvEXT" */,
        41884 /* "glPointParameterfvSGIS" */,
    };
    return gl_provider_resolver(entrypoint_strings + 41840 /* "glPointParameterfvARB" */,
                                providers, entrypoints);
}

static PFNGLPOINTPARAMETERFVEXTPROC
epoxy_glPointParameterfvEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_point_parameters,
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_GL_ARB_point_parameters,
        PROVIDER_GL_SGIS_point_parameters,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        41862 /* "glPointParameterfvEXT" */,
        41821 /* "glPointParameterfv" */,
        41821 /* "glPointParameterfv" */,
        41840 /* "glPointParameterfvARB" */,
        41884 /* "glPointParameterfvSGIS" */,
    };
    return gl_provider_resolver(entrypoint_strings + 41862 /* "glPointParameterfvEXT" */,
                                providers, entrypoints);
}

static PFNGLPOINTPARAMETERFVSGISPROC
epoxy_glPointParameterfvSGIS_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_SGIS_point_parameters,
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_GL_ARB_point_parameters,
        PROVIDER_GL_EXT_point_parameters,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        41884 /* "glPointParameterfvSGIS" */,
        41821 /* "glPointParameterfv" */,
        41821 /* "glPointParameterfv" */,
        41840 /* "glPointParameterfvARB" */,
        41862 /* "glPointParameterfvEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 41884 /* "glPointParameterfvSGIS" */,
                                providers, entrypoints);
}

static PFNGLPOINTPARAMETERIPROC
epoxy_glPointParameteri_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_NV_point_sprite,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        41907 /* "glPointParameteri" */,
        41925 /* "glPointParameteriNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 41907 /* "glPointParameteri" */,
                                providers, entrypoints);
}

static PFNGLPOINTPARAMETERINVPROC
epoxy_glPointParameteriNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_point_sprite,
        PROVIDER_Desktop_OpenGL_1_4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        41925 /* "glPointParameteriNV" */,
        41907 /* "glPointParameteri" */,
    };
    return gl_provider_resolver(entrypoint_strings + 41925 /* "glPointParameteriNV" */,
                                providers, entrypoints);
}

static PFNGLPOINTPARAMETERIVPROC
epoxy_glPointParameteriv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_NV_point_sprite,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        41945 /* "glPointParameteriv" */,
        41964 /* "glPointParameterivNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 41945 /* "glPointParameteriv" */,
                                providers, entrypoints);
}

static PFNGLPOINTPARAMETERIVNVPROC
epoxy_glPointParameterivNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_point_sprite,
        PROVIDER_Desktop_OpenGL_1_4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        41964 /* "glPointParameterivNV" */,
        41945 /* "glPointParameteriv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 41964 /* "glPointParameterivNV" */,
                                providers, entrypoints);
}

static PFNGLPOINTPARAMETERXPROC
epoxy_glPointParameterx_resolver(void)
{
    return gl_single_resolver(PROVIDER_OpenGL_ES_1_0, 41985 /* glPointParameterx */);
}

static PFNGLPOINTPARAMETERXOESPROC
epoxy_glPointParameterxOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 42003 /* glPointParameterxOES */);
}

static PFNGLPOINTPARAMETERXVPROC
epoxy_glPointParameterxv_resolver(void)
{
    return gl_single_resolver(PROVIDER_OpenGL_ES_1_0, 42024 /* glPointParameterxv */);
}

static PFNGLPOINTPARAMETERXVOESPROC
epoxy_glPointParameterxvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 42043 /* glPointParameterxvOES */);
}

static PFNGLPOINTSIZEPROC
epoxy_glPointSize_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        42065 /* "glPointSize" */,
        42065 /* "glPointSize" */,
    };
    return gl_provider_resolver(entrypoint_strings + 42065 /* "glPointSize" */,
                                providers, entrypoints);
}

static PFNGLPOINTSIZEPOINTEROESPROC
epoxy_glPointSizePointerOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_point_size_array, 42077 /* glPointSizePointerOES */);
}

static PFNGLPOINTSIZEXPROC
epoxy_glPointSizex_resolver(void)
{
    return gl_single_resolver(PROVIDER_OpenGL_ES_1_0, 42099 /* glPointSizex */);
}

static PFNGLPOINTSIZEXOESPROC
epoxy_glPointSizexOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 42112 /* glPointSizexOES */);
}

static PFNGLPOLLASYNCSGIXPROC
epoxy_glPollAsyncSGIX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIX_async, 42128 /* glPollAsyncSGIX */);
}

static PFNGLPOLLINSTRUMENTSSGIXPROC
epoxy_glPollInstrumentsSGIX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIX_instruments, 42144 /* glPollInstrumentsSGIX */);
}

static PFNGLPOLYGONMODEPROC
epoxy_glPolygonMode_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_GL_NV_polygon_mode,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        42166 /* "glPolygonMode" */,
        42180 /* "glPolygonModeNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 42166 /* "glPolygonMode" */,
                                providers, entrypoints);
}

static PFNGLPOLYGONMODENVPROC
epoxy_glPolygonModeNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_polygon_mode,
        PROVIDER_Desktop_OpenGL_1_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        42180 /* "glPolygonModeNV" */,
        42166 /* "glPolygonMode" */,
    };
    return gl_provider_resolver(entrypoint_strings + 42180 /* "glPolygonModeNV" */,
                                providers, entrypoints);
}

static PFNGLPOLYGONOFFSETPROC
epoxy_glPolygonOffset_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_1,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        42196 /* "glPolygonOffset" */,
        42196 /* "glPolygonOffset" */,
        42196 /* "glPolygonOffset" */,
    };
    return gl_provider_resolver(entrypoint_strings + 42196 /* "glPolygonOffset" */,
                                providers, entrypoints);
}

static PFNGLPOLYGONOFFSETCLAMPPROC
epoxy_glPolygonOffsetClamp_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_6,
        PROVIDER_GL_ARB_polygon_offset_clamp,
        PROVIDER_GL_EXT_polygon_offset_clamp,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        42212 /* "glPolygonOffsetClamp" */,
        42212 /* "glPolygonOffsetClamp" */,
        42233 /* "glPolygonOffsetClampEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 42212 /* "glPolygonOffsetClamp" */,
                                providers, entrypoints);
}

static PFNGLPOLYGONOFFSETCLAMPEXTPROC
epoxy_glPolygonOffsetClampEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_polygon_offset_clamp,
        PROVIDER_Desktop_OpenGL_4_6,
        PROVIDER_GL_ARB_polygon_offset_clamp,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        42233 /* "glPolygonOffsetClampEXT" */,
        42212 /* "glPolygonOffsetClamp" */,
        42212 /* "glPolygonOffsetClamp" */,
    };
    return gl_provider_resolver(entrypoint_strings + 42233 /* "glPolygonOffsetClampEXT" */,
                                providers, entrypoints);
}

static PFNGLPOLYGONOFFSETEXTPROC
epoxy_glPolygonOffsetEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_polygon_offset, 42257 /* glPolygonOffsetEXT */);
}

static PFNGLPOLYGONOFFSETXPROC
epoxy_glPolygonOffsetx_resolver(void)
{
    return gl_single_resolver(PROVIDER_OpenGL_ES_1_0, 42276 /* glPolygonOffsetx */);
}

static PFNGLPOLYGONOFFSETXOESPROC
epoxy_glPolygonOffsetxOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 42293 /* glPolygonOffsetxOES */);
}

static PFNGLPOLYGONSTIPPLEPROC
epoxy_glPolygonStipple_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 42313 /* glPolygonStipple */);
}

static PFNGLPOPATTRIBPROC
epoxy_glPopAttrib_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 42330 /* glPopAttrib */);
}

static PFNGLPOPCLIENTATTRIBPROC
epoxy_glPopClientAttrib_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_1, 42342 /* glPopClientAttrib */);
}

static PFNGLPOPDEBUGGROUPPROC
epoxy_glPopDebugGroup_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_KHR_debug,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_KHR_debug,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        42360 /* "glPopDebugGroup" */,
        42360 /* "glPopDebugGroup" */,
        42360 /* "glPopDebugGroup" */,
        42376 /* "glPopDebugGroupKHR" */,
    };
    return gl_provider_resolver(entrypoint_strings + 42360 /* "glPopDebugGroup" */,
                                providers, entrypoints);
}

static PFNGLPOPDEBUGGROUPKHRPROC
epoxy_glPopDebugGroupKHR_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_KHR_debug,
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_KHR_debug,
        PROVIDER_OpenGL_ES_3_2,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        42376 /* "glPopDebugGroupKHR" */,
        42360 /* "glPopDebugGroup" */,
        42360 /* "glPopDebugGroup" */,
        42360 /* "glPopDebugGroup" */,
    };
    return gl_provider_resolver(entrypoint_strings + 42376 /* "glPopDebugGroupKHR" */,
                                providers, entrypoints);
}

static PFNGLPOPGROUPMARKEREXTPROC
epoxy_glPopGroupMarkerEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_debug_marker, 42395 /* glPopGroupMarkerEXT */);
}

static PFNGLPOPMATRIXPROC
epoxy_glPopMatrix_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        42415 /* "glPopMatrix" */,
        42415 /* "glPopMatrix" */,
    };
    return gl_provider_resolver(entrypoint_strings + 42415 /* "glPopMatrix" */,
                                providers, entrypoints);
}

static PFNGLPOPNAMEPROC
epoxy_glPopName_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 42427 /* glPopName */);
}

static PFNGLPRESENTFRAMEDUALFILLNVPROC
epoxy_glPresentFrameDualFillNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_present_video, 42437 /* glPresentFrameDualFillNV */);
}

static PFNGLPRESENTFRAMEKEYEDNVPROC
epoxy_glPresentFrameKeyedNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_present_video, 42462 /* glPresentFrameKeyedNV */);
}

static PFNGLPRIMITIVEBOUNDINGBOXPROC
epoxy_glPrimitiveBoundingBox_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_ARB_ES3_2_compatibility,
        PROVIDER_GL_EXT_primitive_bounding_box,
        PROVIDER_GL_OES_primitive_bounding_box,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        42484 /* "glPrimitiveBoundingBox" */,
        42507 /* "glPrimitiveBoundingBoxARB" */,
        42533 /* "glPrimitiveBoundingBoxEXT" */,
        42559 /* "glPrimitiveBoundingBoxOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 42484 /* "glPrimitiveBoundingBox" */,
                                providers, entrypoints);
}

static PFNGLPRIMITIVEBOUNDINGBOXARBPROC
epoxy_glPrimitiveBoundingBoxARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_ES3_2_compatibility,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_primitive_bounding_box,
        PROVIDER_GL_OES_primitive_bounding_box,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        42507 /* "glPrimitiveBoundingBoxARB" */,
        42484 /* "glPrimitiveBoundingBox" */,
        42533 /* "glPrimitiveBoundingBoxEXT" */,
        42559 /* "glPrimitiveBoundingBoxOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 42507 /* "glPrimitiveBoundingBoxARB" */,
                                providers, entrypoints);
}

static PFNGLPRIMITIVEBOUNDINGBOXEXTPROC
epoxy_glPrimitiveBoundingBoxEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_primitive_bounding_box,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_ARB_ES3_2_compatibility,
        PROVIDER_GL_OES_primitive_bounding_box,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        42533 /* "glPrimitiveBoundingBoxEXT" */,
        42484 /* "glPrimitiveBoundingBox" */,
        42507 /* "glPrimitiveBoundingBoxARB" */,
        42559 /* "glPrimitiveBoundingBoxOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 42533 /* "glPrimitiveBoundingBoxEXT" */,
                                providers, entrypoints);
}

static PFNGLPRIMITIVEBOUNDINGBOXOESPROC
epoxy_glPrimitiveBoundingBoxOES_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_OES_primitive_bounding_box,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_ARB_ES3_2_compatibility,
        PROVIDER_GL_EXT_primitive_bounding_box,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        42559 /* "glPrimitiveBoundingBoxOES" */,
        42484 /* "glPrimitiveBoundingBox" */,
        42507 /* "glPrimitiveBoundingBoxARB" */,
        42533 /* "glPrimitiveBoundingBoxEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 42559 /* "glPrimitiveBoundingBoxOES" */,
                                providers, entrypoints);
}

static PFNGLPRIMITIVERESTARTINDEXPROC
epoxy_glPrimitiveRestartIndex_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_3_1, 42585 /* glPrimitiveRestartIndex */);
}

static PFNGLPRIMITIVERESTARTINDEXNVPROC
epoxy_glPrimitiveRestartIndexNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_primitive_restart, 42609 /* glPrimitiveRestartIndexNV */);
}

static PFNGLPRIMITIVERESTARTNVPROC
epoxy_glPrimitiveRestartNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_primitive_restart, 42635 /* glPrimitiveRestartNV */);
}

static PFNGLPRIORITIZETEXTURESPROC
epoxy_glPrioritizeTextures_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_1,
        PROVIDER_GL_EXT_texture_object,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        42656 /* "glPrioritizeTextures" */,
        42677 /* "glPrioritizeTexturesEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 42656 /* "glPrioritizeTextures" */,
                                providers, entrypoints);
}

static PFNGLPRIORITIZETEXTURESEXTPROC
epoxy_glPrioritizeTexturesEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_texture_object,
        PROVIDER_Desktop_OpenGL_1_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        42677 /* "glPrioritizeTexturesEXT" */,
        42656 /* "glPrioritizeTextures" */,
    };
    return gl_provider_resolver(entrypoint_strings + 42677 /* "glPrioritizeTexturesEXT" */,
                                providers, entrypoints);
}

static PFNGLPRIORITIZETEXTURESXOESPROC
epoxy_glPrioritizeTexturesxOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 42701 /* glPrioritizeTexturesxOES */);
}

static PFNGLPROGRAMBINARYPROC
epoxy_glProgramBinary_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_get_program_binary,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_OES_get_program_binary,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        42726 /* "glProgramBinary" */,
        42726 /* "glProgramBinary" */,
        42726 /* "glProgramBinary" */,
        42742 /* "glProgramBinaryOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 42726 /* "glProgramBinary" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMBINARYOESPROC
epoxy_glProgramBinaryOES_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_OES_get_program_binary,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_get_program_binary,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        42742 /* "glProgramBinaryOES" */,
        42726 /* "glProgramBinary" */,
        42726 /* "glProgramBinary" */,
        42726 /* "glProgramBinary" */,
    };
    return gl_provider_resolver(entrypoint_strings + 42742 /* "glProgramBinaryOES" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMBUFFERPARAMETERSIIVNVPROC
epoxy_glProgramBufferParametersIivNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_parameter_buffer_object, 42761 /* glProgramBufferParametersIivNV */);
}

static PFNGLPROGRAMBUFFERPARAMETERSIUIVNVPROC
epoxy_glProgramBufferParametersIuivNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_parameter_buffer_object, 42792 /* glProgramBufferParametersIuivNV */);
}

static PFNGLPROGRAMBUFFERPARAMETERSFVNVPROC
epoxy_glProgramBufferParametersfvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_parameter_buffer_object, 42824 /* glProgramBufferParametersfvNV */);
}

static PFNGLPROGRAMENVPARAMETER4DARBPROC
epoxy_glProgramEnvParameter4dARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_fragment_program,
        PROVIDER_GL_ARB_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        42854 /* "glProgramEnvParameter4dARB" */,
        42854 /* "glProgramEnvParameter4dARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 42854 /* "glProgramEnvParameter4dARB" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMENVPARAMETER4DVARBPROC
epoxy_glProgramEnvParameter4dvARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_fragment_program,
        PROVIDER_GL_ARB_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        42881 /* "glProgramEnvParameter4dvARB" */,
        42881 /* "glProgramEnvParameter4dvARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 42881 /* "glProgramEnvParameter4dvARB" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMENVPARAMETER4FARBPROC
epoxy_glProgramEnvParameter4fARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_fragment_program,
        PROVIDER_GL_ARB_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        42909 /* "glProgramEnvParameter4fARB" */,
        42909 /* "glProgramEnvParameter4fARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 42909 /* "glProgramEnvParameter4fARB" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMENVPARAMETER4FVARBPROC
epoxy_glProgramEnvParameter4fvARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_fragment_program,
        PROVIDER_GL_ARB_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        42936 /* "glProgramEnvParameter4fvARB" */,
        42936 /* "glProgramEnvParameter4fvARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 42936 /* "glProgramEnvParameter4fvARB" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMENVPARAMETERI4INVPROC
epoxy_glProgramEnvParameterI4iNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_gpu_program4, 42964 /* glProgramEnvParameterI4iNV */);
}

static PFNGLPROGRAMENVPARAMETERI4IVNVPROC
epoxy_glProgramEnvParameterI4ivNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_gpu_program4, 42991 /* glProgramEnvParameterI4ivNV */);
}

static PFNGLPROGRAMENVPARAMETERI4UINVPROC
epoxy_glProgramEnvParameterI4uiNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_gpu_program4, 43019 /* glProgramEnvParameterI4uiNV */);
}

static PFNGLPROGRAMENVPARAMETERI4UIVNVPROC
epoxy_glProgramEnvParameterI4uivNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_gpu_program4, 43047 /* glProgramEnvParameterI4uivNV */);
}

static PFNGLPROGRAMENVPARAMETERS4FVEXTPROC
epoxy_glProgramEnvParameters4fvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_gpu_program_parameters, 43076 /* glProgramEnvParameters4fvEXT */);
}

static PFNGLPROGRAMENVPARAMETERSI4IVNVPROC
epoxy_glProgramEnvParametersI4ivNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_gpu_program4, 43105 /* glProgramEnvParametersI4ivNV */);
}

static PFNGLPROGRAMENVPARAMETERSI4UIVNVPROC
epoxy_glProgramEnvParametersI4uivNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_gpu_program4, 43134 /* glProgramEnvParametersI4uivNV */);
}

static PFNGLPROGRAMLOCALPARAMETER4DARBPROC
epoxy_glProgramLocalParameter4dARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_fragment_program,
        PROVIDER_GL_ARB_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        43164 /* "glProgramLocalParameter4dARB" */,
        43164 /* "glProgramLocalParameter4dARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 43164 /* "glProgramLocalParameter4dARB" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMLOCALPARAMETER4DVARBPROC
epoxy_glProgramLocalParameter4dvARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_fragment_program,
        PROVIDER_GL_ARB_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        43193 /* "glProgramLocalParameter4dvARB" */,
        43193 /* "glProgramLocalParameter4dvARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 43193 /* "glProgramLocalParameter4dvARB" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMLOCALPARAMETER4FARBPROC
epoxy_glProgramLocalParameter4fARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_fragment_program,
        PROVIDER_GL_ARB_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        43223 /* "glProgramLocalParameter4fARB" */,
        43223 /* "glProgramLocalParameter4fARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 43223 /* "glProgramLocalParameter4fARB" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMLOCALPARAMETER4FVARBPROC
epoxy_glProgramLocalParameter4fvARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_fragment_program,
        PROVIDER_GL_ARB_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        43252 /* "glProgramLocalParameter4fvARB" */,
        43252 /* "glProgramLocalParameter4fvARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 43252 /* "glProgramLocalParameter4fvARB" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMLOCALPARAMETERI4INVPROC
epoxy_glProgramLocalParameterI4iNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_gpu_program4, 43282 /* glProgramLocalParameterI4iNV */);
}

static PFNGLPROGRAMLOCALPARAMETERI4IVNVPROC
epoxy_glProgramLocalParameterI4ivNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_gpu_program4, 43311 /* glProgramLocalParameterI4ivNV */);
}

static PFNGLPROGRAMLOCALPARAMETERI4UINVPROC
epoxy_glProgramLocalParameterI4uiNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_gpu_program4, 43341 /* glProgramLocalParameterI4uiNV */);
}

static PFNGLPROGRAMLOCALPARAMETERI4UIVNVPROC
epoxy_glProgramLocalParameterI4uivNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_gpu_program4, 43371 /* glProgramLocalParameterI4uivNV */);
}

static PFNGLPROGRAMLOCALPARAMETERS4FVEXTPROC
epoxy_glProgramLocalParameters4fvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_gpu_program_parameters, 43402 /* glProgramLocalParameters4fvEXT */);
}

static PFNGLPROGRAMLOCALPARAMETERSI4IVNVPROC
epoxy_glProgramLocalParametersI4ivNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_gpu_program4, 43433 /* glProgramLocalParametersI4ivNV */);
}

static PFNGLPROGRAMLOCALPARAMETERSI4UIVNVPROC
epoxy_glProgramLocalParametersI4uivNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_gpu_program4, 43464 /* glProgramLocalParametersI4uivNV */);
}

static PFNGLPROGRAMNAMEDPARAMETER4DNVPROC
epoxy_glProgramNamedParameter4dNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_fragment_program, 43496 /* glProgramNamedParameter4dNV */);
}

static PFNGLPROGRAMNAMEDPARAMETER4DVNVPROC
epoxy_glProgramNamedParameter4dvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_fragment_program, 43524 /* glProgramNamedParameter4dvNV */);
}

static PFNGLPROGRAMNAMEDPARAMETER4FNVPROC
epoxy_glProgramNamedParameter4fNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_fragment_program, 43553 /* glProgramNamedParameter4fNV */);
}

static PFNGLPROGRAMNAMEDPARAMETER4FVNVPROC
epoxy_glProgramNamedParameter4fvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_fragment_program, 43581 /* glProgramNamedParameter4fvNV */);
}

static PFNGLPROGRAMPARAMETER4DNVPROC
epoxy_glProgramParameter4dNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_program, 43610 /* glProgramParameter4dNV */);
}

static PFNGLPROGRAMPARAMETER4DVNVPROC
epoxy_glProgramParameter4dvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_program, 43633 /* glProgramParameter4dvNV */);
}

static PFNGLPROGRAMPARAMETER4FNVPROC
epoxy_glProgramParameter4fNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_program, 43657 /* glProgramParameter4fNV */);
}

static PFNGLPROGRAMPARAMETER4FVNVPROC
epoxy_glProgramParameter4fvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_program, 43680 /* glProgramParameter4fvNV */);
}

static PFNGLPROGRAMPARAMETERIPROC
epoxy_glProgramParameteri_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_get_program_binary,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_ARB_geometry_shader4,
        PROVIDER_GL_EXT_geometry_shader4,
        PROVIDER_GL_EXT_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        43704 /* "glProgramParameteri" */,
        43704 /* "glProgramParameteri" */,
        43704 /* "glProgramParameteri" */,
        43704 /* "glProgramParameteri" */,
        43724 /* "glProgramParameteriARB" */,
        43747 /* "glProgramParameteriEXT" */,
        43747 /* "glProgramParameteriEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 43704 /* "glProgramParameteri" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMPARAMETERIARBPROC
epoxy_glProgramParameteriARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_geometry_shader4,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_get_program_binary,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_EXT_geometry_shader4,
        PROVIDER_GL_EXT_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        43724 /* "glProgramParameteriARB" */,
        43704 /* "glProgramParameteri" */,
        43704 /* "glProgramParameteri" */,
        43704 /* "glProgramParameteri" */,
        43704 /* "glProgramParameteri" */,
        43747 /* "glProgramParameteriEXT" */,
        43747 /* "glProgramParameteriEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 43724 /* "glProgramParameteriARB" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMPARAMETERIEXTPROC
epoxy_glProgramParameteriEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_geometry_shader4,
        PROVIDER_GL_EXT_separate_shader_objects,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_get_program_binary,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_ARB_geometry_shader4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        43747 /* "glProgramParameteriEXT" */,
        43747 /* "glProgramParameteriEXT" */,
        43704 /* "glProgramParameteri" */,
        43704 /* "glProgramParameteri" */,
        43704 /* "glProgramParameteri" */,
        43704 /* "glProgramParameteri" */,
        43724 /* "glProgramParameteriARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 43747 /* "glProgramParameteriEXT" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMPARAMETERS4DVNVPROC
epoxy_glProgramParameters4dvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_program, 43770 /* glProgramParameters4dvNV */);
}

static PFNGLPROGRAMPARAMETERS4FVNVPROC
epoxy_glProgramParameters4fvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_program, 43795 /* glProgramParameters4fvNV */);
}

static PFNGLPROGRAMPATHFRAGMENTINPUTGENNVPROC
epoxy_glProgramPathFragmentInputGenNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 43820 /* glProgramPathFragmentInputGenNV */);
}

static PFNGLPROGRAMSTRINGARBPROC
epoxy_glProgramStringARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_fragment_program,
        PROVIDER_GL_ARB_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        43852 /* "glProgramStringARB" */,
        43852 /* "glProgramStringARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 43852 /* "glProgramStringARB" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMSUBROUTINEPARAMETERSUIVNVPROC
epoxy_glProgramSubroutineParametersuivNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_gpu_program5, 43871 /* glProgramSubroutineParametersuivNV */);
}

static PFNGLPROGRAMUNIFORM1DPROC
epoxy_glProgramUniform1d_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        43906 /* "glProgramUniform1d" */,
        43906 /* "glProgramUniform1d" */,
    };
    return gl_provider_resolver(entrypoint_strings + 43906 /* "glProgramUniform1d" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM1DEXTPROC
epoxy_glProgramUniform1dEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 43925 /* glProgramUniform1dEXT */);
}

static PFNGLPROGRAMUNIFORM1DVPROC
epoxy_glProgramUniform1dv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        43947 /* "glProgramUniform1dv" */,
        43947 /* "glProgramUniform1dv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 43947 /* "glProgramUniform1dv" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM1DVEXTPROC
epoxy_glProgramUniform1dvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 43967 /* glProgramUniform1dvEXT */);
}

static PFNGLPROGRAMUNIFORM1FPROC
epoxy_glProgramUniform1f_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        43990 /* "glProgramUniform1f" */,
        43990 /* "glProgramUniform1f" */,
        43990 /* "glProgramUniform1f" */,
        44009 /* "glProgramUniform1fEXT" */,
        44009 /* "glProgramUniform1fEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 43990 /* "glProgramUniform1f" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM1FEXTPROC
epoxy_glProgramUniform1fEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        44009 /* "glProgramUniform1fEXT" */,
        44009 /* "glProgramUniform1fEXT" */,
        43990 /* "glProgramUniform1f" */,
        43990 /* "glProgramUniform1f" */,
        43990 /* "glProgramUniform1f" */,
    };
    return gl_provider_resolver(entrypoint_strings + 44009 /* "glProgramUniform1fEXT" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM1FVPROC
epoxy_glProgramUniform1fv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        44031 /* "glProgramUniform1fv" */,
        44031 /* "glProgramUniform1fv" */,
        44031 /* "glProgramUniform1fv" */,
        44051 /* "glProgramUniform1fvEXT" */,
        44051 /* "glProgramUniform1fvEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 44031 /* "glProgramUniform1fv" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM1FVEXTPROC
epoxy_glProgramUniform1fvEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        44051 /* "glProgramUniform1fvEXT" */,
        44051 /* "glProgramUniform1fvEXT" */,
        44031 /* "glProgramUniform1fv" */,
        44031 /* "glProgramUniform1fv" */,
        44031 /* "glProgramUniform1fv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 44051 /* "glProgramUniform1fvEXT" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM1IPROC
epoxy_glProgramUniform1i_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        44074 /* "glProgramUniform1i" */,
        44074 /* "glProgramUniform1i" */,
        44074 /* "glProgramUniform1i" */,
        44189 /* "glProgramUniform1iEXT" */,
        44189 /* "glProgramUniform1iEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 44074 /* "glProgramUniform1i" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM1I64ARBPROC
epoxy_glProgramUniform1i64ARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_gpu_shader_int64, 44093 /* glProgramUniform1i64ARB */);
}

static PFNGLPROGRAMUNIFORM1I64NVPROC
epoxy_glProgramUniform1i64NV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_AMD_gpu_shader_int64,
        PROVIDER_GL_NV_gpu_shader5,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        44117 /* "glProgramUniform1i64NV" */,
        44117 /* "glProgramUniform1i64NV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 44117 /* "glProgramUniform1i64NV" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM1I64VARBPROC
epoxy_glProgramUniform1i64vARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_gpu_shader_int64, 44140 /* glProgramUniform1i64vARB */);
}

static PFNGLPROGRAMUNIFORM1I64VNVPROC
epoxy_glProgramUniform1i64vNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_AMD_gpu_shader_int64,
        PROVIDER_GL_NV_gpu_shader5,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        44165 /* "glProgramUniform1i64vNV" */,
        44165 /* "glProgramUniform1i64vNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 44165 /* "glProgramUniform1i64vNV" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM1IEXTPROC
epoxy_glProgramUniform1iEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        44189 /* "glProgramUniform1iEXT" */,
        44189 /* "glProgramUniform1iEXT" */,
        44074 /* "glProgramUniform1i" */,
        44074 /* "glProgramUniform1i" */,
        44074 /* "glProgramUniform1i" */,
    };
    return gl_provider_resolver(entrypoint_strings + 44189 /* "glProgramUniform1iEXT" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM1IVPROC
epoxy_glProgramUniform1iv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        44211 /* "glProgramUniform1iv" */,
        44211 /* "glProgramUniform1iv" */,
        44211 /* "glProgramUniform1iv" */,
        44231 /* "glProgramUniform1ivEXT" */,
        44231 /* "glProgramUniform1ivEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 44211 /* "glProgramUniform1iv" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM1IVEXTPROC
epoxy_glProgramUniform1ivEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        44231 /* "glProgramUniform1ivEXT" */,
        44231 /* "glProgramUniform1ivEXT" */,
        44211 /* "glProgramUniform1iv" */,
        44211 /* "glProgramUniform1iv" */,
        44211 /* "glProgramUniform1iv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 44231 /* "glProgramUniform1ivEXT" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM1UIPROC
epoxy_glProgramUniform1ui_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        44254 /* "glProgramUniform1ui" */,
        44254 /* "glProgramUniform1ui" */,
        44254 /* "glProgramUniform1ui" */,
        44374 /* "glProgramUniform1uiEXT" */,
        44374 /* "glProgramUniform1uiEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 44254 /* "glProgramUniform1ui" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM1UI64ARBPROC
epoxy_glProgramUniform1ui64ARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_gpu_shader_int64, 44274 /* glProgramUniform1ui64ARB */);
}

static PFNGLPROGRAMUNIFORM1UI64NVPROC
epoxy_glProgramUniform1ui64NV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_AMD_gpu_shader_int64,
        PROVIDER_GL_NV_gpu_shader5,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        44299 /* "glProgramUniform1ui64NV" */,
        44299 /* "glProgramUniform1ui64NV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 44299 /* "glProgramUniform1ui64NV" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM1UI64VARBPROC
epoxy_glProgramUniform1ui64vARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_gpu_shader_int64, 44323 /* glProgramUniform1ui64vARB */);
}

static PFNGLPROGRAMUNIFORM1UI64VNVPROC
epoxy_glProgramUniform1ui64vNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_AMD_gpu_shader_int64,
        PROVIDER_GL_NV_gpu_shader5,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        44349 /* "glProgramUniform1ui64vNV" */,
        44349 /* "glProgramUniform1ui64vNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 44349 /* "glProgramUniform1ui64vNV" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM1UIEXTPROC
epoxy_glProgramUniform1uiEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        44374 /* "glProgramUniform1uiEXT" */,
        44374 /* "glProgramUniform1uiEXT" */,
        44254 /* "glProgramUniform1ui" */,
        44254 /* "glProgramUniform1ui" */,
        44254 /* "glProgramUniform1ui" */,
    };
    return gl_provider_resolver(entrypoint_strings + 44374 /* "glProgramUniform1uiEXT" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM1UIVPROC
epoxy_glProgramUniform1uiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        44397 /* "glProgramUniform1uiv" */,
        44397 /* "glProgramUniform1uiv" */,
        44397 /* "glProgramUniform1uiv" */,
        44418 /* "glProgramUniform1uivEXT" */,
        44418 /* "glProgramUniform1uivEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 44397 /* "glProgramUniform1uiv" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM1UIVEXTPROC
epoxy_glProgramUniform1uivEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        44418 /* "glProgramUniform1uivEXT" */,
        44418 /* "glProgramUniform1uivEXT" */,
        44397 /* "glProgramUniform1uiv" */,
        44397 /* "glProgramUniform1uiv" */,
        44397 /* "glProgramUniform1uiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 44418 /* "glProgramUniform1uivEXT" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM2DPROC
epoxy_glProgramUniform2d_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        44442 /* "glProgramUniform2d" */,
        44442 /* "glProgramUniform2d" */,
    };
    return gl_provider_resolver(entrypoint_strings + 44442 /* "glProgramUniform2d" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM2DEXTPROC
epoxy_glProgramUniform2dEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 44461 /* glProgramUniform2dEXT */);
}

static PFNGLPROGRAMUNIFORM2DVPROC
epoxy_glProgramUniform2dv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        44483 /* "glProgramUniform2dv" */,
        44483 /* "glProgramUniform2dv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 44483 /* "glProgramUniform2dv" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM2DVEXTPROC
epoxy_glProgramUniform2dvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 44503 /* glProgramUniform2dvEXT */);
}

static PFNGLPROGRAMUNIFORM2FPROC
epoxy_glProgramUniform2f_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        44526 /* "glProgramUniform2f" */,
        44526 /* "glProgramUniform2f" */,
        44526 /* "glProgramUniform2f" */,
        44545 /* "glProgramUniform2fEXT" */,
        44545 /* "glProgramUniform2fEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 44526 /* "glProgramUniform2f" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM2FEXTPROC
epoxy_glProgramUniform2fEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        44545 /* "glProgramUniform2fEXT" */,
        44545 /* "glProgramUniform2fEXT" */,
        44526 /* "glProgramUniform2f" */,
        44526 /* "glProgramUniform2f" */,
        44526 /* "glProgramUniform2f" */,
    };
    return gl_provider_resolver(entrypoint_strings + 44545 /* "glProgramUniform2fEXT" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM2FVPROC
epoxy_glProgramUniform2fv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        44567 /* "glProgramUniform2fv" */,
        44567 /* "glProgramUniform2fv" */,
        44567 /* "glProgramUniform2fv" */,
        44587 /* "glProgramUniform2fvEXT" */,
        44587 /* "glProgramUniform2fvEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 44567 /* "glProgramUniform2fv" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM2FVEXTPROC
epoxy_glProgramUniform2fvEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        44587 /* "glProgramUniform2fvEXT" */,
        44587 /* "glProgramUniform2fvEXT" */,
        44567 /* "glProgramUniform2fv" */,
        44567 /* "glProgramUniform2fv" */,
        44567 /* "glProgramUniform2fv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 44587 /* "glProgramUniform2fvEXT" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM2IPROC
epoxy_glProgramUniform2i_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        44610 /* "glProgramUniform2i" */,
        44610 /* "glProgramUniform2i" */,
        44610 /* "glProgramUniform2i" */,
        44725 /* "glProgramUniform2iEXT" */,
        44725 /* "glProgramUniform2iEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 44610 /* "glProgramUniform2i" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM2I64ARBPROC
epoxy_glProgramUniform2i64ARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_gpu_shader_int64, 44629 /* glProgramUniform2i64ARB */);
}

static PFNGLPROGRAMUNIFORM2I64NVPROC
epoxy_glProgramUniform2i64NV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_AMD_gpu_shader_int64,
        PROVIDER_GL_NV_gpu_shader5,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        44653 /* "glProgramUniform2i64NV" */,
        44653 /* "glProgramUniform2i64NV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 44653 /* "glProgramUniform2i64NV" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM2I64VARBPROC
epoxy_glProgramUniform2i64vARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_gpu_shader_int64, 44676 /* glProgramUniform2i64vARB */);
}

static PFNGLPROGRAMUNIFORM2I64VNVPROC
epoxy_glProgramUniform2i64vNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_AMD_gpu_shader_int64,
        PROVIDER_GL_NV_gpu_shader5,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        44701 /* "glProgramUniform2i64vNV" */,
        44701 /* "glProgramUniform2i64vNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 44701 /* "glProgramUniform2i64vNV" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM2IEXTPROC
epoxy_glProgramUniform2iEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        44725 /* "glProgramUniform2iEXT" */,
        44725 /* "glProgramUniform2iEXT" */,
        44610 /* "glProgramUniform2i" */,
        44610 /* "glProgramUniform2i" */,
        44610 /* "glProgramUniform2i" */,
    };
    return gl_provider_resolver(entrypoint_strings + 44725 /* "glProgramUniform2iEXT" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM2IVPROC
epoxy_glProgramUniform2iv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        44747 /* "glProgramUniform2iv" */,
        44747 /* "glProgramUniform2iv" */,
        44747 /* "glProgramUniform2iv" */,
        44767 /* "glProgramUniform2ivEXT" */,
        44767 /* "glProgramUniform2ivEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 44747 /* "glProgramUniform2iv" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM2IVEXTPROC
epoxy_glProgramUniform2ivEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        44767 /* "glProgramUniform2ivEXT" */,
        44767 /* "glProgramUniform2ivEXT" */,
        44747 /* "glProgramUniform2iv" */,
        44747 /* "glProgramUniform2iv" */,
        44747 /* "glProgramUniform2iv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 44767 /* "glProgramUniform2ivEXT" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM2UIPROC
epoxy_glProgramUniform2ui_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        44790 /* "glProgramUniform2ui" */,
        44790 /* "glProgramUniform2ui" */,
        44790 /* "glProgramUniform2ui" */,
        44910 /* "glProgramUniform2uiEXT" */,
        44910 /* "glProgramUniform2uiEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 44790 /* "glProgramUniform2ui" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM2UI64ARBPROC
epoxy_glProgramUniform2ui64ARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_gpu_shader_int64, 44810 /* glProgramUniform2ui64ARB */);
}

static PFNGLPROGRAMUNIFORM2UI64NVPROC
epoxy_glProgramUniform2ui64NV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_AMD_gpu_shader_int64,
        PROVIDER_GL_NV_gpu_shader5,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        44835 /* "glProgramUniform2ui64NV" */,
        44835 /* "glProgramUniform2ui64NV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 44835 /* "glProgramUniform2ui64NV" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM2UI64VARBPROC
epoxy_glProgramUniform2ui64vARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_gpu_shader_int64, 44859 /* glProgramUniform2ui64vARB */);
}

static PFNGLPROGRAMUNIFORM2UI64VNVPROC
epoxy_glProgramUniform2ui64vNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_AMD_gpu_shader_int64,
        PROVIDER_GL_NV_gpu_shader5,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        44885 /* "glProgramUniform2ui64vNV" */,
        44885 /* "glProgramUniform2ui64vNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 44885 /* "glProgramUniform2ui64vNV" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM2UIEXTPROC
epoxy_glProgramUniform2uiEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        44910 /* "glProgramUniform2uiEXT" */,
        44910 /* "glProgramUniform2uiEXT" */,
        44790 /* "glProgramUniform2ui" */,
        44790 /* "glProgramUniform2ui" */,
        44790 /* "glProgramUniform2ui" */,
    };
    return gl_provider_resolver(entrypoint_strings + 44910 /* "glProgramUniform2uiEXT" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM2UIVPROC
epoxy_glProgramUniform2uiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        44933 /* "glProgramUniform2uiv" */,
        44933 /* "glProgramUniform2uiv" */,
        44933 /* "glProgramUniform2uiv" */,
        44954 /* "glProgramUniform2uivEXT" */,
        44954 /* "glProgramUniform2uivEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 44933 /* "glProgramUniform2uiv" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM2UIVEXTPROC
epoxy_glProgramUniform2uivEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        44954 /* "glProgramUniform2uivEXT" */,
        44954 /* "glProgramUniform2uivEXT" */,
        44933 /* "glProgramUniform2uiv" */,
        44933 /* "glProgramUniform2uiv" */,
        44933 /* "glProgramUniform2uiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 44954 /* "glProgramUniform2uivEXT" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM3DPROC
epoxy_glProgramUniform3d_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        44978 /* "glProgramUniform3d" */,
        44978 /* "glProgramUniform3d" */,
    };
    return gl_provider_resolver(entrypoint_strings + 44978 /* "glProgramUniform3d" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM3DEXTPROC
epoxy_glProgramUniform3dEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 44997 /* glProgramUniform3dEXT */);
}

static PFNGLPROGRAMUNIFORM3DVPROC
epoxy_glProgramUniform3dv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        45019 /* "glProgramUniform3dv" */,
        45019 /* "glProgramUniform3dv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 45019 /* "glProgramUniform3dv" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM3DVEXTPROC
epoxy_glProgramUniform3dvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 45039 /* glProgramUniform3dvEXT */);
}

static PFNGLPROGRAMUNIFORM3FPROC
epoxy_glProgramUniform3f_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        45062 /* "glProgramUniform3f" */,
        45062 /* "glProgramUniform3f" */,
        45062 /* "glProgramUniform3f" */,
        45081 /* "glProgramUniform3fEXT" */,
        45081 /* "glProgramUniform3fEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 45062 /* "glProgramUniform3f" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM3FEXTPROC
epoxy_glProgramUniform3fEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        45081 /* "glProgramUniform3fEXT" */,
        45081 /* "glProgramUniform3fEXT" */,
        45062 /* "glProgramUniform3f" */,
        45062 /* "glProgramUniform3f" */,
        45062 /* "glProgramUniform3f" */,
    };
    return gl_provider_resolver(entrypoint_strings + 45081 /* "glProgramUniform3fEXT" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM3FVPROC
epoxy_glProgramUniform3fv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        45103 /* "glProgramUniform3fv" */,
        45103 /* "glProgramUniform3fv" */,
        45103 /* "glProgramUniform3fv" */,
        45123 /* "glProgramUniform3fvEXT" */,
        45123 /* "glProgramUniform3fvEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 45103 /* "glProgramUniform3fv" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM3FVEXTPROC
epoxy_glProgramUniform3fvEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        45123 /* "glProgramUniform3fvEXT" */,
        45123 /* "glProgramUniform3fvEXT" */,
        45103 /* "glProgramUniform3fv" */,
        45103 /* "glProgramUniform3fv" */,
        45103 /* "glProgramUniform3fv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 45123 /* "glProgramUniform3fvEXT" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM3IPROC
epoxy_glProgramUniform3i_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        45146 /* "glProgramUniform3i" */,
        45146 /* "glProgramUniform3i" */,
        45146 /* "glProgramUniform3i" */,
        45261 /* "glProgramUniform3iEXT" */,
        45261 /* "glProgramUniform3iEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 45146 /* "glProgramUniform3i" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM3I64ARBPROC
epoxy_glProgramUniform3i64ARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_gpu_shader_int64, 45165 /* glProgramUniform3i64ARB */);
}

static PFNGLPROGRAMUNIFORM3I64NVPROC
epoxy_glProgramUniform3i64NV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_AMD_gpu_shader_int64,
        PROVIDER_GL_NV_gpu_shader5,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        45189 /* "glProgramUniform3i64NV" */,
        45189 /* "glProgramUniform3i64NV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 45189 /* "glProgramUniform3i64NV" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM3I64VARBPROC
epoxy_glProgramUniform3i64vARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_gpu_shader_int64, 45212 /* glProgramUniform3i64vARB */);
}

static PFNGLPROGRAMUNIFORM3I64VNVPROC
epoxy_glProgramUniform3i64vNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_AMD_gpu_shader_int64,
        PROVIDER_GL_NV_gpu_shader5,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        45237 /* "glProgramUniform3i64vNV" */,
        45237 /* "glProgramUniform3i64vNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 45237 /* "glProgramUniform3i64vNV" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM3IEXTPROC
epoxy_glProgramUniform3iEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        45261 /* "glProgramUniform3iEXT" */,
        45261 /* "glProgramUniform3iEXT" */,
        45146 /* "glProgramUniform3i" */,
        45146 /* "glProgramUniform3i" */,
        45146 /* "glProgramUniform3i" */,
    };
    return gl_provider_resolver(entrypoint_strings + 45261 /* "glProgramUniform3iEXT" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM3IVPROC
epoxy_glProgramUniform3iv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        45283 /* "glProgramUniform3iv" */,
        45283 /* "glProgramUniform3iv" */,
        45283 /* "glProgramUniform3iv" */,
        45303 /* "glProgramUniform3ivEXT" */,
        45303 /* "glProgramUniform3ivEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 45283 /* "glProgramUniform3iv" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM3IVEXTPROC
epoxy_glProgramUniform3ivEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        45303 /* "glProgramUniform3ivEXT" */,
        45303 /* "glProgramUniform3ivEXT" */,
        45283 /* "glProgramUniform3iv" */,
        45283 /* "glProgramUniform3iv" */,
        45283 /* "glProgramUniform3iv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 45303 /* "glProgramUniform3ivEXT" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM3UIPROC
epoxy_glProgramUniform3ui_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        45326 /* "glProgramUniform3ui" */,
        45326 /* "glProgramUniform3ui" */,
        45326 /* "glProgramUniform3ui" */,
        45446 /* "glProgramUniform3uiEXT" */,
        45446 /* "glProgramUniform3uiEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 45326 /* "glProgramUniform3ui" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM3UI64ARBPROC
epoxy_glProgramUniform3ui64ARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_gpu_shader_int64, 45346 /* glProgramUniform3ui64ARB */);
}

static PFNGLPROGRAMUNIFORM3UI64NVPROC
epoxy_glProgramUniform3ui64NV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_AMD_gpu_shader_int64,
        PROVIDER_GL_NV_gpu_shader5,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        45371 /* "glProgramUniform3ui64NV" */,
        45371 /* "glProgramUniform3ui64NV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 45371 /* "glProgramUniform3ui64NV" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM3UI64VARBPROC
epoxy_glProgramUniform3ui64vARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_gpu_shader_int64, 45395 /* glProgramUniform3ui64vARB */);
}

static PFNGLPROGRAMUNIFORM3UI64VNVPROC
epoxy_glProgramUniform3ui64vNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_AMD_gpu_shader_int64,
        PROVIDER_GL_NV_gpu_shader5,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        45421 /* "glProgramUniform3ui64vNV" */,
        45421 /* "glProgramUniform3ui64vNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 45421 /* "glProgramUniform3ui64vNV" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM3UIEXTPROC
epoxy_glProgramUniform3uiEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        45446 /* "glProgramUniform3uiEXT" */,
        45446 /* "glProgramUniform3uiEXT" */,
        45326 /* "glProgramUniform3ui" */,
        45326 /* "glProgramUniform3ui" */,
        45326 /* "glProgramUniform3ui" */,
    };
    return gl_provider_resolver(entrypoint_strings + 45446 /* "glProgramUniform3uiEXT" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM3UIVPROC
epoxy_glProgramUniform3uiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        45469 /* "glProgramUniform3uiv" */,
        45469 /* "glProgramUniform3uiv" */,
        45469 /* "glProgramUniform3uiv" */,
        45490 /* "glProgramUniform3uivEXT" */,
        45490 /* "glProgramUniform3uivEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 45469 /* "glProgramUniform3uiv" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM3UIVEXTPROC
epoxy_glProgramUniform3uivEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        45490 /* "glProgramUniform3uivEXT" */,
        45490 /* "glProgramUniform3uivEXT" */,
        45469 /* "glProgramUniform3uiv" */,
        45469 /* "glProgramUniform3uiv" */,
        45469 /* "glProgramUniform3uiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 45490 /* "glProgramUniform3uivEXT" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM4DPROC
epoxy_glProgramUniform4d_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        45514 /* "glProgramUniform4d" */,
        45514 /* "glProgramUniform4d" */,
    };
    return gl_provider_resolver(entrypoint_strings + 45514 /* "glProgramUniform4d" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM4DEXTPROC
epoxy_glProgramUniform4dEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 45533 /* glProgramUniform4dEXT */);
}

static PFNGLPROGRAMUNIFORM4DVPROC
epoxy_glProgramUniform4dv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        45555 /* "glProgramUniform4dv" */,
        45555 /* "glProgramUniform4dv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 45555 /* "glProgramUniform4dv" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM4DVEXTPROC
epoxy_glProgramUniform4dvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 45575 /* glProgramUniform4dvEXT */);
}

static PFNGLPROGRAMUNIFORM4FPROC
epoxy_glProgramUniform4f_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        45598 /* "glProgramUniform4f" */,
        45598 /* "glProgramUniform4f" */,
        45598 /* "glProgramUniform4f" */,
        45617 /* "glProgramUniform4fEXT" */,
        45617 /* "glProgramUniform4fEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 45598 /* "glProgramUniform4f" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM4FEXTPROC
epoxy_glProgramUniform4fEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        45617 /* "glProgramUniform4fEXT" */,
        45617 /* "glProgramUniform4fEXT" */,
        45598 /* "glProgramUniform4f" */,
        45598 /* "glProgramUniform4f" */,
        45598 /* "glProgramUniform4f" */,
    };
    return gl_provider_resolver(entrypoint_strings + 45617 /* "glProgramUniform4fEXT" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM4FVPROC
epoxy_glProgramUniform4fv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        45639 /* "glProgramUniform4fv" */,
        45639 /* "glProgramUniform4fv" */,
        45639 /* "glProgramUniform4fv" */,
        45659 /* "glProgramUniform4fvEXT" */,
        45659 /* "glProgramUniform4fvEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 45639 /* "glProgramUniform4fv" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM4FVEXTPROC
epoxy_glProgramUniform4fvEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        45659 /* "glProgramUniform4fvEXT" */,
        45659 /* "glProgramUniform4fvEXT" */,
        45639 /* "glProgramUniform4fv" */,
        45639 /* "glProgramUniform4fv" */,
        45639 /* "glProgramUniform4fv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 45659 /* "glProgramUniform4fvEXT" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM4IPROC
epoxy_glProgramUniform4i_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        45682 /* "glProgramUniform4i" */,
        45682 /* "glProgramUniform4i" */,
        45682 /* "glProgramUniform4i" */,
        45797 /* "glProgramUniform4iEXT" */,
        45797 /* "glProgramUniform4iEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 45682 /* "glProgramUniform4i" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM4I64ARBPROC
epoxy_glProgramUniform4i64ARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_gpu_shader_int64, 45701 /* glProgramUniform4i64ARB */);
}

static PFNGLPROGRAMUNIFORM4I64NVPROC
epoxy_glProgramUniform4i64NV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_AMD_gpu_shader_int64,
        PROVIDER_GL_NV_gpu_shader5,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        45725 /* "glProgramUniform4i64NV" */,
        45725 /* "glProgramUniform4i64NV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 45725 /* "glProgramUniform4i64NV" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM4I64VARBPROC
epoxy_glProgramUniform4i64vARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_gpu_shader_int64, 45748 /* glProgramUniform4i64vARB */);
}

static PFNGLPROGRAMUNIFORM4I64VNVPROC
epoxy_glProgramUniform4i64vNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_AMD_gpu_shader_int64,
        PROVIDER_GL_NV_gpu_shader5,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        45773 /* "glProgramUniform4i64vNV" */,
        45773 /* "glProgramUniform4i64vNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 45773 /* "glProgramUniform4i64vNV" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM4IEXTPROC
epoxy_glProgramUniform4iEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        45797 /* "glProgramUniform4iEXT" */,
        45797 /* "glProgramUniform4iEXT" */,
        45682 /* "glProgramUniform4i" */,
        45682 /* "glProgramUniform4i" */,
        45682 /* "glProgramUniform4i" */,
    };
    return gl_provider_resolver(entrypoint_strings + 45797 /* "glProgramUniform4iEXT" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM4IVPROC
epoxy_glProgramUniform4iv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        45819 /* "glProgramUniform4iv" */,
        45819 /* "glProgramUniform4iv" */,
        45819 /* "glProgramUniform4iv" */,
        45839 /* "glProgramUniform4ivEXT" */,
        45839 /* "glProgramUniform4ivEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 45819 /* "glProgramUniform4iv" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM4IVEXTPROC
epoxy_glProgramUniform4ivEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        45839 /* "glProgramUniform4ivEXT" */,
        45839 /* "glProgramUniform4ivEXT" */,
        45819 /* "glProgramUniform4iv" */,
        45819 /* "glProgramUniform4iv" */,
        45819 /* "glProgramUniform4iv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 45839 /* "glProgramUniform4ivEXT" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM4UIPROC
epoxy_glProgramUniform4ui_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        45862 /* "glProgramUniform4ui" */,
        45862 /* "glProgramUniform4ui" */,
        45862 /* "glProgramUniform4ui" */,
        45982 /* "glProgramUniform4uiEXT" */,
        45982 /* "glProgramUniform4uiEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 45862 /* "glProgramUniform4ui" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM4UI64ARBPROC
epoxy_glProgramUniform4ui64ARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_gpu_shader_int64, 45882 /* glProgramUniform4ui64ARB */);
}

static PFNGLPROGRAMUNIFORM4UI64NVPROC
epoxy_glProgramUniform4ui64NV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_AMD_gpu_shader_int64,
        PROVIDER_GL_NV_gpu_shader5,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        45907 /* "glProgramUniform4ui64NV" */,
        45907 /* "glProgramUniform4ui64NV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 45907 /* "glProgramUniform4ui64NV" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM4UI64VARBPROC
epoxy_glProgramUniform4ui64vARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_gpu_shader_int64, 45931 /* glProgramUniform4ui64vARB */);
}

static PFNGLPROGRAMUNIFORM4UI64VNVPROC
epoxy_glProgramUniform4ui64vNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_AMD_gpu_shader_int64,
        PROVIDER_GL_NV_gpu_shader5,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        45957 /* "glProgramUniform4ui64vNV" */,
        45957 /* "glProgramUniform4ui64vNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 45957 /* "glProgramUniform4ui64vNV" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM4UIEXTPROC
epoxy_glProgramUniform4uiEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        45982 /* "glProgramUniform4uiEXT" */,
        45982 /* "glProgramUniform4uiEXT" */,
        45862 /* "glProgramUniform4ui" */,
        45862 /* "glProgramUniform4ui" */,
        45862 /* "glProgramUniform4ui" */,
    };
    return gl_provider_resolver(entrypoint_strings + 45982 /* "glProgramUniform4uiEXT" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM4UIVPROC
epoxy_glProgramUniform4uiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        46005 /* "glProgramUniform4uiv" */,
        46005 /* "glProgramUniform4uiv" */,
        46005 /* "glProgramUniform4uiv" */,
        46026 /* "glProgramUniform4uivEXT" */,
        46026 /* "glProgramUniform4uivEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 46005 /* "glProgramUniform4uiv" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORM4UIVEXTPROC
epoxy_glProgramUniform4uivEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        46026 /* "glProgramUniform4uivEXT" */,
        46026 /* "glProgramUniform4uivEXT" */,
        46005 /* "glProgramUniform4uiv" */,
        46005 /* "glProgramUniform4uiv" */,
        46005 /* "glProgramUniform4uiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 46026 /* "glProgramUniform4uivEXT" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORMHANDLEUI64ARBPROC
epoxy_glProgramUniformHandleui64ARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_bindless_texture,
        PROVIDER_GL_IMG_bindless_texture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        46050 /* "glProgramUniformHandleui64ARB" */,
        46080 /* "glProgramUniformHandleui64IMG" */,
    };
    return gl_provider_resolver(entrypoint_strings + 46050 /* "glProgramUniformHandleui64ARB" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORMHANDLEUI64IMGPROC
epoxy_glProgramUniformHandleui64IMG_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_IMG_bindless_texture,
        PROVIDER_GL_ARB_bindless_texture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        46080 /* "glProgramUniformHandleui64IMG" */,
        46050 /* "glProgramUniformHandleui64ARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 46080 /* "glProgramUniformHandleui64IMG" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORMHANDLEUI64NVPROC
epoxy_glProgramUniformHandleui64NV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_bindless_texture, 46110 /* glProgramUniformHandleui64NV */);
}

static PFNGLPROGRAMUNIFORMHANDLEUI64VARBPROC
epoxy_glProgramUniformHandleui64vARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_bindless_texture,
        PROVIDER_GL_IMG_bindless_texture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        46139 /* "glProgramUniformHandleui64vARB" */,
        46170 /* "glProgramUniformHandleui64vIMG" */,
    };
    return gl_provider_resolver(entrypoint_strings + 46139 /* "glProgramUniformHandleui64vARB" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORMHANDLEUI64VIMGPROC
epoxy_glProgramUniformHandleui64vIMG_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_IMG_bindless_texture,
        PROVIDER_GL_ARB_bindless_texture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        46170 /* "glProgramUniformHandleui64vIMG" */,
        46139 /* "glProgramUniformHandleui64vARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 46170 /* "glProgramUniformHandleui64vIMG" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORMHANDLEUI64VNVPROC
epoxy_glProgramUniformHandleui64vNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_bindless_texture, 46201 /* glProgramUniformHandleui64vNV */);
}

static PFNGLPROGRAMUNIFORMMATRIX2DVPROC
epoxy_glProgramUniformMatrix2dv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        46231 /* "glProgramUniformMatrix2dv" */,
        46231 /* "glProgramUniformMatrix2dv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 46231 /* "glProgramUniformMatrix2dv" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORMMATRIX2DVEXTPROC
epoxy_glProgramUniformMatrix2dvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 46257 /* glProgramUniformMatrix2dvEXT */);
}

static PFNGLPROGRAMUNIFORMMATRIX2FVPROC
epoxy_glProgramUniformMatrix2fv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        46286 /* "glProgramUniformMatrix2fv" */,
        46286 /* "glProgramUniformMatrix2fv" */,
        46286 /* "glProgramUniformMatrix2fv" */,
        46312 /* "glProgramUniformMatrix2fvEXT" */,
        46312 /* "glProgramUniformMatrix2fvEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 46286 /* "glProgramUniformMatrix2fv" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORMMATRIX2FVEXTPROC
epoxy_glProgramUniformMatrix2fvEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        46312 /* "glProgramUniformMatrix2fvEXT" */,
        46312 /* "glProgramUniformMatrix2fvEXT" */,
        46286 /* "glProgramUniformMatrix2fv" */,
        46286 /* "glProgramUniformMatrix2fv" */,
        46286 /* "glProgramUniformMatrix2fv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 46312 /* "glProgramUniformMatrix2fvEXT" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORMMATRIX2X3DVPROC
epoxy_glProgramUniformMatrix2x3dv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        46341 /* "glProgramUniformMatrix2x3dv" */,
        46341 /* "glProgramUniformMatrix2x3dv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 46341 /* "glProgramUniformMatrix2x3dv" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORMMATRIX2X3DVEXTPROC
epoxy_glProgramUniformMatrix2x3dvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 46369 /* glProgramUniformMatrix2x3dvEXT */);
}

static PFNGLPROGRAMUNIFORMMATRIX2X3FVPROC
epoxy_glProgramUniformMatrix2x3fv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        46400 /* "glProgramUniformMatrix2x3fv" */,
        46400 /* "glProgramUniformMatrix2x3fv" */,
        46400 /* "glProgramUniformMatrix2x3fv" */,
        46428 /* "glProgramUniformMatrix2x3fvEXT" */,
        46428 /* "glProgramUniformMatrix2x3fvEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 46400 /* "glProgramUniformMatrix2x3fv" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORMMATRIX2X3FVEXTPROC
epoxy_glProgramUniformMatrix2x3fvEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        46428 /* "glProgramUniformMatrix2x3fvEXT" */,
        46428 /* "glProgramUniformMatrix2x3fvEXT" */,
        46400 /* "glProgramUniformMatrix2x3fv" */,
        46400 /* "glProgramUniformMatrix2x3fv" */,
        46400 /* "glProgramUniformMatrix2x3fv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 46428 /* "glProgramUniformMatrix2x3fvEXT" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORMMATRIX2X4DVPROC
epoxy_glProgramUniformMatrix2x4dv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        46459 /* "glProgramUniformMatrix2x4dv" */,
        46459 /* "glProgramUniformMatrix2x4dv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 46459 /* "glProgramUniformMatrix2x4dv" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORMMATRIX2X4DVEXTPROC
epoxy_glProgramUniformMatrix2x4dvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 46487 /* glProgramUniformMatrix2x4dvEXT */);
}

static PFNGLPROGRAMUNIFORMMATRIX2X4FVPROC
epoxy_glProgramUniformMatrix2x4fv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        46518 /* "glProgramUniformMatrix2x4fv" */,
        46518 /* "glProgramUniformMatrix2x4fv" */,
        46518 /* "glProgramUniformMatrix2x4fv" */,
        46546 /* "glProgramUniformMatrix2x4fvEXT" */,
        46546 /* "glProgramUniformMatrix2x4fvEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 46518 /* "glProgramUniformMatrix2x4fv" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORMMATRIX2X4FVEXTPROC
epoxy_glProgramUniformMatrix2x4fvEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        46546 /* "glProgramUniformMatrix2x4fvEXT" */,
        46546 /* "glProgramUniformMatrix2x4fvEXT" */,
        46518 /* "glProgramUniformMatrix2x4fv" */,
        46518 /* "glProgramUniformMatrix2x4fv" */,
        46518 /* "glProgramUniformMatrix2x4fv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 46546 /* "glProgramUniformMatrix2x4fvEXT" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORMMATRIX3DVPROC
epoxy_glProgramUniformMatrix3dv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        46577 /* "glProgramUniformMatrix3dv" */,
        46577 /* "glProgramUniformMatrix3dv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 46577 /* "glProgramUniformMatrix3dv" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORMMATRIX3DVEXTPROC
epoxy_glProgramUniformMatrix3dvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 46603 /* glProgramUniformMatrix3dvEXT */);
}

static PFNGLPROGRAMUNIFORMMATRIX3FVPROC
epoxy_glProgramUniformMatrix3fv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        46632 /* "glProgramUniformMatrix3fv" */,
        46632 /* "glProgramUniformMatrix3fv" */,
        46632 /* "glProgramUniformMatrix3fv" */,
        46658 /* "glProgramUniformMatrix3fvEXT" */,
        46658 /* "glProgramUniformMatrix3fvEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 46632 /* "glProgramUniformMatrix3fv" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORMMATRIX3FVEXTPROC
epoxy_glProgramUniformMatrix3fvEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        46658 /* "glProgramUniformMatrix3fvEXT" */,
        46658 /* "glProgramUniformMatrix3fvEXT" */,
        46632 /* "glProgramUniformMatrix3fv" */,
        46632 /* "glProgramUniformMatrix3fv" */,
        46632 /* "glProgramUniformMatrix3fv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 46658 /* "glProgramUniformMatrix3fvEXT" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORMMATRIX3X2DVPROC
epoxy_glProgramUniformMatrix3x2dv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        46687 /* "glProgramUniformMatrix3x2dv" */,
        46687 /* "glProgramUniformMatrix3x2dv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 46687 /* "glProgramUniformMatrix3x2dv" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORMMATRIX3X2DVEXTPROC
epoxy_glProgramUniformMatrix3x2dvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 46715 /* glProgramUniformMatrix3x2dvEXT */);
}

static PFNGLPROGRAMUNIFORMMATRIX3X2FVPROC
epoxy_glProgramUniformMatrix3x2fv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        46746 /* "glProgramUniformMatrix3x2fv" */,
        46746 /* "glProgramUniformMatrix3x2fv" */,
        46746 /* "glProgramUniformMatrix3x2fv" */,
        46774 /* "glProgramUniformMatrix3x2fvEXT" */,
        46774 /* "glProgramUniformMatrix3x2fvEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 46746 /* "glProgramUniformMatrix3x2fv" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORMMATRIX3X2FVEXTPROC
epoxy_glProgramUniformMatrix3x2fvEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        46774 /* "glProgramUniformMatrix3x2fvEXT" */,
        46774 /* "glProgramUniformMatrix3x2fvEXT" */,
        46746 /* "glProgramUniformMatrix3x2fv" */,
        46746 /* "glProgramUniformMatrix3x2fv" */,
        46746 /* "glProgramUniformMatrix3x2fv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 46774 /* "glProgramUniformMatrix3x2fvEXT" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORMMATRIX3X4DVPROC
epoxy_glProgramUniformMatrix3x4dv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        46805 /* "glProgramUniformMatrix3x4dv" */,
        46805 /* "glProgramUniformMatrix3x4dv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 46805 /* "glProgramUniformMatrix3x4dv" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORMMATRIX3X4DVEXTPROC
epoxy_glProgramUniformMatrix3x4dvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 46833 /* glProgramUniformMatrix3x4dvEXT */);
}

static PFNGLPROGRAMUNIFORMMATRIX3X4FVPROC
epoxy_glProgramUniformMatrix3x4fv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        46864 /* "glProgramUniformMatrix3x4fv" */,
        46864 /* "glProgramUniformMatrix3x4fv" */,
        46864 /* "glProgramUniformMatrix3x4fv" */,
        46892 /* "glProgramUniformMatrix3x4fvEXT" */,
        46892 /* "glProgramUniformMatrix3x4fvEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 46864 /* "glProgramUniformMatrix3x4fv" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORMMATRIX3X4FVEXTPROC
epoxy_glProgramUniformMatrix3x4fvEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        46892 /* "glProgramUniformMatrix3x4fvEXT" */,
        46892 /* "glProgramUniformMatrix3x4fvEXT" */,
        46864 /* "glProgramUniformMatrix3x4fv" */,
        46864 /* "glProgramUniformMatrix3x4fv" */,
        46864 /* "glProgramUniformMatrix3x4fv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 46892 /* "glProgramUniformMatrix3x4fvEXT" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORMMATRIX4DVPROC
epoxy_glProgramUniformMatrix4dv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        46923 /* "glProgramUniformMatrix4dv" */,
        46923 /* "glProgramUniformMatrix4dv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 46923 /* "glProgramUniformMatrix4dv" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORMMATRIX4DVEXTPROC
epoxy_glProgramUniformMatrix4dvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 46949 /* glProgramUniformMatrix4dvEXT */);
}

static PFNGLPROGRAMUNIFORMMATRIX4FVPROC
epoxy_glProgramUniformMatrix4fv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        46978 /* "glProgramUniformMatrix4fv" */,
        46978 /* "glProgramUniformMatrix4fv" */,
        46978 /* "glProgramUniformMatrix4fv" */,
        47004 /* "glProgramUniformMatrix4fvEXT" */,
        47004 /* "glProgramUniformMatrix4fvEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 46978 /* "glProgramUniformMatrix4fv" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORMMATRIX4FVEXTPROC
epoxy_glProgramUniformMatrix4fvEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        47004 /* "glProgramUniformMatrix4fvEXT" */,
        47004 /* "glProgramUniformMatrix4fvEXT" */,
        46978 /* "glProgramUniformMatrix4fv" */,
        46978 /* "glProgramUniformMatrix4fv" */,
        46978 /* "glProgramUniformMatrix4fv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 47004 /* "glProgramUniformMatrix4fvEXT" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORMMATRIX4X2DVPROC
epoxy_glProgramUniformMatrix4x2dv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        47033 /* "glProgramUniformMatrix4x2dv" */,
        47033 /* "glProgramUniformMatrix4x2dv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 47033 /* "glProgramUniformMatrix4x2dv" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORMMATRIX4X2DVEXTPROC
epoxy_glProgramUniformMatrix4x2dvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 47061 /* glProgramUniformMatrix4x2dvEXT */);
}

static PFNGLPROGRAMUNIFORMMATRIX4X2FVPROC
epoxy_glProgramUniformMatrix4x2fv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        47092 /* "glProgramUniformMatrix4x2fv" */,
        47092 /* "glProgramUniformMatrix4x2fv" */,
        47092 /* "glProgramUniformMatrix4x2fv" */,
        47120 /* "glProgramUniformMatrix4x2fvEXT" */,
        47120 /* "glProgramUniformMatrix4x2fvEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 47092 /* "glProgramUniformMatrix4x2fv" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORMMATRIX4X2FVEXTPROC
epoxy_glProgramUniformMatrix4x2fvEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        47120 /* "glProgramUniformMatrix4x2fvEXT" */,
        47120 /* "glProgramUniformMatrix4x2fvEXT" */,
        47092 /* "glProgramUniformMatrix4x2fv" */,
        47092 /* "glProgramUniformMatrix4x2fv" */,
        47092 /* "glProgramUniformMatrix4x2fv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 47120 /* "glProgramUniformMatrix4x2fvEXT" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORMMATRIX4X3DVPROC
epoxy_glProgramUniformMatrix4x3dv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        47151 /* "glProgramUniformMatrix4x3dv" */,
        47151 /* "glProgramUniformMatrix4x3dv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 47151 /* "glProgramUniformMatrix4x3dv" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORMMATRIX4X3DVEXTPROC
epoxy_glProgramUniformMatrix4x3dvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 47179 /* glProgramUniformMatrix4x3dvEXT */);
}

static PFNGLPROGRAMUNIFORMMATRIX4X3FVPROC
epoxy_glProgramUniformMatrix4x3fv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        47210 /* "glProgramUniformMatrix4x3fv" */,
        47210 /* "glProgramUniformMatrix4x3fv" */,
        47210 /* "glProgramUniformMatrix4x3fv" */,
        47238 /* "glProgramUniformMatrix4x3fvEXT" */,
        47238 /* "glProgramUniformMatrix4x3fvEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 47210 /* "glProgramUniformMatrix4x3fv" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORMMATRIX4X3FVEXTPROC
epoxy_glProgramUniformMatrix4x3fvEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_separate_shader_objects,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        47238 /* "glProgramUniformMatrix4x3fvEXT" */,
        47238 /* "glProgramUniformMatrix4x3fvEXT" */,
        47210 /* "glProgramUniformMatrix4x3fv" */,
        47210 /* "glProgramUniformMatrix4x3fv" */,
        47210 /* "glProgramUniformMatrix4x3fv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 47238 /* "glProgramUniformMatrix4x3fvEXT" */,
                                providers, entrypoints);
}

static PFNGLPROGRAMUNIFORMUI64NVPROC
epoxy_glProgramUniformui64NV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_shader_buffer_load, 47269 /* glProgramUniformui64NV */);
}

static PFNGLPROGRAMUNIFORMUI64VNVPROC
epoxy_glProgramUniformui64vNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_shader_buffer_load, 47292 /* glProgramUniformui64vNV */);
}

static PFNGLPROGRAMVERTEXLIMITNVPROC
epoxy_glProgramVertexLimitNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_geometry_program4, 47316 /* glProgramVertexLimitNV */);
}

static PFNGLPROVOKINGVERTEXPROC
epoxy_glProvokingVertex_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_2,
        PROVIDER_GL_ARB_provoking_vertex,
        PROVIDER_GL_EXT_provoking_vertex,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        47339 /* "glProvokingVertex" */,
        47339 /* "glProvokingVertex" */,
        47357 /* "glProvokingVertexEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 47339 /* "glProvokingVertex" */,
                                providers, entrypoints);
}

static PFNGLPROVOKINGVERTEXEXTPROC
epoxy_glProvokingVertexEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_provoking_vertex,
        PROVIDER_Desktop_OpenGL_3_2,
        PROVIDER_GL_ARB_provoking_vertex,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        47357 /* "glProvokingVertexEXT" */,
        47339 /* "glProvokingVertex" */,
        47339 /* "glProvokingVertex" */,
    };
    return gl_provider_resolver(entrypoint_strings + 47357 /* "glProvokingVertexEXT" */,
                                providers, entrypoints);
}

static PFNGLPUSHATTRIBPROC
epoxy_glPushAttrib_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 47378 /* glPushAttrib */);
}

static PFNGLPUSHCLIENTATTRIBPROC
epoxy_glPushClientAttrib_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_1, 47391 /* glPushClientAttrib */);
}

static PFNGLPUSHCLIENTATTRIBDEFAULTEXTPROC
epoxy_glPushClientAttribDefaultEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 47410 /* glPushClientAttribDefaultEXT */);
}

static PFNGLPUSHDEBUGGROUPPROC
epoxy_glPushDebugGroup_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_KHR_debug,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_KHR_debug,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        47439 /* "glPushDebugGroup" */,
        47439 /* "glPushDebugGroup" */,
        47439 /* "glPushDebugGroup" */,
        47456 /* "glPushDebugGroupKHR" */,
    };
    return gl_provider_resolver(entrypoint_strings + 47439 /* "glPushDebugGroup" */,
                                providers, entrypoints);
}

static PFNGLPUSHDEBUGGROUPKHRPROC
epoxy_glPushDebugGroupKHR_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_KHR_debug,
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_KHR_debug,
        PROVIDER_OpenGL_ES_3_2,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        47456 /* "glPushDebugGroupKHR" */,
        47439 /* "glPushDebugGroup" */,
        47439 /* "glPushDebugGroup" */,
        47439 /* "glPushDebugGroup" */,
    };
    return gl_provider_resolver(entrypoint_strings + 47456 /* "glPushDebugGroupKHR" */,
                                providers, entrypoints);
}

static PFNGLPUSHGROUPMARKEREXTPROC
epoxy_glPushGroupMarkerEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_debug_marker, 47476 /* glPushGroupMarkerEXT */);
}

static PFNGLPUSHMATRIXPROC
epoxy_glPushMatrix_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        47497 /* "glPushMatrix" */,
        47497 /* "glPushMatrix" */,
    };
    return gl_provider_resolver(entrypoint_strings + 47497 /* "glPushMatrix" */,
                                providers, entrypoints);
}

static PFNGLPUSHNAMEPROC
epoxy_glPushName_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 47510 /* glPushName */);
}

static PFNGLQUERYCOUNTERPROC
epoxy_glQueryCounter_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_timer_query,
        PROVIDER_GL_EXT_disjoint_timer_query,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        47521 /* "glQueryCounter" */,
        47521 /* "glQueryCounter" */,
        47536 /* "glQueryCounterEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 47521 /* "glQueryCounter" */,
                                providers, entrypoints);
}

static PFNGLQUERYCOUNTEREXTPROC
epoxy_glQueryCounterEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_disjoint_timer_query,
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_timer_query,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        47536 /* "glQueryCounterEXT" */,
        47521 /* "glQueryCounter" */,
        47521 /* "glQueryCounter" */,
    };
    return gl_provider_resolver(entrypoint_strings + 47536 /* "glQueryCounterEXT" */,
                                providers, entrypoints);
}

static PFNGLQUERYMATRIXXOESPROC
epoxy_glQueryMatrixxOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_query_matrix, 47554 /* glQueryMatrixxOES */);
}

static PFNGLQUERYOBJECTPARAMETERUIAMDPROC
epoxy_glQueryObjectParameteruiAMD_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_AMD_occlusion_query_event, 47572 /* glQueryObjectParameteruiAMD */);
}

static PFNGLQUERYRESOURCENVPROC
epoxy_glQueryResourceNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_query_resource, 47600 /* glQueryResourceNV */);
}

static PFNGLQUERYRESOURCETAGNVPROC
epoxy_glQueryResourceTagNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_query_resource_tag, 47618 /* glQueryResourceTagNV */);
}

static PFNGLRASTERPOS2DPROC
epoxy_glRasterPos2d_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 47639 /* glRasterPos2d */);
}

static PFNGLRASTERPOS2DVPROC
epoxy_glRasterPos2dv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 47653 /* glRasterPos2dv */);
}

static PFNGLRASTERPOS2FPROC
epoxy_glRasterPos2f_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 47668 /* glRasterPos2f */);
}

static PFNGLRASTERPOS2FVPROC
epoxy_glRasterPos2fv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 47682 /* glRasterPos2fv */);
}

static PFNGLRASTERPOS2IPROC
epoxy_glRasterPos2i_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 47697 /* glRasterPos2i */);
}

static PFNGLRASTERPOS2IVPROC
epoxy_glRasterPos2iv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 47711 /* glRasterPos2iv */);
}

static PFNGLRASTERPOS2SPROC
epoxy_glRasterPos2s_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 47726 /* glRasterPos2s */);
}

static PFNGLRASTERPOS2SVPROC
epoxy_glRasterPos2sv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 47740 /* glRasterPos2sv */);
}

static PFNGLRASTERPOS2XOESPROC
epoxy_glRasterPos2xOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 47755 /* glRasterPos2xOES */);
}

static PFNGLRASTERPOS2XVOESPROC
epoxy_glRasterPos2xvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 47772 /* glRasterPos2xvOES */);
}

static PFNGLRASTERPOS3DPROC
epoxy_glRasterPos3d_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 47790 /* glRasterPos3d */);
}

static PFNGLRASTERPOS3DVPROC
epoxy_glRasterPos3dv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 47804 /* glRasterPos3dv */);
}

static PFNGLRASTERPOS3FPROC
epoxy_glRasterPos3f_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 47819 /* glRasterPos3f */);
}

static PFNGLRASTERPOS3FVPROC
epoxy_glRasterPos3fv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 47833 /* glRasterPos3fv */);
}

static PFNGLRASTERPOS3IPROC
epoxy_glRasterPos3i_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 47848 /* glRasterPos3i */);
}

static PFNGLRASTERPOS3IVPROC
epoxy_glRasterPos3iv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 47862 /* glRasterPos3iv */);
}

static PFNGLRASTERPOS3SPROC
epoxy_glRasterPos3s_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 47877 /* glRasterPos3s */);
}

static PFNGLRASTERPOS3SVPROC
epoxy_glRasterPos3sv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 47891 /* glRasterPos3sv */);
}

static PFNGLRASTERPOS3XOESPROC
epoxy_glRasterPos3xOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 47906 /* glRasterPos3xOES */);
}

static PFNGLRASTERPOS3XVOESPROC
epoxy_glRasterPos3xvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 47923 /* glRasterPos3xvOES */);
}

static PFNGLRASTERPOS4DPROC
epoxy_glRasterPos4d_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 47941 /* glRasterPos4d */);
}

static PFNGLRASTERPOS4DVPROC
epoxy_glRasterPos4dv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 47955 /* glRasterPos4dv */);
}

static PFNGLRASTERPOS4FPROC
epoxy_glRasterPos4f_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 47970 /* glRasterPos4f */);
}

static PFNGLRASTERPOS4FVPROC
epoxy_glRasterPos4fv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 47984 /* glRasterPos4fv */);
}

static PFNGLRASTERPOS4IPROC
epoxy_glRasterPos4i_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 47999 /* glRasterPos4i */);
}

static PFNGLRASTERPOS4IVPROC
epoxy_glRasterPos4iv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 48013 /* glRasterPos4iv */);
}

static PFNGLRASTERPOS4SPROC
epoxy_glRasterPos4s_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 48028 /* glRasterPos4s */);
}

static PFNGLRASTERPOS4SVPROC
epoxy_glRasterPos4sv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 48042 /* glRasterPos4sv */);
}

static PFNGLRASTERPOS4XOESPROC
epoxy_glRasterPos4xOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 48057 /* glRasterPos4xOES */);
}

static PFNGLRASTERPOS4XVOESPROC
epoxy_glRasterPos4xvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 48074 /* glRasterPos4xvOES */);
}

static PFNGLRASTERSAMPLESEXTPROC
epoxy_glRasterSamplesEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_raster_multisample,
        PROVIDER_GL_NV_framebuffer_mixed_samples,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        48092 /* "glRasterSamplesEXT" */,
        48092 /* "glRasterSamplesEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 48092 /* "glRasterSamplesEXT" */,
                                providers, entrypoints);
}

static PFNGLREADBUFFERPROC
epoxy_glReadBuffer_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        48111 /* "glReadBuffer" */,
        48111 /* "glReadBuffer" */,
    };
    return gl_provider_resolver(entrypoint_strings + 48111 /* "glReadBuffer" */,
                                providers, entrypoints);
}

static PFNGLREADBUFFERINDEXEDEXTPROC
epoxy_glReadBufferIndexedEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_multiview_draw_buffers, 48124 /* glReadBufferIndexedEXT */);
}

static PFNGLREADBUFFERNVPROC
epoxy_glReadBufferNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_read_buffer, 48147 /* glReadBufferNV */);
}

static PFNGLREADINSTRUMENTSSGIXPROC
epoxy_glReadInstrumentsSGIX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIX_instruments, 48162 /* glReadInstrumentsSGIX */);
}

static PFNGLREADPIXELSPROC
epoxy_glReadPixels_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        48184 /* "glReadPixels" */,
        48184 /* "glReadPixels" */,
        48184 /* "glReadPixels" */,
    };
    return gl_provider_resolver(entrypoint_strings + 48184 /* "glReadPixels" */,
                                providers, entrypoints);
}

static PFNGLREADNPIXELSPROC
epoxy_glReadnPixels_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_KHR_robustness,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_ARB_robustness,
        PROVIDER_GL_EXT_robustness,
        PROVIDER_GL_KHR_robustness,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        48197 /* "glReadnPixels" */,
        48197 /* "glReadnPixels" */,
        48197 /* "glReadnPixels" */,
        48211 /* "glReadnPixelsARB" */,
        48228 /* "glReadnPixelsEXT" */,
        48245 /* "glReadnPixelsKHR" */,
    };
    return gl_provider_resolver(entrypoint_strings + 48197 /* "glReadnPixels" */,
                                providers, entrypoints);
}

static PFNGLREADNPIXELSARBPROC
epoxy_glReadnPixelsARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_robustness,
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_KHR_robustness,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_robustness,
        PROVIDER_GL_KHR_robustness,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        48211 /* "glReadnPixelsARB" */,
        48197 /* "glReadnPixels" */,
        48197 /* "glReadnPixels" */,
        48197 /* "glReadnPixels" */,
        48228 /* "glReadnPixelsEXT" */,
        48245 /* "glReadnPixelsKHR" */,
    };
    return gl_provider_resolver(entrypoint_strings + 48211 /* "glReadnPixelsARB" */,
                                providers, entrypoints);
}

static PFNGLREADNPIXELSEXTPROC
epoxy_glReadnPixelsEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_robustness,
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_KHR_robustness,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_ARB_robustness,
        PROVIDER_GL_KHR_robustness,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        48228 /* "glReadnPixelsEXT" */,
        48197 /* "glReadnPixels" */,
        48197 /* "glReadnPixels" */,
        48197 /* "glReadnPixels" */,
        48211 /* "glReadnPixelsARB" */,
        48245 /* "glReadnPixelsKHR" */,
    };
    return gl_provider_resolver(entrypoint_strings + 48228 /* "glReadnPixelsEXT" */,
                                providers, entrypoints);
}

static PFNGLREADNPIXELSKHRPROC
epoxy_glReadnPixelsKHR_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_KHR_robustness,
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_KHR_robustness,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_ARB_robustness,
        PROVIDER_GL_EXT_robustness,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        48245 /* "glReadnPixelsKHR" */,
        48197 /* "glReadnPixels" */,
        48197 /* "glReadnPixels" */,
        48197 /* "glReadnPixels" */,
        48211 /* "glReadnPixelsARB" */,
        48228 /* "glReadnPixelsEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 48245 /* "glReadnPixelsKHR" */,
                                providers, entrypoints);
}

static PFNGLRECTDPROC
epoxy_glRectd_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 48262 /* glRectd */);
}

static PFNGLRECTDVPROC
epoxy_glRectdv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 48270 /* glRectdv */);
}

static PFNGLRECTFPROC
epoxy_glRectf_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 48279 /* glRectf */);
}

static PFNGLRECTFVPROC
epoxy_glRectfv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 48287 /* glRectfv */);
}

static PFNGLRECTIPROC
epoxy_glRecti_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 48296 /* glRecti */);
}

static PFNGLRECTIVPROC
epoxy_glRectiv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 48304 /* glRectiv */);
}

static PFNGLRECTSPROC
epoxy_glRects_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 48313 /* glRects */);
}

static PFNGLRECTSVPROC
epoxy_glRectsv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 48321 /* glRectsv */);
}

static PFNGLRECTXOESPROC
epoxy_glRectxOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 48330 /* glRectxOES */);
}

static PFNGLRECTXVOESPROC
epoxy_glRectxvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 48341 /* glRectxvOES */);
}

static PFNGLREFERENCEPLANESGIXPROC
epoxy_glReferencePlaneSGIX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIX_reference_plane, 48353 /* glReferencePlaneSGIX */);
}

static PFNGLRELEASEKEYEDMUTEXWIN32EXTPROC
epoxy_glReleaseKeyedMutexWin32EXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_win32_keyed_mutex, 48374 /* glReleaseKeyedMutexWin32EXT */);
}

static PFNGLRELEASESHADERCOMPILERPROC
epoxy_glReleaseShaderCompiler_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_ES2_compatibility,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        48402 /* "glReleaseShaderCompiler" */,
        48402 /* "glReleaseShaderCompiler" */,
        48402 /* "glReleaseShaderCompiler" */,
    };
    return gl_provider_resolver(entrypoint_strings + 48402 /* "glReleaseShaderCompiler" */,
                                providers, entrypoints);
}

static PFNGLRENDERGPUMASKNVPROC
epoxy_glRenderGpuMaskNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_gpu_multicast, 48426 /* glRenderGpuMaskNV */);
}

static PFNGLRENDERMODEPROC
epoxy_glRenderMode_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 48444 /* glRenderMode */);
}

static PFNGLRENDERBUFFERSTORAGEPROC
epoxy_glRenderbufferStorage_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_framebuffer_object,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_EXT_framebuffer_object,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        48457 /* "glRenderbufferStorage" */,
        48457 /* "glRenderbufferStorage" */,
        48457 /* "glRenderbufferStorage" */,
        48479 /* "glRenderbufferStorageEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 48457 /* "glRenderbufferStorage" */,
                                providers, entrypoints);
}

static PFNGLRENDERBUFFERSTORAGEEXTPROC
epoxy_glRenderbufferStorageEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_framebuffer_object,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_framebuffer_object,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        48479 /* "glRenderbufferStorageEXT" */,
        48457 /* "glRenderbufferStorage" */,
        48457 /* "glRenderbufferStorage" */,
        48457 /* "glRenderbufferStorage" */,
    };
    return gl_provider_resolver(entrypoint_strings + 48479 /* "glRenderbufferStorageEXT" */,
                                providers, entrypoints);
}

static PFNGLRENDERBUFFERSTORAGEMULTISAMPLEPROC
epoxy_glRenderbufferStorageMultisample_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_framebuffer_object,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_EXT_framebuffer_multisample,
        PROVIDER_GL_EXT_multisampled_render_to_texture,
        PROVIDER_GL_NV_framebuffer_multisample,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        48504 /* "glRenderbufferStorageMultisample" */,
        48504 /* "glRenderbufferStorageMultisample" */,
        48504 /* "glRenderbufferStorageMultisample" */,
        48700 /* "glRenderbufferStorageMultisampleEXT" */,
        48700 /* "glRenderbufferStorageMultisampleEXT" */,
        48772 /* "glRenderbufferStorageMultisampleNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 48504 /* "glRenderbufferStorageMultisample" */,
                                providers, entrypoints);
}

static PFNGLRENDERBUFFERSTORAGEMULTISAMPLEANGLEPROC
epoxy_glRenderbufferStorageMultisampleANGLE_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ANGLE_framebuffer_multisample, 48537 /* glRenderbufferStorageMultisampleANGLE */);
}

static PFNGLRENDERBUFFERSTORAGEMULTISAMPLEAPPLEPROC
epoxy_glRenderbufferStorageMultisampleAPPLE_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_APPLE_framebuffer_multisample, 48575 /* glRenderbufferStorageMultisampleAPPLE */);
}

static PFNGLRENDERBUFFERSTORAGEMULTISAMPLEADVANCEDAMDPROC
epoxy_glRenderbufferStorageMultisampleAdvancedAMD_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_AMD_framebuffer_multisample_advanced, 48613 /* glRenderbufferStorageMultisampleAdvancedAMD */);
}

static PFNGLRENDERBUFFERSTORAGEMULTISAMPLECOVERAGENVPROC
epoxy_glRenderbufferStorageMultisampleCoverageNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_framebuffer_multisample_coverage, 48657 /* glRenderbufferStorageMultisampleCoverageNV */);
}

static PFNGLRENDERBUFFERSTORAGEMULTISAMPLEEXTPROC
epoxy_glRenderbufferStorageMultisampleEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_framebuffer_multisample,
        PROVIDER_GL_EXT_multisampled_render_to_texture,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_framebuffer_object,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_NV_framebuffer_multisample,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        48700 /* "glRenderbufferStorageMultisampleEXT" */,
        48700 /* "glRenderbufferStorageMultisampleEXT" */,
        48504 /* "glRenderbufferStorageMultisample" */,
        48504 /* "glRenderbufferStorageMultisample" */,
        48504 /* "glRenderbufferStorageMultisample" */,
        48772 /* "glRenderbufferStorageMultisampleNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 48700 /* "glRenderbufferStorageMultisampleEXT" */,
                                providers, entrypoints);
}

static PFNGLRENDERBUFFERSTORAGEMULTISAMPLEIMGPROC
epoxy_glRenderbufferStorageMultisampleIMG_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_IMG_multisampled_render_to_texture, 48736 /* glRenderbufferStorageMultisampleIMG */);
}

static PFNGLRENDERBUFFERSTORAGEMULTISAMPLENVPROC
epoxy_glRenderbufferStorageMultisampleNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_framebuffer_multisample,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_ARB_framebuffer_object,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_EXT_framebuffer_multisample,
        PROVIDER_GL_EXT_multisampled_render_to_texture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        48772 /* "glRenderbufferStorageMultisampleNV" */,
        48504 /* "glRenderbufferStorageMultisample" */,
        48504 /* "glRenderbufferStorageMultisample" */,
        48504 /* "glRenderbufferStorageMultisample" */,
        48700 /* "glRenderbufferStorageMultisampleEXT" */,
        48700 /* "glRenderbufferStorageMultisampleEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 48772 /* "glRenderbufferStorageMultisampleNV" */,
                                providers, entrypoints);
}

static PFNGLRENDERBUFFERSTORAGEOESPROC
epoxy_glRenderbufferStorageOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_framebuffer_object, 48807 /* glRenderbufferStorageOES */);
}

static PFNGLREPLACEMENTCODEPOINTERSUNPROC
epoxy_glReplacementCodePointerSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_triangle_list, 48832 /* glReplacementCodePointerSUN */);
}

static PFNGLREPLACEMENTCODEUBSUNPROC
epoxy_glReplacementCodeubSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_triangle_list, 48860 /* glReplacementCodeubSUN */);
}

static PFNGLREPLACEMENTCODEUBVSUNPROC
epoxy_glReplacementCodeubvSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_triangle_list, 48883 /* glReplacementCodeubvSUN */);
}

static PFNGLREPLACEMENTCODEUICOLOR3FVERTEX3FSUNPROC
epoxy_glReplacementCodeuiColor3fVertex3fSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_vertex, 48907 /* glReplacementCodeuiColor3fVertex3fSUN */);
}

static PFNGLREPLACEMENTCODEUICOLOR3FVERTEX3FVSUNPROC
epoxy_glReplacementCodeuiColor3fVertex3fvSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_vertex, 48945 /* glReplacementCodeuiColor3fVertex3fvSUN */);
}

static PFNGLREPLACEMENTCODEUICOLOR4FNORMAL3FVERTEX3FSUNPROC
epoxy_glReplacementCodeuiColor4fNormal3fVertex3fSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_vertex, 48984 /* glReplacementCodeuiColor4fNormal3fVertex3fSUN */);
}

static PFNGLREPLACEMENTCODEUICOLOR4FNORMAL3FVERTEX3FVSUNPROC
epoxy_glReplacementCodeuiColor4fNormal3fVertex3fvSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_vertex, 49030 /* glReplacementCodeuiColor4fNormal3fVertex3fvSUN */);
}

static PFNGLREPLACEMENTCODEUICOLOR4UBVERTEX3FSUNPROC
epoxy_glReplacementCodeuiColor4ubVertex3fSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_vertex, 49077 /* glReplacementCodeuiColor4ubVertex3fSUN */);
}

static PFNGLREPLACEMENTCODEUICOLOR4UBVERTEX3FVSUNPROC
epoxy_glReplacementCodeuiColor4ubVertex3fvSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_vertex, 49116 /* glReplacementCodeuiColor4ubVertex3fvSUN */);
}

static PFNGLREPLACEMENTCODEUINORMAL3FVERTEX3FSUNPROC
epoxy_glReplacementCodeuiNormal3fVertex3fSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_vertex, 49156 /* glReplacementCodeuiNormal3fVertex3fSUN */);
}

static PFNGLREPLACEMENTCODEUINORMAL3FVERTEX3FVSUNPROC
epoxy_glReplacementCodeuiNormal3fVertex3fvSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_vertex, 49195 /* glReplacementCodeuiNormal3fVertex3fvSUN */);
}

static PFNGLREPLACEMENTCODEUISUNPROC
epoxy_glReplacementCodeuiSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_triangle_list, 49235 /* glReplacementCodeuiSUN */);
}

static PFNGLREPLACEMENTCODEUITEXCOORD2FCOLOR4FNORMAL3FVERTEX3FSUNPROC
epoxy_glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_vertex, 49258 /* glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fSUN */);
}

static PFNGLREPLACEMENTCODEUITEXCOORD2FCOLOR4FNORMAL3FVERTEX3FVSUNPROC
epoxy_glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fvSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_vertex, 49314 /* glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fvSUN */);
}

static PFNGLREPLACEMENTCODEUITEXCOORD2FNORMAL3FVERTEX3FSUNPROC
epoxy_glReplacementCodeuiTexCoord2fNormal3fVertex3fSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_vertex, 49371 /* glReplacementCodeuiTexCoord2fNormal3fVertex3fSUN */);
}

static PFNGLREPLACEMENTCODEUITEXCOORD2FNORMAL3FVERTEX3FVSUNPROC
epoxy_glReplacementCodeuiTexCoord2fNormal3fVertex3fvSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_vertex, 49420 /* glReplacementCodeuiTexCoord2fNormal3fVertex3fvSUN */);
}

static PFNGLREPLACEMENTCODEUITEXCOORD2FVERTEX3FSUNPROC
epoxy_glReplacementCodeuiTexCoord2fVertex3fSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_vertex, 49470 /* glReplacementCodeuiTexCoord2fVertex3fSUN */);
}

static PFNGLREPLACEMENTCODEUITEXCOORD2FVERTEX3FVSUNPROC
epoxy_glReplacementCodeuiTexCoord2fVertex3fvSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_vertex, 49511 /* glReplacementCodeuiTexCoord2fVertex3fvSUN */);
}

static PFNGLREPLACEMENTCODEUIVERTEX3FSUNPROC
epoxy_glReplacementCodeuiVertex3fSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_vertex, 49553 /* glReplacementCodeuiVertex3fSUN */);
}

static PFNGLREPLACEMENTCODEUIVERTEX3FVSUNPROC
epoxy_glReplacementCodeuiVertex3fvSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_vertex, 49584 /* glReplacementCodeuiVertex3fvSUN */);
}

static PFNGLREPLACEMENTCODEUIVSUNPROC
epoxy_glReplacementCodeuivSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_triangle_list, 49616 /* glReplacementCodeuivSUN */);
}

static PFNGLREPLACEMENTCODEUSSUNPROC
epoxy_glReplacementCodeusSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_triangle_list, 49640 /* glReplacementCodeusSUN */);
}

static PFNGLREPLACEMENTCODEUSVSUNPROC
epoxy_glReplacementCodeusvSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_triangle_list, 49663 /* glReplacementCodeusvSUN */);
}

static PFNGLREQUESTRESIDENTPROGRAMSNVPROC
epoxy_glRequestResidentProgramsNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_program, 49687 /* glRequestResidentProgramsNV */);
}

static PFNGLRESETHISTOGRAMPROC
epoxy_glResetHistogram_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_imaging,
        PROVIDER_GL_EXT_histogram,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        49715 /* "glResetHistogram" */,
        49732 /* "glResetHistogramEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 49715 /* "glResetHistogram" */,
                                providers, entrypoints);
}

static PFNGLRESETHISTOGRAMEXTPROC
epoxy_glResetHistogramEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_histogram,
        PROVIDER_GL_ARB_imaging,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        49732 /* "glResetHistogramEXT" */,
        49715 /* "glResetHistogram" */,
    };
    return gl_provider_resolver(entrypoint_strings + 49732 /* "glResetHistogramEXT" */,
                                providers, entrypoints);
}

static PFNGLRESETMEMORYOBJECTPARAMETERNVPROC
epoxy_glResetMemoryObjectParameterNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_memory_attachment, 49752 /* glResetMemoryObjectParameterNV */);
}

static PFNGLRESETMINMAXPROC
epoxy_glResetMinmax_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_imaging,
        PROVIDER_GL_EXT_histogram,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        49783 /* "glResetMinmax" */,
        49797 /* "glResetMinmaxEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 49783 /* "glResetMinmax" */,
                                providers, entrypoints);
}

static PFNGLRESETMINMAXEXTPROC
epoxy_glResetMinmaxEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_histogram,
        PROVIDER_GL_ARB_imaging,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        49797 /* "glResetMinmaxEXT" */,
        49783 /* "glResetMinmax" */,
    };
    return gl_provider_resolver(entrypoint_strings + 49797 /* "glResetMinmaxEXT" */,
                                providers, entrypoints);
}

static PFNGLRESIZEBUFFERSMESAPROC
epoxy_glResizeBuffersMESA_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_MESA_resize_buffers, 49814 /* glResizeBuffersMESA */);
}

static PFNGLRESOLVEDEPTHVALUESNVPROC
epoxy_glResolveDepthValuesNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_sample_locations, 49834 /* glResolveDepthValuesNV */);
}

static PFNGLRESOLVEMULTISAMPLEFRAMEBUFFERAPPLEPROC
epoxy_glResolveMultisampleFramebufferAPPLE_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_APPLE_framebuffer_multisample, 49857 /* glResolveMultisampleFramebufferAPPLE */);
}

static PFNGLRESUMETRANSFORMFEEDBACKPROC
epoxy_glResumeTransformFeedback_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_GL_ARB_transform_feedback2,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_NV_transform_feedback2,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        49894 /* "glResumeTransformFeedback" */,
        49894 /* "glResumeTransformFeedback" */,
        49894 /* "glResumeTransformFeedback" */,
        49920 /* "glResumeTransformFeedbackNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 49894 /* "glResumeTransformFeedback" */,
                                providers, entrypoints);
}

static PFNGLRESUMETRANSFORMFEEDBACKNVPROC
epoxy_glResumeTransformFeedbackNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_transform_feedback2,
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_GL_ARB_transform_feedback2,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        49920 /* "glResumeTransformFeedbackNV" */,
        49894 /* "glResumeTransformFeedback" */,
        49894 /* "glResumeTransformFeedback" */,
        49894 /* "glResumeTransformFeedback" */,
    };
    return gl_provider_resolver(entrypoint_strings + 49920 /* "glResumeTransformFeedbackNV" */,
                                providers, entrypoints);
}

static PFNGLROTATEDPROC
epoxy_glRotated_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 49948 /* glRotated */);
}

static PFNGLROTATEFPROC
epoxy_glRotatef_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        49958 /* "glRotatef" */,
        49958 /* "glRotatef" */,
    };
    return gl_provider_resolver(entrypoint_strings + 49958 /* "glRotatef" */,
                                providers, entrypoints);
}

static PFNGLROTATEXPROC
epoxy_glRotatex_resolver(void)
{
    return gl_single_resolver(PROVIDER_OpenGL_ES_1_0, 49968 /* glRotatex */);
}

static PFNGLROTATEXOESPROC
epoxy_glRotatexOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 49978 /* glRotatexOES */);
}

static PFNGLSAMPLECOVERAGEPROC
epoxy_glSampleCoverage_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_multisample,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        49991 /* "glSampleCoverage" */,
        49991 /* "glSampleCoverage" */,
        49991 /* "glSampleCoverage" */,
        50008 /* "glSampleCoverageARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 49991 /* "glSampleCoverage" */,
                                providers, entrypoints);
}

static PFNGLSAMPLECOVERAGEARBPROC
epoxy_glSampleCoverageARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_multisample,
        PROVIDER_Desktop_OpenGL_1_3,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        50008 /* "glSampleCoverageARB" */,
        49991 /* "glSampleCoverage" */,
        49991 /* "glSampleCoverage" */,
        49991 /* "glSampleCoverage" */,
    };
    return gl_provider_resolver(entrypoint_strings + 50008 /* "glSampleCoverageARB" */,
                                providers, entrypoints);
}

static PFNGLSAMPLECOVERAGEXPROC
epoxy_glSampleCoveragex_resolver(void)
{
    return gl_single_resolver(PROVIDER_OpenGL_ES_1_0, 50028 /* glSampleCoveragex */);
}

static PFNGLSAMPLECOVERAGEXOESPROC
epoxy_glSampleCoveragexOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 50046 /* glSampleCoveragexOES */);
}

static PFNGLSAMPLEMAPATIPROC
epoxy_glSampleMapATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_fragment_shader, 50067 /* glSampleMapATI */);
}

static PFNGLSAMPLEMASKEXTPROC
epoxy_glSampleMaskEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_multisample,
        PROVIDER_GL_SGIS_multisample,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        50082 /* "glSampleMaskEXT" */,
        50120 /* "glSampleMaskSGIS" */,
    };
    return gl_provider_resolver(entrypoint_strings + 50082 /* "glSampleMaskEXT" */,
                                providers, entrypoints);
}

static PFNGLSAMPLEMASKINDEXEDNVPROC
epoxy_glSampleMaskIndexedNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_explicit_multisample, 50098 /* glSampleMaskIndexedNV */);
}

static PFNGLSAMPLEMASKSGISPROC
epoxy_glSampleMaskSGIS_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_SGIS_multisample,
        PROVIDER_GL_EXT_multisample,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        50120 /* "glSampleMaskSGIS" */,
        50082 /* "glSampleMaskEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 50120 /* "glSampleMaskSGIS" */,
                                providers, entrypoints);
}

static PFNGLSAMPLEMASKIPROC
epoxy_glSampleMaski_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_2,
        PROVIDER_GL_ARB_texture_multisample,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        50137 /* "glSampleMaski" */,
        50137 /* "glSampleMaski" */,
        50137 /* "glSampleMaski" */,
    };
    return gl_provider_resolver(entrypoint_strings + 50137 /* "glSampleMaski" */,
                                providers, entrypoints);
}

static PFNGLSAMPLEPATTERNEXTPROC
epoxy_glSamplePatternEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_multisample,
        PROVIDER_GL_SGIS_multisample,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        50151 /* "glSamplePatternEXT" */,
        50170 /* "glSamplePatternSGIS" */,
    };
    return gl_provider_resolver(entrypoint_strings + 50151 /* "glSamplePatternEXT" */,
                                providers, entrypoints);
}

static PFNGLSAMPLEPATTERNSGISPROC
epoxy_glSamplePatternSGIS_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_SGIS_multisample,
        PROVIDER_GL_EXT_multisample,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        50170 /* "glSamplePatternSGIS" */,
        50151 /* "glSamplePatternEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 50170 /* "glSamplePatternSGIS" */,
                                providers, entrypoints);
}

static PFNGLSAMPLERPARAMETERIIVPROC
epoxy_glSamplerParameterIiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_sampler_objects,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_texture_border_clamp,
        PROVIDER_GL_OES_texture_border_clamp,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        50190 /* "glSamplerParameterIiv" */,
        50190 /* "glSamplerParameterIiv" */,
        50190 /* "glSamplerParameterIiv" */,
        50212 /* "glSamplerParameterIivEXT" */,
        50237 /* "glSamplerParameterIivOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 50190 /* "glSamplerParameterIiv" */,
                                providers, entrypoints);
}

static PFNGLSAMPLERPARAMETERIIVEXTPROC
epoxy_glSamplerParameterIivEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_texture_border_clamp,
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_sampler_objects,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_OES_texture_border_clamp,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        50212 /* "glSamplerParameterIivEXT" */,
        50190 /* "glSamplerParameterIiv" */,
        50190 /* "glSamplerParameterIiv" */,
        50190 /* "glSamplerParameterIiv" */,
        50237 /* "glSamplerParameterIivOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 50212 /* "glSamplerParameterIivEXT" */,
                                providers, entrypoints);
}

static PFNGLSAMPLERPARAMETERIIVOESPROC
epoxy_glSamplerParameterIivOES_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_OES_texture_border_clamp,
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_sampler_objects,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_texture_border_clamp,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        50237 /* "glSamplerParameterIivOES" */,
        50190 /* "glSamplerParameterIiv" */,
        50190 /* "glSamplerParameterIiv" */,
        50190 /* "glSamplerParameterIiv" */,
        50212 /* "glSamplerParameterIivEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 50237 /* "glSamplerParameterIivOES" */,
                                providers, entrypoints);
}

static PFNGLSAMPLERPARAMETERIUIVPROC
epoxy_glSamplerParameterIuiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_sampler_objects,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_texture_border_clamp,
        PROVIDER_GL_OES_texture_border_clamp,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        50262 /* "glSamplerParameterIuiv" */,
        50262 /* "glSamplerParameterIuiv" */,
        50262 /* "glSamplerParameterIuiv" */,
        50285 /* "glSamplerParameterIuivEXT" */,
        50311 /* "glSamplerParameterIuivOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 50262 /* "glSamplerParameterIuiv" */,
                                providers, entrypoints);
}

static PFNGLSAMPLERPARAMETERIUIVEXTPROC
epoxy_glSamplerParameterIuivEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_texture_border_clamp,
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_sampler_objects,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_OES_texture_border_clamp,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        50285 /* "glSamplerParameterIuivEXT" */,
        50262 /* "glSamplerParameterIuiv" */,
        50262 /* "glSamplerParameterIuiv" */,
        50262 /* "glSamplerParameterIuiv" */,
        50311 /* "glSamplerParameterIuivOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 50285 /* "glSamplerParameterIuivEXT" */,
                                providers, entrypoints);
}

static PFNGLSAMPLERPARAMETERIUIVOESPROC
epoxy_glSamplerParameterIuivOES_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_OES_texture_border_clamp,
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_sampler_objects,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_texture_border_clamp,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        50311 /* "glSamplerParameterIuivOES" */,
        50262 /* "glSamplerParameterIuiv" */,
        50262 /* "glSamplerParameterIuiv" */,
        50262 /* "glSamplerParameterIuiv" */,
        50285 /* "glSamplerParameterIuivEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 50311 /* "glSamplerParameterIuivOES" */,
                                providers, entrypoints);
}

static PFNGLSAMPLERPARAMETERFPROC
epoxy_glSamplerParameterf_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_sampler_objects,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        50337 /* "glSamplerParameterf" */,
        50337 /* "glSamplerParameterf" */,
        50337 /* "glSamplerParameterf" */,
    };
    return gl_provider_resolver(entrypoint_strings + 50337 /* "glSamplerParameterf" */,
                                providers, entrypoints);
}

static PFNGLSAMPLERPARAMETERFVPROC
epoxy_glSamplerParameterfv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_sampler_objects,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        50357 /* "glSamplerParameterfv" */,
        50357 /* "glSamplerParameterfv" */,
        50357 /* "glSamplerParameterfv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 50357 /* "glSamplerParameterfv" */,
                                providers, entrypoints);
}

static PFNGLSAMPLERPARAMETERIPROC
epoxy_glSamplerParameteri_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_sampler_objects,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        50378 /* "glSamplerParameteri" */,
        50378 /* "glSamplerParameteri" */,
        50378 /* "glSamplerParameteri" */,
    };
    return gl_provider_resolver(entrypoint_strings + 50378 /* "glSamplerParameteri" */,
                                providers, entrypoints);
}

static PFNGLSAMPLERPARAMETERIVPROC
epoxy_glSamplerParameteriv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_sampler_objects,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        50398 /* "glSamplerParameteriv" */,
        50398 /* "glSamplerParameteriv" */,
        50398 /* "glSamplerParameteriv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 50398 /* "glSamplerParameteriv" */,
                                providers, entrypoints);
}

static PFNGLSCALEDPROC
epoxy_glScaled_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 50419 /* glScaled */);
}

static PFNGLSCALEFPROC
epoxy_glScalef_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        50428 /* "glScalef" */,
        50428 /* "glScalef" */,
    };
    return gl_provider_resolver(entrypoint_strings + 50428 /* "glScalef" */,
                                providers, entrypoints);
}

static PFNGLSCALEXPROC
epoxy_glScalex_resolver(void)
{
    return gl_single_resolver(PROVIDER_OpenGL_ES_1_0, 50437 /* glScalex */);
}

static PFNGLSCALEXOESPROC
epoxy_glScalexOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 50446 /* glScalexOES */);
}

static PFNGLSCISSORPROC
epoxy_glScissor_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        50458 /* "glScissor" */,
        50458 /* "glScissor" */,
        50458 /* "glScissor" */,
    };
    return gl_provider_resolver(entrypoint_strings + 50458 /* "glScissor" */,
                                providers, entrypoints);
}

static PFNGLSCISSORARRAYVPROC
epoxy_glScissorArrayv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_viewport_array,
        PROVIDER_GL_NV_viewport_array,
        PROVIDER_GL_OES_viewport_array,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        50468 /* "glScissorArrayv" */,
        50468 /* "glScissorArrayv" */,
        50484 /* "glScissorArrayvNV" */,
        50502 /* "glScissorArrayvOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 50468 /* "glScissorArrayv" */,
                                providers, entrypoints);
}

static PFNGLSCISSORARRAYVNVPROC
epoxy_glScissorArrayvNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_viewport_array,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_viewport_array,
        PROVIDER_GL_OES_viewport_array,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        50484 /* "glScissorArrayvNV" */,
        50468 /* "glScissorArrayv" */,
        50468 /* "glScissorArrayv" */,
        50502 /* "glScissorArrayvOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 50484 /* "glScissorArrayvNV" */,
                                providers, entrypoints);
}

static PFNGLSCISSORARRAYVOESPROC
epoxy_glScissorArrayvOES_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_OES_viewport_array,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_viewport_array,
        PROVIDER_GL_NV_viewport_array,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        50502 /* "glScissorArrayvOES" */,
        50468 /* "glScissorArrayv" */,
        50468 /* "glScissorArrayv" */,
        50484 /* "glScissorArrayvNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 50502 /* "glScissorArrayvOES" */,
                                providers, entrypoints);
}

static PFNGLSCISSOREXCLUSIVEARRAYVNVPROC
epoxy_glScissorExclusiveArrayvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_scissor_exclusive, 50521 /* glScissorExclusiveArrayvNV */);
}

static PFNGLSCISSOREXCLUSIVENVPROC
epoxy_glScissorExclusiveNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_scissor_exclusive, 50548 /* glScissorExclusiveNV */);
}

static PFNGLSCISSORINDEXEDPROC
epoxy_glScissorIndexed_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_viewport_array,
        PROVIDER_GL_NV_viewport_array,
        PROVIDER_GL_OES_viewport_array,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        50569 /* "glScissorIndexed" */,
        50569 /* "glScissorIndexed" */,
        50586 /* "glScissorIndexedNV" */,
        50605 /* "glScissorIndexedOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 50569 /* "glScissorIndexed" */,
                                providers, entrypoints);
}

static PFNGLSCISSORINDEXEDNVPROC
epoxy_glScissorIndexedNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_viewport_array,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_viewport_array,
        PROVIDER_GL_OES_viewport_array,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        50586 /* "glScissorIndexedNV" */,
        50569 /* "glScissorIndexed" */,
        50569 /* "glScissorIndexed" */,
        50605 /* "glScissorIndexedOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 50586 /* "glScissorIndexedNV" */,
                                providers, entrypoints);
}

static PFNGLSCISSORINDEXEDOESPROC
epoxy_glScissorIndexedOES_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_OES_viewport_array,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_viewport_array,
        PROVIDER_GL_NV_viewport_array,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        50605 /* "glScissorIndexedOES" */,
        50569 /* "glScissorIndexed" */,
        50569 /* "glScissorIndexed" */,
        50586 /* "glScissorIndexedNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 50605 /* "glScissorIndexedOES" */,
                                providers, entrypoints);
}

static PFNGLSCISSORINDEXEDVPROC
epoxy_glScissorIndexedv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_viewport_array,
        PROVIDER_GL_NV_viewport_array,
        PROVIDER_GL_OES_viewport_array,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        50625 /* "glScissorIndexedv" */,
        50625 /* "glScissorIndexedv" */,
        50643 /* "glScissorIndexedvNV" */,
        50663 /* "glScissorIndexedvOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 50625 /* "glScissorIndexedv" */,
                                providers, entrypoints);
}

static PFNGLSCISSORINDEXEDVNVPROC
epoxy_glScissorIndexedvNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_viewport_array,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_viewport_array,
        PROVIDER_GL_OES_viewport_array,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        50643 /* "glScissorIndexedvNV" */,
        50625 /* "glScissorIndexedv" */,
        50625 /* "glScissorIndexedv" */,
        50663 /* "glScissorIndexedvOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 50643 /* "glScissorIndexedvNV" */,
                                providers, entrypoints);
}

static PFNGLSCISSORINDEXEDVOESPROC
epoxy_glScissorIndexedvOES_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_OES_viewport_array,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_viewport_array,
        PROVIDER_GL_NV_viewport_array,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        50663 /* "glScissorIndexedvOES" */,
        50625 /* "glScissorIndexedv" */,
        50625 /* "glScissorIndexedv" */,
        50643 /* "glScissorIndexedvNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 50663 /* "glScissorIndexedvOES" */,
                                providers, entrypoints);
}

static PFNGLSECONDARYCOLOR3BPROC
epoxy_glSecondaryColor3b_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_EXT_secondary_color,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        50684 /* "glSecondaryColor3b" */,
        50703 /* "glSecondaryColor3bEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 50684 /* "glSecondaryColor3b" */,
                                providers, entrypoints);
}

static PFNGLSECONDARYCOLOR3BEXTPROC
epoxy_glSecondaryColor3bEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_secondary_color,
        PROVIDER_Desktop_OpenGL_1_4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        50703 /* "glSecondaryColor3bEXT" */,
        50684 /* "glSecondaryColor3b" */,
    };
    return gl_provider_resolver(entrypoint_strings + 50703 /* "glSecondaryColor3bEXT" */,
                                providers, entrypoints);
}

static PFNGLSECONDARYCOLOR3BVPROC
epoxy_glSecondaryColor3bv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_EXT_secondary_color,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        50725 /* "glSecondaryColor3bv" */,
        50745 /* "glSecondaryColor3bvEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 50725 /* "glSecondaryColor3bv" */,
                                providers, entrypoints);
}

static PFNGLSECONDARYCOLOR3BVEXTPROC
epoxy_glSecondaryColor3bvEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_secondary_color,
        PROVIDER_Desktop_OpenGL_1_4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        50745 /* "glSecondaryColor3bvEXT" */,
        50725 /* "glSecondaryColor3bv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 50745 /* "glSecondaryColor3bvEXT" */,
                                providers, entrypoints);
}

static PFNGLSECONDARYCOLOR3DPROC
epoxy_glSecondaryColor3d_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_EXT_secondary_color,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        50768 /* "glSecondaryColor3d" */,
        50787 /* "glSecondaryColor3dEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 50768 /* "glSecondaryColor3d" */,
                                providers, entrypoints);
}

static PFNGLSECONDARYCOLOR3DEXTPROC
epoxy_glSecondaryColor3dEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_secondary_color,
        PROVIDER_Desktop_OpenGL_1_4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        50787 /* "glSecondaryColor3dEXT" */,
        50768 /* "glSecondaryColor3d" */,
    };
    return gl_provider_resolver(entrypoint_strings + 50787 /* "glSecondaryColor3dEXT" */,
                                providers, entrypoints);
}

static PFNGLSECONDARYCOLOR3DVPROC
epoxy_glSecondaryColor3dv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_EXT_secondary_color,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        50809 /* "glSecondaryColor3dv" */,
        50829 /* "glSecondaryColor3dvEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 50809 /* "glSecondaryColor3dv" */,
                                providers, entrypoints);
}

static PFNGLSECONDARYCOLOR3DVEXTPROC
epoxy_glSecondaryColor3dvEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_secondary_color,
        PROVIDER_Desktop_OpenGL_1_4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        50829 /* "glSecondaryColor3dvEXT" */,
        50809 /* "glSecondaryColor3dv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 50829 /* "glSecondaryColor3dvEXT" */,
                                providers, entrypoints);
}

static PFNGLSECONDARYCOLOR3FPROC
epoxy_glSecondaryColor3f_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_EXT_secondary_color,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        50852 /* "glSecondaryColor3f" */,
        50871 /* "glSecondaryColor3fEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 50852 /* "glSecondaryColor3f" */,
                                providers, entrypoints);
}

static PFNGLSECONDARYCOLOR3FEXTPROC
epoxy_glSecondaryColor3fEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_secondary_color,
        PROVIDER_Desktop_OpenGL_1_4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        50871 /* "glSecondaryColor3fEXT" */,
        50852 /* "glSecondaryColor3f" */,
    };
    return gl_provider_resolver(entrypoint_strings + 50871 /* "glSecondaryColor3fEXT" */,
                                providers, entrypoints);
}

static PFNGLSECONDARYCOLOR3FVPROC
epoxy_glSecondaryColor3fv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_EXT_secondary_color,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        50893 /* "glSecondaryColor3fv" */,
        50913 /* "glSecondaryColor3fvEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 50893 /* "glSecondaryColor3fv" */,
                                providers, entrypoints);
}

static PFNGLSECONDARYCOLOR3FVEXTPROC
epoxy_glSecondaryColor3fvEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_secondary_color,
        PROVIDER_Desktop_OpenGL_1_4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        50913 /* "glSecondaryColor3fvEXT" */,
        50893 /* "glSecondaryColor3fv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 50913 /* "glSecondaryColor3fvEXT" */,
                                providers, entrypoints);
}

static PFNGLSECONDARYCOLOR3HNVPROC
epoxy_glSecondaryColor3hNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_half_float, 50936 /* glSecondaryColor3hNV */);
}

static PFNGLSECONDARYCOLOR3HVNVPROC
epoxy_glSecondaryColor3hvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_half_float, 50957 /* glSecondaryColor3hvNV */);
}

static PFNGLSECONDARYCOLOR3IPROC
epoxy_glSecondaryColor3i_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_EXT_secondary_color,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        50979 /* "glSecondaryColor3i" */,
        50998 /* "glSecondaryColor3iEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 50979 /* "glSecondaryColor3i" */,
                                providers, entrypoints);
}

static PFNGLSECONDARYCOLOR3IEXTPROC
epoxy_glSecondaryColor3iEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_secondary_color,
        PROVIDER_Desktop_OpenGL_1_4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        50998 /* "glSecondaryColor3iEXT" */,
        50979 /* "glSecondaryColor3i" */,
    };
    return gl_provider_resolver(entrypoint_strings + 50998 /* "glSecondaryColor3iEXT" */,
                                providers, entrypoints);
}

static PFNGLSECONDARYCOLOR3IVPROC
epoxy_glSecondaryColor3iv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_EXT_secondary_color,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        51020 /* "glSecondaryColor3iv" */,
        51040 /* "glSecondaryColor3ivEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 51020 /* "glSecondaryColor3iv" */,
                                providers, entrypoints);
}

static PFNGLSECONDARYCOLOR3IVEXTPROC
epoxy_glSecondaryColor3ivEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_secondary_color,
        PROVIDER_Desktop_OpenGL_1_4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        51040 /* "glSecondaryColor3ivEXT" */,
        51020 /* "glSecondaryColor3iv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 51040 /* "glSecondaryColor3ivEXT" */,
                                providers, entrypoints);
}

static PFNGLSECONDARYCOLOR3SPROC
epoxy_glSecondaryColor3s_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_EXT_secondary_color,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        51063 /* "glSecondaryColor3s" */,
        51082 /* "glSecondaryColor3sEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 51063 /* "glSecondaryColor3s" */,
                                providers, entrypoints);
}

static PFNGLSECONDARYCOLOR3SEXTPROC
epoxy_glSecondaryColor3sEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_secondary_color,
        PROVIDER_Desktop_OpenGL_1_4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        51082 /* "glSecondaryColor3sEXT" */,
        51063 /* "glSecondaryColor3s" */,
    };
    return gl_provider_resolver(entrypoint_strings + 51082 /* "glSecondaryColor3sEXT" */,
                                providers, entrypoints);
}

static PFNGLSECONDARYCOLOR3SVPROC
epoxy_glSecondaryColor3sv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_EXT_secondary_color,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        51104 /* "glSecondaryColor3sv" */,
        51124 /* "glSecondaryColor3svEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 51104 /* "glSecondaryColor3sv" */,
                                providers, entrypoints);
}

static PFNGLSECONDARYCOLOR3SVEXTPROC
epoxy_glSecondaryColor3svEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_secondary_color,
        PROVIDER_Desktop_OpenGL_1_4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        51124 /* "glSecondaryColor3svEXT" */,
        51104 /* "glSecondaryColor3sv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 51124 /* "glSecondaryColor3svEXT" */,
                                providers, entrypoints);
}

static PFNGLSECONDARYCOLOR3UBPROC
epoxy_glSecondaryColor3ub_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_EXT_secondary_color,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        51147 /* "glSecondaryColor3ub" */,
        51167 /* "glSecondaryColor3ubEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 51147 /* "glSecondaryColor3ub" */,
                                providers, entrypoints);
}

static PFNGLSECONDARYCOLOR3UBEXTPROC
epoxy_glSecondaryColor3ubEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_secondary_color,
        PROVIDER_Desktop_OpenGL_1_4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        51167 /* "glSecondaryColor3ubEXT" */,
        51147 /* "glSecondaryColor3ub" */,
    };
    return gl_provider_resolver(entrypoint_strings + 51167 /* "glSecondaryColor3ubEXT" */,
                                providers, entrypoints);
}

static PFNGLSECONDARYCOLOR3UBVPROC
epoxy_glSecondaryColor3ubv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_EXT_secondary_color,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        51190 /* "glSecondaryColor3ubv" */,
        51211 /* "glSecondaryColor3ubvEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 51190 /* "glSecondaryColor3ubv" */,
                                providers, entrypoints);
}

static PFNGLSECONDARYCOLOR3UBVEXTPROC
epoxy_glSecondaryColor3ubvEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_secondary_color,
        PROVIDER_Desktop_OpenGL_1_4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        51211 /* "glSecondaryColor3ubvEXT" */,
        51190 /* "glSecondaryColor3ubv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 51211 /* "glSecondaryColor3ubvEXT" */,
                                providers, entrypoints);
}

static PFNGLSECONDARYCOLOR3UIPROC
epoxy_glSecondaryColor3ui_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_EXT_secondary_color,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        51235 /* "glSecondaryColor3ui" */,
        51255 /* "glSecondaryColor3uiEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 51235 /* "glSecondaryColor3ui" */,
                                providers, entrypoints);
}

static PFNGLSECONDARYCOLOR3UIEXTPROC
epoxy_glSecondaryColor3uiEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_secondary_color,
        PROVIDER_Desktop_OpenGL_1_4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        51255 /* "glSecondaryColor3uiEXT" */,
        51235 /* "glSecondaryColor3ui" */,
    };
    return gl_provider_resolver(entrypoint_strings + 51255 /* "glSecondaryColor3uiEXT" */,
                                providers, entrypoints);
}

static PFNGLSECONDARYCOLOR3UIVPROC
epoxy_glSecondaryColor3uiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_EXT_secondary_color,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        51278 /* "glSecondaryColor3uiv" */,
        51299 /* "glSecondaryColor3uivEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 51278 /* "glSecondaryColor3uiv" */,
                                providers, entrypoints);
}

static PFNGLSECONDARYCOLOR3UIVEXTPROC
epoxy_glSecondaryColor3uivEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_secondary_color,
        PROVIDER_Desktop_OpenGL_1_4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        51299 /* "glSecondaryColor3uivEXT" */,
        51278 /* "glSecondaryColor3uiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 51299 /* "glSecondaryColor3uivEXT" */,
                                providers, entrypoints);
}

static PFNGLSECONDARYCOLOR3USPROC
epoxy_glSecondaryColor3us_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_EXT_secondary_color,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        51323 /* "glSecondaryColor3us" */,
        51343 /* "glSecondaryColor3usEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 51323 /* "glSecondaryColor3us" */,
                                providers, entrypoints);
}

static PFNGLSECONDARYCOLOR3USEXTPROC
epoxy_glSecondaryColor3usEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_secondary_color,
        PROVIDER_Desktop_OpenGL_1_4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        51343 /* "glSecondaryColor3usEXT" */,
        51323 /* "glSecondaryColor3us" */,
    };
    return gl_provider_resolver(entrypoint_strings + 51343 /* "glSecondaryColor3usEXT" */,
                                providers, entrypoints);
}

static PFNGLSECONDARYCOLOR3USVPROC
epoxy_glSecondaryColor3usv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_EXT_secondary_color,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        51366 /* "glSecondaryColor3usv" */,
        51387 /* "glSecondaryColor3usvEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 51366 /* "glSecondaryColor3usv" */,
                                providers, entrypoints);
}

static PFNGLSECONDARYCOLOR3USVEXTPROC
epoxy_glSecondaryColor3usvEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_secondary_color,
        PROVIDER_Desktop_OpenGL_1_4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        51387 /* "glSecondaryColor3usvEXT" */,
        51366 /* "glSecondaryColor3usv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 51387 /* "glSecondaryColor3usvEXT" */,
                                providers, entrypoints);
}

static PFNGLSECONDARYCOLORFORMATNVPROC
epoxy_glSecondaryColorFormatNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_buffer_unified_memory, 51411 /* glSecondaryColorFormatNV */);
}

static PFNGLSECONDARYCOLORP3UIPROC
epoxy_glSecondaryColorP3ui_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_vertex_type_2_10_10_10_rev,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        51436 /* "glSecondaryColorP3ui" */,
        51436 /* "glSecondaryColorP3ui" */,
    };
    return gl_provider_resolver(entrypoint_strings + 51436 /* "glSecondaryColorP3ui" */,
                                providers, entrypoints);
}

static PFNGLSECONDARYCOLORP3UIVPROC
epoxy_glSecondaryColorP3uiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_vertex_type_2_10_10_10_rev,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        51457 /* "glSecondaryColorP3uiv" */,
        51457 /* "glSecondaryColorP3uiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 51457 /* "glSecondaryColorP3uiv" */,
                                providers, entrypoints);
}

static PFNGLSECONDARYCOLORPOINTERPROC
epoxy_glSecondaryColorPointer_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_EXT_secondary_color,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        51479 /* "glSecondaryColorPointer" */,
        51503 /* "glSecondaryColorPointerEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 51479 /* "glSecondaryColorPointer" */,
                                providers, entrypoints);
}

static PFNGLSECONDARYCOLORPOINTEREXTPROC
epoxy_glSecondaryColorPointerEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_secondary_color,
        PROVIDER_Desktop_OpenGL_1_4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        51503 /* "glSecondaryColorPointerEXT" */,
        51479 /* "glSecondaryColorPointer" */,
    };
    return gl_provider_resolver(entrypoint_strings + 51503 /* "glSecondaryColorPointerEXT" */,
                                providers, entrypoints);
}

static PFNGLSECONDARYCOLORPOINTERLISTIBMPROC
epoxy_glSecondaryColorPointerListIBM_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_IBM_vertex_array_lists, 51530 /* glSecondaryColorPointerListIBM */);
}

static PFNGLSELECTBUFFERPROC
epoxy_glSelectBuffer_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 51561 /* glSelectBuffer */);
}

static PFNGLSELECTPERFMONITORCOUNTERSAMDPROC
epoxy_glSelectPerfMonitorCountersAMD_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_AMD_performance_monitor, 51576 /* glSelectPerfMonitorCountersAMD */);
}

static PFNGLSEMAPHOREPARAMETERUI64VEXTPROC
epoxy_glSemaphoreParameterui64vEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_semaphore, 51607 /* glSemaphoreParameterui64vEXT */);
}

static PFNGLSEPARABLEFILTER2DPROC
epoxy_glSeparableFilter2D_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_imaging,
        PROVIDER_GL_EXT_convolution,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        51636 /* "glSeparableFilter2D" */,
        51656 /* "glSeparableFilter2DEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 51636 /* "glSeparableFilter2D" */,
                                providers, entrypoints);
}

static PFNGLSEPARABLEFILTER2DEXTPROC
epoxy_glSeparableFilter2DEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_convolution,
        PROVIDER_GL_ARB_imaging,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        51656 /* "glSeparableFilter2DEXT" */,
        51636 /* "glSeparableFilter2D" */,
    };
    return gl_provider_resolver(entrypoint_strings + 51656 /* "glSeparableFilter2DEXT" */,
                                providers, entrypoints);
}

static PFNGLSETFENCEAPPLEPROC
epoxy_glSetFenceAPPLE_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_APPLE_fence, 51679 /* glSetFenceAPPLE */);
}

static PFNGLSETFENCENVPROC
epoxy_glSetFenceNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_fence, 51695 /* glSetFenceNV */);
}

static PFNGLSETFRAGMENTSHADERCONSTANTATIPROC
epoxy_glSetFragmentShaderConstantATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_fragment_shader, 51708 /* glSetFragmentShaderConstantATI */);
}

static PFNGLSETINVARIANTEXTPROC
epoxy_glSetInvariantEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_shader, 51739 /* glSetInvariantEXT */);
}

static PFNGLSETLOCALCONSTANTEXTPROC
epoxy_glSetLocalConstantEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_shader, 51757 /* glSetLocalConstantEXT */);
}

static PFNGLSETMULTISAMPLEFVAMDPROC
epoxy_glSetMultisamplefvAMD_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_AMD_sample_positions, 51779 /* glSetMultisamplefvAMD */);
}

static PFNGLSHADEMODELPROC
epoxy_glShadeModel_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        51801 /* "glShadeModel" */,
        51801 /* "glShadeModel" */,
    };
    return gl_provider_resolver(entrypoint_strings + 51801 /* "glShadeModel" */,
                                providers, entrypoints);
}

static PFNGLSHADERBINARYPROC
epoxy_glShaderBinary_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_ES2_compatibility,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        51814 /* "glShaderBinary" */,
        51814 /* "glShaderBinary" */,
        51814 /* "glShaderBinary" */,
    };
    return gl_provider_resolver(entrypoint_strings + 51814 /* "glShaderBinary" */,
                                providers, entrypoints);
}

static PFNGLSHADEROP1EXTPROC
epoxy_glShaderOp1EXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_shader, 51829 /* glShaderOp1EXT */);
}

static PFNGLSHADEROP2EXTPROC
epoxy_glShaderOp2EXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_shader, 51844 /* glShaderOp2EXT */);
}

static PFNGLSHADEROP3EXTPROC
epoxy_glShaderOp3EXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_shader, 51859 /* glShaderOp3EXT */);
}

static PFNGLSHADERSOURCEPROC
epoxy_glShaderSource_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        51874 /* "glShaderSource" */,
        51874 /* "glShaderSource" */,
        51889 /* "glShaderSourceARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 51874 /* "glShaderSource" */,
                                providers, entrypoints);
}

static PFNGLSHADERSOURCEARBPROC
epoxy_glShaderSourceARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_shader_objects,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        51889 /* "glShaderSourceARB" */,
        51874 /* "glShaderSource" */,
        51874 /* "glShaderSource" */,
    };
    return gl_provider_resolver(entrypoint_strings + 51889 /* "glShaderSourceARB" */,
                                providers, entrypoints);
}

static PFNGLSHADERSTORAGEBLOCKBINDINGPROC
epoxy_glShaderStorageBlockBinding_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_ARB_shader_storage_buffer_object,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        51907 /* "glShaderStorageBlockBinding" */,
        51907 /* "glShaderStorageBlockBinding" */,
    };
    return gl_provider_resolver(entrypoint_strings + 51907 /* "glShaderStorageBlockBinding" */,
                                providers, entrypoints);
}

static PFNGLSHADINGRATEIMAGEBARRIERNVPROC
epoxy_glShadingRateImageBarrierNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_shading_rate_image, 51935 /* glShadingRateImageBarrierNV */);
}

static PFNGLSHADINGRATEIMAGEPALETTENVPROC
epoxy_glShadingRateImagePaletteNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_shading_rate_image, 51963 /* glShadingRateImagePaletteNV */);
}

static PFNGLSHADINGRATESAMPLEORDERCUSTOMNVPROC
epoxy_glShadingRateSampleOrderCustomNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_shading_rate_image, 51991 /* glShadingRateSampleOrderCustomNV */);
}

static PFNGLSHADINGRATESAMPLEORDERNVPROC
epoxy_glShadingRateSampleOrderNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_shading_rate_image, 52024 /* glShadingRateSampleOrderNV */);
}

static PFNGLSHARPENTEXFUNCSGISPROC
epoxy_glSharpenTexFuncSGIS_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIS_sharpen_texture, 52051 /* glSharpenTexFuncSGIS */);
}

static PFNGLSIGNALSEMAPHOREEXTPROC
epoxy_glSignalSemaphoreEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_semaphore, 52072 /* glSignalSemaphoreEXT */);
}

static PFNGLSIGNALSEMAPHOREUI64NVXPROC
epoxy_glSignalSemaphoreui64NVX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NVX_progress_fence, 52093 /* glSignalSemaphoreui64NVX */);
}

static PFNGLSIGNALVKFENCENVPROC
epoxy_glSignalVkFenceNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_draw_vulkan_image, 52118 /* glSignalVkFenceNV */);
}

static PFNGLSIGNALVKSEMAPHORENVPROC
epoxy_glSignalVkSemaphoreNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_draw_vulkan_image, 52136 /* glSignalVkSemaphoreNV */);
}

static PFNGLSPECIALIZESHADERPROC
epoxy_glSpecializeShader_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_6,
        PROVIDER_GL_ARB_gl_spirv,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        52158 /* "glSpecializeShader" */,
        52177 /* "glSpecializeShaderARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 52158 /* "glSpecializeShader" */,
                                providers, entrypoints);
}

static PFNGLSPECIALIZESHADERARBPROC
epoxy_glSpecializeShaderARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_gl_spirv,
        PROVIDER_Desktop_OpenGL_4_6,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        52177 /* "glSpecializeShaderARB" */,
        52158 /* "glSpecializeShader" */,
    };
    return gl_provider_resolver(entrypoint_strings + 52177 /* "glSpecializeShaderARB" */,
                                providers, entrypoints);
}

static PFNGLSPRITEPARAMETERFSGIXPROC
epoxy_glSpriteParameterfSGIX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIX_sprite, 52199 /* glSpriteParameterfSGIX */);
}

static PFNGLSPRITEPARAMETERFVSGIXPROC
epoxy_glSpriteParameterfvSGIX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIX_sprite, 52222 /* glSpriteParameterfvSGIX */);
}

static PFNGLSPRITEPARAMETERISGIXPROC
epoxy_glSpriteParameteriSGIX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIX_sprite, 52246 /* glSpriteParameteriSGIX */);
}

static PFNGLSPRITEPARAMETERIVSGIXPROC
epoxy_glSpriteParameterivSGIX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIX_sprite, 52269 /* glSpriteParameterivSGIX */);
}

static PFNGLSTARTINSTRUMENTSSGIXPROC
epoxy_glStartInstrumentsSGIX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIX_instruments, 52293 /* glStartInstrumentsSGIX */);
}

static PFNGLSTARTTILINGQCOMPROC
epoxy_glStartTilingQCOM_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_QCOM_tiled_rendering, 52316 /* glStartTilingQCOM */);
}

static PFNGLSTATECAPTURENVPROC
epoxy_glStateCaptureNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_command_list, 52334 /* glStateCaptureNV */);
}

static PFNGLSTENCILCLEARTAGEXTPROC
epoxy_glStencilClearTagEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_stencil_clear_tag, 52351 /* glStencilClearTagEXT */);
}

static PFNGLSTENCILFILLPATHINSTANCEDNVPROC
epoxy_glStencilFillPathInstancedNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 52372 /* glStencilFillPathInstancedNV */);
}

static PFNGLSTENCILFILLPATHNVPROC
epoxy_glStencilFillPathNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 52401 /* glStencilFillPathNV */);
}

static PFNGLSTENCILFUNCPROC
epoxy_glStencilFunc_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        52421 /* "glStencilFunc" */,
        52421 /* "glStencilFunc" */,
        52421 /* "glStencilFunc" */,
    };
    return gl_provider_resolver(entrypoint_strings + 52421 /* "glStencilFunc" */,
                                providers, entrypoints);
}

static PFNGLSTENCILFUNCSEPARATEPROC
epoxy_glStencilFuncSeparate_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        52435 /* "glStencilFuncSeparate" */,
        52435 /* "glStencilFuncSeparate" */,
    };
    return gl_provider_resolver(entrypoint_strings + 52435 /* "glStencilFuncSeparate" */,
                                providers, entrypoints);
}

static PFNGLSTENCILFUNCSEPARATEATIPROC
epoxy_glStencilFuncSeparateATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_separate_stencil, 52457 /* glStencilFuncSeparateATI */);
}

static PFNGLSTENCILMASKPROC
epoxy_glStencilMask_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        52482 /* "glStencilMask" */,
        52482 /* "glStencilMask" */,
        52482 /* "glStencilMask" */,
    };
    return gl_provider_resolver(entrypoint_strings + 52482 /* "glStencilMask" */,
                                providers, entrypoints);
}

static PFNGLSTENCILMASKSEPARATEPROC
epoxy_glStencilMaskSeparate_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        52496 /* "glStencilMaskSeparate" */,
        52496 /* "glStencilMaskSeparate" */,
    };
    return gl_provider_resolver(entrypoint_strings + 52496 /* "glStencilMaskSeparate" */,
                                providers, entrypoints);
}

static PFNGLSTENCILOPPROC
epoxy_glStencilOp_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        52518 /* "glStencilOp" */,
        52518 /* "glStencilOp" */,
        52518 /* "glStencilOp" */,
    };
    return gl_provider_resolver(entrypoint_strings + 52518 /* "glStencilOp" */,
                                providers, entrypoints);
}

static PFNGLSTENCILOPSEPARATEPROC
epoxy_glStencilOpSeparate_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ATI_separate_stencil,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        52530 /* "glStencilOpSeparate" */,
        52530 /* "glStencilOpSeparate" */,
        52550 /* "glStencilOpSeparateATI" */,
    };
    return gl_provider_resolver(entrypoint_strings + 52530 /* "glStencilOpSeparate" */,
                                providers, entrypoints);
}

static PFNGLSTENCILOPSEPARATEATIPROC
epoxy_glStencilOpSeparateATI_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ATI_separate_stencil,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        52550 /* "glStencilOpSeparateATI" */,
        52530 /* "glStencilOpSeparate" */,
        52530 /* "glStencilOpSeparate" */,
    };
    return gl_provider_resolver(entrypoint_strings + 52550 /* "glStencilOpSeparateATI" */,
                                providers, entrypoints);
}

static PFNGLSTENCILOPVALUEAMDPROC
epoxy_glStencilOpValueAMD_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_AMD_stencil_operation_extended, 52573 /* glStencilOpValueAMD */);
}

static PFNGLSTENCILSTROKEPATHINSTANCEDNVPROC
epoxy_glStencilStrokePathInstancedNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 52593 /* glStencilStrokePathInstancedNV */);
}

static PFNGLSTENCILSTROKEPATHNVPROC
epoxy_glStencilStrokePathNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 52624 /* glStencilStrokePathNV */);
}

static PFNGLSTENCILTHENCOVERFILLPATHINSTANCEDNVPROC
epoxy_glStencilThenCoverFillPathInstancedNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 52646 /* glStencilThenCoverFillPathInstancedNV */);
}

static PFNGLSTENCILTHENCOVERFILLPATHNVPROC
epoxy_glStencilThenCoverFillPathNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 52684 /* glStencilThenCoverFillPathNV */);
}

static PFNGLSTENCILTHENCOVERSTROKEPATHINSTANCEDNVPROC
epoxy_glStencilThenCoverStrokePathInstancedNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 52713 /* glStencilThenCoverStrokePathInstancedNV */);
}

static PFNGLSTENCILTHENCOVERSTROKEPATHNVPROC
epoxy_glStencilThenCoverStrokePathNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 52753 /* glStencilThenCoverStrokePathNV */);
}

static PFNGLSTOPINSTRUMENTSSGIXPROC
epoxy_glStopInstrumentsSGIX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIX_instruments, 52784 /* glStopInstrumentsSGIX */);
}

static PFNGLSTRINGMARKERGREMEDYPROC
epoxy_glStringMarkerGREMEDY_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_GREMEDY_string_marker, 52806 /* glStringMarkerGREMEDY */);
}

static PFNGLSUBPIXELPRECISIONBIASNVPROC
epoxy_glSubpixelPrecisionBiasNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_conservative_raster, 52828 /* glSubpixelPrecisionBiasNV */);
}

static PFNGLSWIZZLEEXTPROC
epoxy_glSwizzleEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_shader, 52854 /* glSwizzleEXT */);
}

static PFNGLSYNCTEXTUREINTELPROC
epoxy_glSyncTextureINTEL_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_INTEL_map_texture, 52867 /* glSyncTextureINTEL */);
}

static PFNGLTAGSAMPLEBUFFERSGIXPROC
epoxy_glTagSampleBufferSGIX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIX_tag_sample_buffer, 52886 /* glTagSampleBufferSGIX */);
}

static PFNGLTANGENT3BEXTPROC
epoxy_glTangent3bEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_coordinate_frame, 52908 /* glTangent3bEXT */);
}

static PFNGLTANGENT3BVEXTPROC
epoxy_glTangent3bvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_coordinate_frame, 52923 /* glTangent3bvEXT */);
}

static PFNGLTANGENT3DEXTPROC
epoxy_glTangent3dEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_coordinate_frame, 52939 /* glTangent3dEXT */);
}

static PFNGLTANGENT3DVEXTPROC
epoxy_glTangent3dvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_coordinate_frame, 52954 /* glTangent3dvEXT */);
}

static PFNGLTANGENT3FEXTPROC
epoxy_glTangent3fEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_coordinate_frame, 52970 /* glTangent3fEXT */);
}

static PFNGLTANGENT3FVEXTPROC
epoxy_glTangent3fvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_coordinate_frame, 52985 /* glTangent3fvEXT */);
}

static PFNGLTANGENT3IEXTPROC
epoxy_glTangent3iEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_coordinate_frame, 53001 /* glTangent3iEXT */);
}

static PFNGLTANGENT3IVEXTPROC
epoxy_glTangent3ivEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_coordinate_frame, 53016 /* glTangent3ivEXT */);
}

static PFNGLTANGENT3SEXTPROC
epoxy_glTangent3sEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_coordinate_frame, 53032 /* glTangent3sEXT */);
}

static PFNGLTANGENT3SVEXTPROC
epoxy_glTangent3svEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_coordinate_frame, 53047 /* glTangent3svEXT */);
}

static PFNGLTANGENTPOINTEREXTPROC
epoxy_glTangentPointerEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_coordinate_frame, 53063 /* glTangentPointerEXT */);
}

static PFNGLTBUFFERMASK3DFXPROC
epoxy_glTbufferMask3DFX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_3DFX_tbuffer, 53083 /* glTbufferMask3DFX */);
}

static PFNGLTESSELLATIONFACTORAMDPROC
epoxy_glTessellationFactorAMD_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_AMD_vertex_shader_tessellator, 53101 /* glTessellationFactorAMD */);
}

static PFNGLTESSELLATIONMODEAMDPROC
epoxy_glTessellationModeAMD_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_AMD_vertex_shader_tessellator, 53125 /* glTessellationModeAMD */);
}

static PFNGLTESTFENCEAPPLEPROC
epoxy_glTestFenceAPPLE_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_APPLE_fence, 53147 /* glTestFenceAPPLE */);
}

static PFNGLTESTFENCENVPROC
epoxy_glTestFenceNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_fence, 53164 /* glTestFenceNV */);
}

static PFNGLTESTOBJECTAPPLEPROC
epoxy_glTestObjectAPPLE_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_APPLE_fence, 53178 /* glTestObjectAPPLE */);
}

static PFNGLTEXATTACHMEMORYNVPROC
epoxy_glTexAttachMemoryNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_memory_attachment, 53196 /* glTexAttachMemoryNV */);
}

static PFNGLTEXBUFFERPROC
epoxy_glTexBuffer_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_1,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_ARB_texture_buffer_object,
        PROVIDER_GL_EXT_texture_buffer,
        PROVIDER_GL_EXT_texture_buffer_object,
        PROVIDER_GL_OES_texture_buffer,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        53216 /* "glTexBuffer" */,
        53216 /* "glTexBuffer" */,
        53228 /* "glTexBufferARB" */,
        53243 /* "glTexBufferEXT" */,
        53243 /* "glTexBufferEXT" */,
        53258 /* "glTexBufferOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 53216 /* "glTexBuffer" */,
                                providers, entrypoints);
}

static PFNGLTEXBUFFERARBPROC
epoxy_glTexBufferARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_texture_buffer_object,
        PROVIDER_Desktop_OpenGL_3_1,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_texture_buffer,
        PROVIDER_GL_EXT_texture_buffer_object,
        PROVIDER_GL_OES_texture_buffer,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        53228 /* "glTexBufferARB" */,
        53216 /* "glTexBuffer" */,
        53216 /* "glTexBuffer" */,
        53243 /* "glTexBufferEXT" */,
        53243 /* "glTexBufferEXT" */,
        53258 /* "glTexBufferOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 53228 /* "glTexBufferARB" */,
                                providers, entrypoints);
}

static PFNGLTEXBUFFEREXTPROC
epoxy_glTexBufferEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_texture_buffer,
        PROVIDER_GL_EXT_texture_buffer_object,
        PROVIDER_Desktop_OpenGL_3_1,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_ARB_texture_buffer_object,
        PROVIDER_GL_OES_texture_buffer,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        53243 /* "glTexBufferEXT" */,
        53243 /* "glTexBufferEXT" */,
        53216 /* "glTexBuffer" */,
        53216 /* "glTexBuffer" */,
        53228 /* "glTexBufferARB" */,
        53258 /* "glTexBufferOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 53243 /* "glTexBufferEXT" */,
                                providers, entrypoints);
}

static PFNGLTEXBUFFEROESPROC
epoxy_glTexBufferOES_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_OES_texture_buffer,
        PROVIDER_Desktop_OpenGL_3_1,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_ARB_texture_buffer_object,
        PROVIDER_GL_EXT_texture_buffer,
        PROVIDER_GL_EXT_texture_buffer_object,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        53258 /* "glTexBufferOES" */,
        53216 /* "glTexBuffer" */,
        53216 /* "glTexBuffer" */,
        53228 /* "glTexBufferARB" */,
        53243 /* "glTexBufferEXT" */,
        53243 /* "glTexBufferEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 53258 /* "glTexBufferOES" */,
                                providers, entrypoints);
}

static PFNGLTEXBUFFERRANGEPROC
epoxy_glTexBufferRange_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_ARB_texture_buffer_range,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_texture_buffer,
        PROVIDER_GL_OES_texture_buffer,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        53273 /* "glTexBufferRange" */,
        53273 /* "glTexBufferRange" */,
        53273 /* "glTexBufferRange" */,
        53290 /* "glTexBufferRangeEXT" */,
        53310 /* "glTexBufferRangeOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 53273 /* "glTexBufferRange" */,
                                providers, entrypoints);
}

static PFNGLTEXBUFFERRANGEEXTPROC
epoxy_glTexBufferRangeEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_texture_buffer,
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_ARB_texture_buffer_range,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_OES_texture_buffer,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        53290 /* "glTexBufferRangeEXT" */,
        53273 /* "glTexBufferRange" */,
        53273 /* "glTexBufferRange" */,
        53273 /* "glTexBufferRange" */,
        53310 /* "glTexBufferRangeOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 53290 /* "glTexBufferRangeEXT" */,
                                providers, entrypoints);
}

static PFNGLTEXBUFFERRANGEOESPROC
epoxy_glTexBufferRangeOES_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_OES_texture_buffer,
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_ARB_texture_buffer_range,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_texture_buffer,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        53310 /* "glTexBufferRangeOES" */,
        53273 /* "glTexBufferRange" */,
        53273 /* "glTexBufferRange" */,
        53273 /* "glTexBufferRange" */,
        53290 /* "glTexBufferRangeEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 53310 /* "glTexBufferRangeOES" */,
                                providers, entrypoints);
}

static PFNGLTEXBUMPPARAMETERFVATIPROC
epoxy_glTexBumpParameterfvATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_envmap_bumpmap, 53330 /* glTexBumpParameterfvATI */);
}

static PFNGLTEXBUMPPARAMETERIVATIPROC
epoxy_glTexBumpParameterivATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_envmap_bumpmap, 53354 /* glTexBumpParameterivATI */);
}

static PFNGLTEXCOORD1BOESPROC
epoxy_glTexCoord1bOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_byte_coordinates, 53378 /* glTexCoord1bOES */);
}

static PFNGLTEXCOORD1BVOESPROC
epoxy_glTexCoord1bvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_byte_coordinates, 53394 /* glTexCoord1bvOES */);
}

static PFNGLTEXCOORD1DPROC
epoxy_glTexCoord1d_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 53411 /* glTexCoord1d */);
}

static PFNGLTEXCOORD1DVPROC
epoxy_glTexCoord1dv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 53424 /* glTexCoord1dv */);
}

static PFNGLTEXCOORD1FPROC
epoxy_glTexCoord1f_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 53438 /* glTexCoord1f */);
}

static PFNGLTEXCOORD1FVPROC
epoxy_glTexCoord1fv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 53451 /* glTexCoord1fv */);
}

static PFNGLTEXCOORD1HNVPROC
epoxy_glTexCoord1hNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_half_float, 53465 /* glTexCoord1hNV */);
}

static PFNGLTEXCOORD1HVNVPROC
epoxy_glTexCoord1hvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_half_float, 53480 /* glTexCoord1hvNV */);
}

static PFNGLTEXCOORD1IPROC
epoxy_glTexCoord1i_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 53496 /* glTexCoord1i */);
}

static PFNGLTEXCOORD1IVPROC
epoxy_glTexCoord1iv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 53509 /* glTexCoord1iv */);
}

static PFNGLTEXCOORD1SPROC
epoxy_glTexCoord1s_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 53523 /* glTexCoord1s */);
}

static PFNGLTEXCOORD1SVPROC
epoxy_glTexCoord1sv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 53536 /* glTexCoord1sv */);
}

static PFNGLTEXCOORD1XOESPROC
epoxy_glTexCoord1xOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 53550 /* glTexCoord1xOES */);
}

static PFNGLTEXCOORD1XVOESPROC
epoxy_glTexCoord1xvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 53566 /* glTexCoord1xvOES */);
}

static PFNGLTEXCOORD2BOESPROC
epoxy_glTexCoord2bOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_byte_coordinates, 53583 /* glTexCoord2bOES */);
}

static PFNGLTEXCOORD2BVOESPROC
epoxy_glTexCoord2bvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_byte_coordinates, 53599 /* glTexCoord2bvOES */);
}

static PFNGLTEXCOORD2DPROC
epoxy_glTexCoord2d_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 53616 /* glTexCoord2d */);
}

static PFNGLTEXCOORD2DVPROC
epoxy_glTexCoord2dv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 53629 /* glTexCoord2dv */);
}

static PFNGLTEXCOORD2FPROC
epoxy_glTexCoord2f_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 53643 /* glTexCoord2f */);
}

static PFNGLTEXCOORD2FCOLOR3FVERTEX3FSUNPROC
epoxy_glTexCoord2fColor3fVertex3fSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_vertex, 53656 /* glTexCoord2fColor3fVertex3fSUN */);
}

static PFNGLTEXCOORD2FCOLOR3FVERTEX3FVSUNPROC
epoxy_glTexCoord2fColor3fVertex3fvSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_vertex, 53687 /* glTexCoord2fColor3fVertex3fvSUN */);
}

static PFNGLTEXCOORD2FCOLOR4FNORMAL3FVERTEX3FSUNPROC
epoxy_glTexCoord2fColor4fNormal3fVertex3fSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_vertex, 53719 /* glTexCoord2fColor4fNormal3fVertex3fSUN */);
}

static PFNGLTEXCOORD2FCOLOR4FNORMAL3FVERTEX3FVSUNPROC
epoxy_glTexCoord2fColor4fNormal3fVertex3fvSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_vertex, 53758 /* glTexCoord2fColor4fNormal3fVertex3fvSUN */);
}

static PFNGLTEXCOORD2FCOLOR4UBVERTEX3FSUNPROC
epoxy_glTexCoord2fColor4ubVertex3fSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_vertex, 53798 /* glTexCoord2fColor4ubVertex3fSUN */);
}

static PFNGLTEXCOORD2FCOLOR4UBVERTEX3FVSUNPROC
epoxy_glTexCoord2fColor4ubVertex3fvSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_vertex, 53830 /* glTexCoord2fColor4ubVertex3fvSUN */);
}

static PFNGLTEXCOORD2FNORMAL3FVERTEX3FSUNPROC
epoxy_glTexCoord2fNormal3fVertex3fSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_vertex, 53863 /* glTexCoord2fNormal3fVertex3fSUN */);
}

static PFNGLTEXCOORD2FNORMAL3FVERTEX3FVSUNPROC
epoxy_glTexCoord2fNormal3fVertex3fvSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_vertex, 53895 /* glTexCoord2fNormal3fVertex3fvSUN */);
}

static PFNGLTEXCOORD2FVERTEX3FSUNPROC
epoxy_glTexCoord2fVertex3fSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_vertex, 53928 /* glTexCoord2fVertex3fSUN */);
}

static PFNGLTEXCOORD2FVERTEX3FVSUNPROC
epoxy_glTexCoord2fVertex3fvSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_vertex, 53952 /* glTexCoord2fVertex3fvSUN */);
}

static PFNGLTEXCOORD2FVPROC
epoxy_glTexCoord2fv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 53977 /* glTexCoord2fv */);
}

static PFNGLTEXCOORD2HNVPROC
epoxy_glTexCoord2hNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_half_float, 53991 /* glTexCoord2hNV */);
}

static PFNGLTEXCOORD2HVNVPROC
epoxy_glTexCoord2hvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_half_float, 54006 /* glTexCoord2hvNV */);
}

static PFNGLTEXCOORD2IPROC
epoxy_glTexCoord2i_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 54022 /* glTexCoord2i */);
}

static PFNGLTEXCOORD2IVPROC
epoxy_glTexCoord2iv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 54035 /* glTexCoord2iv */);
}

static PFNGLTEXCOORD2SPROC
epoxy_glTexCoord2s_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 54049 /* glTexCoord2s */);
}

static PFNGLTEXCOORD2SVPROC
epoxy_glTexCoord2sv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 54062 /* glTexCoord2sv */);
}

static PFNGLTEXCOORD2XOESPROC
epoxy_glTexCoord2xOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 54076 /* glTexCoord2xOES */);
}

static PFNGLTEXCOORD2XVOESPROC
epoxy_glTexCoord2xvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 54092 /* glTexCoord2xvOES */);
}

static PFNGLTEXCOORD3BOESPROC
epoxy_glTexCoord3bOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_byte_coordinates, 54109 /* glTexCoord3bOES */);
}

static PFNGLTEXCOORD3BVOESPROC
epoxy_glTexCoord3bvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_byte_coordinates, 54125 /* glTexCoord3bvOES */);
}

static PFNGLTEXCOORD3DPROC
epoxy_glTexCoord3d_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 54142 /* glTexCoord3d */);
}

static PFNGLTEXCOORD3DVPROC
epoxy_glTexCoord3dv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 54155 /* glTexCoord3dv */);
}

static PFNGLTEXCOORD3FPROC
epoxy_glTexCoord3f_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 54169 /* glTexCoord3f */);
}

static PFNGLTEXCOORD3FVPROC
epoxy_glTexCoord3fv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 54182 /* glTexCoord3fv */);
}

static PFNGLTEXCOORD3HNVPROC
epoxy_glTexCoord3hNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_half_float, 54196 /* glTexCoord3hNV */);
}

static PFNGLTEXCOORD3HVNVPROC
epoxy_glTexCoord3hvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_half_float, 54211 /* glTexCoord3hvNV */);
}

static PFNGLTEXCOORD3IPROC
epoxy_glTexCoord3i_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 54227 /* glTexCoord3i */);
}

static PFNGLTEXCOORD3IVPROC
epoxy_glTexCoord3iv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 54240 /* glTexCoord3iv */);
}

static PFNGLTEXCOORD3SPROC
epoxy_glTexCoord3s_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 54254 /* glTexCoord3s */);
}

static PFNGLTEXCOORD3SVPROC
epoxy_glTexCoord3sv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 54267 /* glTexCoord3sv */);
}

static PFNGLTEXCOORD3XOESPROC
epoxy_glTexCoord3xOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 54281 /* glTexCoord3xOES */);
}

static PFNGLTEXCOORD3XVOESPROC
epoxy_glTexCoord3xvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 54297 /* glTexCoord3xvOES */);
}

static PFNGLTEXCOORD4BOESPROC
epoxy_glTexCoord4bOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_byte_coordinates, 54314 /* glTexCoord4bOES */);
}

static PFNGLTEXCOORD4BVOESPROC
epoxy_glTexCoord4bvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_byte_coordinates, 54330 /* glTexCoord4bvOES */);
}

static PFNGLTEXCOORD4DPROC
epoxy_glTexCoord4d_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 54347 /* glTexCoord4d */);
}

static PFNGLTEXCOORD4DVPROC
epoxy_glTexCoord4dv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 54360 /* glTexCoord4dv */);
}

static PFNGLTEXCOORD4FPROC
epoxy_glTexCoord4f_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 54374 /* glTexCoord4f */);
}

static PFNGLTEXCOORD4FCOLOR4FNORMAL3FVERTEX4FSUNPROC
epoxy_glTexCoord4fColor4fNormal3fVertex4fSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_vertex, 54387 /* glTexCoord4fColor4fNormal3fVertex4fSUN */);
}

static PFNGLTEXCOORD4FCOLOR4FNORMAL3FVERTEX4FVSUNPROC
epoxy_glTexCoord4fColor4fNormal3fVertex4fvSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_vertex, 54426 /* glTexCoord4fColor4fNormal3fVertex4fvSUN */);
}

static PFNGLTEXCOORD4FVERTEX4FSUNPROC
epoxy_glTexCoord4fVertex4fSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_vertex, 54466 /* glTexCoord4fVertex4fSUN */);
}

static PFNGLTEXCOORD4FVERTEX4FVSUNPROC
epoxy_glTexCoord4fVertex4fvSUN_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SUN_vertex, 54490 /* glTexCoord4fVertex4fvSUN */);
}

static PFNGLTEXCOORD4FVPROC
epoxy_glTexCoord4fv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 54515 /* glTexCoord4fv */);
}

static PFNGLTEXCOORD4HNVPROC
epoxy_glTexCoord4hNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_half_float, 54529 /* glTexCoord4hNV */);
}

static PFNGLTEXCOORD4HVNVPROC
epoxy_glTexCoord4hvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_half_float, 54544 /* glTexCoord4hvNV */);
}

static PFNGLTEXCOORD4IPROC
epoxy_glTexCoord4i_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 54560 /* glTexCoord4i */);
}

static PFNGLTEXCOORD4IVPROC
epoxy_glTexCoord4iv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 54573 /* glTexCoord4iv */);
}

static PFNGLTEXCOORD4SPROC
epoxy_glTexCoord4s_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 54587 /* glTexCoord4s */);
}

static PFNGLTEXCOORD4SVPROC
epoxy_glTexCoord4sv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 54600 /* glTexCoord4sv */);
}

static PFNGLTEXCOORD4XOESPROC
epoxy_glTexCoord4xOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 54614 /* glTexCoord4xOES */);
}

static PFNGLTEXCOORD4XVOESPROC
epoxy_glTexCoord4xvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 54630 /* glTexCoord4xvOES */);
}

static PFNGLTEXCOORDFORMATNVPROC
epoxy_glTexCoordFormatNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_buffer_unified_memory, 54647 /* glTexCoordFormatNV */);
}

static PFNGLTEXCOORDP1UIPROC
epoxy_glTexCoordP1ui_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_vertex_type_2_10_10_10_rev,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        54666 /* "glTexCoordP1ui" */,
        54666 /* "glTexCoordP1ui" */,
    };
    return gl_provider_resolver(entrypoint_strings + 54666 /* "glTexCoordP1ui" */,
                                providers, entrypoints);
}

static PFNGLTEXCOORDP1UIVPROC
epoxy_glTexCoordP1uiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_vertex_type_2_10_10_10_rev,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        54681 /* "glTexCoordP1uiv" */,
        54681 /* "glTexCoordP1uiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 54681 /* "glTexCoordP1uiv" */,
                                providers, entrypoints);
}

static PFNGLTEXCOORDP2UIPROC
epoxy_glTexCoordP2ui_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_vertex_type_2_10_10_10_rev,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        54697 /* "glTexCoordP2ui" */,
        54697 /* "glTexCoordP2ui" */,
    };
    return gl_provider_resolver(entrypoint_strings + 54697 /* "glTexCoordP2ui" */,
                                providers, entrypoints);
}

static PFNGLTEXCOORDP2UIVPROC
epoxy_glTexCoordP2uiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_vertex_type_2_10_10_10_rev,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        54712 /* "glTexCoordP2uiv" */,
        54712 /* "glTexCoordP2uiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 54712 /* "glTexCoordP2uiv" */,
                                providers, entrypoints);
}

static PFNGLTEXCOORDP3UIPROC
epoxy_glTexCoordP3ui_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_vertex_type_2_10_10_10_rev,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        54728 /* "glTexCoordP3ui" */,
        54728 /* "glTexCoordP3ui" */,
    };
    return gl_provider_resolver(entrypoint_strings + 54728 /* "glTexCoordP3ui" */,
                                providers, entrypoints);
}

static PFNGLTEXCOORDP3UIVPROC
epoxy_glTexCoordP3uiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_vertex_type_2_10_10_10_rev,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        54743 /* "glTexCoordP3uiv" */,
        54743 /* "glTexCoordP3uiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 54743 /* "glTexCoordP3uiv" */,
                                providers, entrypoints);
}

static PFNGLTEXCOORDP4UIPROC
epoxy_glTexCoordP4ui_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_vertex_type_2_10_10_10_rev,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        54759 /* "glTexCoordP4ui" */,
        54759 /* "glTexCoordP4ui" */,
    };
    return gl_provider_resolver(entrypoint_strings + 54759 /* "glTexCoordP4ui" */,
                                providers, entrypoints);
}

static PFNGLTEXCOORDP4UIVPROC
epoxy_glTexCoordP4uiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_vertex_type_2_10_10_10_rev,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        54774 /* "glTexCoordP4uiv" */,
        54774 /* "glTexCoordP4uiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 54774 /* "glTexCoordP4uiv" */,
                                providers, entrypoints);
}

static PFNGLTEXCOORDPOINTERPROC
epoxy_glTexCoordPointer_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_1,
        PROVIDER_OpenGL_ES_1_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        54790 /* "glTexCoordPointer" */,
        54790 /* "glTexCoordPointer" */,
    };
    return gl_provider_resolver(entrypoint_strings + 54790 /* "glTexCoordPointer" */,
                                providers, entrypoints);
}

static PFNGLTEXCOORDPOINTEREXTPROC
epoxy_glTexCoordPointerEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_array, 54808 /* glTexCoordPointerEXT */);
}

static PFNGLTEXCOORDPOINTERLISTIBMPROC
epoxy_glTexCoordPointerListIBM_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_IBM_vertex_array_lists, 54829 /* glTexCoordPointerListIBM */);
}

static PFNGLTEXCOORDPOINTERVINTELPROC
epoxy_glTexCoordPointervINTEL_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_INTEL_parallel_arrays, 54854 /* glTexCoordPointervINTEL */);
}

static PFNGLTEXENVFPROC
epoxy_glTexEnvf_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        54878 /* "glTexEnvf" */,
        54878 /* "glTexEnvf" */,
    };
    return gl_provider_resolver(entrypoint_strings + 54878 /* "glTexEnvf" */,
                                providers, entrypoints);
}

static PFNGLTEXENVFVPROC
epoxy_glTexEnvfv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        54888 /* "glTexEnvfv" */,
        54888 /* "glTexEnvfv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 54888 /* "glTexEnvfv" */,
                                providers, entrypoints);
}

static PFNGLTEXENVIPROC
epoxy_glTexEnvi_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        54899 /* "glTexEnvi" */,
        54899 /* "glTexEnvi" */,
    };
    return gl_provider_resolver(entrypoint_strings + 54899 /* "glTexEnvi" */,
                                providers, entrypoints);
}

static PFNGLTEXENVIVPROC
epoxy_glTexEnviv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        54909 /* "glTexEnviv" */,
        54909 /* "glTexEnviv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 54909 /* "glTexEnviv" */,
                                providers, entrypoints);
}

static PFNGLTEXENVXPROC
epoxy_glTexEnvx_resolver(void)
{
    return gl_single_resolver(PROVIDER_OpenGL_ES_1_0, 54920 /* glTexEnvx */);
}

static PFNGLTEXENVXOESPROC
epoxy_glTexEnvxOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 54930 /* glTexEnvxOES */);
}

static PFNGLTEXENVXVPROC
epoxy_glTexEnvxv_resolver(void)
{
    return gl_single_resolver(PROVIDER_OpenGL_ES_1_0, 54943 /* glTexEnvxv */);
}

static PFNGLTEXENVXVOESPROC
epoxy_glTexEnvxvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 54954 /* glTexEnvxvOES */);
}

static PFNGLTEXFILTERFUNCSGISPROC
epoxy_glTexFilterFuncSGIS_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIS_texture_filter4, 54968 /* glTexFilterFuncSGIS */);
}

static PFNGLTEXGENDPROC
epoxy_glTexGend_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 54988 /* glTexGend */);
}

static PFNGLTEXGENDVPROC
epoxy_glTexGendv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 54998 /* glTexGendv */);
}

static PFNGLTEXGENFPROC
epoxy_glTexGenf_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 55009 /* glTexGenf */);
}

static PFNGLTEXGENFOESPROC
epoxy_glTexGenfOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_texture_cube_map, 55019 /* glTexGenfOES */);
}

static PFNGLTEXGENFVPROC
epoxy_glTexGenfv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 55032 /* glTexGenfv */);
}

static PFNGLTEXGENFVOESPROC
epoxy_glTexGenfvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_texture_cube_map, 55043 /* glTexGenfvOES */);
}

static PFNGLTEXGENIPROC
epoxy_glTexGeni_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 55057 /* glTexGeni */);
}

static PFNGLTEXGENIOESPROC
epoxy_glTexGeniOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_texture_cube_map, 55067 /* glTexGeniOES */);
}

static PFNGLTEXGENIVPROC
epoxy_glTexGeniv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 55080 /* glTexGeniv */);
}

static PFNGLTEXGENIVOESPROC
epoxy_glTexGenivOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_texture_cube_map, 55091 /* glTexGenivOES */);
}

static PFNGLTEXGENXOESPROC
epoxy_glTexGenxOES_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_OES_fixed_point,
        PROVIDER_GL_OES_texture_cube_map,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        55105 /* "glTexGenxOES" */,
        55105 /* "glTexGenxOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 55105 /* "glTexGenxOES" */,
                                providers, entrypoints);
}

static PFNGLTEXGENXVOESPROC
epoxy_glTexGenxvOES_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_OES_fixed_point,
        PROVIDER_GL_OES_texture_cube_map,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        55118 /* "glTexGenxvOES" */,
        55118 /* "glTexGenxvOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 55118 /* "glTexGenxvOES" */,
                                providers, entrypoints);
}

static PFNGLTEXIMAGE1DPROC
epoxy_glTexImage1D_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 55132 /* glTexImage1D */);
}

static PFNGLTEXIMAGE2DPROC
epoxy_glTexImage2D_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        55145 /* "glTexImage2D" */,
        55145 /* "glTexImage2D" */,
        55145 /* "glTexImage2D" */,
    };
    return gl_provider_resolver(entrypoint_strings + 55145 /* "glTexImage2D" */,
                                providers, entrypoints);
}

static PFNGLTEXIMAGE2DMULTISAMPLEPROC
epoxy_glTexImage2DMultisample_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_2,
        PROVIDER_GL_ARB_texture_multisample,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        55158 /* "glTexImage2DMultisample" */,
        55158 /* "glTexImage2DMultisample" */,
    };
    return gl_provider_resolver(entrypoint_strings + 55158 /* "glTexImage2DMultisample" */,
                                providers, entrypoints);
}

static PFNGLTEXIMAGE2DMULTISAMPLECOVERAGENVPROC
epoxy_glTexImage2DMultisampleCoverageNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_texture_multisample, 55182 /* glTexImage2DMultisampleCoverageNV */);
}

static PFNGLTEXIMAGE3DPROC
epoxy_glTexImage3D_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_2,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_EXT_texture3D,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        55216 /* "glTexImage3D" */,
        55216 /* "glTexImage3D" */,
        55229 /* "glTexImage3DEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 55216 /* "glTexImage3D" */,
                                providers, entrypoints);
}

static PFNGLTEXIMAGE3DEXTPROC
epoxy_glTexImage3DEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_texture3D,
        PROVIDER_Desktop_OpenGL_1_2,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        55229 /* "glTexImage3DEXT" */,
        55216 /* "glTexImage3D" */,
        55216 /* "glTexImage3D" */,
    };
    return gl_provider_resolver(entrypoint_strings + 55229 /* "glTexImage3DEXT" */,
                                providers, entrypoints);
}

static PFNGLTEXIMAGE3DMULTISAMPLEPROC
epoxy_glTexImage3DMultisample_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_2,
        PROVIDER_GL_ARB_texture_multisample,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        55245 /* "glTexImage3DMultisample" */,
        55245 /* "glTexImage3DMultisample" */,
    };
    return gl_provider_resolver(entrypoint_strings + 55245 /* "glTexImage3DMultisample" */,
                                providers, entrypoints);
}

static PFNGLTEXIMAGE3DMULTISAMPLECOVERAGENVPROC
epoxy_glTexImage3DMultisampleCoverageNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_texture_multisample, 55269 /* glTexImage3DMultisampleCoverageNV */);
}

static PFNGLTEXIMAGE3DOESPROC
epoxy_glTexImage3DOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_texture_3D, 55303 /* glTexImage3DOES */);
}

static PFNGLTEXIMAGE4DSGISPROC
epoxy_glTexImage4DSGIS_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIS_texture4D, 55319 /* glTexImage4DSGIS */);
}

static PFNGLTEXPAGECOMMITMENTARBPROC
epoxy_glTexPageCommitmentARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_sparse_texture,
        PROVIDER_GL_EXT_sparse_texture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        55336 /* "glTexPageCommitmentARB" */,
        55359 /* "glTexPageCommitmentEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 55336 /* "glTexPageCommitmentARB" */,
                                providers, entrypoints);
}

static PFNGLTEXPAGECOMMITMENTEXTPROC
epoxy_glTexPageCommitmentEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_sparse_texture,
        PROVIDER_GL_ARB_sparse_texture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        55359 /* "glTexPageCommitmentEXT" */,
        55336 /* "glTexPageCommitmentARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 55359 /* "glTexPageCommitmentEXT" */,
                                providers, entrypoints);
}

static PFNGLTEXPARAMETERIIVPROC
epoxy_glTexParameterIiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_texture_border_clamp,
        PROVIDER_GL_EXT_texture_integer,
        PROVIDER_GL_OES_texture_border_clamp,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        55382 /* "glTexParameterIiv" */,
        55382 /* "glTexParameterIiv" */,
        55400 /* "glTexParameterIivEXT" */,
        55400 /* "glTexParameterIivEXT" */,
        55421 /* "glTexParameterIivOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 55382 /* "glTexParameterIiv" */,
                                providers, entrypoints);
}

static PFNGLTEXPARAMETERIIVEXTPROC
epoxy_glTexParameterIivEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_texture_border_clamp,
        PROVIDER_GL_EXT_texture_integer,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_OES_texture_border_clamp,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        55400 /* "glTexParameterIivEXT" */,
        55400 /* "glTexParameterIivEXT" */,
        55382 /* "glTexParameterIiv" */,
        55382 /* "glTexParameterIiv" */,
        55421 /* "glTexParameterIivOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 55400 /* "glTexParameterIivEXT" */,
                                providers, entrypoints);
}

static PFNGLTEXPARAMETERIIVOESPROC
epoxy_glTexParameterIivOES_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_OES_texture_border_clamp,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_texture_border_clamp,
        PROVIDER_GL_EXT_texture_integer,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        55421 /* "glTexParameterIivOES" */,
        55382 /* "glTexParameterIiv" */,
        55382 /* "glTexParameterIiv" */,
        55400 /* "glTexParameterIivEXT" */,
        55400 /* "glTexParameterIivEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 55421 /* "glTexParameterIivOES" */,
                                providers, entrypoints);
}

static PFNGLTEXPARAMETERIUIVPROC
epoxy_glTexParameterIuiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_texture_border_clamp,
        PROVIDER_GL_EXT_texture_integer,
        PROVIDER_GL_OES_texture_border_clamp,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        55442 /* "glTexParameterIuiv" */,
        55442 /* "glTexParameterIuiv" */,
        55461 /* "glTexParameterIuivEXT" */,
        55461 /* "glTexParameterIuivEXT" */,
        55483 /* "glTexParameterIuivOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 55442 /* "glTexParameterIuiv" */,
                                providers, entrypoints);
}

static PFNGLTEXPARAMETERIUIVEXTPROC
epoxy_glTexParameterIuivEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_texture_border_clamp,
        PROVIDER_GL_EXT_texture_integer,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_OES_texture_border_clamp,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        55461 /* "glTexParameterIuivEXT" */,
        55461 /* "glTexParameterIuivEXT" */,
        55442 /* "glTexParameterIuiv" */,
        55442 /* "glTexParameterIuiv" */,
        55483 /* "glTexParameterIuivOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 55461 /* "glTexParameterIuivEXT" */,
                                providers, entrypoints);
}

static PFNGLTEXPARAMETERIUIVOESPROC
epoxy_glTexParameterIuivOES_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_OES_texture_border_clamp,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_EXT_texture_border_clamp,
        PROVIDER_GL_EXT_texture_integer,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        55483 /* "glTexParameterIuivOES" */,
        55442 /* "glTexParameterIuiv" */,
        55442 /* "glTexParameterIuiv" */,
        55461 /* "glTexParameterIuivEXT" */,
        55461 /* "glTexParameterIuivEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 55483 /* "glTexParameterIuivOES" */,
                                providers, entrypoints);
}

static PFNGLTEXPARAMETERFPROC
epoxy_glTexParameterf_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        55505 /* "glTexParameterf" */,
        55505 /* "glTexParameterf" */,
        55505 /* "glTexParameterf" */,
    };
    return gl_provider_resolver(entrypoint_strings + 55505 /* "glTexParameterf" */,
                                providers, entrypoints);
}

static PFNGLTEXPARAMETERFVPROC
epoxy_glTexParameterfv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        55521 /* "glTexParameterfv" */,
        55521 /* "glTexParameterfv" */,
        55521 /* "glTexParameterfv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 55521 /* "glTexParameterfv" */,
                                providers, entrypoints);
}

static PFNGLTEXPARAMETERIPROC
epoxy_glTexParameteri_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        55538 /* "glTexParameteri" */,
        55538 /* "glTexParameteri" */,
        55538 /* "glTexParameteri" */,
    };
    return gl_provider_resolver(entrypoint_strings + 55538 /* "glTexParameteri" */,
                                providers, entrypoints);
}

static PFNGLTEXPARAMETERIVPROC
epoxy_glTexParameteriv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        55554 /* "glTexParameteriv" */,
        55554 /* "glTexParameteriv" */,
        55554 /* "glTexParameteriv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 55554 /* "glTexParameteriv" */,
                                providers, entrypoints);
}

static PFNGLTEXPARAMETERXPROC
epoxy_glTexParameterx_resolver(void)
{
    return gl_single_resolver(PROVIDER_OpenGL_ES_1_0, 55571 /* glTexParameterx */);
}

static PFNGLTEXPARAMETERXOESPROC
epoxy_glTexParameterxOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 55587 /* glTexParameterxOES */);
}

static PFNGLTEXPARAMETERXVPROC
epoxy_glTexParameterxv_resolver(void)
{
    return gl_single_resolver(PROVIDER_OpenGL_ES_1_0, 55606 /* glTexParameterxv */);
}

static PFNGLTEXPARAMETERXVOESPROC
epoxy_glTexParameterxvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 55623 /* glTexParameterxvOES */);
}

static PFNGLTEXRENDERBUFFERNVPROC
epoxy_glTexRenderbufferNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_explicit_multisample, 55643 /* glTexRenderbufferNV */);
}

static PFNGLTEXSTORAGE1DPROC
epoxy_glTexStorage1D_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_2,
        PROVIDER_GL_ARB_texture_storage,
        PROVIDER_GL_EXT_texture_storage,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        55663 /* "glTexStorage1D" */,
        55663 /* "glTexStorage1D" */,
        55678 /* "glTexStorage1DEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 55663 /* "glTexStorage1D" */,
                                providers, entrypoints);
}

static PFNGLTEXSTORAGE1DEXTPROC
epoxy_glTexStorage1DEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_texture_storage,
        PROVIDER_Desktop_OpenGL_4_2,
        PROVIDER_GL_ARB_texture_storage,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        55678 /* "glTexStorage1DEXT" */,
        55663 /* "glTexStorage1D" */,
        55663 /* "glTexStorage1D" */,
    };
    return gl_provider_resolver(entrypoint_strings + 55678 /* "glTexStorage1DEXT" */,
                                providers, entrypoints);
}

static PFNGLTEXSTORAGE2DPROC
epoxy_glTexStorage2D_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_2,
        PROVIDER_GL_ARB_texture_storage,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_EXT_texture_storage,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        55696 /* "glTexStorage2D" */,
        55696 /* "glTexStorage2D" */,
        55696 /* "glTexStorage2D" */,
        55711 /* "glTexStorage2DEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 55696 /* "glTexStorage2D" */,
                                providers, entrypoints);
}

static PFNGLTEXSTORAGE2DEXTPROC
epoxy_glTexStorage2DEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_texture_storage,
        PROVIDER_Desktop_OpenGL_4_2,
        PROVIDER_GL_ARB_texture_storage,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        55711 /* "glTexStorage2DEXT" */,
        55696 /* "glTexStorage2D" */,
        55696 /* "glTexStorage2D" */,
        55696 /* "glTexStorage2D" */,
    };
    return gl_provider_resolver(entrypoint_strings + 55711 /* "glTexStorage2DEXT" */,
                                providers, entrypoints);
}

static PFNGLTEXSTORAGE2DMULTISAMPLEPROC
epoxy_glTexStorage2DMultisample_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_ARB_texture_storage_multisample,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        55729 /* "glTexStorage2DMultisample" */,
        55729 /* "glTexStorage2DMultisample" */,
        55729 /* "glTexStorage2DMultisample" */,
    };
    return gl_provider_resolver(entrypoint_strings + 55729 /* "glTexStorage2DMultisample" */,
                                providers, entrypoints);
}

static PFNGLTEXSTORAGE3DPROC
epoxy_glTexStorage3D_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_2,
        PROVIDER_GL_ARB_texture_storage,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_EXT_texture_storage,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        55755 /* "glTexStorage3D" */,
        55755 /* "glTexStorage3D" */,
        55755 /* "glTexStorage3D" */,
        55770 /* "glTexStorage3DEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 55755 /* "glTexStorage3D" */,
                                providers, entrypoints);
}

static PFNGLTEXSTORAGE3DEXTPROC
epoxy_glTexStorage3DEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_texture_storage,
        PROVIDER_Desktop_OpenGL_4_2,
        PROVIDER_GL_ARB_texture_storage,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        55770 /* "glTexStorage3DEXT" */,
        55755 /* "glTexStorage3D" */,
        55755 /* "glTexStorage3D" */,
        55755 /* "glTexStorage3D" */,
    };
    return gl_provider_resolver(entrypoint_strings + 55770 /* "glTexStorage3DEXT" */,
                                providers, entrypoints);
}

static PFNGLTEXSTORAGE3DMULTISAMPLEPROC
epoxy_glTexStorage3DMultisample_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_ARB_texture_storage_multisample,
        PROVIDER_OpenGL_ES_3_2,
        PROVIDER_GL_OES_texture_storage_multisample_2d_array,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        55788 /* "glTexStorage3DMultisample" */,
        55788 /* "glTexStorage3DMultisample" */,
        55788 /* "glTexStorage3DMultisample" */,
        55814 /* "glTexStorage3DMultisampleOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 55788 /* "glTexStorage3DMultisample" */,
                                providers, entrypoints);
}

static PFNGLTEXSTORAGE3DMULTISAMPLEOESPROC
epoxy_glTexStorage3DMultisampleOES_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_OES_texture_storage_multisample_2d_array,
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_ARB_texture_storage_multisample,
        PROVIDER_OpenGL_ES_3_2,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        55814 /* "glTexStorage3DMultisampleOES" */,
        55788 /* "glTexStorage3DMultisample" */,
        55788 /* "glTexStorage3DMultisample" */,
        55788 /* "glTexStorage3DMultisample" */,
    };
    return gl_provider_resolver(entrypoint_strings + 55814 /* "glTexStorage3DMultisampleOES" */,
                                providers, entrypoints);
}

static PFNGLTEXSTORAGEMEM1DEXTPROC
epoxy_glTexStorageMem1DEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_memory_object, 55843 /* glTexStorageMem1DEXT */);
}

static PFNGLTEXSTORAGEMEM2DEXTPROC
epoxy_glTexStorageMem2DEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_memory_object, 55864 /* glTexStorageMem2DEXT */);
}

static PFNGLTEXSTORAGEMEM2DMULTISAMPLEEXTPROC
epoxy_glTexStorageMem2DMultisampleEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_memory_object, 55885 /* glTexStorageMem2DMultisampleEXT */);
}

static PFNGLTEXSTORAGEMEM3DEXTPROC
epoxy_glTexStorageMem3DEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_memory_object, 55917 /* glTexStorageMem3DEXT */);
}

static PFNGLTEXSTORAGEMEM3DMULTISAMPLEEXTPROC
epoxy_glTexStorageMem3DMultisampleEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_memory_object, 55938 /* glTexStorageMem3DMultisampleEXT */);
}

static PFNGLTEXSTORAGESPARSEAMDPROC
epoxy_glTexStorageSparseAMD_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_AMD_sparse_texture, 55970 /* glTexStorageSparseAMD */);
}

static PFNGLTEXSUBIMAGE1DPROC
epoxy_glTexSubImage1D_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_1,
        PROVIDER_GL_EXT_subtexture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        55992 /* "glTexSubImage1D" */,
        56008 /* "glTexSubImage1DEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 55992 /* "glTexSubImage1D" */,
                                providers, entrypoints);
}

static PFNGLTEXSUBIMAGE1DEXTPROC
epoxy_glTexSubImage1DEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_subtexture,
        PROVIDER_Desktop_OpenGL_1_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        56008 /* "glTexSubImage1DEXT" */,
        55992 /* "glTexSubImage1D" */,
    };
    return gl_provider_resolver(entrypoint_strings + 56008 /* "glTexSubImage1DEXT" */,
                                providers, entrypoints);
}

static PFNGLTEXSUBIMAGE2DPROC
epoxy_glTexSubImage2D_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_1,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_EXT_subtexture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        56027 /* "glTexSubImage2D" */,
        56027 /* "glTexSubImage2D" */,
        56027 /* "glTexSubImage2D" */,
        56043 /* "glTexSubImage2DEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 56027 /* "glTexSubImage2D" */,
                                providers, entrypoints);
}

static PFNGLTEXSUBIMAGE2DEXTPROC
epoxy_glTexSubImage2DEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_subtexture,
        PROVIDER_Desktop_OpenGL_1_1,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        56043 /* "glTexSubImage2DEXT" */,
        56027 /* "glTexSubImage2D" */,
        56027 /* "glTexSubImage2D" */,
        56027 /* "glTexSubImage2D" */,
    };
    return gl_provider_resolver(entrypoint_strings + 56043 /* "glTexSubImage2DEXT" */,
                                providers, entrypoints);
}

static PFNGLTEXSUBIMAGE3DPROC
epoxy_glTexSubImage3D_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_2,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_EXT_texture3D,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        56062 /* "glTexSubImage3D" */,
        56062 /* "glTexSubImage3D" */,
        56078 /* "glTexSubImage3DEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 56062 /* "glTexSubImage3D" */,
                                providers, entrypoints);
}

static PFNGLTEXSUBIMAGE3DEXTPROC
epoxy_glTexSubImage3DEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_texture3D,
        PROVIDER_Desktop_OpenGL_1_2,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        56078 /* "glTexSubImage3DEXT" */,
        56062 /* "glTexSubImage3D" */,
        56062 /* "glTexSubImage3D" */,
    };
    return gl_provider_resolver(entrypoint_strings + 56078 /* "glTexSubImage3DEXT" */,
                                providers, entrypoints);
}

static PFNGLTEXSUBIMAGE3DOESPROC
epoxy_glTexSubImage3DOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_texture_3D, 56097 /* glTexSubImage3DOES */);
}

static PFNGLTEXSUBIMAGE4DSGISPROC
epoxy_glTexSubImage4DSGIS_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIS_texture4D, 56116 /* glTexSubImage4DSGIS */);
}

static PFNGLTEXTUREATTACHMEMORYNVPROC
epoxy_glTextureAttachMemoryNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_memory_attachment, 56136 /* glTextureAttachMemoryNV */);
}

static PFNGLTEXTUREBARRIERPROC
epoxy_glTextureBarrier_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_texture_barrier,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        56160 /* "glTextureBarrier" */,
        56160 /* "glTextureBarrier" */,
    };
    return gl_provider_resolver(entrypoint_strings + 56160 /* "glTextureBarrier" */,
                                providers, entrypoints);
}

static PFNGLTEXTUREBARRIERNVPROC
epoxy_glTextureBarrierNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_texture_barrier, 56177 /* glTextureBarrierNV */);
}

static PFNGLTEXTUREBUFFERPROC
epoxy_glTextureBuffer_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        56196 /* "glTextureBuffer" */,
        56196 /* "glTextureBuffer" */,
    };
    return gl_provider_resolver(entrypoint_strings + 56196 /* "glTextureBuffer" */,
                                providers, entrypoints);
}

static PFNGLTEXTUREBUFFEREXTPROC
epoxy_glTextureBufferEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 56212 /* glTextureBufferEXT */);
}

static PFNGLTEXTUREBUFFERRANGEPROC
epoxy_glTextureBufferRange_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        56231 /* "glTextureBufferRange" */,
        56231 /* "glTextureBufferRange" */,
    };
    return gl_provider_resolver(entrypoint_strings + 56231 /* "glTextureBufferRange" */,
                                providers, entrypoints);
}

static PFNGLTEXTUREBUFFERRANGEEXTPROC
epoxy_glTextureBufferRangeEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 56252 /* glTextureBufferRangeEXT */);
}

static PFNGLTEXTURECOLORMASKSGISPROC
epoxy_glTextureColorMaskSGIS_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_SGIS_texture_color_mask, 56276 /* glTextureColorMaskSGIS */);
}

static PFNGLTEXTUREFOVEATIONPARAMETERSQCOMPROC
epoxy_glTextureFoveationParametersQCOM_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_QCOM_texture_foveated, 56299 /* glTextureFoveationParametersQCOM */);
}

static PFNGLTEXTUREIMAGE1DEXTPROC
epoxy_glTextureImage1DEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 56332 /* glTextureImage1DEXT */);
}

static PFNGLTEXTUREIMAGE2DEXTPROC
epoxy_glTextureImage2DEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 56352 /* glTextureImage2DEXT */);
}

static PFNGLTEXTUREIMAGE2DMULTISAMPLECOVERAGENVPROC
epoxy_glTextureImage2DMultisampleCoverageNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_texture_multisample, 56372 /* glTextureImage2DMultisampleCoverageNV */);
}

static PFNGLTEXTUREIMAGE2DMULTISAMPLENVPROC
epoxy_glTextureImage2DMultisampleNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_texture_multisample, 56410 /* glTextureImage2DMultisampleNV */);
}

static PFNGLTEXTUREIMAGE3DEXTPROC
epoxy_glTextureImage3DEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 56440 /* glTextureImage3DEXT */);
}

static PFNGLTEXTUREIMAGE3DMULTISAMPLECOVERAGENVPROC
epoxy_glTextureImage3DMultisampleCoverageNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_texture_multisample, 56460 /* glTextureImage3DMultisampleCoverageNV */);
}

static PFNGLTEXTUREIMAGE3DMULTISAMPLENVPROC
epoxy_glTextureImage3DMultisampleNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_texture_multisample, 56498 /* glTextureImage3DMultisampleNV */);
}

static PFNGLTEXTURELIGHTEXTPROC
epoxy_glTextureLightEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_light_texture, 56528 /* glTextureLightEXT */);
}

static PFNGLTEXTUREMATERIALEXTPROC
epoxy_glTextureMaterialEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_light_texture, 56546 /* glTextureMaterialEXT */);
}

static PFNGLTEXTURENORMALEXTPROC
epoxy_glTextureNormalEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_texture_perturb_normal, 56567 /* glTextureNormalEXT */);
}

static PFNGLTEXTUREPAGECOMMITMENTEXTPROC
epoxy_glTexturePageCommitmentEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 56586 /* glTexturePageCommitmentEXT */);
}

static PFNGLTEXTUREPARAMETERIIVPROC
epoxy_glTextureParameterIiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        56613 /* "glTextureParameterIiv" */,
        56613 /* "glTextureParameterIiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 56613 /* "glTextureParameterIiv" */,
                                providers, entrypoints);
}

static PFNGLTEXTUREPARAMETERIIVEXTPROC
epoxy_glTextureParameterIivEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 56635 /* glTextureParameterIivEXT */);
}

static PFNGLTEXTUREPARAMETERIUIVPROC
epoxy_glTextureParameterIuiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        56660 /* "glTextureParameterIuiv" */,
        56660 /* "glTextureParameterIuiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 56660 /* "glTextureParameterIuiv" */,
                                providers, entrypoints);
}

static PFNGLTEXTUREPARAMETERIUIVEXTPROC
epoxy_glTextureParameterIuivEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 56683 /* glTextureParameterIuivEXT */);
}

static PFNGLTEXTUREPARAMETERFPROC
epoxy_glTextureParameterf_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        56709 /* "glTextureParameterf" */,
        56709 /* "glTextureParameterf" */,
    };
    return gl_provider_resolver(entrypoint_strings + 56709 /* "glTextureParameterf" */,
                                providers, entrypoints);
}

static PFNGLTEXTUREPARAMETERFEXTPROC
epoxy_glTextureParameterfEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 56729 /* glTextureParameterfEXT */);
}

static PFNGLTEXTUREPARAMETERFVPROC
epoxy_glTextureParameterfv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        56752 /* "glTextureParameterfv" */,
        56752 /* "glTextureParameterfv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 56752 /* "glTextureParameterfv" */,
                                providers, entrypoints);
}

static PFNGLTEXTUREPARAMETERFVEXTPROC
epoxy_glTextureParameterfvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 56773 /* glTextureParameterfvEXT */);
}

static PFNGLTEXTUREPARAMETERIPROC
epoxy_glTextureParameteri_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        56797 /* "glTextureParameteri" */,
        56797 /* "glTextureParameteri" */,
    };
    return gl_provider_resolver(entrypoint_strings + 56797 /* "glTextureParameteri" */,
                                providers, entrypoints);
}

static PFNGLTEXTUREPARAMETERIEXTPROC
epoxy_glTextureParameteriEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 56817 /* glTextureParameteriEXT */);
}

static PFNGLTEXTUREPARAMETERIVPROC
epoxy_glTextureParameteriv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        56840 /* "glTextureParameteriv" */,
        56840 /* "glTextureParameteriv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 56840 /* "glTextureParameteriv" */,
                                providers, entrypoints);
}

static PFNGLTEXTUREPARAMETERIVEXTPROC
epoxy_glTextureParameterivEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 56861 /* glTextureParameterivEXT */);
}

static PFNGLTEXTURERANGEAPPLEPROC
epoxy_glTextureRangeAPPLE_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_APPLE_texture_range, 56885 /* glTextureRangeAPPLE */);
}

static PFNGLTEXTURERENDERBUFFEREXTPROC
epoxy_glTextureRenderbufferEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 56905 /* glTextureRenderbufferEXT */);
}

static PFNGLTEXTURESTORAGE1DPROC
epoxy_glTextureStorage1D_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        56930 /* "glTextureStorage1D" */,
        56930 /* "glTextureStorage1D" */,
    };
    return gl_provider_resolver(entrypoint_strings + 56930 /* "glTextureStorage1D" */,
                                providers, entrypoints);
}

static PFNGLTEXTURESTORAGE1DEXTPROC
epoxy_glTextureStorage1DEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_texture_storage,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        56949 /* "glTextureStorage1DEXT" */,
        56949 /* "glTextureStorage1DEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 56949 /* "glTextureStorage1DEXT" */,
                                providers, entrypoints);
}

static PFNGLTEXTURESTORAGE2DPROC
epoxy_glTextureStorage2D_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        56971 /* "glTextureStorage2D" */,
        56971 /* "glTextureStorage2D" */,
    };
    return gl_provider_resolver(entrypoint_strings + 56971 /* "glTextureStorage2D" */,
                                providers, entrypoints);
}

static PFNGLTEXTURESTORAGE2DEXTPROC
epoxy_glTextureStorage2DEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_texture_storage,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        56990 /* "glTextureStorage2DEXT" */,
        56990 /* "glTextureStorage2DEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 56990 /* "glTextureStorage2DEXT" */,
                                providers, entrypoints);
}

static PFNGLTEXTURESTORAGE2DMULTISAMPLEPROC
epoxy_glTextureStorage2DMultisample_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        57012 /* "glTextureStorage2DMultisample" */,
        57012 /* "glTextureStorage2DMultisample" */,
    };
    return gl_provider_resolver(entrypoint_strings + 57012 /* "glTextureStorage2DMultisample" */,
                                providers, entrypoints);
}

static PFNGLTEXTURESTORAGE2DMULTISAMPLEEXTPROC
epoxy_glTextureStorage2DMultisampleEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 57042 /* glTextureStorage2DMultisampleEXT */);
}

static PFNGLTEXTURESTORAGE3DPROC
epoxy_glTextureStorage3D_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        57075 /* "glTextureStorage3D" */,
        57075 /* "glTextureStorage3D" */,
    };
    return gl_provider_resolver(entrypoint_strings + 57075 /* "glTextureStorage3D" */,
                                providers, entrypoints);
}

static PFNGLTEXTURESTORAGE3DEXTPROC
epoxy_glTextureStorage3DEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_direct_state_access,
        PROVIDER_GL_EXT_texture_storage,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        57094 /* "glTextureStorage3DEXT" */,
        57094 /* "glTextureStorage3DEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 57094 /* "glTextureStorage3DEXT" */,
                                providers, entrypoints);
}

static PFNGLTEXTURESTORAGE3DMULTISAMPLEPROC
epoxy_glTextureStorage3DMultisample_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        57116 /* "glTextureStorage3DMultisample" */,
        57116 /* "glTextureStorage3DMultisample" */,
    };
    return gl_provider_resolver(entrypoint_strings + 57116 /* "glTextureStorage3DMultisample" */,
                                providers, entrypoints);
}

static PFNGLTEXTURESTORAGE3DMULTISAMPLEEXTPROC
epoxy_glTextureStorage3DMultisampleEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 57146 /* glTextureStorage3DMultisampleEXT */);
}

static PFNGLTEXTURESTORAGEMEM1DEXTPROC
epoxy_glTextureStorageMem1DEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_memory_object, 57179 /* glTextureStorageMem1DEXT */);
}

static PFNGLTEXTURESTORAGEMEM2DEXTPROC
epoxy_glTextureStorageMem2DEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_memory_object, 57204 /* glTextureStorageMem2DEXT */);
}

static PFNGLTEXTURESTORAGEMEM2DMULTISAMPLEEXTPROC
epoxy_glTextureStorageMem2DMultisampleEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_memory_object, 57229 /* glTextureStorageMem2DMultisampleEXT */);
}

static PFNGLTEXTURESTORAGEMEM3DEXTPROC
epoxy_glTextureStorageMem3DEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_memory_object, 57265 /* glTextureStorageMem3DEXT */);
}

static PFNGLTEXTURESTORAGEMEM3DMULTISAMPLEEXTPROC
epoxy_glTextureStorageMem3DMultisampleEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_memory_object, 57290 /* glTextureStorageMem3DMultisampleEXT */);
}

static PFNGLTEXTURESTORAGESPARSEAMDPROC
epoxy_glTextureStorageSparseAMD_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_AMD_sparse_texture, 57326 /* glTextureStorageSparseAMD */);
}

static PFNGLTEXTURESUBIMAGE1DPROC
epoxy_glTextureSubImage1D_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        57352 /* "glTextureSubImage1D" */,
        57352 /* "glTextureSubImage1D" */,
    };
    return gl_provider_resolver(entrypoint_strings + 57352 /* "glTextureSubImage1D" */,
                                providers, entrypoints);
}

static PFNGLTEXTURESUBIMAGE1DEXTPROC
epoxy_glTextureSubImage1DEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 57372 /* glTextureSubImage1DEXT */);
}

static PFNGLTEXTURESUBIMAGE2DPROC
epoxy_glTextureSubImage2D_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        57395 /* "glTextureSubImage2D" */,
        57395 /* "glTextureSubImage2D" */,
    };
    return gl_provider_resolver(entrypoint_strings + 57395 /* "glTextureSubImage2D" */,
                                providers, entrypoints);
}

static PFNGLTEXTURESUBIMAGE2DEXTPROC
epoxy_glTextureSubImage2DEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 57415 /* glTextureSubImage2DEXT */);
}

static PFNGLTEXTURESUBIMAGE3DPROC
epoxy_glTextureSubImage3D_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        57438 /* "glTextureSubImage3D" */,
        57438 /* "glTextureSubImage3D" */,
    };
    return gl_provider_resolver(entrypoint_strings + 57438 /* "glTextureSubImage3D" */,
                                providers, entrypoints);
}

static PFNGLTEXTURESUBIMAGE3DEXTPROC
epoxy_glTextureSubImage3DEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 57458 /* glTextureSubImage3DEXT */);
}

static PFNGLTEXTUREVIEWPROC
epoxy_glTextureView_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_ARB_texture_view,
        PROVIDER_GL_EXT_texture_view,
        PROVIDER_GL_OES_texture_view,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        57481 /* "glTextureView" */,
        57481 /* "glTextureView" */,
        57495 /* "glTextureViewEXT" */,
        57512 /* "glTextureViewOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 57481 /* "glTextureView" */,
                                providers, entrypoints);
}

static PFNGLTEXTUREVIEWEXTPROC
epoxy_glTextureViewEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_texture_view,
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_ARB_texture_view,
        PROVIDER_GL_OES_texture_view,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        57495 /* "glTextureViewEXT" */,
        57481 /* "glTextureView" */,
        57481 /* "glTextureView" */,
        57512 /* "glTextureViewOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 57495 /* "glTextureViewEXT" */,
                                providers, entrypoints);
}

static PFNGLTEXTUREVIEWOESPROC
epoxy_glTextureViewOES_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_OES_texture_view,
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_ARB_texture_view,
        PROVIDER_GL_EXT_texture_view,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        57512 /* "glTextureViewOES" */,
        57481 /* "glTextureView" */,
        57481 /* "glTextureView" */,
        57495 /* "glTextureViewEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 57512 /* "glTextureViewOES" */,
                                providers, entrypoints);
}

static PFNGLTRACKMATRIXNVPROC
epoxy_glTrackMatrixNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_program, 57529 /* glTrackMatrixNV */);
}

static PFNGLTRANSFORMFEEDBACKATTRIBSNVPROC
epoxy_glTransformFeedbackAttribsNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_transform_feedback, 57545 /* glTransformFeedbackAttribsNV */);
}

static PFNGLTRANSFORMFEEDBACKBUFFERBASEPROC
epoxy_glTransformFeedbackBufferBase_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        57574 /* "glTransformFeedbackBufferBase" */,
        57574 /* "glTransformFeedbackBufferBase" */,
    };
    return gl_provider_resolver(entrypoint_strings + 57574 /* "glTransformFeedbackBufferBase" */,
                                providers, entrypoints);
}

static PFNGLTRANSFORMFEEDBACKBUFFERRANGEPROC
epoxy_glTransformFeedbackBufferRange_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        57604 /* "glTransformFeedbackBufferRange" */,
        57604 /* "glTransformFeedbackBufferRange" */,
    };
    return gl_provider_resolver(entrypoint_strings + 57604 /* "glTransformFeedbackBufferRange" */,
                                providers, entrypoints);
}

static PFNGLTRANSFORMFEEDBACKSTREAMATTRIBSNVPROC
epoxy_glTransformFeedbackStreamAttribsNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_transform_feedback, 57635 /* glTransformFeedbackStreamAttribsNV */);
}

static PFNGLTRANSFORMFEEDBACKVARYINGSPROC
epoxy_glTransformFeedbackVaryings_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_EXT_transform_feedback,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        57670 /* "glTransformFeedbackVaryings" */,
        57670 /* "glTransformFeedbackVaryings" */,
        57698 /* "glTransformFeedbackVaryingsEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 57670 /* "glTransformFeedbackVaryings" */,
                                providers, entrypoints);
}

static PFNGLTRANSFORMFEEDBACKVARYINGSEXTPROC
epoxy_glTransformFeedbackVaryingsEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_transform_feedback,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        57698 /* "glTransformFeedbackVaryingsEXT" */,
        57670 /* "glTransformFeedbackVaryings" */,
        57670 /* "glTransformFeedbackVaryings" */,
    };
    return gl_provider_resolver(entrypoint_strings + 57698 /* "glTransformFeedbackVaryingsEXT" */,
                                providers, entrypoints);
}

static PFNGLTRANSFORMFEEDBACKVARYINGSNVPROC
epoxy_glTransformFeedbackVaryingsNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_transform_feedback, 57729 /* glTransformFeedbackVaryingsNV */);
}

static PFNGLTRANSFORMPATHNVPROC
epoxy_glTransformPathNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 57759 /* glTransformPathNV */);
}

static PFNGLTRANSLATEDPROC
epoxy_glTranslated_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 57777 /* glTranslated */);
}

static PFNGLTRANSLATEFPROC
epoxy_glTranslatef_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        57790 /* "glTranslatef" */,
        57790 /* "glTranslatef" */,
    };
    return gl_provider_resolver(entrypoint_strings + 57790 /* "glTranslatef" */,
                                providers, entrypoints);
}

static PFNGLTRANSLATEXPROC
epoxy_glTranslatex_resolver(void)
{
    return gl_single_resolver(PROVIDER_OpenGL_ES_1_0, 57803 /* glTranslatex */);
}

static PFNGLTRANSLATEXOESPROC
epoxy_glTranslatexOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 57816 /* glTranslatexOES */);
}

static PFNGLUNIFORM1DPROC
epoxy_glUniform1d_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_GL_ARB_gpu_shader_fp64,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        57832 /* "glUniform1d" */,
        57832 /* "glUniform1d" */,
    };
    return gl_provider_resolver(entrypoint_strings + 57832 /* "glUniform1d" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM1DVPROC
epoxy_glUniform1dv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_GL_ARB_gpu_shader_fp64,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        57844 /* "glUniform1dv" */,
        57844 /* "glUniform1dv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 57844 /* "glUniform1dv" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM1FPROC
epoxy_glUniform1f_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        57857 /* "glUniform1f" */,
        57857 /* "glUniform1f" */,
        57869 /* "glUniform1fARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 57857 /* "glUniform1f" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM1FARBPROC
epoxy_glUniform1fARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_shader_objects,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        57869 /* "glUniform1fARB" */,
        57857 /* "glUniform1f" */,
        57857 /* "glUniform1f" */,
    };
    return gl_provider_resolver(entrypoint_strings + 57869 /* "glUniform1fARB" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM1FVPROC
epoxy_glUniform1fv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        57884 /* "glUniform1fv" */,
        57884 /* "glUniform1fv" */,
        57897 /* "glUniform1fvARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 57884 /* "glUniform1fv" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM1FVARBPROC
epoxy_glUniform1fvARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_shader_objects,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        57897 /* "glUniform1fvARB" */,
        57884 /* "glUniform1fv" */,
        57884 /* "glUniform1fv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 57897 /* "glUniform1fvARB" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM1IPROC
epoxy_glUniform1i_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        57913 /* "glUniform1i" */,
        57913 /* "glUniform1i" */,
        57993 /* "glUniform1iARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 57913 /* "glUniform1i" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM1I64ARBPROC
epoxy_glUniform1i64ARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_gpu_shader_int64, 57925 /* glUniform1i64ARB */);
}

static PFNGLUNIFORM1I64NVPROC
epoxy_glUniform1i64NV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_AMD_gpu_shader_int64,
        PROVIDER_GL_NV_gpu_shader5,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        57942 /* "glUniform1i64NV" */,
        57942 /* "glUniform1i64NV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 57942 /* "glUniform1i64NV" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM1I64VARBPROC
epoxy_glUniform1i64vARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_gpu_shader_int64, 57958 /* glUniform1i64vARB */);
}

static PFNGLUNIFORM1I64VNVPROC
epoxy_glUniform1i64vNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_AMD_gpu_shader_int64,
        PROVIDER_GL_NV_gpu_shader5,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        57976 /* "glUniform1i64vNV" */,
        57976 /* "glUniform1i64vNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 57976 /* "glUniform1i64vNV" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM1IARBPROC
epoxy_glUniform1iARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_shader_objects,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        57993 /* "glUniform1iARB" */,
        57913 /* "glUniform1i" */,
        57913 /* "glUniform1i" */,
    };
    return gl_provider_resolver(entrypoint_strings + 57993 /* "glUniform1iARB" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM1IVPROC
epoxy_glUniform1iv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58008 /* "glUniform1iv" */,
        58008 /* "glUniform1iv" */,
        58021 /* "glUniform1ivARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58008 /* "glUniform1iv" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM1IVARBPROC
epoxy_glUniform1ivARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_shader_objects,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58021 /* "glUniform1ivARB" */,
        58008 /* "glUniform1iv" */,
        58008 /* "glUniform1iv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58021 /* "glUniform1ivARB" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM1UIPROC
epoxy_glUniform1ui_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_EXT_gpu_shader4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58037 /* "glUniform1ui" */,
        58037 /* "glUniform1ui" */,
        58122 /* "glUniform1uiEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58037 /* "glUniform1ui" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM1UI64ARBPROC
epoxy_glUniform1ui64ARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_gpu_shader_int64, 58050 /* glUniform1ui64ARB */);
}

static PFNGLUNIFORM1UI64NVPROC
epoxy_glUniform1ui64NV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_AMD_gpu_shader_int64,
        PROVIDER_GL_NV_gpu_shader5,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58068 /* "glUniform1ui64NV" */,
        58068 /* "glUniform1ui64NV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58068 /* "glUniform1ui64NV" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM1UI64VARBPROC
epoxy_glUniform1ui64vARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_gpu_shader_int64, 58085 /* glUniform1ui64vARB */);
}

static PFNGLUNIFORM1UI64VNVPROC
epoxy_glUniform1ui64vNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_AMD_gpu_shader_int64,
        PROVIDER_GL_NV_gpu_shader5,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58104 /* "glUniform1ui64vNV" */,
        58104 /* "glUniform1ui64vNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58104 /* "glUniform1ui64vNV" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM1UIEXTPROC
epoxy_glUniform1uiEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_gpu_shader4,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58122 /* "glUniform1uiEXT" */,
        58037 /* "glUniform1ui" */,
        58037 /* "glUniform1ui" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58122 /* "glUniform1uiEXT" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM1UIVPROC
epoxy_glUniform1uiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_EXT_gpu_shader4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58138 /* "glUniform1uiv" */,
        58138 /* "glUniform1uiv" */,
        58152 /* "glUniform1uivEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58138 /* "glUniform1uiv" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM1UIVEXTPROC
epoxy_glUniform1uivEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_gpu_shader4,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58152 /* "glUniform1uivEXT" */,
        58138 /* "glUniform1uiv" */,
        58138 /* "glUniform1uiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58152 /* "glUniform1uivEXT" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM2DPROC
epoxy_glUniform2d_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_GL_ARB_gpu_shader_fp64,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58169 /* "glUniform2d" */,
        58169 /* "glUniform2d" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58169 /* "glUniform2d" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM2DVPROC
epoxy_glUniform2dv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_GL_ARB_gpu_shader_fp64,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58181 /* "glUniform2dv" */,
        58181 /* "glUniform2dv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58181 /* "glUniform2dv" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM2FPROC
epoxy_glUniform2f_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58194 /* "glUniform2f" */,
        58194 /* "glUniform2f" */,
        58206 /* "glUniform2fARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58194 /* "glUniform2f" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM2FARBPROC
epoxy_glUniform2fARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_shader_objects,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58206 /* "glUniform2fARB" */,
        58194 /* "glUniform2f" */,
        58194 /* "glUniform2f" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58206 /* "glUniform2fARB" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM2FVPROC
epoxy_glUniform2fv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58221 /* "glUniform2fv" */,
        58221 /* "glUniform2fv" */,
        58234 /* "glUniform2fvARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58221 /* "glUniform2fv" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM2FVARBPROC
epoxy_glUniform2fvARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_shader_objects,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58234 /* "glUniform2fvARB" */,
        58221 /* "glUniform2fv" */,
        58221 /* "glUniform2fv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58234 /* "glUniform2fvARB" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM2IPROC
epoxy_glUniform2i_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58250 /* "glUniform2i" */,
        58250 /* "glUniform2i" */,
        58330 /* "glUniform2iARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58250 /* "glUniform2i" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM2I64ARBPROC
epoxy_glUniform2i64ARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_gpu_shader_int64, 58262 /* glUniform2i64ARB */);
}

static PFNGLUNIFORM2I64NVPROC
epoxy_glUniform2i64NV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_AMD_gpu_shader_int64,
        PROVIDER_GL_NV_gpu_shader5,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58279 /* "glUniform2i64NV" */,
        58279 /* "glUniform2i64NV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58279 /* "glUniform2i64NV" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM2I64VARBPROC
epoxy_glUniform2i64vARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_gpu_shader_int64, 58295 /* glUniform2i64vARB */);
}

static PFNGLUNIFORM2I64VNVPROC
epoxy_glUniform2i64vNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_AMD_gpu_shader_int64,
        PROVIDER_GL_NV_gpu_shader5,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58313 /* "glUniform2i64vNV" */,
        58313 /* "glUniform2i64vNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58313 /* "glUniform2i64vNV" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM2IARBPROC
epoxy_glUniform2iARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_shader_objects,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58330 /* "glUniform2iARB" */,
        58250 /* "glUniform2i" */,
        58250 /* "glUniform2i" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58330 /* "glUniform2iARB" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM2IVPROC
epoxy_glUniform2iv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58345 /* "glUniform2iv" */,
        58345 /* "glUniform2iv" */,
        58358 /* "glUniform2ivARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58345 /* "glUniform2iv" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM2IVARBPROC
epoxy_glUniform2ivARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_shader_objects,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58358 /* "glUniform2ivARB" */,
        58345 /* "glUniform2iv" */,
        58345 /* "glUniform2iv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58358 /* "glUniform2ivARB" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM2UIPROC
epoxy_glUniform2ui_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_EXT_gpu_shader4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58374 /* "glUniform2ui" */,
        58374 /* "glUniform2ui" */,
        58459 /* "glUniform2uiEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58374 /* "glUniform2ui" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM2UI64ARBPROC
epoxy_glUniform2ui64ARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_gpu_shader_int64, 58387 /* glUniform2ui64ARB */);
}

static PFNGLUNIFORM2UI64NVPROC
epoxy_glUniform2ui64NV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_AMD_gpu_shader_int64,
        PROVIDER_GL_NV_gpu_shader5,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58405 /* "glUniform2ui64NV" */,
        58405 /* "glUniform2ui64NV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58405 /* "glUniform2ui64NV" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM2UI64VARBPROC
epoxy_glUniform2ui64vARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_gpu_shader_int64, 58422 /* glUniform2ui64vARB */);
}

static PFNGLUNIFORM2UI64VNVPROC
epoxy_glUniform2ui64vNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_AMD_gpu_shader_int64,
        PROVIDER_GL_NV_gpu_shader5,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58441 /* "glUniform2ui64vNV" */,
        58441 /* "glUniform2ui64vNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58441 /* "glUniform2ui64vNV" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM2UIEXTPROC
epoxy_glUniform2uiEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_gpu_shader4,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58459 /* "glUniform2uiEXT" */,
        58374 /* "glUniform2ui" */,
        58374 /* "glUniform2ui" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58459 /* "glUniform2uiEXT" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM2UIVPROC
epoxy_glUniform2uiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_EXT_gpu_shader4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58475 /* "glUniform2uiv" */,
        58475 /* "glUniform2uiv" */,
        58489 /* "glUniform2uivEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58475 /* "glUniform2uiv" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM2UIVEXTPROC
epoxy_glUniform2uivEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_gpu_shader4,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58489 /* "glUniform2uivEXT" */,
        58475 /* "glUniform2uiv" */,
        58475 /* "glUniform2uiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58489 /* "glUniform2uivEXT" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM3DPROC
epoxy_glUniform3d_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_GL_ARB_gpu_shader_fp64,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58506 /* "glUniform3d" */,
        58506 /* "glUniform3d" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58506 /* "glUniform3d" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM3DVPROC
epoxy_glUniform3dv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_GL_ARB_gpu_shader_fp64,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58518 /* "glUniform3dv" */,
        58518 /* "glUniform3dv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58518 /* "glUniform3dv" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM3FPROC
epoxy_glUniform3f_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58531 /* "glUniform3f" */,
        58531 /* "glUniform3f" */,
        58543 /* "glUniform3fARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58531 /* "glUniform3f" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM3FARBPROC
epoxy_glUniform3fARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_shader_objects,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58543 /* "glUniform3fARB" */,
        58531 /* "glUniform3f" */,
        58531 /* "glUniform3f" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58543 /* "glUniform3fARB" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM3FVPROC
epoxy_glUniform3fv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58558 /* "glUniform3fv" */,
        58558 /* "glUniform3fv" */,
        58571 /* "glUniform3fvARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58558 /* "glUniform3fv" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM3FVARBPROC
epoxy_glUniform3fvARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_shader_objects,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58571 /* "glUniform3fvARB" */,
        58558 /* "glUniform3fv" */,
        58558 /* "glUniform3fv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58571 /* "glUniform3fvARB" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM3IPROC
epoxy_glUniform3i_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58587 /* "glUniform3i" */,
        58587 /* "glUniform3i" */,
        58667 /* "glUniform3iARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58587 /* "glUniform3i" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM3I64ARBPROC
epoxy_glUniform3i64ARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_gpu_shader_int64, 58599 /* glUniform3i64ARB */);
}

static PFNGLUNIFORM3I64NVPROC
epoxy_glUniform3i64NV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_AMD_gpu_shader_int64,
        PROVIDER_GL_NV_gpu_shader5,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58616 /* "glUniform3i64NV" */,
        58616 /* "glUniform3i64NV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58616 /* "glUniform3i64NV" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM3I64VARBPROC
epoxy_glUniform3i64vARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_gpu_shader_int64, 58632 /* glUniform3i64vARB */);
}

static PFNGLUNIFORM3I64VNVPROC
epoxy_glUniform3i64vNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_AMD_gpu_shader_int64,
        PROVIDER_GL_NV_gpu_shader5,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58650 /* "glUniform3i64vNV" */,
        58650 /* "glUniform3i64vNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58650 /* "glUniform3i64vNV" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM3IARBPROC
epoxy_glUniform3iARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_shader_objects,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58667 /* "glUniform3iARB" */,
        58587 /* "glUniform3i" */,
        58587 /* "glUniform3i" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58667 /* "glUniform3iARB" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM3IVPROC
epoxy_glUniform3iv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58682 /* "glUniform3iv" */,
        58682 /* "glUniform3iv" */,
        58695 /* "glUniform3ivARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58682 /* "glUniform3iv" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM3IVARBPROC
epoxy_glUniform3ivARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_shader_objects,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58695 /* "glUniform3ivARB" */,
        58682 /* "glUniform3iv" */,
        58682 /* "glUniform3iv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58695 /* "glUniform3ivARB" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM3UIPROC
epoxy_glUniform3ui_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_EXT_gpu_shader4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58711 /* "glUniform3ui" */,
        58711 /* "glUniform3ui" */,
        58796 /* "glUniform3uiEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58711 /* "glUniform3ui" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM3UI64ARBPROC
epoxy_glUniform3ui64ARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_gpu_shader_int64, 58724 /* glUniform3ui64ARB */);
}

static PFNGLUNIFORM3UI64NVPROC
epoxy_glUniform3ui64NV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_AMD_gpu_shader_int64,
        PROVIDER_GL_NV_gpu_shader5,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58742 /* "glUniform3ui64NV" */,
        58742 /* "glUniform3ui64NV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58742 /* "glUniform3ui64NV" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM3UI64VARBPROC
epoxy_glUniform3ui64vARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_gpu_shader_int64, 58759 /* glUniform3ui64vARB */);
}

static PFNGLUNIFORM3UI64VNVPROC
epoxy_glUniform3ui64vNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_AMD_gpu_shader_int64,
        PROVIDER_GL_NV_gpu_shader5,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58778 /* "glUniform3ui64vNV" */,
        58778 /* "glUniform3ui64vNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58778 /* "glUniform3ui64vNV" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM3UIEXTPROC
epoxy_glUniform3uiEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_gpu_shader4,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58796 /* "glUniform3uiEXT" */,
        58711 /* "glUniform3ui" */,
        58711 /* "glUniform3ui" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58796 /* "glUniform3uiEXT" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM3UIVPROC
epoxy_glUniform3uiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_EXT_gpu_shader4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58812 /* "glUniform3uiv" */,
        58812 /* "glUniform3uiv" */,
        58826 /* "glUniform3uivEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58812 /* "glUniform3uiv" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM3UIVEXTPROC
epoxy_glUniform3uivEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_gpu_shader4,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58826 /* "glUniform3uivEXT" */,
        58812 /* "glUniform3uiv" */,
        58812 /* "glUniform3uiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58826 /* "glUniform3uivEXT" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM4DPROC
epoxy_glUniform4d_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_GL_ARB_gpu_shader_fp64,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58843 /* "glUniform4d" */,
        58843 /* "glUniform4d" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58843 /* "glUniform4d" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM4DVPROC
epoxy_glUniform4dv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_GL_ARB_gpu_shader_fp64,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58855 /* "glUniform4dv" */,
        58855 /* "glUniform4dv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58855 /* "glUniform4dv" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM4FPROC
epoxy_glUniform4f_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58868 /* "glUniform4f" */,
        58868 /* "glUniform4f" */,
        58880 /* "glUniform4fARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58868 /* "glUniform4f" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM4FARBPROC
epoxy_glUniform4fARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_shader_objects,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58880 /* "glUniform4fARB" */,
        58868 /* "glUniform4f" */,
        58868 /* "glUniform4f" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58880 /* "glUniform4fARB" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM4FVPROC
epoxy_glUniform4fv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58895 /* "glUniform4fv" */,
        58895 /* "glUniform4fv" */,
        58908 /* "glUniform4fvARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58895 /* "glUniform4fv" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM4FVARBPROC
epoxy_glUniform4fvARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_shader_objects,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58908 /* "glUniform4fvARB" */,
        58895 /* "glUniform4fv" */,
        58895 /* "glUniform4fv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58908 /* "glUniform4fvARB" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM4IPROC
epoxy_glUniform4i_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58924 /* "glUniform4i" */,
        58924 /* "glUniform4i" */,
        59004 /* "glUniform4iARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58924 /* "glUniform4i" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM4I64ARBPROC
epoxy_glUniform4i64ARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_gpu_shader_int64, 58936 /* glUniform4i64ARB */);
}

static PFNGLUNIFORM4I64NVPROC
epoxy_glUniform4i64NV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_AMD_gpu_shader_int64,
        PROVIDER_GL_NV_gpu_shader5,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58953 /* "glUniform4i64NV" */,
        58953 /* "glUniform4i64NV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58953 /* "glUniform4i64NV" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM4I64VARBPROC
epoxy_glUniform4i64vARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_gpu_shader_int64, 58969 /* glUniform4i64vARB */);
}

static PFNGLUNIFORM4I64VNVPROC
epoxy_glUniform4i64vNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_AMD_gpu_shader_int64,
        PROVIDER_GL_NV_gpu_shader5,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        58987 /* "glUniform4i64vNV" */,
        58987 /* "glUniform4i64vNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 58987 /* "glUniform4i64vNV" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM4IARBPROC
epoxy_glUniform4iARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_shader_objects,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        59004 /* "glUniform4iARB" */,
        58924 /* "glUniform4i" */,
        58924 /* "glUniform4i" */,
    };
    return gl_provider_resolver(entrypoint_strings + 59004 /* "glUniform4iARB" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM4IVPROC
epoxy_glUniform4iv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        59019 /* "glUniform4iv" */,
        59019 /* "glUniform4iv" */,
        59032 /* "glUniform4ivARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 59019 /* "glUniform4iv" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM4IVARBPROC
epoxy_glUniform4ivARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_shader_objects,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        59032 /* "glUniform4ivARB" */,
        59019 /* "glUniform4iv" */,
        59019 /* "glUniform4iv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 59032 /* "glUniform4ivARB" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM4UIPROC
epoxy_glUniform4ui_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_EXT_gpu_shader4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        59048 /* "glUniform4ui" */,
        59048 /* "glUniform4ui" */,
        59133 /* "glUniform4uiEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 59048 /* "glUniform4ui" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM4UI64ARBPROC
epoxy_glUniform4ui64ARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_gpu_shader_int64, 59061 /* glUniform4ui64ARB */);
}

static PFNGLUNIFORM4UI64NVPROC
epoxy_glUniform4ui64NV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_AMD_gpu_shader_int64,
        PROVIDER_GL_NV_gpu_shader5,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        59079 /* "glUniform4ui64NV" */,
        59079 /* "glUniform4ui64NV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 59079 /* "glUniform4ui64NV" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM4UI64VARBPROC
epoxy_glUniform4ui64vARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_gpu_shader_int64, 59096 /* glUniform4ui64vARB */);
}

static PFNGLUNIFORM4UI64VNVPROC
epoxy_glUniform4ui64vNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_AMD_gpu_shader_int64,
        PROVIDER_GL_NV_gpu_shader5,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        59115 /* "glUniform4ui64vNV" */,
        59115 /* "glUniform4ui64vNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 59115 /* "glUniform4ui64vNV" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM4UIEXTPROC
epoxy_glUniform4uiEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_gpu_shader4,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        59133 /* "glUniform4uiEXT" */,
        59048 /* "glUniform4ui" */,
        59048 /* "glUniform4ui" */,
    };
    return gl_provider_resolver(entrypoint_strings + 59133 /* "glUniform4uiEXT" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM4UIVPROC
epoxy_glUniform4uiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_EXT_gpu_shader4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        59149 /* "glUniform4uiv" */,
        59149 /* "glUniform4uiv" */,
        59163 /* "glUniform4uivEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 59149 /* "glUniform4uiv" */,
                                providers, entrypoints);
}

static PFNGLUNIFORM4UIVEXTPROC
epoxy_glUniform4uivEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_gpu_shader4,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        59163 /* "glUniform4uivEXT" */,
        59149 /* "glUniform4uiv" */,
        59149 /* "glUniform4uiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 59163 /* "glUniform4uivEXT" */,
                                providers, entrypoints);
}

static PFNGLUNIFORMBLOCKBINDINGPROC
epoxy_glUniformBlockBinding_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_1,
        PROVIDER_GL_ARB_uniform_buffer_object,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        59180 /* "glUniformBlockBinding" */,
        59180 /* "glUniformBlockBinding" */,
        59180 /* "glUniformBlockBinding" */,
    };
    return gl_provider_resolver(entrypoint_strings + 59180 /* "glUniformBlockBinding" */,
                                providers, entrypoints);
}

static PFNGLUNIFORMBUFFEREXTPROC
epoxy_glUniformBufferEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_bindable_uniform, 59202 /* glUniformBufferEXT */);
}

static PFNGLUNIFORMHANDLEUI64ARBPROC
epoxy_glUniformHandleui64ARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_bindless_texture,
        PROVIDER_GL_IMG_bindless_texture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        59221 /* "glUniformHandleui64ARB" */,
        59244 /* "glUniformHandleui64IMG" */,
    };
    return gl_provider_resolver(entrypoint_strings + 59221 /* "glUniformHandleui64ARB" */,
                                providers, entrypoints);
}

static PFNGLUNIFORMHANDLEUI64IMGPROC
epoxy_glUniformHandleui64IMG_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_IMG_bindless_texture,
        PROVIDER_GL_ARB_bindless_texture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        59244 /* "glUniformHandleui64IMG" */,
        59221 /* "glUniformHandleui64ARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 59244 /* "glUniformHandleui64IMG" */,
                                providers, entrypoints);
}

static PFNGLUNIFORMHANDLEUI64NVPROC
epoxy_glUniformHandleui64NV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_bindless_texture, 59267 /* glUniformHandleui64NV */);
}

static PFNGLUNIFORMHANDLEUI64VARBPROC
epoxy_glUniformHandleui64vARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_bindless_texture,
        PROVIDER_GL_IMG_bindless_texture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        59289 /* "glUniformHandleui64vARB" */,
        59313 /* "glUniformHandleui64vIMG" */,
    };
    return gl_provider_resolver(entrypoint_strings + 59289 /* "glUniformHandleui64vARB" */,
                                providers, entrypoints);
}

static PFNGLUNIFORMHANDLEUI64VIMGPROC
epoxy_glUniformHandleui64vIMG_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_IMG_bindless_texture,
        PROVIDER_GL_ARB_bindless_texture,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        59313 /* "glUniformHandleui64vIMG" */,
        59289 /* "glUniformHandleui64vARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 59313 /* "glUniformHandleui64vIMG" */,
                                providers, entrypoints);
}

static PFNGLUNIFORMHANDLEUI64VNVPROC
epoxy_glUniformHandleui64vNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_bindless_texture, 59337 /* glUniformHandleui64vNV */);
}

static PFNGLUNIFORMMATRIX2DVPROC
epoxy_glUniformMatrix2dv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_GL_ARB_gpu_shader_fp64,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        59360 /* "glUniformMatrix2dv" */,
        59360 /* "glUniformMatrix2dv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 59360 /* "glUniformMatrix2dv" */,
                                providers, entrypoints);
}

static PFNGLUNIFORMMATRIX2FVPROC
epoxy_glUniformMatrix2fv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        59379 /* "glUniformMatrix2fv" */,
        59379 /* "glUniformMatrix2fv" */,
        59398 /* "glUniformMatrix2fvARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 59379 /* "glUniformMatrix2fv" */,
                                providers, entrypoints);
}

static PFNGLUNIFORMMATRIX2FVARBPROC
epoxy_glUniformMatrix2fvARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_shader_objects,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        59398 /* "glUniformMatrix2fvARB" */,
        59379 /* "glUniformMatrix2fv" */,
        59379 /* "glUniformMatrix2fv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 59398 /* "glUniformMatrix2fvARB" */,
                                providers, entrypoints);
}

static PFNGLUNIFORMMATRIX2X3DVPROC
epoxy_glUniformMatrix2x3dv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_GL_ARB_gpu_shader_fp64,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        59420 /* "glUniformMatrix2x3dv" */,
        59420 /* "glUniformMatrix2x3dv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 59420 /* "glUniformMatrix2x3dv" */,
                                providers, entrypoints);
}

static PFNGLUNIFORMMATRIX2X3FVPROC
epoxy_glUniformMatrix2x3fv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_1,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_NV_non_square_matrices,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        59441 /* "glUniformMatrix2x3fv" */,
        59441 /* "glUniformMatrix2x3fv" */,
        59462 /* "glUniformMatrix2x3fvNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 59441 /* "glUniformMatrix2x3fv" */,
                                providers, entrypoints);
}

static PFNGLUNIFORMMATRIX2X3FVNVPROC
epoxy_glUniformMatrix2x3fvNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_non_square_matrices,
        PROVIDER_Desktop_OpenGL_2_1,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        59462 /* "glUniformMatrix2x3fvNV" */,
        59441 /* "glUniformMatrix2x3fv" */,
        59441 /* "glUniformMatrix2x3fv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 59462 /* "glUniformMatrix2x3fvNV" */,
                                providers, entrypoints);
}

static PFNGLUNIFORMMATRIX2X4DVPROC
epoxy_glUniformMatrix2x4dv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_GL_ARB_gpu_shader_fp64,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        59485 /* "glUniformMatrix2x4dv" */,
        59485 /* "glUniformMatrix2x4dv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 59485 /* "glUniformMatrix2x4dv" */,
                                providers, entrypoints);
}

static PFNGLUNIFORMMATRIX2X4FVPROC
epoxy_glUniformMatrix2x4fv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_1,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_NV_non_square_matrices,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        59506 /* "glUniformMatrix2x4fv" */,
        59506 /* "glUniformMatrix2x4fv" */,
        59527 /* "glUniformMatrix2x4fvNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 59506 /* "glUniformMatrix2x4fv" */,
                                providers, entrypoints);
}

static PFNGLUNIFORMMATRIX2X4FVNVPROC
epoxy_glUniformMatrix2x4fvNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_non_square_matrices,
        PROVIDER_Desktop_OpenGL_2_1,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        59527 /* "glUniformMatrix2x4fvNV" */,
        59506 /* "glUniformMatrix2x4fv" */,
        59506 /* "glUniformMatrix2x4fv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 59527 /* "glUniformMatrix2x4fvNV" */,
                                providers, entrypoints);
}

static PFNGLUNIFORMMATRIX3DVPROC
epoxy_glUniformMatrix3dv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_GL_ARB_gpu_shader_fp64,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        59550 /* "glUniformMatrix3dv" */,
        59550 /* "glUniformMatrix3dv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 59550 /* "glUniformMatrix3dv" */,
                                providers, entrypoints);
}

static PFNGLUNIFORMMATRIX3FVPROC
epoxy_glUniformMatrix3fv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        59569 /* "glUniformMatrix3fv" */,
        59569 /* "glUniformMatrix3fv" */,
        59588 /* "glUniformMatrix3fvARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 59569 /* "glUniformMatrix3fv" */,
                                providers, entrypoints);
}

static PFNGLUNIFORMMATRIX3FVARBPROC
epoxy_glUniformMatrix3fvARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_shader_objects,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        59588 /* "glUniformMatrix3fvARB" */,
        59569 /* "glUniformMatrix3fv" */,
        59569 /* "glUniformMatrix3fv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 59588 /* "glUniformMatrix3fvARB" */,
                                providers, entrypoints);
}

static PFNGLUNIFORMMATRIX3X2DVPROC
epoxy_glUniformMatrix3x2dv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_GL_ARB_gpu_shader_fp64,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        59610 /* "glUniformMatrix3x2dv" */,
        59610 /* "glUniformMatrix3x2dv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 59610 /* "glUniformMatrix3x2dv" */,
                                providers, entrypoints);
}

static PFNGLUNIFORMMATRIX3X2FVPROC
epoxy_glUniformMatrix3x2fv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_1,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_NV_non_square_matrices,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        59631 /* "glUniformMatrix3x2fv" */,
        59631 /* "glUniformMatrix3x2fv" */,
        59652 /* "glUniformMatrix3x2fvNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 59631 /* "glUniformMatrix3x2fv" */,
                                providers, entrypoints);
}

static PFNGLUNIFORMMATRIX3X2FVNVPROC
epoxy_glUniformMatrix3x2fvNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_non_square_matrices,
        PROVIDER_Desktop_OpenGL_2_1,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        59652 /* "glUniformMatrix3x2fvNV" */,
        59631 /* "glUniformMatrix3x2fv" */,
        59631 /* "glUniformMatrix3x2fv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 59652 /* "glUniformMatrix3x2fvNV" */,
                                providers, entrypoints);
}

static PFNGLUNIFORMMATRIX3X4DVPROC
epoxy_glUniformMatrix3x4dv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_GL_ARB_gpu_shader_fp64,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        59675 /* "glUniformMatrix3x4dv" */,
        59675 /* "glUniformMatrix3x4dv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 59675 /* "glUniformMatrix3x4dv" */,
                                providers, entrypoints);
}

static PFNGLUNIFORMMATRIX3X4FVPROC
epoxy_glUniformMatrix3x4fv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_1,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_NV_non_square_matrices,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        59696 /* "glUniformMatrix3x4fv" */,
        59696 /* "glUniformMatrix3x4fv" */,
        59717 /* "glUniformMatrix3x4fvNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 59696 /* "glUniformMatrix3x4fv" */,
                                providers, entrypoints);
}

static PFNGLUNIFORMMATRIX3X4FVNVPROC
epoxy_glUniformMatrix3x4fvNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_non_square_matrices,
        PROVIDER_Desktop_OpenGL_2_1,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        59717 /* "glUniformMatrix3x4fvNV" */,
        59696 /* "glUniformMatrix3x4fv" */,
        59696 /* "glUniformMatrix3x4fv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 59717 /* "glUniformMatrix3x4fvNV" */,
                                providers, entrypoints);
}

static PFNGLUNIFORMMATRIX4DVPROC
epoxy_glUniformMatrix4dv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_GL_ARB_gpu_shader_fp64,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        59740 /* "glUniformMatrix4dv" */,
        59740 /* "glUniformMatrix4dv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 59740 /* "glUniformMatrix4dv" */,
                                providers, entrypoints);
}

static PFNGLUNIFORMMATRIX4FVPROC
epoxy_glUniformMatrix4fv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        59759 /* "glUniformMatrix4fv" */,
        59759 /* "glUniformMatrix4fv" */,
        59778 /* "glUniformMatrix4fvARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 59759 /* "glUniformMatrix4fv" */,
                                providers, entrypoints);
}

static PFNGLUNIFORMMATRIX4FVARBPROC
epoxy_glUniformMatrix4fvARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_shader_objects,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        59778 /* "glUniformMatrix4fvARB" */,
        59759 /* "glUniformMatrix4fv" */,
        59759 /* "glUniformMatrix4fv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 59778 /* "glUniformMatrix4fvARB" */,
                                providers, entrypoints);
}

static PFNGLUNIFORMMATRIX4X2DVPROC
epoxy_glUniformMatrix4x2dv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_GL_ARB_gpu_shader_fp64,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        59800 /* "glUniformMatrix4x2dv" */,
        59800 /* "glUniformMatrix4x2dv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 59800 /* "glUniformMatrix4x2dv" */,
                                providers, entrypoints);
}

static PFNGLUNIFORMMATRIX4X2FVPROC
epoxy_glUniformMatrix4x2fv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_1,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_NV_non_square_matrices,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        59821 /* "glUniformMatrix4x2fv" */,
        59821 /* "glUniformMatrix4x2fv" */,
        59842 /* "glUniformMatrix4x2fvNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 59821 /* "glUniformMatrix4x2fv" */,
                                providers, entrypoints);
}

static PFNGLUNIFORMMATRIX4X2FVNVPROC
epoxy_glUniformMatrix4x2fvNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_non_square_matrices,
        PROVIDER_Desktop_OpenGL_2_1,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        59842 /* "glUniformMatrix4x2fvNV" */,
        59821 /* "glUniformMatrix4x2fv" */,
        59821 /* "glUniformMatrix4x2fv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 59842 /* "glUniformMatrix4x2fvNV" */,
                                providers, entrypoints);
}

static PFNGLUNIFORMMATRIX4X3DVPROC
epoxy_glUniformMatrix4x3dv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_GL_ARB_gpu_shader_fp64,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        59865 /* "glUniformMatrix4x3dv" */,
        59865 /* "glUniformMatrix4x3dv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 59865 /* "glUniformMatrix4x3dv" */,
                                providers, entrypoints);
}

static PFNGLUNIFORMMATRIX4X3FVPROC
epoxy_glUniformMatrix4x3fv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_1,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_NV_non_square_matrices,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        59886 /* "glUniformMatrix4x3fv" */,
        59886 /* "glUniformMatrix4x3fv" */,
        59907 /* "glUniformMatrix4x3fvNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 59886 /* "glUniformMatrix4x3fv" */,
                                providers, entrypoints);
}

static PFNGLUNIFORMMATRIX4X3FVNVPROC
epoxy_glUniformMatrix4x3fvNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_non_square_matrices,
        PROVIDER_Desktop_OpenGL_2_1,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        59907 /* "glUniformMatrix4x3fvNV" */,
        59886 /* "glUniformMatrix4x3fv" */,
        59886 /* "glUniformMatrix4x3fv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 59907 /* "glUniformMatrix4x3fvNV" */,
                                providers, entrypoints);
}

static PFNGLUNIFORMSUBROUTINESUIVPROC
epoxy_glUniformSubroutinesuiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_0,
        PROVIDER_GL_ARB_shader_subroutine,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        59930 /* "glUniformSubroutinesuiv" */,
        59930 /* "glUniformSubroutinesuiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 59930 /* "glUniformSubroutinesuiv" */,
                                providers, entrypoints);
}

static PFNGLUNIFORMUI64NVPROC
epoxy_glUniformui64NV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_shader_buffer_load, 59954 /* glUniformui64NV */);
}

static PFNGLUNIFORMUI64VNVPROC
epoxy_glUniformui64vNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_shader_buffer_load, 59970 /* glUniformui64vNV */);
}

static PFNGLUNLOCKARRAYSEXTPROC
epoxy_glUnlockArraysEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_compiled_vertex_array, 59987 /* glUnlockArraysEXT */);
}

static PFNGLUNMAPBUFFERPROC
epoxy_glUnmapBuffer_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_5,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_ARB_vertex_buffer_object,
        PROVIDER_GL_OES_mapbuffer,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        60005 /* "glUnmapBuffer" */,
        60005 /* "glUnmapBuffer" */,
        60019 /* "glUnmapBufferARB" */,
        60036 /* "glUnmapBufferOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 60005 /* "glUnmapBuffer" */,
                                providers, entrypoints);
}

static PFNGLUNMAPBUFFERARBPROC
epoxy_glUnmapBufferARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_buffer_object,
        PROVIDER_Desktop_OpenGL_1_5,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_OES_mapbuffer,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        60019 /* "glUnmapBufferARB" */,
        60005 /* "glUnmapBuffer" */,
        60005 /* "glUnmapBuffer" */,
        60036 /* "glUnmapBufferOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 60019 /* "glUnmapBufferARB" */,
                                providers, entrypoints);
}

static PFNGLUNMAPBUFFEROESPROC
epoxy_glUnmapBufferOES_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_OES_mapbuffer,
        PROVIDER_Desktop_OpenGL_1_5,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_ARB_vertex_buffer_object,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        60036 /* "glUnmapBufferOES" */,
        60005 /* "glUnmapBuffer" */,
        60005 /* "glUnmapBuffer" */,
        60019 /* "glUnmapBufferARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 60036 /* "glUnmapBufferOES" */,
                                providers, entrypoints);
}

static PFNGLUNMAPNAMEDBUFFERPROC
epoxy_glUnmapNamedBuffer_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        60053 /* "glUnmapNamedBuffer" */,
        60053 /* "glUnmapNamedBuffer" */,
    };
    return gl_provider_resolver(entrypoint_strings + 60053 /* "glUnmapNamedBuffer" */,
                                providers, entrypoints);
}

static PFNGLUNMAPNAMEDBUFFEREXTPROC
epoxy_glUnmapNamedBufferEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 60072 /* glUnmapNamedBufferEXT */);
}

static PFNGLUNMAPOBJECTBUFFERATIPROC
epoxy_glUnmapObjectBufferATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_map_object_buffer, 60094 /* glUnmapObjectBufferATI */);
}

static PFNGLUNMAPTEXTURE2DINTELPROC
epoxy_glUnmapTexture2DINTEL_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_INTEL_map_texture, 60117 /* glUnmapTexture2DINTEL */);
}

static PFNGLUPDATEOBJECTBUFFERATIPROC
epoxy_glUpdateObjectBufferATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_array_object, 60139 /* glUpdateObjectBufferATI */);
}

static PFNGLUPLOADGPUMASKNVXPROC
epoxy_glUploadGpuMaskNVX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NVX_gpu_multicast2, 60163 /* glUploadGpuMaskNVX */);
}

static PFNGLUSEPROGRAMPROC
epoxy_glUseProgram_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        60182 /* "glUseProgram" */,
        60182 /* "glUseProgram" */,
        60195 /* "glUseProgramObjectARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 60182 /* "glUseProgram" */,
                                providers, entrypoints);
}

static PFNGLUSEPROGRAMOBJECTARBPROC
epoxy_glUseProgramObjectARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_shader_objects,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        60195 /* "glUseProgramObjectARB" */,
        60182 /* "glUseProgram" */,
        60182 /* "glUseProgram" */,
    };
    return gl_provider_resolver(entrypoint_strings + 60195 /* "glUseProgramObjectARB" */,
                                providers, entrypoints);
}

static PFNGLUSEPROGRAMSTAGESPROC
epoxy_glUseProgramStages_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        60217 /* "glUseProgramStages" */,
        60217 /* "glUseProgramStages" */,
        60217 /* "glUseProgramStages" */,
    };
    return gl_provider_resolver(entrypoint_strings + 60217 /* "glUseProgramStages" */,
                                providers, entrypoints);
}

static PFNGLUSEPROGRAMSTAGESEXTPROC
epoxy_glUseProgramStagesEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_separate_shader_objects, 60236 /* glUseProgramStagesEXT */);
}

static PFNGLUSESHADERPROGRAMEXTPROC
epoxy_glUseShaderProgramEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_separate_shader_objects, 60258 /* glUseShaderProgramEXT */);
}

static PFNGLVDPAUFININVPROC
epoxy_glVDPAUFiniNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vdpau_interop, 60280 /* glVDPAUFiniNV */);
}

static PFNGLVDPAUGETSURFACEIVNVPROC
epoxy_glVDPAUGetSurfaceivNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vdpau_interop, 60294 /* glVDPAUGetSurfaceivNV */);
}

static PFNGLVDPAUINITNVPROC
epoxy_glVDPAUInitNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vdpau_interop, 60316 /* glVDPAUInitNV */);
}

static PFNGLVDPAUISSURFACENVPROC
epoxy_glVDPAUIsSurfaceNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vdpau_interop, 60330 /* glVDPAUIsSurfaceNV */);
}

static PFNGLVDPAUMAPSURFACESNVPROC
epoxy_glVDPAUMapSurfacesNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vdpau_interop, 60349 /* glVDPAUMapSurfacesNV */);
}

static PFNGLVDPAUREGISTEROUTPUTSURFACENVPROC
epoxy_glVDPAURegisterOutputSurfaceNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vdpau_interop, 60370 /* glVDPAURegisterOutputSurfaceNV */);
}

static PFNGLVDPAUREGISTERVIDEOSURFACENVPROC
epoxy_glVDPAURegisterVideoSurfaceNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vdpau_interop, 60401 /* glVDPAURegisterVideoSurfaceNV */);
}

static PFNGLVDPAUREGISTERVIDEOSURFACEWITHPICTURESTRUCTURENVPROC
epoxy_glVDPAURegisterVideoSurfaceWithPictureStructureNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vdpau_interop2, 60431 /* glVDPAURegisterVideoSurfaceWithPictureStructureNV */);
}

static PFNGLVDPAUSURFACEACCESSNVPROC
epoxy_glVDPAUSurfaceAccessNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vdpau_interop, 60481 /* glVDPAUSurfaceAccessNV */);
}

static PFNGLVDPAUUNMAPSURFACESNVPROC
epoxy_glVDPAUUnmapSurfacesNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vdpau_interop, 60504 /* glVDPAUUnmapSurfacesNV */);
}

static PFNGLVDPAUUNREGISTERSURFACENVPROC
epoxy_glVDPAUUnregisterSurfaceNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vdpau_interop, 60527 /* glVDPAUUnregisterSurfaceNV */);
}

static PFNGLVALIDATEPROGRAMPROC
epoxy_glValidateProgram_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_shader_objects,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        60554 /* "glValidateProgram" */,
        60554 /* "glValidateProgram" */,
        60572 /* "glValidateProgramARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 60554 /* "glValidateProgram" */,
                                providers, entrypoints);
}

static PFNGLVALIDATEPROGRAMARBPROC
epoxy_glValidateProgramARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_shader_objects,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        60572 /* "glValidateProgramARB" */,
        60554 /* "glValidateProgram" */,
        60554 /* "glValidateProgram" */,
    };
    return gl_provider_resolver(entrypoint_strings + 60572 /* "glValidateProgramARB" */,
                                providers, entrypoints);
}

static PFNGLVALIDATEPROGRAMPIPELINEPROC
epoxy_glValidateProgramPipeline_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_separate_shader_objects,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        60593 /* "glValidateProgramPipeline" */,
        60593 /* "glValidateProgramPipeline" */,
        60593 /* "glValidateProgramPipeline" */,
    };
    return gl_provider_resolver(entrypoint_strings + 60593 /* "glValidateProgramPipeline" */,
                                providers, entrypoints);
}

static PFNGLVALIDATEPROGRAMPIPELINEEXTPROC
epoxy_glValidateProgramPipelineEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_separate_shader_objects, 60619 /* glValidateProgramPipelineEXT */);
}

static PFNGLVARIANTARRAYOBJECTATIPROC
epoxy_glVariantArrayObjectATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_array_object, 60648 /* glVariantArrayObjectATI */);
}

static PFNGLVARIANTPOINTEREXTPROC
epoxy_glVariantPointerEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_shader, 60672 /* glVariantPointerEXT */);
}

static PFNGLVARIANTBVEXTPROC
epoxy_glVariantbvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_shader, 60692 /* glVariantbvEXT */);
}

static PFNGLVARIANTDVEXTPROC
epoxy_glVariantdvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_shader, 60707 /* glVariantdvEXT */);
}

static PFNGLVARIANTFVEXTPROC
epoxy_glVariantfvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_shader, 60722 /* glVariantfvEXT */);
}

static PFNGLVARIANTIVEXTPROC
epoxy_glVariantivEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_shader, 60737 /* glVariantivEXT */);
}

static PFNGLVARIANTSVEXTPROC
epoxy_glVariantsvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_shader, 60752 /* glVariantsvEXT */);
}

static PFNGLVARIANTUBVEXTPROC
epoxy_glVariantubvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_shader, 60767 /* glVariantubvEXT */);
}

static PFNGLVARIANTUIVEXTPROC
epoxy_glVariantuivEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_shader, 60783 /* glVariantuivEXT */);
}

static PFNGLVARIANTUSVEXTPROC
epoxy_glVariantusvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_shader, 60799 /* glVariantusvEXT */);
}

static PFNGLVERTEX2BOESPROC
epoxy_glVertex2bOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_byte_coordinates, 60815 /* glVertex2bOES */);
}

static PFNGLVERTEX2BVOESPROC
epoxy_glVertex2bvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_byte_coordinates, 60829 /* glVertex2bvOES */);
}

static PFNGLVERTEX2DPROC
epoxy_glVertex2d_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 60844 /* glVertex2d */);
}

static PFNGLVERTEX2DVPROC
epoxy_glVertex2dv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 60855 /* glVertex2dv */);
}

static PFNGLVERTEX2FPROC
epoxy_glVertex2f_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 60867 /* glVertex2f */);
}

static PFNGLVERTEX2FVPROC
epoxy_glVertex2fv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 60878 /* glVertex2fv */);
}

static PFNGLVERTEX2HNVPROC
epoxy_glVertex2hNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_half_float, 60890 /* glVertex2hNV */);
}

static PFNGLVERTEX2HVNVPROC
epoxy_glVertex2hvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_half_float, 60903 /* glVertex2hvNV */);
}

static PFNGLVERTEX2IPROC
epoxy_glVertex2i_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 60917 /* glVertex2i */);
}

static PFNGLVERTEX2IVPROC
epoxy_glVertex2iv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 60928 /* glVertex2iv */);
}

static PFNGLVERTEX2SPROC
epoxy_glVertex2s_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 60940 /* glVertex2s */);
}

static PFNGLVERTEX2SVPROC
epoxy_glVertex2sv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 60951 /* glVertex2sv */);
}

static PFNGLVERTEX2XOESPROC
epoxy_glVertex2xOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 60963 /* glVertex2xOES */);
}

static PFNGLVERTEX2XVOESPROC
epoxy_glVertex2xvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 60977 /* glVertex2xvOES */);
}

static PFNGLVERTEX3BOESPROC
epoxy_glVertex3bOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_byte_coordinates, 60992 /* glVertex3bOES */);
}

static PFNGLVERTEX3BVOESPROC
epoxy_glVertex3bvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_byte_coordinates, 61006 /* glVertex3bvOES */);
}

static PFNGLVERTEX3DPROC
epoxy_glVertex3d_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 61021 /* glVertex3d */);
}

static PFNGLVERTEX3DVPROC
epoxy_glVertex3dv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 61032 /* glVertex3dv */);
}

static PFNGLVERTEX3FPROC
epoxy_glVertex3f_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 61044 /* glVertex3f */);
}

static PFNGLVERTEX3FVPROC
epoxy_glVertex3fv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 61055 /* glVertex3fv */);
}

static PFNGLVERTEX3HNVPROC
epoxy_glVertex3hNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_half_float, 61067 /* glVertex3hNV */);
}

static PFNGLVERTEX3HVNVPROC
epoxy_glVertex3hvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_half_float, 61080 /* glVertex3hvNV */);
}

static PFNGLVERTEX3IPROC
epoxy_glVertex3i_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 61094 /* glVertex3i */);
}

static PFNGLVERTEX3IVPROC
epoxy_glVertex3iv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 61105 /* glVertex3iv */);
}

static PFNGLVERTEX3SPROC
epoxy_glVertex3s_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 61117 /* glVertex3s */);
}

static PFNGLVERTEX3SVPROC
epoxy_glVertex3sv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 61128 /* glVertex3sv */);
}

static PFNGLVERTEX3XOESPROC
epoxy_glVertex3xOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 61140 /* glVertex3xOES */);
}

static PFNGLVERTEX3XVOESPROC
epoxy_glVertex3xvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 61154 /* glVertex3xvOES */);
}

static PFNGLVERTEX4BOESPROC
epoxy_glVertex4bOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_byte_coordinates, 61169 /* glVertex4bOES */);
}

static PFNGLVERTEX4BVOESPROC
epoxy_glVertex4bvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_byte_coordinates, 61183 /* glVertex4bvOES */);
}

static PFNGLVERTEX4DPROC
epoxy_glVertex4d_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 61198 /* glVertex4d */);
}

static PFNGLVERTEX4DVPROC
epoxy_glVertex4dv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 61209 /* glVertex4dv */);
}

static PFNGLVERTEX4FPROC
epoxy_glVertex4f_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 61221 /* glVertex4f */);
}

static PFNGLVERTEX4FVPROC
epoxy_glVertex4fv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 61232 /* glVertex4fv */);
}

static PFNGLVERTEX4HNVPROC
epoxy_glVertex4hNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_half_float, 61244 /* glVertex4hNV */);
}

static PFNGLVERTEX4HVNVPROC
epoxy_glVertex4hvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_half_float, 61257 /* glVertex4hvNV */);
}

static PFNGLVERTEX4IPROC
epoxy_glVertex4i_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 61271 /* glVertex4i */);
}

static PFNGLVERTEX4IVPROC
epoxy_glVertex4iv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 61282 /* glVertex4iv */);
}

static PFNGLVERTEX4SPROC
epoxy_glVertex4s_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 61294 /* glVertex4s */);
}

static PFNGLVERTEX4SVPROC
epoxy_glVertex4sv_resolver(void)
{
    return gl_single_resolver(PROVIDER_Desktop_OpenGL_1_0, 61305 /* glVertex4sv */);
}

static PFNGLVERTEX4XOESPROC
epoxy_glVertex4xOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 61317 /* glVertex4xOES */);
}

static PFNGLVERTEX4XVOESPROC
epoxy_glVertex4xvOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_fixed_point, 61331 /* glVertex4xvOES */);
}

static PFNGLVERTEXARRAYATTRIBBINDINGPROC
epoxy_glVertexArrayAttribBinding_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        61346 /* "glVertexArrayAttribBinding" */,
        61346 /* "glVertexArrayAttribBinding" */,
    };
    return gl_provider_resolver(entrypoint_strings + 61346 /* "glVertexArrayAttribBinding" */,
                                providers, entrypoints);
}

static PFNGLVERTEXARRAYATTRIBFORMATPROC
epoxy_glVertexArrayAttribFormat_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        61373 /* "glVertexArrayAttribFormat" */,
        61373 /* "glVertexArrayAttribFormat" */,
    };
    return gl_provider_resolver(entrypoint_strings + 61373 /* "glVertexArrayAttribFormat" */,
                                providers, entrypoints);
}

static PFNGLVERTEXARRAYATTRIBIFORMATPROC
epoxy_glVertexArrayAttribIFormat_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        61399 /* "glVertexArrayAttribIFormat" */,
        61399 /* "glVertexArrayAttribIFormat" */,
    };
    return gl_provider_resolver(entrypoint_strings + 61399 /* "glVertexArrayAttribIFormat" */,
                                providers, entrypoints);
}

static PFNGLVERTEXARRAYATTRIBLFORMATPROC
epoxy_glVertexArrayAttribLFormat_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        61426 /* "glVertexArrayAttribLFormat" */,
        61426 /* "glVertexArrayAttribLFormat" */,
    };
    return gl_provider_resolver(entrypoint_strings + 61426 /* "glVertexArrayAttribLFormat" */,
                                providers, entrypoints);
}

static PFNGLVERTEXARRAYBINDVERTEXBUFFEREXTPROC
epoxy_glVertexArrayBindVertexBufferEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 61453 /* glVertexArrayBindVertexBufferEXT */);
}

static PFNGLVERTEXARRAYBINDINGDIVISORPROC
epoxy_glVertexArrayBindingDivisor_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        61486 /* "glVertexArrayBindingDivisor" */,
        61486 /* "glVertexArrayBindingDivisor" */,
    };
    return gl_provider_resolver(entrypoint_strings + 61486 /* "glVertexArrayBindingDivisor" */,
                                providers, entrypoints);
}

static PFNGLVERTEXARRAYCOLOROFFSETEXTPROC
epoxy_glVertexArrayColorOffsetEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 61514 /* glVertexArrayColorOffsetEXT */);
}

static PFNGLVERTEXARRAYEDGEFLAGOFFSETEXTPROC
epoxy_glVertexArrayEdgeFlagOffsetEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 61542 /* glVertexArrayEdgeFlagOffsetEXT */);
}

static PFNGLVERTEXARRAYELEMENTBUFFERPROC
epoxy_glVertexArrayElementBuffer_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        61573 /* "glVertexArrayElementBuffer" */,
        61573 /* "glVertexArrayElementBuffer" */,
    };
    return gl_provider_resolver(entrypoint_strings + 61573 /* "glVertexArrayElementBuffer" */,
                                providers, entrypoints);
}

static PFNGLVERTEXARRAYFOGCOORDOFFSETEXTPROC
epoxy_glVertexArrayFogCoordOffsetEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 61600 /* glVertexArrayFogCoordOffsetEXT */);
}

static PFNGLVERTEXARRAYINDEXOFFSETEXTPROC
epoxy_glVertexArrayIndexOffsetEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 61631 /* glVertexArrayIndexOffsetEXT */);
}

static PFNGLVERTEXARRAYMULTITEXCOORDOFFSETEXTPROC
epoxy_glVertexArrayMultiTexCoordOffsetEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 61659 /* glVertexArrayMultiTexCoordOffsetEXT */);
}

static PFNGLVERTEXARRAYNORMALOFFSETEXTPROC
epoxy_glVertexArrayNormalOffsetEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 61695 /* glVertexArrayNormalOffsetEXT */);
}

static PFNGLVERTEXARRAYPARAMETERIAPPLEPROC
epoxy_glVertexArrayParameteriAPPLE_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_APPLE_vertex_array_range, 61724 /* glVertexArrayParameteriAPPLE */);
}

static PFNGLVERTEXARRAYRANGEAPPLEPROC
epoxy_glVertexArrayRangeAPPLE_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_APPLE_vertex_array_range, 61753 /* glVertexArrayRangeAPPLE */);
}

static PFNGLVERTEXARRAYRANGENVPROC
epoxy_glVertexArrayRangeNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_array_range, 61777 /* glVertexArrayRangeNV */);
}

static PFNGLVERTEXARRAYSECONDARYCOLOROFFSETEXTPROC
epoxy_glVertexArraySecondaryColorOffsetEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 61798 /* glVertexArraySecondaryColorOffsetEXT */);
}

static PFNGLVERTEXARRAYTEXCOORDOFFSETEXTPROC
epoxy_glVertexArrayTexCoordOffsetEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 61835 /* glVertexArrayTexCoordOffsetEXT */);
}

static PFNGLVERTEXARRAYVERTEXATTRIBBINDINGEXTPROC
epoxy_glVertexArrayVertexAttribBindingEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 61866 /* glVertexArrayVertexAttribBindingEXT */);
}

static PFNGLVERTEXARRAYVERTEXATTRIBDIVISOREXTPROC
epoxy_glVertexArrayVertexAttribDivisorEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 61902 /* glVertexArrayVertexAttribDivisorEXT */);
}

static PFNGLVERTEXARRAYVERTEXATTRIBFORMATEXTPROC
epoxy_glVertexArrayVertexAttribFormatEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 61938 /* glVertexArrayVertexAttribFormatEXT */);
}

static PFNGLVERTEXARRAYVERTEXATTRIBIFORMATEXTPROC
epoxy_glVertexArrayVertexAttribIFormatEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 61973 /* glVertexArrayVertexAttribIFormatEXT */);
}

static PFNGLVERTEXARRAYVERTEXATTRIBIOFFSETEXTPROC
epoxy_glVertexArrayVertexAttribIOffsetEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 62009 /* glVertexArrayVertexAttribIOffsetEXT */);
}

static PFNGLVERTEXARRAYVERTEXATTRIBLFORMATEXTPROC
epoxy_glVertexArrayVertexAttribLFormatEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 62045 /* glVertexArrayVertexAttribLFormatEXT */);
}

static PFNGLVERTEXARRAYVERTEXATTRIBLOFFSETEXTPROC
epoxy_glVertexArrayVertexAttribLOffsetEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 62081 /* glVertexArrayVertexAttribLOffsetEXT */);
}

static PFNGLVERTEXARRAYVERTEXATTRIBOFFSETEXTPROC
epoxy_glVertexArrayVertexAttribOffsetEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 62117 /* glVertexArrayVertexAttribOffsetEXT */);
}

static PFNGLVERTEXARRAYVERTEXBINDINGDIVISOREXTPROC
epoxy_glVertexArrayVertexBindingDivisorEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 62152 /* glVertexArrayVertexBindingDivisorEXT */);
}

static PFNGLVERTEXARRAYVERTEXBUFFERPROC
epoxy_glVertexArrayVertexBuffer_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        62189 /* "glVertexArrayVertexBuffer" */,
        62189 /* "glVertexArrayVertexBuffer" */,
    };
    return gl_provider_resolver(entrypoint_strings + 62189 /* "glVertexArrayVertexBuffer" */,
                                providers, entrypoints);
}

static PFNGLVERTEXARRAYVERTEXBUFFERSPROC
epoxy_glVertexArrayVertexBuffers_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_5,
        PROVIDER_GL_ARB_direct_state_access,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        62215 /* "glVertexArrayVertexBuffers" */,
        62215 /* "glVertexArrayVertexBuffers" */,
    };
    return gl_provider_resolver(entrypoint_strings + 62215 /* "glVertexArrayVertexBuffers" */,
                                providers, entrypoints);
}

static PFNGLVERTEXARRAYVERTEXOFFSETEXTPROC
epoxy_glVertexArrayVertexOffsetEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_direct_state_access, 62242 /* glVertexArrayVertexOffsetEXT */);
}

static PFNGLVERTEXATTRIB1DPROC
epoxy_glVertexAttrib1d_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        62271 /* "glVertexAttrib1d" */,
        62288 /* "glVertexAttrib1dARB" */,
        62288 /* "glVertexAttrib1dARB" */,
        62308 /* "glVertexAttrib1dNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 62271 /* "glVertexAttrib1d" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB1DARBPROC
epoxy_glVertexAttrib1dARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        62288 /* "glVertexAttrib1dARB" */,
        62288 /* "glVertexAttrib1dARB" */,
        62271 /* "glVertexAttrib1d" */,
        62308 /* "glVertexAttrib1dNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 62288 /* "glVertexAttrib1dARB" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB1DNVPROC
epoxy_glVertexAttrib1dNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        62308 /* "glVertexAttrib1dNV" */,
        62271 /* "glVertexAttrib1d" */,
        62288 /* "glVertexAttrib1dARB" */,
        62288 /* "glVertexAttrib1dARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 62308 /* "glVertexAttrib1dNV" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB1DVPROC
epoxy_glVertexAttrib1dv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        62327 /* "glVertexAttrib1dv" */,
        62345 /* "glVertexAttrib1dvARB" */,
        62345 /* "glVertexAttrib1dvARB" */,
        62366 /* "glVertexAttrib1dvNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 62327 /* "glVertexAttrib1dv" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB1DVARBPROC
epoxy_glVertexAttrib1dvARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        62345 /* "glVertexAttrib1dvARB" */,
        62345 /* "glVertexAttrib1dvARB" */,
        62327 /* "glVertexAttrib1dv" */,
        62366 /* "glVertexAttrib1dvNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 62345 /* "glVertexAttrib1dvARB" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB1DVNVPROC
epoxy_glVertexAttrib1dvNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        62366 /* "glVertexAttrib1dvNV" */,
        62327 /* "glVertexAttrib1dv" */,
        62345 /* "glVertexAttrib1dvARB" */,
        62345 /* "glVertexAttrib1dvARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 62366 /* "glVertexAttrib1dvNV" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB1FPROC
epoxy_glVertexAttrib1f_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        62386 /* "glVertexAttrib1f" */,
        62386 /* "glVertexAttrib1f" */,
        62403 /* "glVertexAttrib1fARB" */,
        62403 /* "glVertexAttrib1fARB" */,
        62423 /* "glVertexAttrib1fNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 62386 /* "glVertexAttrib1f" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB1FARBPROC
epoxy_glVertexAttrib1fARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        62403 /* "glVertexAttrib1fARB" */,
        62403 /* "glVertexAttrib1fARB" */,
        62386 /* "glVertexAttrib1f" */,
        62386 /* "glVertexAttrib1f" */,
        62423 /* "glVertexAttrib1fNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 62403 /* "glVertexAttrib1fARB" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB1FNVPROC
epoxy_glVertexAttrib1fNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        62423 /* "glVertexAttrib1fNV" */,
        62386 /* "glVertexAttrib1f" */,
        62386 /* "glVertexAttrib1f" */,
        62403 /* "glVertexAttrib1fARB" */,
        62403 /* "glVertexAttrib1fARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 62423 /* "glVertexAttrib1fNV" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB1FVPROC
epoxy_glVertexAttrib1fv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        62442 /* "glVertexAttrib1fv" */,
        62442 /* "glVertexAttrib1fv" */,
        62460 /* "glVertexAttrib1fvARB" */,
        62460 /* "glVertexAttrib1fvARB" */,
        62481 /* "glVertexAttrib1fvNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 62442 /* "glVertexAttrib1fv" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB1FVARBPROC
epoxy_glVertexAttrib1fvARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        62460 /* "glVertexAttrib1fvARB" */,
        62460 /* "glVertexAttrib1fvARB" */,
        62442 /* "glVertexAttrib1fv" */,
        62442 /* "glVertexAttrib1fv" */,
        62481 /* "glVertexAttrib1fvNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 62460 /* "glVertexAttrib1fvARB" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB1FVNVPROC
epoxy_glVertexAttrib1fvNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        62481 /* "glVertexAttrib1fvNV" */,
        62442 /* "glVertexAttrib1fv" */,
        62442 /* "glVertexAttrib1fv" */,
        62460 /* "glVertexAttrib1fvARB" */,
        62460 /* "glVertexAttrib1fvARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 62481 /* "glVertexAttrib1fvNV" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB1HNVPROC
epoxy_glVertexAttrib1hNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_half_float, 62501 /* glVertexAttrib1hNV */);
}

static PFNGLVERTEXATTRIB1HVNVPROC
epoxy_glVertexAttrib1hvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_half_float, 62520 /* glVertexAttrib1hvNV */);
}

static PFNGLVERTEXATTRIB1SPROC
epoxy_glVertexAttrib1s_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        62540 /* "glVertexAttrib1s" */,
        62557 /* "glVertexAttrib1sARB" */,
        62557 /* "glVertexAttrib1sARB" */,
        62577 /* "glVertexAttrib1sNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 62540 /* "glVertexAttrib1s" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB1SARBPROC
epoxy_glVertexAttrib1sARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        62557 /* "glVertexAttrib1sARB" */,
        62557 /* "glVertexAttrib1sARB" */,
        62540 /* "glVertexAttrib1s" */,
        62577 /* "glVertexAttrib1sNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 62557 /* "glVertexAttrib1sARB" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB1SNVPROC
epoxy_glVertexAttrib1sNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        62577 /* "glVertexAttrib1sNV" */,
        62540 /* "glVertexAttrib1s" */,
        62557 /* "glVertexAttrib1sARB" */,
        62557 /* "glVertexAttrib1sARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 62577 /* "glVertexAttrib1sNV" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB1SVPROC
epoxy_glVertexAttrib1sv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        62596 /* "glVertexAttrib1sv" */,
        62614 /* "glVertexAttrib1svARB" */,
        62614 /* "glVertexAttrib1svARB" */,
        62635 /* "glVertexAttrib1svNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 62596 /* "glVertexAttrib1sv" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB1SVARBPROC
epoxy_glVertexAttrib1svARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        62614 /* "glVertexAttrib1svARB" */,
        62614 /* "glVertexAttrib1svARB" */,
        62596 /* "glVertexAttrib1sv" */,
        62635 /* "glVertexAttrib1svNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 62614 /* "glVertexAttrib1svARB" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB1SVNVPROC
epoxy_glVertexAttrib1svNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        62635 /* "glVertexAttrib1svNV" */,
        62596 /* "glVertexAttrib1sv" */,
        62614 /* "glVertexAttrib1svARB" */,
        62614 /* "glVertexAttrib1svARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 62635 /* "glVertexAttrib1svNV" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB2DPROC
epoxy_glVertexAttrib2d_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        62655 /* "glVertexAttrib2d" */,
        62672 /* "glVertexAttrib2dARB" */,
        62672 /* "glVertexAttrib2dARB" */,
        62692 /* "glVertexAttrib2dNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 62655 /* "glVertexAttrib2d" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB2DARBPROC
epoxy_glVertexAttrib2dARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        62672 /* "glVertexAttrib2dARB" */,
        62672 /* "glVertexAttrib2dARB" */,
        62655 /* "glVertexAttrib2d" */,
        62692 /* "glVertexAttrib2dNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 62672 /* "glVertexAttrib2dARB" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB2DNVPROC
epoxy_glVertexAttrib2dNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        62692 /* "glVertexAttrib2dNV" */,
        62655 /* "glVertexAttrib2d" */,
        62672 /* "glVertexAttrib2dARB" */,
        62672 /* "glVertexAttrib2dARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 62692 /* "glVertexAttrib2dNV" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB2DVPROC
epoxy_glVertexAttrib2dv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        62711 /* "glVertexAttrib2dv" */,
        62729 /* "glVertexAttrib2dvARB" */,
        62729 /* "glVertexAttrib2dvARB" */,
        62750 /* "glVertexAttrib2dvNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 62711 /* "glVertexAttrib2dv" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB2DVARBPROC
epoxy_glVertexAttrib2dvARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        62729 /* "glVertexAttrib2dvARB" */,
        62729 /* "glVertexAttrib2dvARB" */,
        62711 /* "glVertexAttrib2dv" */,
        62750 /* "glVertexAttrib2dvNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 62729 /* "glVertexAttrib2dvARB" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB2DVNVPROC
epoxy_glVertexAttrib2dvNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        62750 /* "glVertexAttrib2dvNV" */,
        62711 /* "glVertexAttrib2dv" */,
        62729 /* "glVertexAttrib2dvARB" */,
        62729 /* "glVertexAttrib2dvARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 62750 /* "glVertexAttrib2dvNV" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB2FPROC
epoxy_glVertexAttrib2f_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        62770 /* "glVertexAttrib2f" */,
        62770 /* "glVertexAttrib2f" */,
        62787 /* "glVertexAttrib2fARB" */,
        62787 /* "glVertexAttrib2fARB" */,
        62807 /* "glVertexAttrib2fNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 62770 /* "glVertexAttrib2f" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB2FARBPROC
epoxy_glVertexAttrib2fARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        62787 /* "glVertexAttrib2fARB" */,
        62787 /* "glVertexAttrib2fARB" */,
        62770 /* "glVertexAttrib2f" */,
        62770 /* "glVertexAttrib2f" */,
        62807 /* "glVertexAttrib2fNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 62787 /* "glVertexAttrib2fARB" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB2FNVPROC
epoxy_glVertexAttrib2fNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        62807 /* "glVertexAttrib2fNV" */,
        62770 /* "glVertexAttrib2f" */,
        62770 /* "glVertexAttrib2f" */,
        62787 /* "glVertexAttrib2fARB" */,
        62787 /* "glVertexAttrib2fARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 62807 /* "glVertexAttrib2fNV" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB2FVPROC
epoxy_glVertexAttrib2fv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        62826 /* "glVertexAttrib2fv" */,
        62826 /* "glVertexAttrib2fv" */,
        62844 /* "glVertexAttrib2fvARB" */,
        62844 /* "glVertexAttrib2fvARB" */,
        62865 /* "glVertexAttrib2fvNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 62826 /* "glVertexAttrib2fv" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB2FVARBPROC
epoxy_glVertexAttrib2fvARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        62844 /* "glVertexAttrib2fvARB" */,
        62844 /* "glVertexAttrib2fvARB" */,
        62826 /* "glVertexAttrib2fv" */,
        62826 /* "glVertexAttrib2fv" */,
        62865 /* "glVertexAttrib2fvNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 62844 /* "glVertexAttrib2fvARB" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB2FVNVPROC
epoxy_glVertexAttrib2fvNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        62865 /* "glVertexAttrib2fvNV" */,
        62826 /* "glVertexAttrib2fv" */,
        62826 /* "glVertexAttrib2fv" */,
        62844 /* "glVertexAttrib2fvARB" */,
        62844 /* "glVertexAttrib2fvARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 62865 /* "glVertexAttrib2fvNV" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB2HNVPROC
epoxy_glVertexAttrib2hNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_half_float, 62885 /* glVertexAttrib2hNV */);
}

static PFNGLVERTEXATTRIB2HVNVPROC
epoxy_glVertexAttrib2hvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_half_float, 62904 /* glVertexAttrib2hvNV */);
}

static PFNGLVERTEXATTRIB2SPROC
epoxy_glVertexAttrib2s_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        62924 /* "glVertexAttrib2s" */,
        62941 /* "glVertexAttrib2sARB" */,
        62941 /* "glVertexAttrib2sARB" */,
        62961 /* "glVertexAttrib2sNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 62924 /* "glVertexAttrib2s" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB2SARBPROC
epoxy_glVertexAttrib2sARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        62941 /* "glVertexAttrib2sARB" */,
        62941 /* "glVertexAttrib2sARB" */,
        62924 /* "glVertexAttrib2s" */,
        62961 /* "glVertexAttrib2sNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 62941 /* "glVertexAttrib2sARB" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB2SNVPROC
epoxy_glVertexAttrib2sNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        62961 /* "glVertexAttrib2sNV" */,
        62924 /* "glVertexAttrib2s" */,
        62941 /* "glVertexAttrib2sARB" */,
        62941 /* "glVertexAttrib2sARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 62961 /* "glVertexAttrib2sNV" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB2SVPROC
epoxy_glVertexAttrib2sv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        62980 /* "glVertexAttrib2sv" */,
        62998 /* "glVertexAttrib2svARB" */,
        62998 /* "glVertexAttrib2svARB" */,
        63019 /* "glVertexAttrib2svNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 62980 /* "glVertexAttrib2sv" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB2SVARBPROC
epoxy_glVertexAttrib2svARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        62998 /* "glVertexAttrib2svARB" */,
        62998 /* "glVertexAttrib2svARB" */,
        62980 /* "glVertexAttrib2sv" */,
        63019 /* "glVertexAttrib2svNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 62998 /* "glVertexAttrib2svARB" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB2SVNVPROC
epoxy_glVertexAttrib2svNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        63019 /* "glVertexAttrib2svNV" */,
        62980 /* "glVertexAttrib2sv" */,
        62998 /* "glVertexAttrib2svARB" */,
        62998 /* "glVertexAttrib2svARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 63019 /* "glVertexAttrib2svNV" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB3DPROC
epoxy_glVertexAttrib3d_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        63039 /* "glVertexAttrib3d" */,
        63056 /* "glVertexAttrib3dARB" */,
        63056 /* "glVertexAttrib3dARB" */,
        63076 /* "glVertexAttrib3dNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 63039 /* "glVertexAttrib3d" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB3DARBPROC
epoxy_glVertexAttrib3dARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        63056 /* "glVertexAttrib3dARB" */,
        63056 /* "glVertexAttrib3dARB" */,
        63039 /* "glVertexAttrib3d" */,
        63076 /* "glVertexAttrib3dNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 63056 /* "glVertexAttrib3dARB" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB3DNVPROC
epoxy_glVertexAttrib3dNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        63076 /* "glVertexAttrib3dNV" */,
        63039 /* "glVertexAttrib3d" */,
        63056 /* "glVertexAttrib3dARB" */,
        63056 /* "glVertexAttrib3dARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 63076 /* "glVertexAttrib3dNV" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB3DVPROC
epoxy_glVertexAttrib3dv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        63095 /* "glVertexAttrib3dv" */,
        63113 /* "glVertexAttrib3dvARB" */,
        63113 /* "glVertexAttrib3dvARB" */,
        63134 /* "glVertexAttrib3dvNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 63095 /* "glVertexAttrib3dv" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB3DVARBPROC
epoxy_glVertexAttrib3dvARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        63113 /* "glVertexAttrib3dvARB" */,
        63113 /* "glVertexAttrib3dvARB" */,
        63095 /* "glVertexAttrib3dv" */,
        63134 /* "glVertexAttrib3dvNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 63113 /* "glVertexAttrib3dvARB" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB3DVNVPROC
epoxy_glVertexAttrib3dvNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        63134 /* "glVertexAttrib3dvNV" */,
        63095 /* "glVertexAttrib3dv" */,
        63113 /* "glVertexAttrib3dvARB" */,
        63113 /* "glVertexAttrib3dvARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 63134 /* "glVertexAttrib3dvNV" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB3FPROC
epoxy_glVertexAttrib3f_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        63154 /* "glVertexAttrib3f" */,
        63154 /* "glVertexAttrib3f" */,
        63171 /* "glVertexAttrib3fARB" */,
        63171 /* "glVertexAttrib3fARB" */,
        63191 /* "glVertexAttrib3fNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 63154 /* "glVertexAttrib3f" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB3FARBPROC
epoxy_glVertexAttrib3fARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        63171 /* "glVertexAttrib3fARB" */,
        63171 /* "glVertexAttrib3fARB" */,
        63154 /* "glVertexAttrib3f" */,
        63154 /* "glVertexAttrib3f" */,
        63191 /* "glVertexAttrib3fNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 63171 /* "glVertexAttrib3fARB" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB3FNVPROC
epoxy_glVertexAttrib3fNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        63191 /* "glVertexAttrib3fNV" */,
        63154 /* "glVertexAttrib3f" */,
        63154 /* "glVertexAttrib3f" */,
        63171 /* "glVertexAttrib3fARB" */,
        63171 /* "glVertexAttrib3fARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 63191 /* "glVertexAttrib3fNV" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB3FVPROC
epoxy_glVertexAttrib3fv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        63210 /* "glVertexAttrib3fv" */,
        63210 /* "glVertexAttrib3fv" */,
        63228 /* "glVertexAttrib3fvARB" */,
        63228 /* "glVertexAttrib3fvARB" */,
        63249 /* "glVertexAttrib3fvNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 63210 /* "glVertexAttrib3fv" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB3FVARBPROC
epoxy_glVertexAttrib3fvARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        63228 /* "glVertexAttrib3fvARB" */,
        63228 /* "glVertexAttrib3fvARB" */,
        63210 /* "glVertexAttrib3fv" */,
        63210 /* "glVertexAttrib3fv" */,
        63249 /* "glVertexAttrib3fvNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 63228 /* "glVertexAttrib3fvARB" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB3FVNVPROC
epoxy_glVertexAttrib3fvNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        63249 /* "glVertexAttrib3fvNV" */,
        63210 /* "glVertexAttrib3fv" */,
        63210 /* "glVertexAttrib3fv" */,
        63228 /* "glVertexAttrib3fvARB" */,
        63228 /* "glVertexAttrib3fvARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 63249 /* "glVertexAttrib3fvNV" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB3HNVPROC
epoxy_glVertexAttrib3hNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_half_float, 63269 /* glVertexAttrib3hNV */);
}

static PFNGLVERTEXATTRIB3HVNVPROC
epoxy_glVertexAttrib3hvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_half_float, 63288 /* glVertexAttrib3hvNV */);
}

static PFNGLVERTEXATTRIB3SPROC
epoxy_glVertexAttrib3s_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        63308 /* "glVertexAttrib3s" */,
        63325 /* "glVertexAttrib3sARB" */,
        63325 /* "glVertexAttrib3sARB" */,
        63345 /* "glVertexAttrib3sNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 63308 /* "glVertexAttrib3s" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB3SARBPROC
epoxy_glVertexAttrib3sARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        63325 /* "glVertexAttrib3sARB" */,
        63325 /* "glVertexAttrib3sARB" */,
        63308 /* "glVertexAttrib3s" */,
        63345 /* "glVertexAttrib3sNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 63325 /* "glVertexAttrib3sARB" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB3SNVPROC
epoxy_glVertexAttrib3sNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        63345 /* "glVertexAttrib3sNV" */,
        63308 /* "glVertexAttrib3s" */,
        63325 /* "glVertexAttrib3sARB" */,
        63325 /* "glVertexAttrib3sARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 63345 /* "glVertexAttrib3sNV" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB3SVPROC
epoxy_glVertexAttrib3sv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        63364 /* "glVertexAttrib3sv" */,
        63382 /* "glVertexAttrib3svARB" */,
        63382 /* "glVertexAttrib3svARB" */,
        63403 /* "glVertexAttrib3svNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 63364 /* "glVertexAttrib3sv" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB3SVARBPROC
epoxy_glVertexAttrib3svARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        63382 /* "glVertexAttrib3svARB" */,
        63382 /* "glVertexAttrib3svARB" */,
        63364 /* "glVertexAttrib3sv" */,
        63403 /* "glVertexAttrib3svNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 63382 /* "glVertexAttrib3svARB" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB3SVNVPROC
epoxy_glVertexAttrib3svNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        63403 /* "glVertexAttrib3svNV" */,
        63364 /* "glVertexAttrib3sv" */,
        63382 /* "glVertexAttrib3svARB" */,
        63382 /* "glVertexAttrib3svARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 63403 /* "glVertexAttrib3svNV" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB4NBVPROC
epoxy_glVertexAttrib4Nbv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        63423 /* "glVertexAttrib4Nbv" */,
        63442 /* "glVertexAttrib4NbvARB" */,
        63442 /* "glVertexAttrib4NbvARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 63423 /* "glVertexAttrib4Nbv" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB4NBVARBPROC
epoxy_glVertexAttrib4NbvARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_Desktop_OpenGL_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        63442 /* "glVertexAttrib4NbvARB" */,
        63442 /* "glVertexAttrib4NbvARB" */,
        63423 /* "glVertexAttrib4Nbv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 63442 /* "glVertexAttrib4NbvARB" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB4NIVPROC
epoxy_glVertexAttrib4Niv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        63464 /* "glVertexAttrib4Niv" */,
        63483 /* "glVertexAttrib4NivARB" */,
        63483 /* "glVertexAttrib4NivARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 63464 /* "glVertexAttrib4Niv" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB4NIVARBPROC
epoxy_glVertexAttrib4NivARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_Desktop_OpenGL_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        63483 /* "glVertexAttrib4NivARB" */,
        63483 /* "glVertexAttrib4NivARB" */,
        63464 /* "glVertexAttrib4Niv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 63483 /* "glVertexAttrib4NivARB" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB4NSVPROC
epoxy_glVertexAttrib4Nsv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        63505 /* "glVertexAttrib4Nsv" */,
        63524 /* "glVertexAttrib4NsvARB" */,
        63524 /* "glVertexAttrib4NsvARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 63505 /* "glVertexAttrib4Nsv" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB4NSVARBPROC
epoxy_glVertexAttrib4NsvARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_Desktop_OpenGL_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        63524 /* "glVertexAttrib4NsvARB" */,
        63524 /* "glVertexAttrib4NsvARB" */,
        63505 /* "glVertexAttrib4Nsv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 63524 /* "glVertexAttrib4NsvARB" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB4NUBPROC
epoxy_glVertexAttrib4Nub_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        63546 /* "glVertexAttrib4Nub" */,
        63565 /* "glVertexAttrib4NubARB" */,
        63565 /* "glVertexAttrib4NubARB" */,
        64178 /* "glVertexAttrib4ubNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 63546 /* "glVertexAttrib4Nub" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB4NUBARBPROC
epoxy_glVertexAttrib4NubARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        63565 /* "glVertexAttrib4NubARB" */,
        63565 /* "glVertexAttrib4NubARB" */,
        63546 /* "glVertexAttrib4Nub" */,
        64178 /* "glVertexAttrib4ubNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 63565 /* "glVertexAttrib4NubARB" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB4NUBVPROC
epoxy_glVertexAttrib4Nubv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        63587 /* "glVertexAttrib4Nubv" */,
        63607 /* "glVertexAttrib4NubvARB" */,
        63607 /* "glVertexAttrib4NubvARB" */,
        64239 /* "glVertexAttrib4ubvNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 63587 /* "glVertexAttrib4Nubv" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB4NUBVARBPROC
epoxy_glVertexAttrib4NubvARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        63607 /* "glVertexAttrib4NubvARB" */,
        63607 /* "glVertexAttrib4NubvARB" */,
        63587 /* "glVertexAttrib4Nubv" */,
        64239 /* "glVertexAttrib4ubvNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 63607 /* "glVertexAttrib4NubvARB" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB4NUIVPROC
epoxy_glVertexAttrib4Nuiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        63630 /* "glVertexAttrib4Nuiv" */,
        63650 /* "glVertexAttrib4NuivARB" */,
        63650 /* "glVertexAttrib4NuivARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 63630 /* "glVertexAttrib4Nuiv" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB4NUIVARBPROC
epoxy_glVertexAttrib4NuivARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_Desktop_OpenGL_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        63650 /* "glVertexAttrib4NuivARB" */,
        63650 /* "glVertexAttrib4NuivARB" */,
        63630 /* "glVertexAttrib4Nuiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 63650 /* "glVertexAttrib4NuivARB" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB4NUSVPROC
epoxy_glVertexAttrib4Nusv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        63673 /* "glVertexAttrib4Nusv" */,
        63693 /* "glVertexAttrib4NusvARB" */,
        63693 /* "glVertexAttrib4NusvARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 63673 /* "glVertexAttrib4Nusv" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB4NUSVARBPROC
epoxy_glVertexAttrib4NusvARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_Desktop_OpenGL_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        63693 /* "glVertexAttrib4NusvARB" */,
        63693 /* "glVertexAttrib4NusvARB" */,
        63673 /* "glVertexAttrib4Nusv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 63693 /* "glVertexAttrib4NusvARB" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB4BVPROC
epoxy_glVertexAttrib4bv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        63716 /* "glVertexAttrib4bv" */,
        63734 /* "glVertexAttrib4bvARB" */,
        63734 /* "glVertexAttrib4bvARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 63716 /* "glVertexAttrib4bv" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB4BVARBPROC
epoxy_glVertexAttrib4bvARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_Desktop_OpenGL_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        63734 /* "glVertexAttrib4bvARB" */,
        63734 /* "glVertexAttrib4bvARB" */,
        63716 /* "glVertexAttrib4bv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 63734 /* "glVertexAttrib4bvARB" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB4DPROC
epoxy_glVertexAttrib4d_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        63755 /* "glVertexAttrib4d" */,
        63772 /* "glVertexAttrib4dARB" */,
        63772 /* "glVertexAttrib4dARB" */,
        63792 /* "glVertexAttrib4dNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 63755 /* "glVertexAttrib4d" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB4DARBPROC
epoxy_glVertexAttrib4dARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        63772 /* "glVertexAttrib4dARB" */,
        63772 /* "glVertexAttrib4dARB" */,
        63755 /* "glVertexAttrib4d" */,
        63792 /* "glVertexAttrib4dNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 63772 /* "glVertexAttrib4dARB" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB4DNVPROC
epoxy_glVertexAttrib4dNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        63792 /* "glVertexAttrib4dNV" */,
        63755 /* "glVertexAttrib4d" */,
        63772 /* "glVertexAttrib4dARB" */,
        63772 /* "glVertexAttrib4dARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 63792 /* "glVertexAttrib4dNV" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB4DVPROC
epoxy_glVertexAttrib4dv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        63811 /* "glVertexAttrib4dv" */,
        63829 /* "glVertexAttrib4dvARB" */,
        63829 /* "glVertexAttrib4dvARB" */,
        63850 /* "glVertexAttrib4dvNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 63811 /* "glVertexAttrib4dv" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB4DVARBPROC
epoxy_glVertexAttrib4dvARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        63829 /* "glVertexAttrib4dvARB" */,
        63829 /* "glVertexAttrib4dvARB" */,
        63811 /* "glVertexAttrib4dv" */,
        63850 /* "glVertexAttrib4dvNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 63829 /* "glVertexAttrib4dvARB" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB4DVNVPROC
epoxy_glVertexAttrib4dvNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        63850 /* "glVertexAttrib4dvNV" */,
        63811 /* "glVertexAttrib4dv" */,
        63829 /* "glVertexAttrib4dvARB" */,
        63829 /* "glVertexAttrib4dvARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 63850 /* "glVertexAttrib4dvNV" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB4FPROC
epoxy_glVertexAttrib4f_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        63870 /* "glVertexAttrib4f" */,
        63870 /* "glVertexAttrib4f" */,
        63887 /* "glVertexAttrib4fARB" */,
        63887 /* "glVertexAttrib4fARB" */,
        63907 /* "glVertexAttrib4fNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 63870 /* "glVertexAttrib4f" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB4FARBPROC
epoxy_glVertexAttrib4fARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        63887 /* "glVertexAttrib4fARB" */,
        63887 /* "glVertexAttrib4fARB" */,
        63870 /* "glVertexAttrib4f" */,
        63870 /* "glVertexAttrib4f" */,
        63907 /* "glVertexAttrib4fNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 63887 /* "glVertexAttrib4fARB" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB4FNVPROC
epoxy_glVertexAttrib4fNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        63907 /* "glVertexAttrib4fNV" */,
        63870 /* "glVertexAttrib4f" */,
        63870 /* "glVertexAttrib4f" */,
        63887 /* "glVertexAttrib4fARB" */,
        63887 /* "glVertexAttrib4fARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 63907 /* "glVertexAttrib4fNV" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB4FVPROC
epoxy_glVertexAttrib4fv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        63926 /* "glVertexAttrib4fv" */,
        63926 /* "glVertexAttrib4fv" */,
        63944 /* "glVertexAttrib4fvARB" */,
        63944 /* "glVertexAttrib4fvARB" */,
        63965 /* "glVertexAttrib4fvNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 63926 /* "glVertexAttrib4fv" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB4FVARBPROC
epoxy_glVertexAttrib4fvARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        63944 /* "glVertexAttrib4fvARB" */,
        63944 /* "glVertexAttrib4fvARB" */,
        63926 /* "glVertexAttrib4fv" */,
        63926 /* "glVertexAttrib4fv" */,
        63965 /* "glVertexAttrib4fvNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 63944 /* "glVertexAttrib4fvARB" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB4FVNVPROC
epoxy_glVertexAttrib4fvNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        63965 /* "glVertexAttrib4fvNV" */,
        63926 /* "glVertexAttrib4fv" */,
        63926 /* "glVertexAttrib4fv" */,
        63944 /* "glVertexAttrib4fvARB" */,
        63944 /* "glVertexAttrib4fvARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 63965 /* "glVertexAttrib4fvNV" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB4HNVPROC
epoxy_glVertexAttrib4hNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_half_float, 63985 /* glVertexAttrib4hNV */);
}

static PFNGLVERTEXATTRIB4HVNVPROC
epoxy_glVertexAttrib4hvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_half_float, 64004 /* glVertexAttrib4hvNV */);
}

static PFNGLVERTEXATTRIB4IVPROC
epoxy_glVertexAttrib4iv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        64024 /* "glVertexAttrib4iv" */,
        64042 /* "glVertexAttrib4ivARB" */,
        64042 /* "glVertexAttrib4ivARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 64024 /* "glVertexAttrib4iv" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB4IVARBPROC
epoxy_glVertexAttrib4ivARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_Desktop_OpenGL_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        64042 /* "glVertexAttrib4ivARB" */,
        64042 /* "glVertexAttrib4ivARB" */,
        64024 /* "glVertexAttrib4iv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 64042 /* "glVertexAttrib4ivARB" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB4SPROC
epoxy_glVertexAttrib4s_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        64063 /* "glVertexAttrib4s" */,
        64080 /* "glVertexAttrib4sARB" */,
        64080 /* "glVertexAttrib4sARB" */,
        64100 /* "glVertexAttrib4sNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 64063 /* "glVertexAttrib4s" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB4SARBPROC
epoxy_glVertexAttrib4sARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        64080 /* "glVertexAttrib4sARB" */,
        64080 /* "glVertexAttrib4sARB" */,
        64063 /* "glVertexAttrib4s" */,
        64100 /* "glVertexAttrib4sNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 64080 /* "glVertexAttrib4sARB" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB4SNVPROC
epoxy_glVertexAttrib4sNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        64100 /* "glVertexAttrib4sNV" */,
        64063 /* "glVertexAttrib4s" */,
        64080 /* "glVertexAttrib4sARB" */,
        64080 /* "glVertexAttrib4sARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 64100 /* "glVertexAttrib4sNV" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB4SVPROC
epoxy_glVertexAttrib4sv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        64119 /* "glVertexAttrib4sv" */,
        64137 /* "glVertexAttrib4svARB" */,
        64137 /* "glVertexAttrib4svARB" */,
        64158 /* "glVertexAttrib4svNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 64119 /* "glVertexAttrib4sv" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB4SVARBPROC
epoxy_glVertexAttrib4svARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_NV_vertex_program,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        64137 /* "glVertexAttrib4svARB" */,
        64137 /* "glVertexAttrib4svARB" */,
        64119 /* "glVertexAttrib4sv" */,
        64158 /* "glVertexAttrib4svNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 64137 /* "glVertexAttrib4svARB" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB4SVNVPROC
epoxy_glVertexAttrib4svNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        64158 /* "glVertexAttrib4svNV" */,
        64119 /* "glVertexAttrib4sv" */,
        64137 /* "glVertexAttrib4svARB" */,
        64137 /* "glVertexAttrib4svARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 64158 /* "glVertexAttrib4svNV" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB4UBNVPROC
epoxy_glVertexAttrib4ubNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        64178 /* "glVertexAttrib4ubNV" */,
        63546 /* "glVertexAttrib4Nub" */,
        63565 /* "glVertexAttrib4NubARB" */,
        63565 /* "glVertexAttrib4NubARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 64178 /* "glVertexAttrib4ubNV" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB4UBVPROC
epoxy_glVertexAttrib4ubv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        64198 /* "glVertexAttrib4ubv" */,
        64217 /* "glVertexAttrib4ubvARB" */,
        64217 /* "glVertexAttrib4ubvARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 64198 /* "glVertexAttrib4ubv" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB4UBVARBPROC
epoxy_glVertexAttrib4ubvARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_Desktop_OpenGL_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        64217 /* "glVertexAttrib4ubvARB" */,
        64217 /* "glVertexAttrib4ubvARB" */,
        64198 /* "glVertexAttrib4ubv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 64217 /* "glVertexAttrib4ubvARB" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB4UBVNVPROC
epoxy_glVertexAttrib4ubvNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        64239 /* "glVertexAttrib4ubvNV" */,
        63587 /* "glVertexAttrib4Nubv" */,
        63607 /* "glVertexAttrib4NubvARB" */,
        63607 /* "glVertexAttrib4NubvARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 64239 /* "glVertexAttrib4ubvNV" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB4UIVPROC
epoxy_glVertexAttrib4uiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        64260 /* "glVertexAttrib4uiv" */,
        64279 /* "glVertexAttrib4uivARB" */,
        64279 /* "glVertexAttrib4uivARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 64260 /* "glVertexAttrib4uiv" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB4UIVARBPROC
epoxy_glVertexAttrib4uivARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_Desktop_OpenGL_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        64279 /* "glVertexAttrib4uivARB" */,
        64279 /* "glVertexAttrib4uivARB" */,
        64260 /* "glVertexAttrib4uiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 64279 /* "glVertexAttrib4uivARB" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB4USVPROC
epoxy_glVertexAttrib4usv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        64301 /* "glVertexAttrib4usv" */,
        64320 /* "glVertexAttrib4usvARB" */,
        64320 /* "glVertexAttrib4usvARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 64301 /* "glVertexAttrib4usv" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIB4USVARBPROC
epoxy_glVertexAttrib4usvARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_Desktop_OpenGL_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        64320 /* "glVertexAttrib4usvARB" */,
        64320 /* "glVertexAttrib4usvARB" */,
        64301 /* "glVertexAttrib4usv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 64320 /* "glVertexAttrib4usvARB" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBARRAYOBJECTATIPROC
epoxy_glVertexAttribArrayObjectATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_attrib_array_object, 64342 /* glVertexAttribArrayObjectATI */);
}

static PFNGLVERTEXATTRIBBINDINGPROC
epoxy_glVertexAttribBinding_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_ARB_vertex_attrib_binding,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        64371 /* "glVertexAttribBinding" */,
        64371 /* "glVertexAttribBinding" */,
        64371 /* "glVertexAttribBinding" */,
    };
    return gl_provider_resolver(entrypoint_strings + 64371 /* "glVertexAttribBinding" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBDIVISORPROC
epoxy_glVertexAttribDivisor_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_ANGLE_instanced_arrays,
        PROVIDER_GL_ARB_instanced_arrays,
        PROVIDER_GL_EXT_instanced_arrays,
        PROVIDER_GL_NV_instanced_arrays,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        64393 /* "glVertexAttribDivisor" */,
        64393 /* "glVertexAttribDivisor" */,
        64415 /* "glVertexAttribDivisorANGLE" */,
        64442 /* "glVertexAttribDivisorARB" */,
        64467 /* "glVertexAttribDivisorEXT" */,
        64492 /* "glVertexAttribDivisorNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 64393 /* "glVertexAttribDivisor" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBDIVISORANGLEPROC
epoxy_glVertexAttribDivisorANGLE_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ANGLE_instanced_arrays,
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_ARB_instanced_arrays,
        PROVIDER_GL_EXT_instanced_arrays,
        PROVIDER_GL_NV_instanced_arrays,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        64415 /* "glVertexAttribDivisorANGLE" */,
        64393 /* "glVertexAttribDivisor" */,
        64393 /* "glVertexAttribDivisor" */,
        64442 /* "glVertexAttribDivisorARB" */,
        64467 /* "glVertexAttribDivisorEXT" */,
        64492 /* "glVertexAttribDivisorNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 64415 /* "glVertexAttribDivisorANGLE" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBDIVISORARBPROC
epoxy_glVertexAttribDivisorARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_instanced_arrays,
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_ANGLE_instanced_arrays,
        PROVIDER_GL_EXT_instanced_arrays,
        PROVIDER_GL_NV_instanced_arrays,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        64442 /* "glVertexAttribDivisorARB" */,
        64393 /* "glVertexAttribDivisor" */,
        64393 /* "glVertexAttribDivisor" */,
        64415 /* "glVertexAttribDivisorANGLE" */,
        64467 /* "glVertexAttribDivisorEXT" */,
        64492 /* "glVertexAttribDivisorNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 64442 /* "glVertexAttribDivisorARB" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBDIVISOREXTPROC
epoxy_glVertexAttribDivisorEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_instanced_arrays,
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_ANGLE_instanced_arrays,
        PROVIDER_GL_ARB_instanced_arrays,
        PROVIDER_GL_NV_instanced_arrays,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        64467 /* "glVertexAttribDivisorEXT" */,
        64393 /* "glVertexAttribDivisor" */,
        64393 /* "glVertexAttribDivisor" */,
        64415 /* "glVertexAttribDivisorANGLE" */,
        64442 /* "glVertexAttribDivisorARB" */,
        64492 /* "glVertexAttribDivisorNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 64467 /* "glVertexAttribDivisorEXT" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBDIVISORNVPROC
epoxy_glVertexAttribDivisorNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_instanced_arrays,
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_ANGLE_instanced_arrays,
        PROVIDER_GL_ARB_instanced_arrays,
        PROVIDER_GL_EXT_instanced_arrays,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        64492 /* "glVertexAttribDivisorNV" */,
        64393 /* "glVertexAttribDivisor" */,
        64393 /* "glVertexAttribDivisor" */,
        64415 /* "glVertexAttribDivisorANGLE" */,
        64442 /* "glVertexAttribDivisorARB" */,
        64467 /* "glVertexAttribDivisorEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 64492 /* "glVertexAttribDivisorNV" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBFORMATPROC
epoxy_glVertexAttribFormat_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_ARB_vertex_attrib_binding,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        64516 /* "glVertexAttribFormat" */,
        64516 /* "glVertexAttribFormat" */,
        64516 /* "glVertexAttribFormat" */,
    };
    return gl_provider_resolver(entrypoint_strings + 64516 /* "glVertexAttribFormat" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBFORMATNVPROC
epoxy_glVertexAttribFormatNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_buffer_unified_memory, 64537 /* glVertexAttribFormatNV */);
}

static PFNGLVERTEXATTRIBI1IPROC
epoxy_glVertexAttribI1i_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_NV_vertex_program4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        64560 /* "glVertexAttribI1i" */,
        64578 /* "glVertexAttribI1iEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 64560 /* "glVertexAttribI1i" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBI1IEXTPROC
epoxy_glVertexAttribI1iEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program4,
        PROVIDER_Desktop_OpenGL_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        64578 /* "glVertexAttribI1iEXT" */,
        64560 /* "glVertexAttribI1i" */,
    };
    return gl_provider_resolver(entrypoint_strings + 64578 /* "glVertexAttribI1iEXT" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBI1IVPROC
epoxy_glVertexAttribI1iv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_NV_vertex_program4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        64599 /* "glVertexAttribI1iv" */,
        64618 /* "glVertexAttribI1ivEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 64599 /* "glVertexAttribI1iv" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBI1IVEXTPROC
epoxy_glVertexAttribI1ivEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program4,
        PROVIDER_Desktop_OpenGL_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        64618 /* "glVertexAttribI1ivEXT" */,
        64599 /* "glVertexAttribI1iv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 64618 /* "glVertexAttribI1ivEXT" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBI1UIPROC
epoxy_glVertexAttribI1ui_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_NV_vertex_program4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        64640 /* "glVertexAttribI1ui" */,
        64659 /* "glVertexAttribI1uiEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 64640 /* "glVertexAttribI1ui" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBI1UIEXTPROC
epoxy_glVertexAttribI1uiEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program4,
        PROVIDER_Desktop_OpenGL_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        64659 /* "glVertexAttribI1uiEXT" */,
        64640 /* "glVertexAttribI1ui" */,
    };
    return gl_provider_resolver(entrypoint_strings + 64659 /* "glVertexAttribI1uiEXT" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBI1UIVPROC
epoxy_glVertexAttribI1uiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_NV_vertex_program4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        64681 /* "glVertexAttribI1uiv" */,
        64701 /* "glVertexAttribI1uivEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 64681 /* "glVertexAttribI1uiv" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBI1UIVEXTPROC
epoxy_glVertexAttribI1uivEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program4,
        PROVIDER_Desktop_OpenGL_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        64701 /* "glVertexAttribI1uivEXT" */,
        64681 /* "glVertexAttribI1uiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 64701 /* "glVertexAttribI1uivEXT" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBI2IPROC
epoxy_glVertexAttribI2i_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_NV_vertex_program4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        64724 /* "glVertexAttribI2i" */,
        64742 /* "glVertexAttribI2iEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 64724 /* "glVertexAttribI2i" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBI2IEXTPROC
epoxy_glVertexAttribI2iEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program4,
        PROVIDER_Desktop_OpenGL_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        64742 /* "glVertexAttribI2iEXT" */,
        64724 /* "glVertexAttribI2i" */,
    };
    return gl_provider_resolver(entrypoint_strings + 64742 /* "glVertexAttribI2iEXT" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBI2IVPROC
epoxy_glVertexAttribI2iv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_NV_vertex_program4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        64763 /* "glVertexAttribI2iv" */,
        64782 /* "glVertexAttribI2ivEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 64763 /* "glVertexAttribI2iv" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBI2IVEXTPROC
epoxy_glVertexAttribI2ivEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program4,
        PROVIDER_Desktop_OpenGL_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        64782 /* "glVertexAttribI2ivEXT" */,
        64763 /* "glVertexAttribI2iv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 64782 /* "glVertexAttribI2ivEXT" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBI2UIPROC
epoxy_glVertexAttribI2ui_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_NV_vertex_program4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        64804 /* "glVertexAttribI2ui" */,
        64823 /* "glVertexAttribI2uiEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 64804 /* "glVertexAttribI2ui" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBI2UIEXTPROC
epoxy_glVertexAttribI2uiEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program4,
        PROVIDER_Desktop_OpenGL_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        64823 /* "glVertexAttribI2uiEXT" */,
        64804 /* "glVertexAttribI2ui" */,
    };
    return gl_provider_resolver(entrypoint_strings + 64823 /* "glVertexAttribI2uiEXT" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBI2UIVPROC
epoxy_glVertexAttribI2uiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_NV_vertex_program4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        64845 /* "glVertexAttribI2uiv" */,
        64865 /* "glVertexAttribI2uivEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 64845 /* "glVertexAttribI2uiv" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBI2UIVEXTPROC
epoxy_glVertexAttribI2uivEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program4,
        PROVIDER_Desktop_OpenGL_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        64865 /* "glVertexAttribI2uivEXT" */,
        64845 /* "glVertexAttribI2uiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 64865 /* "glVertexAttribI2uivEXT" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBI3IPROC
epoxy_glVertexAttribI3i_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_NV_vertex_program4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        64888 /* "glVertexAttribI3i" */,
        64906 /* "glVertexAttribI3iEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 64888 /* "glVertexAttribI3i" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBI3IEXTPROC
epoxy_glVertexAttribI3iEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program4,
        PROVIDER_Desktop_OpenGL_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        64906 /* "glVertexAttribI3iEXT" */,
        64888 /* "glVertexAttribI3i" */,
    };
    return gl_provider_resolver(entrypoint_strings + 64906 /* "glVertexAttribI3iEXT" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBI3IVPROC
epoxy_glVertexAttribI3iv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_NV_vertex_program4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        64927 /* "glVertexAttribI3iv" */,
        64946 /* "glVertexAttribI3ivEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 64927 /* "glVertexAttribI3iv" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBI3IVEXTPROC
epoxy_glVertexAttribI3ivEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program4,
        PROVIDER_Desktop_OpenGL_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        64946 /* "glVertexAttribI3ivEXT" */,
        64927 /* "glVertexAttribI3iv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 64946 /* "glVertexAttribI3ivEXT" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBI3UIPROC
epoxy_glVertexAttribI3ui_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_NV_vertex_program4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        64968 /* "glVertexAttribI3ui" */,
        64987 /* "glVertexAttribI3uiEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 64968 /* "glVertexAttribI3ui" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBI3UIEXTPROC
epoxy_glVertexAttribI3uiEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program4,
        PROVIDER_Desktop_OpenGL_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        64987 /* "glVertexAttribI3uiEXT" */,
        64968 /* "glVertexAttribI3ui" */,
    };
    return gl_provider_resolver(entrypoint_strings + 64987 /* "glVertexAttribI3uiEXT" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBI3UIVPROC
epoxy_glVertexAttribI3uiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_NV_vertex_program4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        65009 /* "glVertexAttribI3uiv" */,
        65029 /* "glVertexAttribI3uivEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 65009 /* "glVertexAttribI3uiv" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBI3UIVEXTPROC
epoxy_glVertexAttribI3uivEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program4,
        PROVIDER_Desktop_OpenGL_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        65029 /* "glVertexAttribI3uivEXT" */,
        65009 /* "glVertexAttribI3uiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 65029 /* "glVertexAttribI3uivEXT" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBI4BVPROC
epoxy_glVertexAttribI4bv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_NV_vertex_program4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        65052 /* "glVertexAttribI4bv" */,
        65071 /* "glVertexAttribI4bvEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 65052 /* "glVertexAttribI4bv" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBI4BVEXTPROC
epoxy_glVertexAttribI4bvEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program4,
        PROVIDER_Desktop_OpenGL_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        65071 /* "glVertexAttribI4bvEXT" */,
        65052 /* "glVertexAttribI4bv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 65071 /* "glVertexAttribI4bvEXT" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBI4IPROC
epoxy_glVertexAttribI4i_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_NV_vertex_program4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        65093 /* "glVertexAttribI4i" */,
        65093 /* "glVertexAttribI4i" */,
        65111 /* "glVertexAttribI4iEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 65093 /* "glVertexAttribI4i" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBI4IEXTPROC
epoxy_glVertexAttribI4iEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program4,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        65111 /* "glVertexAttribI4iEXT" */,
        65093 /* "glVertexAttribI4i" */,
        65093 /* "glVertexAttribI4i" */,
    };
    return gl_provider_resolver(entrypoint_strings + 65111 /* "glVertexAttribI4iEXT" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBI4IVPROC
epoxy_glVertexAttribI4iv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_NV_vertex_program4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        65132 /* "glVertexAttribI4iv" */,
        65132 /* "glVertexAttribI4iv" */,
        65151 /* "glVertexAttribI4ivEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 65132 /* "glVertexAttribI4iv" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBI4IVEXTPROC
epoxy_glVertexAttribI4ivEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program4,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        65151 /* "glVertexAttribI4ivEXT" */,
        65132 /* "glVertexAttribI4iv" */,
        65132 /* "glVertexAttribI4iv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 65151 /* "glVertexAttribI4ivEXT" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBI4SVPROC
epoxy_glVertexAttribI4sv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_NV_vertex_program4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        65173 /* "glVertexAttribI4sv" */,
        65192 /* "glVertexAttribI4svEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 65173 /* "glVertexAttribI4sv" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBI4SVEXTPROC
epoxy_glVertexAttribI4svEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program4,
        PROVIDER_Desktop_OpenGL_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        65192 /* "glVertexAttribI4svEXT" */,
        65173 /* "glVertexAttribI4sv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 65192 /* "glVertexAttribI4svEXT" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBI4UBVPROC
epoxy_glVertexAttribI4ubv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_NV_vertex_program4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        65214 /* "glVertexAttribI4ubv" */,
        65234 /* "glVertexAttribI4ubvEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 65214 /* "glVertexAttribI4ubv" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBI4UBVEXTPROC
epoxy_glVertexAttribI4ubvEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program4,
        PROVIDER_Desktop_OpenGL_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        65234 /* "glVertexAttribI4ubvEXT" */,
        65214 /* "glVertexAttribI4ubv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 65234 /* "glVertexAttribI4ubvEXT" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBI4UIPROC
epoxy_glVertexAttribI4ui_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_NV_vertex_program4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        65257 /* "glVertexAttribI4ui" */,
        65257 /* "glVertexAttribI4ui" */,
        65276 /* "glVertexAttribI4uiEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 65257 /* "glVertexAttribI4ui" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBI4UIEXTPROC
epoxy_glVertexAttribI4uiEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program4,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        65276 /* "glVertexAttribI4uiEXT" */,
        65257 /* "glVertexAttribI4ui" */,
        65257 /* "glVertexAttribI4ui" */,
    };
    return gl_provider_resolver(entrypoint_strings + 65276 /* "glVertexAttribI4uiEXT" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBI4UIVPROC
epoxy_glVertexAttribI4uiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_NV_vertex_program4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        65298 /* "glVertexAttribI4uiv" */,
        65298 /* "glVertexAttribI4uiv" */,
        65318 /* "glVertexAttribI4uivEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 65298 /* "glVertexAttribI4uiv" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBI4UIVEXTPROC
epoxy_glVertexAttribI4uivEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program4,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        65318 /* "glVertexAttribI4uivEXT" */,
        65298 /* "glVertexAttribI4uiv" */,
        65298 /* "glVertexAttribI4uiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 65318 /* "glVertexAttribI4uivEXT" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBI4USVPROC
epoxy_glVertexAttribI4usv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_GL_NV_vertex_program4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        65341 /* "glVertexAttribI4usv" */,
        65361 /* "glVertexAttribI4usvEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 65341 /* "glVertexAttribI4usv" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBI4USVEXTPROC
epoxy_glVertexAttribI4usvEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program4,
        PROVIDER_Desktop_OpenGL_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        65361 /* "glVertexAttribI4usvEXT" */,
        65341 /* "glVertexAttribI4usv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 65361 /* "glVertexAttribI4usvEXT" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBIFORMATPROC
epoxy_glVertexAttribIFormat_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_ARB_vertex_attrib_binding,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        65384 /* "glVertexAttribIFormat" */,
        65384 /* "glVertexAttribIFormat" */,
        65384 /* "glVertexAttribIFormat" */,
    };
    return gl_provider_resolver(entrypoint_strings + 65384 /* "glVertexAttribIFormat" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBIFORMATNVPROC
epoxy_glVertexAttribIFormatNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_buffer_unified_memory, 65406 /* glVertexAttribIFormatNV */);
}

static PFNGLVERTEXATTRIBIPOINTERPROC
epoxy_glVertexAttribIPointer_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_NV_vertex_program4,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        65430 /* "glVertexAttribIPointer" */,
        65430 /* "glVertexAttribIPointer" */,
        65453 /* "glVertexAttribIPointerEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 65430 /* "glVertexAttribIPointer" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBIPOINTEREXTPROC
epoxy_glVertexAttribIPointerEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_vertex_program4,
        PROVIDER_Desktop_OpenGL_3_0,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        65453 /* "glVertexAttribIPointerEXT" */,
        65430 /* "glVertexAttribIPointer" */,
        65430 /* "glVertexAttribIPointer" */,
    };
    return gl_provider_resolver(entrypoint_strings + 65453 /* "glVertexAttribIPointerEXT" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBL1DPROC
epoxy_glVertexAttribL1d_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_vertex_attrib_64bit,
        PROVIDER_GL_EXT_vertex_attrib_64bit,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        65479 /* "glVertexAttribL1d" */,
        65479 /* "glVertexAttribL1d" */,
        65497 /* "glVertexAttribL1dEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 65479 /* "glVertexAttribL1d" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBL1DEXTPROC
epoxy_glVertexAttribL1dEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_vertex_attrib_64bit,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_vertex_attrib_64bit,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        65497 /* "glVertexAttribL1dEXT" */,
        65479 /* "glVertexAttribL1d" */,
        65479 /* "glVertexAttribL1d" */,
    };
    return gl_provider_resolver(entrypoint_strings + 65497 /* "glVertexAttribL1dEXT" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBL1DVPROC
epoxy_glVertexAttribL1dv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_vertex_attrib_64bit,
        PROVIDER_GL_EXT_vertex_attrib_64bit,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        65518 /* "glVertexAttribL1dv" */,
        65518 /* "glVertexAttribL1dv" */,
        65537 /* "glVertexAttribL1dvEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 65518 /* "glVertexAttribL1dv" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBL1DVEXTPROC
epoxy_glVertexAttribL1dvEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_vertex_attrib_64bit,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_vertex_attrib_64bit,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        65537 /* "glVertexAttribL1dvEXT" */,
        65518 /* "glVertexAttribL1dv" */,
        65518 /* "glVertexAttribL1dv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 65537 /* "glVertexAttribL1dvEXT" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBL1I64NVPROC
epoxy_glVertexAttribL1i64NV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_attrib_integer_64bit, 65559 /* glVertexAttribL1i64NV */);
}

static PFNGLVERTEXATTRIBL1I64VNVPROC
epoxy_glVertexAttribL1i64vNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_attrib_integer_64bit, 65581 /* glVertexAttribL1i64vNV */);
}

static PFNGLVERTEXATTRIBL1UI64ARBPROC
epoxy_glVertexAttribL1ui64ARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_bindless_texture, 65604 /* glVertexAttribL1ui64ARB */);
}

static PFNGLVERTEXATTRIBL1UI64NVPROC
epoxy_glVertexAttribL1ui64NV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_attrib_integer_64bit, 65628 /* glVertexAttribL1ui64NV */);
}

static PFNGLVERTEXATTRIBL1UI64VARBPROC
epoxy_glVertexAttribL1ui64vARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_bindless_texture, 65651 /* glVertexAttribL1ui64vARB */);
}

static PFNGLVERTEXATTRIBL1UI64VNVPROC
epoxy_glVertexAttribL1ui64vNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_attrib_integer_64bit, 65676 /* glVertexAttribL1ui64vNV */);
}

static PFNGLVERTEXATTRIBL2DPROC
epoxy_glVertexAttribL2d_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_vertex_attrib_64bit,
        PROVIDER_GL_EXT_vertex_attrib_64bit,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        65700 /* "glVertexAttribL2d" */,
        65700 /* "glVertexAttribL2d" */,
        65718 /* "glVertexAttribL2dEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 65700 /* "glVertexAttribL2d" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBL2DEXTPROC
epoxy_glVertexAttribL2dEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_vertex_attrib_64bit,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_vertex_attrib_64bit,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        65718 /* "glVertexAttribL2dEXT" */,
        65700 /* "glVertexAttribL2d" */,
        65700 /* "glVertexAttribL2d" */,
    };
    return gl_provider_resolver(entrypoint_strings + 65718 /* "glVertexAttribL2dEXT" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBL2DVPROC
epoxy_glVertexAttribL2dv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_vertex_attrib_64bit,
        PROVIDER_GL_EXT_vertex_attrib_64bit,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        65739 /* "glVertexAttribL2dv" */,
        65739 /* "glVertexAttribL2dv" */,
        65758 /* "glVertexAttribL2dvEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 65739 /* "glVertexAttribL2dv" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBL2DVEXTPROC
epoxy_glVertexAttribL2dvEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_vertex_attrib_64bit,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_vertex_attrib_64bit,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        65758 /* "glVertexAttribL2dvEXT" */,
        65739 /* "glVertexAttribL2dv" */,
        65739 /* "glVertexAttribL2dv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 65758 /* "glVertexAttribL2dvEXT" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBL2I64NVPROC
epoxy_glVertexAttribL2i64NV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_attrib_integer_64bit, 65780 /* glVertexAttribL2i64NV */);
}

static PFNGLVERTEXATTRIBL2I64VNVPROC
epoxy_glVertexAttribL2i64vNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_attrib_integer_64bit, 65802 /* glVertexAttribL2i64vNV */);
}

static PFNGLVERTEXATTRIBL2UI64NVPROC
epoxy_glVertexAttribL2ui64NV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_attrib_integer_64bit, 65825 /* glVertexAttribL2ui64NV */);
}

static PFNGLVERTEXATTRIBL2UI64VNVPROC
epoxy_glVertexAttribL2ui64vNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_attrib_integer_64bit, 65848 /* glVertexAttribL2ui64vNV */);
}

static PFNGLVERTEXATTRIBL3DPROC
epoxy_glVertexAttribL3d_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_vertex_attrib_64bit,
        PROVIDER_GL_EXT_vertex_attrib_64bit,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        65872 /* "glVertexAttribL3d" */,
        65872 /* "glVertexAttribL3d" */,
        65890 /* "glVertexAttribL3dEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 65872 /* "glVertexAttribL3d" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBL3DEXTPROC
epoxy_glVertexAttribL3dEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_vertex_attrib_64bit,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_vertex_attrib_64bit,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        65890 /* "glVertexAttribL3dEXT" */,
        65872 /* "glVertexAttribL3d" */,
        65872 /* "glVertexAttribL3d" */,
    };
    return gl_provider_resolver(entrypoint_strings + 65890 /* "glVertexAttribL3dEXT" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBL3DVPROC
epoxy_glVertexAttribL3dv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_vertex_attrib_64bit,
        PROVIDER_GL_EXT_vertex_attrib_64bit,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        65911 /* "glVertexAttribL3dv" */,
        65911 /* "glVertexAttribL3dv" */,
        65930 /* "glVertexAttribL3dvEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 65911 /* "glVertexAttribL3dv" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBL3DVEXTPROC
epoxy_glVertexAttribL3dvEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_vertex_attrib_64bit,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_vertex_attrib_64bit,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        65930 /* "glVertexAttribL3dvEXT" */,
        65911 /* "glVertexAttribL3dv" */,
        65911 /* "glVertexAttribL3dv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 65930 /* "glVertexAttribL3dvEXT" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBL3I64NVPROC
epoxy_glVertexAttribL3i64NV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_attrib_integer_64bit, 65952 /* glVertexAttribL3i64NV */);
}

static PFNGLVERTEXATTRIBL3I64VNVPROC
epoxy_glVertexAttribL3i64vNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_attrib_integer_64bit, 65974 /* glVertexAttribL3i64vNV */);
}

static PFNGLVERTEXATTRIBL3UI64NVPROC
epoxy_glVertexAttribL3ui64NV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_attrib_integer_64bit, 65997 /* glVertexAttribL3ui64NV */);
}

static PFNGLVERTEXATTRIBL3UI64VNVPROC
epoxy_glVertexAttribL3ui64vNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_attrib_integer_64bit, 66020 /* glVertexAttribL3ui64vNV */);
}

static PFNGLVERTEXATTRIBL4DPROC
epoxy_glVertexAttribL4d_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_vertex_attrib_64bit,
        PROVIDER_GL_EXT_vertex_attrib_64bit,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        66044 /* "glVertexAttribL4d" */,
        66044 /* "glVertexAttribL4d" */,
        66062 /* "glVertexAttribL4dEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 66044 /* "glVertexAttribL4d" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBL4DEXTPROC
epoxy_glVertexAttribL4dEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_vertex_attrib_64bit,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_vertex_attrib_64bit,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        66062 /* "glVertexAttribL4dEXT" */,
        66044 /* "glVertexAttribL4d" */,
        66044 /* "glVertexAttribL4d" */,
    };
    return gl_provider_resolver(entrypoint_strings + 66062 /* "glVertexAttribL4dEXT" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBL4DVPROC
epoxy_glVertexAttribL4dv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_vertex_attrib_64bit,
        PROVIDER_GL_EXT_vertex_attrib_64bit,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        66083 /* "glVertexAttribL4dv" */,
        66083 /* "glVertexAttribL4dv" */,
        66102 /* "glVertexAttribL4dvEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 66083 /* "glVertexAttribL4dv" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBL4DVEXTPROC
epoxy_glVertexAttribL4dvEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_vertex_attrib_64bit,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_vertex_attrib_64bit,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        66102 /* "glVertexAttribL4dvEXT" */,
        66083 /* "glVertexAttribL4dv" */,
        66083 /* "glVertexAttribL4dv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 66102 /* "glVertexAttribL4dvEXT" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBL4I64NVPROC
epoxy_glVertexAttribL4i64NV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_attrib_integer_64bit, 66124 /* glVertexAttribL4i64NV */);
}

static PFNGLVERTEXATTRIBL4I64VNVPROC
epoxy_glVertexAttribL4i64vNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_attrib_integer_64bit, 66146 /* glVertexAttribL4i64vNV */);
}

static PFNGLVERTEXATTRIBL4UI64NVPROC
epoxy_glVertexAttribL4ui64NV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_attrib_integer_64bit, 66169 /* glVertexAttribL4ui64NV */);
}

static PFNGLVERTEXATTRIBL4UI64VNVPROC
epoxy_glVertexAttribL4ui64vNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_attrib_integer_64bit, 66192 /* glVertexAttribL4ui64vNV */);
}

static PFNGLVERTEXATTRIBLFORMATPROC
epoxy_glVertexAttribLFormat_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_ARB_vertex_attrib_binding,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        66216 /* "glVertexAttribLFormat" */,
        66216 /* "glVertexAttribLFormat" */,
    };
    return gl_provider_resolver(entrypoint_strings + 66216 /* "glVertexAttribLFormat" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBLFORMATNVPROC
epoxy_glVertexAttribLFormatNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_attrib_integer_64bit, 66238 /* glVertexAttribLFormatNV */);
}

static PFNGLVERTEXATTRIBLPOINTERPROC
epoxy_glVertexAttribLPointer_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_vertex_attrib_64bit,
        PROVIDER_GL_EXT_vertex_attrib_64bit,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        66262 /* "glVertexAttribLPointer" */,
        66262 /* "glVertexAttribLPointer" */,
        66285 /* "glVertexAttribLPointerEXT" */,
    };
    return gl_provider_resolver(entrypoint_strings + 66262 /* "glVertexAttribLPointer" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBLPOINTEREXTPROC
epoxy_glVertexAttribLPointerEXT_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_EXT_vertex_attrib_64bit,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_vertex_attrib_64bit,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        66285 /* "glVertexAttribLPointerEXT" */,
        66262 /* "glVertexAttribLPointer" */,
        66262 /* "glVertexAttribLPointer" */,
    };
    return gl_provider_resolver(entrypoint_strings + 66285 /* "glVertexAttribLPointerEXT" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBP1UIPROC
epoxy_glVertexAttribP1ui_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_vertex_type_2_10_10_10_rev,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        66311 /* "glVertexAttribP1ui" */,
        66311 /* "glVertexAttribP1ui" */,
    };
    return gl_provider_resolver(entrypoint_strings + 66311 /* "glVertexAttribP1ui" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBP1UIVPROC
epoxy_glVertexAttribP1uiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_vertex_type_2_10_10_10_rev,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        66330 /* "glVertexAttribP1uiv" */,
        66330 /* "glVertexAttribP1uiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 66330 /* "glVertexAttribP1uiv" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBP2UIPROC
epoxy_glVertexAttribP2ui_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_vertex_type_2_10_10_10_rev,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        66350 /* "glVertexAttribP2ui" */,
        66350 /* "glVertexAttribP2ui" */,
    };
    return gl_provider_resolver(entrypoint_strings + 66350 /* "glVertexAttribP2ui" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBP2UIVPROC
epoxy_glVertexAttribP2uiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_vertex_type_2_10_10_10_rev,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        66369 /* "glVertexAttribP2uiv" */,
        66369 /* "glVertexAttribP2uiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 66369 /* "glVertexAttribP2uiv" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBP3UIPROC
epoxy_glVertexAttribP3ui_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_vertex_type_2_10_10_10_rev,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        66389 /* "glVertexAttribP3ui" */,
        66389 /* "glVertexAttribP3ui" */,
    };
    return gl_provider_resolver(entrypoint_strings + 66389 /* "glVertexAttribP3ui" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBP3UIVPROC
epoxy_glVertexAttribP3uiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_vertex_type_2_10_10_10_rev,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        66408 /* "glVertexAttribP3uiv" */,
        66408 /* "glVertexAttribP3uiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 66408 /* "glVertexAttribP3uiv" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBP4UIPROC
epoxy_glVertexAttribP4ui_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_vertex_type_2_10_10_10_rev,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        66428 /* "glVertexAttribP4ui" */,
        66428 /* "glVertexAttribP4ui" */,
    };
    return gl_provider_resolver(entrypoint_strings + 66428 /* "glVertexAttribP4ui" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBP4UIVPROC
epoxy_glVertexAttribP4uiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_vertex_type_2_10_10_10_rev,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        66447 /* "glVertexAttribP4uiv" */,
        66447 /* "glVertexAttribP4uiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 66447 /* "glVertexAttribP4uiv" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBPARAMETERIAMDPROC
epoxy_glVertexAttribParameteriAMD_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_AMD_interleaved_elements, 66467 /* glVertexAttribParameteriAMD */);
}

static PFNGLVERTEXATTRIBPOINTERPROC
epoxy_glVertexAttribPointer_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        66495 /* "glVertexAttribPointer" */,
        66495 /* "glVertexAttribPointer" */,
        66517 /* "glVertexAttribPointerARB" */,
        66517 /* "glVertexAttribPointerARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 66495 /* "glVertexAttribPointer" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBPOINTERARBPROC
epoxy_glVertexAttribPointerARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_vertex_program,
        PROVIDER_GL_ARB_vertex_shader,
        PROVIDER_Desktop_OpenGL_2_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        66517 /* "glVertexAttribPointerARB" */,
        66517 /* "glVertexAttribPointerARB" */,
        66495 /* "glVertexAttribPointer" */,
        66495 /* "glVertexAttribPointer" */,
    };
    return gl_provider_resolver(entrypoint_strings + 66517 /* "glVertexAttribPointerARB" */,
                                providers, entrypoints);
}

static PFNGLVERTEXATTRIBPOINTERNVPROC
epoxy_glVertexAttribPointerNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_program, 66542 /* glVertexAttribPointerNV */);
}

static PFNGLVERTEXATTRIBS1DVNVPROC
epoxy_glVertexAttribs1dvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_program, 66566 /* glVertexAttribs1dvNV */);
}

static PFNGLVERTEXATTRIBS1FVNVPROC
epoxy_glVertexAttribs1fvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_program, 66587 /* glVertexAttribs1fvNV */);
}

static PFNGLVERTEXATTRIBS1HVNVPROC
epoxy_glVertexAttribs1hvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_half_float, 66608 /* glVertexAttribs1hvNV */);
}

static PFNGLVERTEXATTRIBS1SVNVPROC
epoxy_glVertexAttribs1svNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_program, 66629 /* glVertexAttribs1svNV */);
}

static PFNGLVERTEXATTRIBS2DVNVPROC
epoxy_glVertexAttribs2dvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_program, 66650 /* glVertexAttribs2dvNV */);
}

static PFNGLVERTEXATTRIBS2FVNVPROC
epoxy_glVertexAttribs2fvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_program, 66671 /* glVertexAttribs2fvNV */);
}

static PFNGLVERTEXATTRIBS2HVNVPROC
epoxy_glVertexAttribs2hvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_half_float, 66692 /* glVertexAttribs2hvNV */);
}

static PFNGLVERTEXATTRIBS2SVNVPROC
epoxy_glVertexAttribs2svNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_program, 66713 /* glVertexAttribs2svNV */);
}

static PFNGLVERTEXATTRIBS3DVNVPROC
epoxy_glVertexAttribs3dvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_program, 66734 /* glVertexAttribs3dvNV */);
}

static PFNGLVERTEXATTRIBS3FVNVPROC
epoxy_glVertexAttribs3fvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_program, 66755 /* glVertexAttribs3fvNV */);
}

static PFNGLVERTEXATTRIBS3HVNVPROC
epoxy_glVertexAttribs3hvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_half_float, 66776 /* glVertexAttribs3hvNV */);
}

static PFNGLVERTEXATTRIBS3SVNVPROC
epoxy_glVertexAttribs3svNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_program, 66797 /* glVertexAttribs3svNV */);
}

static PFNGLVERTEXATTRIBS4DVNVPROC
epoxy_glVertexAttribs4dvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_program, 66818 /* glVertexAttribs4dvNV */);
}

static PFNGLVERTEXATTRIBS4FVNVPROC
epoxy_glVertexAttribs4fvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_program, 66839 /* glVertexAttribs4fvNV */);
}

static PFNGLVERTEXATTRIBS4HVNVPROC
epoxy_glVertexAttribs4hvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_half_float, 66860 /* glVertexAttribs4hvNV */);
}

static PFNGLVERTEXATTRIBS4SVNVPROC
epoxy_glVertexAttribs4svNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_program, 66881 /* glVertexAttribs4svNV */);
}

static PFNGLVERTEXATTRIBS4UBVNVPROC
epoxy_glVertexAttribs4ubvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_program, 66902 /* glVertexAttribs4ubvNV */);
}

static PFNGLVERTEXBINDINGDIVISORPROC
epoxy_glVertexBindingDivisor_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_3,
        PROVIDER_GL_ARB_vertex_attrib_binding,
        PROVIDER_OpenGL_ES_3_1,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        66924 /* "glVertexBindingDivisor" */,
        66924 /* "glVertexBindingDivisor" */,
        66924 /* "glVertexBindingDivisor" */,
    };
    return gl_provider_resolver(entrypoint_strings + 66924 /* "glVertexBindingDivisor" */,
                                providers, entrypoints);
}

static PFNGLVERTEXBLENDARBPROC
epoxy_glVertexBlendARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_vertex_blend, 66947 /* glVertexBlendARB */);
}

static PFNGLVERTEXBLENDENVFATIPROC
epoxy_glVertexBlendEnvfATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_streams, 66964 /* glVertexBlendEnvfATI */);
}

static PFNGLVERTEXBLENDENVIATIPROC
epoxy_glVertexBlendEnviATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_streams, 66985 /* glVertexBlendEnviATI */);
}

static PFNGLVERTEXFORMATNVPROC
epoxy_glVertexFormatNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_vertex_buffer_unified_memory, 67006 /* glVertexFormatNV */);
}

static PFNGLVERTEXP2UIPROC
epoxy_glVertexP2ui_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_vertex_type_2_10_10_10_rev,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        67023 /* "glVertexP2ui" */,
        67023 /* "glVertexP2ui" */,
    };
    return gl_provider_resolver(entrypoint_strings + 67023 /* "glVertexP2ui" */,
                                providers, entrypoints);
}

static PFNGLVERTEXP2UIVPROC
epoxy_glVertexP2uiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_vertex_type_2_10_10_10_rev,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        67036 /* "glVertexP2uiv" */,
        67036 /* "glVertexP2uiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 67036 /* "glVertexP2uiv" */,
                                providers, entrypoints);
}

static PFNGLVERTEXP3UIPROC
epoxy_glVertexP3ui_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_vertex_type_2_10_10_10_rev,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        67050 /* "glVertexP3ui" */,
        67050 /* "glVertexP3ui" */,
    };
    return gl_provider_resolver(entrypoint_strings + 67050 /* "glVertexP3ui" */,
                                providers, entrypoints);
}

static PFNGLVERTEXP3UIVPROC
epoxy_glVertexP3uiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_vertex_type_2_10_10_10_rev,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        67063 /* "glVertexP3uiv" */,
        67063 /* "glVertexP3uiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 67063 /* "glVertexP3uiv" */,
                                providers, entrypoints);
}

static PFNGLVERTEXP4UIPROC
epoxy_glVertexP4ui_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_vertex_type_2_10_10_10_rev,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        67077 /* "glVertexP4ui" */,
        67077 /* "glVertexP4ui" */,
    };
    return gl_provider_resolver(entrypoint_strings + 67077 /* "glVertexP4ui" */,
                                providers, entrypoints);
}

static PFNGLVERTEXP4UIVPROC
epoxy_glVertexP4uiv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_3,
        PROVIDER_GL_ARB_vertex_type_2_10_10_10_rev,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        67090 /* "glVertexP4uiv" */,
        67090 /* "glVertexP4uiv" */,
    };
    return gl_provider_resolver(entrypoint_strings + 67090 /* "glVertexP4uiv" */,
                                providers, entrypoints);
}

static PFNGLVERTEXPOINTERPROC
epoxy_glVertexPointer_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_1,
        PROVIDER_OpenGL_ES_1_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        67104 /* "glVertexPointer" */,
        67104 /* "glVertexPointer" */,
    };
    return gl_provider_resolver(entrypoint_strings + 67104 /* "glVertexPointer" */,
                                providers, entrypoints);
}

static PFNGLVERTEXPOINTEREXTPROC
epoxy_glVertexPointerEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_array, 67120 /* glVertexPointerEXT */);
}

static PFNGLVERTEXPOINTERLISTIBMPROC
epoxy_glVertexPointerListIBM_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_IBM_vertex_array_lists, 67139 /* glVertexPointerListIBM */);
}

static PFNGLVERTEXPOINTERVINTELPROC
epoxy_glVertexPointervINTEL_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_INTEL_parallel_arrays, 67162 /* glVertexPointervINTEL */);
}

static PFNGLVERTEXSTREAM1DATIPROC
epoxy_glVertexStream1dATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_streams, 67184 /* glVertexStream1dATI */);
}

static PFNGLVERTEXSTREAM1DVATIPROC
epoxy_glVertexStream1dvATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_streams, 67204 /* glVertexStream1dvATI */);
}

static PFNGLVERTEXSTREAM1FATIPROC
epoxy_glVertexStream1fATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_streams, 67225 /* glVertexStream1fATI */);
}

static PFNGLVERTEXSTREAM1FVATIPROC
epoxy_glVertexStream1fvATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_streams, 67245 /* glVertexStream1fvATI */);
}

static PFNGLVERTEXSTREAM1IATIPROC
epoxy_glVertexStream1iATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_streams, 67266 /* glVertexStream1iATI */);
}

static PFNGLVERTEXSTREAM1IVATIPROC
epoxy_glVertexStream1ivATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_streams, 67286 /* glVertexStream1ivATI */);
}

static PFNGLVERTEXSTREAM1SATIPROC
epoxy_glVertexStream1sATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_streams, 67307 /* glVertexStream1sATI */);
}

static PFNGLVERTEXSTREAM1SVATIPROC
epoxy_glVertexStream1svATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_streams, 67327 /* glVertexStream1svATI */);
}

static PFNGLVERTEXSTREAM2DATIPROC
epoxy_glVertexStream2dATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_streams, 67348 /* glVertexStream2dATI */);
}

static PFNGLVERTEXSTREAM2DVATIPROC
epoxy_glVertexStream2dvATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_streams, 67368 /* glVertexStream2dvATI */);
}

static PFNGLVERTEXSTREAM2FATIPROC
epoxy_glVertexStream2fATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_streams, 67389 /* glVertexStream2fATI */);
}

static PFNGLVERTEXSTREAM2FVATIPROC
epoxy_glVertexStream2fvATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_streams, 67409 /* glVertexStream2fvATI */);
}

static PFNGLVERTEXSTREAM2IATIPROC
epoxy_glVertexStream2iATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_streams, 67430 /* glVertexStream2iATI */);
}

static PFNGLVERTEXSTREAM2IVATIPROC
epoxy_glVertexStream2ivATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_streams, 67450 /* glVertexStream2ivATI */);
}

static PFNGLVERTEXSTREAM2SATIPROC
epoxy_glVertexStream2sATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_streams, 67471 /* glVertexStream2sATI */);
}

static PFNGLVERTEXSTREAM2SVATIPROC
epoxy_glVertexStream2svATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_streams, 67491 /* glVertexStream2svATI */);
}

static PFNGLVERTEXSTREAM3DATIPROC
epoxy_glVertexStream3dATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_streams, 67512 /* glVertexStream3dATI */);
}

static PFNGLVERTEXSTREAM3DVATIPROC
epoxy_glVertexStream3dvATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_streams, 67532 /* glVertexStream3dvATI */);
}

static PFNGLVERTEXSTREAM3FATIPROC
epoxy_glVertexStream3fATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_streams, 67553 /* glVertexStream3fATI */);
}

static PFNGLVERTEXSTREAM3FVATIPROC
epoxy_glVertexStream3fvATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_streams, 67573 /* glVertexStream3fvATI */);
}

static PFNGLVERTEXSTREAM3IATIPROC
epoxy_glVertexStream3iATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_streams, 67594 /* glVertexStream3iATI */);
}

static PFNGLVERTEXSTREAM3IVATIPROC
epoxy_glVertexStream3ivATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_streams, 67614 /* glVertexStream3ivATI */);
}

static PFNGLVERTEXSTREAM3SATIPROC
epoxy_glVertexStream3sATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_streams, 67635 /* glVertexStream3sATI */);
}

static PFNGLVERTEXSTREAM3SVATIPROC
epoxy_glVertexStream3svATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_streams, 67655 /* glVertexStream3svATI */);
}

static PFNGLVERTEXSTREAM4DATIPROC
epoxy_glVertexStream4dATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_streams, 67676 /* glVertexStream4dATI */);
}

static PFNGLVERTEXSTREAM4DVATIPROC
epoxy_glVertexStream4dvATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_streams, 67696 /* glVertexStream4dvATI */);
}

static PFNGLVERTEXSTREAM4FATIPROC
epoxy_glVertexStream4fATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_streams, 67717 /* glVertexStream4fATI */);
}

static PFNGLVERTEXSTREAM4FVATIPROC
epoxy_glVertexStream4fvATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_streams, 67737 /* glVertexStream4fvATI */);
}

static PFNGLVERTEXSTREAM4IATIPROC
epoxy_glVertexStream4iATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_streams, 67758 /* glVertexStream4iATI */);
}

static PFNGLVERTEXSTREAM4IVATIPROC
epoxy_glVertexStream4ivATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_streams, 67778 /* glVertexStream4ivATI */);
}

static PFNGLVERTEXSTREAM4SATIPROC
epoxy_glVertexStream4sATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_streams, 67799 /* glVertexStream4sATI */);
}

static PFNGLVERTEXSTREAM4SVATIPROC
epoxy_glVertexStream4svATI_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ATI_vertex_streams, 67819 /* glVertexStream4svATI */);
}

static PFNGLVERTEXWEIGHTPOINTEREXTPROC
epoxy_glVertexWeightPointerEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_weighting, 67840 /* glVertexWeightPointerEXT */);
}

static PFNGLVERTEXWEIGHTFEXTPROC
epoxy_glVertexWeightfEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_weighting, 67865 /* glVertexWeightfEXT */);
}

static PFNGLVERTEXWEIGHTFVEXTPROC
epoxy_glVertexWeightfvEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_weighting, 67884 /* glVertexWeightfvEXT */);
}

static PFNGLVERTEXWEIGHTHNVPROC
epoxy_glVertexWeighthNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_half_float, 67904 /* glVertexWeighthNV */);
}

static PFNGLVERTEXWEIGHTHVNVPROC
epoxy_glVertexWeighthvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_half_float, 67922 /* glVertexWeighthvNV */);
}

static PFNGLVIDEOCAPTURENVPROC
epoxy_glVideoCaptureNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_video_capture, 67941 /* glVideoCaptureNV */);
}

static PFNGLVIDEOCAPTURESTREAMPARAMETERDVNVPROC
epoxy_glVideoCaptureStreamParameterdvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_video_capture, 67958 /* glVideoCaptureStreamParameterdvNV */);
}

static PFNGLVIDEOCAPTURESTREAMPARAMETERFVNVPROC
epoxy_glVideoCaptureStreamParameterfvNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_video_capture, 67992 /* glVideoCaptureStreamParameterfvNV */);
}

static PFNGLVIDEOCAPTURESTREAMPARAMETERIVNVPROC
epoxy_glVideoCaptureStreamParameterivNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_video_capture, 68026 /* glVideoCaptureStreamParameterivNV */);
}

static PFNGLVIEWPORTPROC
epoxy_glViewport_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_0,
        PROVIDER_OpenGL_ES_1_0,
        PROVIDER_OpenGL_ES_2_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        68060 /* "glViewport" */,
        68060 /* "glViewport" */,
        68060 /* "glViewport" */,
    };
    return gl_provider_resolver(entrypoint_strings + 68060 /* "glViewport" */,
                                providers, entrypoints);
}

static PFNGLVIEWPORTARRAYVPROC
epoxy_glViewportArrayv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_viewport_array,
        PROVIDER_GL_NV_viewport_array,
        PROVIDER_GL_OES_viewport_array,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        68071 /* "glViewportArrayv" */,
        68071 /* "glViewportArrayv" */,
        68088 /* "glViewportArrayvNV" */,
        68107 /* "glViewportArrayvOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 68071 /* "glViewportArrayv" */,
                                providers, entrypoints);
}

static PFNGLVIEWPORTARRAYVNVPROC
epoxy_glViewportArrayvNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_viewport_array,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_viewport_array,
        PROVIDER_GL_OES_viewport_array,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        68088 /* "glViewportArrayvNV" */,
        68071 /* "glViewportArrayv" */,
        68071 /* "glViewportArrayv" */,
        68107 /* "glViewportArrayvOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 68088 /* "glViewportArrayvNV" */,
                                providers, entrypoints);
}

static PFNGLVIEWPORTARRAYVOESPROC
epoxy_glViewportArrayvOES_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_OES_viewport_array,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_viewport_array,
        PROVIDER_GL_NV_viewport_array,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        68107 /* "glViewportArrayvOES" */,
        68071 /* "glViewportArrayv" */,
        68071 /* "glViewportArrayv" */,
        68088 /* "glViewportArrayvNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 68107 /* "glViewportArrayvOES" */,
                                providers, entrypoints);
}

static PFNGLVIEWPORTINDEXEDFPROC
epoxy_glViewportIndexedf_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_viewport_array,
        PROVIDER_GL_NV_viewport_array,
        PROVIDER_GL_OES_viewport_array,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        68127 /* "glViewportIndexedf" */,
        68127 /* "glViewportIndexedf" */,
        68146 /* "glViewportIndexedfNV" */,
        68167 /* "glViewportIndexedfOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 68127 /* "glViewportIndexedf" */,
                                providers, entrypoints);
}

static PFNGLVIEWPORTINDEXEDFNVPROC
epoxy_glViewportIndexedfNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_viewport_array,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_viewport_array,
        PROVIDER_GL_OES_viewport_array,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        68146 /* "glViewportIndexedfNV" */,
        68127 /* "glViewportIndexedf" */,
        68127 /* "glViewportIndexedf" */,
        68167 /* "glViewportIndexedfOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 68146 /* "glViewportIndexedfNV" */,
                                providers, entrypoints);
}

static PFNGLVIEWPORTINDEXEDFOESPROC
epoxy_glViewportIndexedfOES_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_OES_viewport_array,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_viewport_array,
        PROVIDER_GL_NV_viewport_array,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        68167 /* "glViewportIndexedfOES" */,
        68127 /* "glViewportIndexedf" */,
        68127 /* "glViewportIndexedf" */,
        68146 /* "glViewportIndexedfNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 68167 /* "glViewportIndexedfOES" */,
                                providers, entrypoints);
}

static PFNGLVIEWPORTINDEXEDFVPROC
epoxy_glViewportIndexedfv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_viewport_array,
        PROVIDER_GL_NV_viewport_array,
        PROVIDER_GL_OES_viewport_array,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        68189 /* "glViewportIndexedfv" */,
        68189 /* "glViewportIndexedfv" */,
        68209 /* "glViewportIndexedfvNV" */,
        68231 /* "glViewportIndexedfvOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 68189 /* "glViewportIndexedfv" */,
                                providers, entrypoints);
}

static PFNGLVIEWPORTINDEXEDFVNVPROC
epoxy_glViewportIndexedfvNV_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_NV_viewport_array,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_viewport_array,
        PROVIDER_GL_OES_viewport_array,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        68209 /* "glViewportIndexedfvNV" */,
        68189 /* "glViewportIndexedfv" */,
        68189 /* "glViewportIndexedfv" */,
        68231 /* "glViewportIndexedfvOES" */,
    };
    return gl_provider_resolver(entrypoint_strings + 68209 /* "glViewportIndexedfvNV" */,
                                providers, entrypoints);
}

static PFNGLVIEWPORTINDEXEDFVOESPROC
epoxy_glViewportIndexedfvOES_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_OES_viewport_array,
        PROVIDER_Desktop_OpenGL_4_1,
        PROVIDER_GL_ARB_viewport_array,
        PROVIDER_GL_NV_viewport_array,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        68231 /* "glViewportIndexedfvOES" */,
        68189 /* "glViewportIndexedfv" */,
        68189 /* "glViewportIndexedfv" */,
        68209 /* "glViewportIndexedfvNV" */,
    };
    return gl_provider_resolver(entrypoint_strings + 68231 /* "glViewportIndexedfvOES" */,
                                providers, entrypoints);
}

static PFNGLVIEWPORTPOSITIONWSCALENVPROC
epoxy_glViewportPositionWScaleNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_clip_space_w_scaling, 68254 /* glViewportPositionWScaleNV */);
}

static PFNGLVIEWPORTSWIZZLENVPROC
epoxy_glViewportSwizzleNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_viewport_swizzle, 68281 /* glViewportSwizzleNV */);
}

static PFNGLWAITSEMAPHOREEXTPROC
epoxy_glWaitSemaphoreEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_semaphore, 68301 /* glWaitSemaphoreEXT */);
}

static PFNGLWAITSEMAPHOREUI64NVXPROC
epoxy_glWaitSemaphoreui64NVX_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NVX_progress_fence, 68320 /* glWaitSemaphoreui64NVX */);
}

static PFNGLWAITSYNCPROC
epoxy_glWaitSync_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_3_2,
        PROVIDER_GL_ARB_sync,
        PROVIDER_OpenGL_ES_3_0,
        PROVIDER_GL_APPLE_sync,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        68343 /* "glWaitSync" */,
        68343 /* "glWaitSync" */,
        68343 /* "glWaitSync" */,
        68354 /* "glWaitSyncAPPLE" */,
    };
    return gl_provider_resolver(entrypoint_strings + 68343 /* "glWaitSync" */,
                                providers, entrypoints);
}

static PFNGLWAITSYNCAPPLEPROC
epoxy_glWaitSyncAPPLE_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_APPLE_sync,
        PROVIDER_Desktop_OpenGL_3_2,
        PROVIDER_GL_ARB_sync,
        PROVIDER_OpenGL_ES_3_0,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        68354 /* "glWaitSyncAPPLE" */,
        68343 /* "glWaitSync" */,
        68343 /* "glWaitSync" */,
        68343 /* "glWaitSync" */,
    };
    return gl_provider_resolver(entrypoint_strings + 68354 /* "glWaitSyncAPPLE" */,
                                providers, entrypoints);
}

static PFNGLWAITVKSEMAPHORENVPROC
epoxy_glWaitVkSemaphoreNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_draw_vulkan_image, 68370 /* glWaitVkSemaphoreNV */);
}

static PFNGLWEIGHTPATHSNVPROC
epoxy_glWeightPathsNV_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_NV_path_rendering, 68390 /* glWeightPathsNV */);
}

static PFNGLWEIGHTPOINTERARBPROC
epoxy_glWeightPointerARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_vertex_blend, 68406 /* glWeightPointerARB */);
}

static PFNGLWEIGHTPOINTEROESPROC
epoxy_glWeightPointerOES_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_OES_matrix_palette, 68425 /* glWeightPointerOES */);
}

static PFNGLWEIGHTBVARBPROC
epoxy_glWeightbvARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_vertex_blend, 68444 /* glWeightbvARB */);
}

static PFNGLWEIGHTDVARBPROC
epoxy_glWeightdvARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_vertex_blend, 68458 /* glWeightdvARB */);
}

static PFNGLWEIGHTFVARBPROC
epoxy_glWeightfvARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_vertex_blend, 68472 /* glWeightfvARB */);
}

static PFNGLWEIGHTIVARBPROC
epoxy_glWeightivARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_vertex_blend, 68486 /* glWeightivARB */);
}

static PFNGLWEIGHTSVARBPROC
epoxy_glWeightsvARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_vertex_blend, 68500 /* glWeightsvARB */);
}

static PFNGLWEIGHTUBVARBPROC
epoxy_glWeightubvARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_vertex_blend, 68514 /* glWeightubvARB */);
}

static PFNGLWEIGHTUIVARBPROC
epoxy_glWeightuivARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_vertex_blend, 68529 /* glWeightuivARB */);
}

static PFNGLWEIGHTUSVARBPROC
epoxy_glWeightusvARB_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_ARB_vertex_blend, 68544 /* glWeightusvARB */);
}

static PFNGLWINDOWPOS2DPROC
epoxy_glWindowPos2d_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_ARB_window_pos,
        PROVIDER_GL_MESA_window_pos,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        68559 /* "glWindowPos2d" */,
        68573 /* "glWindowPos2dARB" */,
        68590 /* "glWindowPos2dMESA" */,
    };
    return gl_provider_resolver(entrypoint_strings + 68559 /* "glWindowPos2d" */,
                                providers, entrypoints);
}

static PFNGLWINDOWPOS2DARBPROC
epoxy_glWindowPos2dARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_window_pos,
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_MESA_window_pos,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        68573 /* "glWindowPos2dARB" */,
        68559 /* "glWindowPos2d" */,
        68590 /* "glWindowPos2dMESA" */,
    };
    return gl_provider_resolver(entrypoint_strings + 68573 /* "glWindowPos2dARB" */,
                                providers, entrypoints);
}

static PFNGLWINDOWPOS2DMESAPROC
epoxy_glWindowPos2dMESA_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_MESA_window_pos,
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_ARB_window_pos,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        68590 /* "glWindowPos2dMESA" */,
        68559 /* "glWindowPos2d" */,
        68573 /* "glWindowPos2dARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 68590 /* "glWindowPos2dMESA" */,
                                providers, entrypoints);
}

static PFNGLWINDOWPOS2DVPROC
epoxy_glWindowPos2dv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_ARB_window_pos,
        PROVIDER_GL_MESA_window_pos,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        68608 /* "glWindowPos2dv" */,
        68623 /* "glWindowPos2dvARB" */,
        68641 /* "glWindowPos2dvMESA" */,
    };
    return gl_provider_resolver(entrypoint_strings + 68608 /* "glWindowPos2dv" */,
                                providers, entrypoints);
}

static PFNGLWINDOWPOS2DVARBPROC
epoxy_glWindowPos2dvARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_window_pos,
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_MESA_window_pos,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        68623 /* "glWindowPos2dvARB" */,
        68608 /* "glWindowPos2dv" */,
        68641 /* "glWindowPos2dvMESA" */,
    };
    return gl_provider_resolver(entrypoint_strings + 68623 /* "glWindowPos2dvARB" */,
                                providers, entrypoints);
}

static PFNGLWINDOWPOS2DVMESAPROC
epoxy_glWindowPos2dvMESA_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_MESA_window_pos,
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_ARB_window_pos,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        68641 /* "glWindowPos2dvMESA" */,
        68608 /* "glWindowPos2dv" */,
        68623 /* "glWindowPos2dvARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 68641 /* "glWindowPos2dvMESA" */,
                                providers, entrypoints);
}

static PFNGLWINDOWPOS2FPROC
epoxy_glWindowPos2f_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_ARB_window_pos,
        PROVIDER_GL_MESA_window_pos,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        68660 /* "glWindowPos2f" */,
        68674 /* "glWindowPos2fARB" */,
        68691 /* "glWindowPos2fMESA" */,
    };
    return gl_provider_resolver(entrypoint_strings + 68660 /* "glWindowPos2f" */,
                                providers, entrypoints);
}

static PFNGLWINDOWPOS2FARBPROC
epoxy_glWindowPos2fARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_window_pos,
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_MESA_window_pos,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        68674 /* "glWindowPos2fARB" */,
        68660 /* "glWindowPos2f" */,
        68691 /* "glWindowPos2fMESA" */,
    };
    return gl_provider_resolver(entrypoint_strings + 68674 /* "glWindowPos2fARB" */,
                                providers, entrypoints);
}

static PFNGLWINDOWPOS2FMESAPROC
epoxy_glWindowPos2fMESA_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_MESA_window_pos,
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_ARB_window_pos,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        68691 /* "glWindowPos2fMESA" */,
        68660 /* "glWindowPos2f" */,
        68674 /* "glWindowPos2fARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 68691 /* "glWindowPos2fMESA" */,
                                providers, entrypoints);
}

static PFNGLWINDOWPOS2FVPROC
epoxy_glWindowPos2fv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_ARB_window_pos,
        PROVIDER_GL_MESA_window_pos,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        68709 /* "glWindowPos2fv" */,
        68724 /* "glWindowPos2fvARB" */,
        68742 /* "glWindowPos2fvMESA" */,
    };
    return gl_provider_resolver(entrypoint_strings + 68709 /* "glWindowPos2fv" */,
                                providers, entrypoints);
}

static PFNGLWINDOWPOS2FVARBPROC
epoxy_glWindowPos2fvARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_window_pos,
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_MESA_window_pos,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        68724 /* "glWindowPos2fvARB" */,
        68709 /* "glWindowPos2fv" */,
        68742 /* "glWindowPos2fvMESA" */,
    };
    return gl_provider_resolver(entrypoint_strings + 68724 /* "glWindowPos2fvARB" */,
                                providers, entrypoints);
}

static PFNGLWINDOWPOS2FVMESAPROC
epoxy_glWindowPos2fvMESA_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_MESA_window_pos,
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_ARB_window_pos,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        68742 /* "glWindowPos2fvMESA" */,
        68709 /* "glWindowPos2fv" */,
        68724 /* "glWindowPos2fvARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 68742 /* "glWindowPos2fvMESA" */,
                                providers, entrypoints);
}

static PFNGLWINDOWPOS2IPROC
epoxy_glWindowPos2i_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_ARB_window_pos,
        PROVIDER_GL_MESA_window_pos,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        68761 /* "glWindowPos2i" */,
        68775 /* "glWindowPos2iARB" */,
        68792 /* "glWindowPos2iMESA" */,
    };
    return gl_provider_resolver(entrypoint_strings + 68761 /* "glWindowPos2i" */,
                                providers, entrypoints);
}

static PFNGLWINDOWPOS2IARBPROC
epoxy_glWindowPos2iARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_window_pos,
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_MESA_window_pos,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        68775 /* "glWindowPos2iARB" */,
        68761 /* "glWindowPos2i" */,
        68792 /* "glWindowPos2iMESA" */,
    };
    return gl_provider_resolver(entrypoint_strings + 68775 /* "glWindowPos2iARB" */,
                                providers, entrypoints);
}

static PFNGLWINDOWPOS2IMESAPROC
epoxy_glWindowPos2iMESA_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_MESA_window_pos,
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_ARB_window_pos,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        68792 /* "glWindowPos2iMESA" */,
        68761 /* "glWindowPos2i" */,
        68775 /* "glWindowPos2iARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 68792 /* "glWindowPos2iMESA" */,
                                providers, entrypoints);
}

static PFNGLWINDOWPOS2IVPROC
epoxy_glWindowPos2iv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_ARB_window_pos,
        PROVIDER_GL_MESA_window_pos,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        68810 /* "glWindowPos2iv" */,
        68825 /* "glWindowPos2ivARB" */,
        68843 /* "glWindowPos2ivMESA" */,
    };
    return gl_provider_resolver(entrypoint_strings + 68810 /* "glWindowPos2iv" */,
                                providers, entrypoints);
}

static PFNGLWINDOWPOS2IVARBPROC
epoxy_glWindowPos2ivARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_window_pos,
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_MESA_window_pos,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        68825 /* "glWindowPos2ivARB" */,
        68810 /* "glWindowPos2iv" */,
        68843 /* "glWindowPos2ivMESA" */,
    };
    return gl_provider_resolver(entrypoint_strings + 68825 /* "glWindowPos2ivARB" */,
                                providers, entrypoints);
}

static PFNGLWINDOWPOS2IVMESAPROC
epoxy_glWindowPos2ivMESA_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_MESA_window_pos,
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_ARB_window_pos,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        68843 /* "glWindowPos2ivMESA" */,
        68810 /* "glWindowPos2iv" */,
        68825 /* "glWindowPos2ivARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 68843 /* "glWindowPos2ivMESA" */,
                                providers, entrypoints);
}

static PFNGLWINDOWPOS2SPROC
epoxy_glWindowPos2s_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_ARB_window_pos,
        PROVIDER_GL_MESA_window_pos,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        68862 /* "glWindowPos2s" */,
        68876 /* "glWindowPos2sARB" */,
        68893 /* "glWindowPos2sMESA" */,
    };
    return gl_provider_resolver(entrypoint_strings + 68862 /* "glWindowPos2s" */,
                                providers, entrypoints);
}

static PFNGLWINDOWPOS2SARBPROC
epoxy_glWindowPos2sARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_window_pos,
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_MESA_window_pos,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        68876 /* "glWindowPos2sARB" */,
        68862 /* "glWindowPos2s" */,
        68893 /* "glWindowPos2sMESA" */,
    };
    return gl_provider_resolver(entrypoint_strings + 68876 /* "glWindowPos2sARB" */,
                                providers, entrypoints);
}

static PFNGLWINDOWPOS2SMESAPROC
epoxy_glWindowPos2sMESA_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_MESA_window_pos,
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_ARB_window_pos,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        68893 /* "glWindowPos2sMESA" */,
        68862 /* "glWindowPos2s" */,
        68876 /* "glWindowPos2sARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 68893 /* "glWindowPos2sMESA" */,
                                providers, entrypoints);
}

static PFNGLWINDOWPOS2SVPROC
epoxy_glWindowPos2sv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_ARB_window_pos,
        PROVIDER_GL_MESA_window_pos,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        68911 /* "glWindowPos2sv" */,
        68926 /* "glWindowPos2svARB" */,
        68944 /* "glWindowPos2svMESA" */,
    };
    return gl_provider_resolver(entrypoint_strings + 68911 /* "glWindowPos2sv" */,
                                providers, entrypoints);
}

static PFNGLWINDOWPOS2SVARBPROC
epoxy_glWindowPos2svARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_window_pos,
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_MESA_window_pos,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        68926 /* "glWindowPos2svARB" */,
        68911 /* "glWindowPos2sv" */,
        68944 /* "glWindowPos2svMESA" */,
    };
    return gl_provider_resolver(entrypoint_strings + 68926 /* "glWindowPos2svARB" */,
                                providers, entrypoints);
}

static PFNGLWINDOWPOS2SVMESAPROC
epoxy_glWindowPos2svMESA_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_MESA_window_pos,
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_ARB_window_pos,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        68944 /* "glWindowPos2svMESA" */,
        68911 /* "glWindowPos2sv" */,
        68926 /* "glWindowPos2svARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 68944 /* "glWindowPos2svMESA" */,
                                providers, entrypoints);
}

static PFNGLWINDOWPOS3DPROC
epoxy_glWindowPos3d_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_ARB_window_pos,
        PROVIDER_GL_MESA_window_pos,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        68963 /* "glWindowPos3d" */,
        68977 /* "glWindowPos3dARB" */,
        68994 /* "glWindowPos3dMESA" */,
    };
    return gl_provider_resolver(entrypoint_strings + 68963 /* "glWindowPos3d" */,
                                providers, entrypoints);
}

static PFNGLWINDOWPOS3DARBPROC
epoxy_glWindowPos3dARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_window_pos,
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_MESA_window_pos,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        68977 /* "glWindowPos3dARB" */,
        68963 /* "glWindowPos3d" */,
        68994 /* "glWindowPos3dMESA" */,
    };
    return gl_provider_resolver(entrypoint_strings + 68977 /* "glWindowPos3dARB" */,
                                providers, entrypoints);
}

static PFNGLWINDOWPOS3DMESAPROC
epoxy_glWindowPos3dMESA_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_MESA_window_pos,
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_ARB_window_pos,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        68994 /* "glWindowPos3dMESA" */,
        68963 /* "glWindowPos3d" */,
        68977 /* "glWindowPos3dARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 68994 /* "glWindowPos3dMESA" */,
                                providers, entrypoints);
}

static PFNGLWINDOWPOS3DVPROC
epoxy_glWindowPos3dv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_ARB_window_pos,
        PROVIDER_GL_MESA_window_pos,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        69012 /* "glWindowPos3dv" */,
        69027 /* "glWindowPos3dvARB" */,
        69045 /* "glWindowPos3dvMESA" */,
    };
    return gl_provider_resolver(entrypoint_strings + 69012 /* "glWindowPos3dv" */,
                                providers, entrypoints);
}

static PFNGLWINDOWPOS3DVARBPROC
epoxy_glWindowPos3dvARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_window_pos,
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_MESA_window_pos,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        69027 /* "glWindowPos3dvARB" */,
        69012 /* "glWindowPos3dv" */,
        69045 /* "glWindowPos3dvMESA" */,
    };
    return gl_provider_resolver(entrypoint_strings + 69027 /* "glWindowPos3dvARB" */,
                                providers, entrypoints);
}

static PFNGLWINDOWPOS3DVMESAPROC
epoxy_glWindowPos3dvMESA_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_MESA_window_pos,
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_ARB_window_pos,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        69045 /* "glWindowPos3dvMESA" */,
        69012 /* "glWindowPos3dv" */,
        69027 /* "glWindowPos3dvARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 69045 /* "glWindowPos3dvMESA" */,
                                providers, entrypoints);
}

static PFNGLWINDOWPOS3FPROC
epoxy_glWindowPos3f_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_ARB_window_pos,
        PROVIDER_GL_MESA_window_pos,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        69064 /* "glWindowPos3f" */,
        69078 /* "glWindowPos3fARB" */,
        69095 /* "glWindowPos3fMESA" */,
    };
    return gl_provider_resolver(entrypoint_strings + 69064 /* "glWindowPos3f" */,
                                providers, entrypoints);
}

static PFNGLWINDOWPOS3FARBPROC
epoxy_glWindowPos3fARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_window_pos,
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_MESA_window_pos,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        69078 /* "glWindowPos3fARB" */,
        69064 /* "glWindowPos3f" */,
        69095 /* "glWindowPos3fMESA" */,
    };
    return gl_provider_resolver(entrypoint_strings + 69078 /* "glWindowPos3fARB" */,
                                providers, entrypoints);
}

static PFNGLWINDOWPOS3FMESAPROC
epoxy_glWindowPos3fMESA_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_MESA_window_pos,
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_ARB_window_pos,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        69095 /* "glWindowPos3fMESA" */,
        69064 /* "glWindowPos3f" */,
        69078 /* "glWindowPos3fARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 69095 /* "glWindowPos3fMESA" */,
                                providers, entrypoints);
}

static PFNGLWINDOWPOS3FVPROC
epoxy_glWindowPos3fv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_ARB_window_pos,
        PROVIDER_GL_MESA_window_pos,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        69113 /* "glWindowPos3fv" */,
        69128 /* "glWindowPos3fvARB" */,
        69146 /* "glWindowPos3fvMESA" */,
    };
    return gl_provider_resolver(entrypoint_strings + 69113 /* "glWindowPos3fv" */,
                                providers, entrypoints);
}

static PFNGLWINDOWPOS3FVARBPROC
epoxy_glWindowPos3fvARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_window_pos,
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_MESA_window_pos,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        69128 /* "glWindowPos3fvARB" */,
        69113 /* "glWindowPos3fv" */,
        69146 /* "glWindowPos3fvMESA" */,
    };
    return gl_provider_resolver(entrypoint_strings + 69128 /* "glWindowPos3fvARB" */,
                                providers, entrypoints);
}

static PFNGLWINDOWPOS3FVMESAPROC
epoxy_glWindowPos3fvMESA_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_MESA_window_pos,
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_ARB_window_pos,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        69146 /* "glWindowPos3fvMESA" */,
        69113 /* "glWindowPos3fv" */,
        69128 /* "glWindowPos3fvARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 69146 /* "glWindowPos3fvMESA" */,
                                providers, entrypoints);
}

static PFNGLWINDOWPOS3IPROC
epoxy_glWindowPos3i_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_ARB_window_pos,
        PROVIDER_GL_MESA_window_pos,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        69165 /* "glWindowPos3i" */,
        69179 /* "glWindowPos3iARB" */,
        69196 /* "glWindowPos3iMESA" */,
    };
    return gl_provider_resolver(entrypoint_strings + 69165 /* "glWindowPos3i" */,
                                providers, entrypoints);
}

static PFNGLWINDOWPOS3IARBPROC
epoxy_glWindowPos3iARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_window_pos,
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_MESA_window_pos,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        69179 /* "glWindowPos3iARB" */,
        69165 /* "glWindowPos3i" */,
        69196 /* "glWindowPos3iMESA" */,
    };
    return gl_provider_resolver(entrypoint_strings + 69179 /* "glWindowPos3iARB" */,
                                providers, entrypoints);
}

static PFNGLWINDOWPOS3IMESAPROC
epoxy_glWindowPos3iMESA_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_MESA_window_pos,
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_ARB_window_pos,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        69196 /* "glWindowPos3iMESA" */,
        69165 /* "glWindowPos3i" */,
        69179 /* "glWindowPos3iARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 69196 /* "glWindowPos3iMESA" */,
                                providers, entrypoints);
}

static PFNGLWINDOWPOS3IVPROC
epoxy_glWindowPos3iv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_ARB_window_pos,
        PROVIDER_GL_MESA_window_pos,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        69214 /* "glWindowPos3iv" */,
        69229 /* "glWindowPos3ivARB" */,
        69247 /* "glWindowPos3ivMESA" */,
    };
    return gl_provider_resolver(entrypoint_strings + 69214 /* "glWindowPos3iv" */,
                                providers, entrypoints);
}

static PFNGLWINDOWPOS3IVARBPROC
epoxy_glWindowPos3ivARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_window_pos,
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_MESA_window_pos,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        69229 /* "glWindowPos3ivARB" */,
        69214 /* "glWindowPos3iv" */,
        69247 /* "glWindowPos3ivMESA" */,
    };
    return gl_provider_resolver(entrypoint_strings + 69229 /* "glWindowPos3ivARB" */,
                                providers, entrypoints);
}

static PFNGLWINDOWPOS3IVMESAPROC
epoxy_glWindowPos3ivMESA_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_MESA_window_pos,
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_ARB_window_pos,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        69247 /* "glWindowPos3ivMESA" */,
        69214 /* "glWindowPos3iv" */,
        69229 /* "glWindowPos3ivARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 69247 /* "glWindowPos3ivMESA" */,
                                providers, entrypoints);
}

static PFNGLWINDOWPOS3SPROC
epoxy_glWindowPos3s_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_ARB_window_pos,
        PROVIDER_GL_MESA_window_pos,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        69266 /* "glWindowPos3s" */,
        69280 /* "glWindowPos3sARB" */,
        69297 /* "glWindowPos3sMESA" */,
    };
    return gl_provider_resolver(entrypoint_strings + 69266 /* "glWindowPos3s" */,
                                providers, entrypoints);
}

static PFNGLWINDOWPOS3SARBPROC
epoxy_glWindowPos3sARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_window_pos,
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_MESA_window_pos,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        69280 /* "glWindowPos3sARB" */,
        69266 /* "glWindowPos3s" */,
        69297 /* "glWindowPos3sMESA" */,
    };
    return gl_provider_resolver(entrypoint_strings + 69280 /* "glWindowPos3sARB" */,
                                providers, entrypoints);
}

static PFNGLWINDOWPOS3SMESAPROC
epoxy_glWindowPos3sMESA_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_MESA_window_pos,
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_ARB_window_pos,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        69297 /* "glWindowPos3sMESA" */,
        69266 /* "glWindowPos3s" */,
        69280 /* "glWindowPos3sARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 69297 /* "glWindowPos3sMESA" */,
                                providers, entrypoints);
}

static PFNGLWINDOWPOS3SVPROC
epoxy_glWindowPos3sv_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_ARB_window_pos,
        PROVIDER_GL_MESA_window_pos,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        69315 /* "glWindowPos3sv" */,
        69330 /* "glWindowPos3svARB" */,
        69348 /* "glWindowPos3svMESA" */,
    };
    return gl_provider_resolver(entrypoint_strings + 69315 /* "glWindowPos3sv" */,
                                providers, entrypoints);
}

static PFNGLWINDOWPOS3SVARBPROC
epoxy_glWindowPos3svARB_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_ARB_window_pos,
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_MESA_window_pos,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        69330 /* "glWindowPos3svARB" */,
        69315 /* "glWindowPos3sv" */,
        69348 /* "glWindowPos3svMESA" */,
    };
    return gl_provider_resolver(entrypoint_strings + 69330 /* "glWindowPos3svARB" */,
                                providers, entrypoints);
}

static PFNGLWINDOWPOS3SVMESAPROC
epoxy_glWindowPos3svMESA_resolver(void)
{
    static const enum gl_provider providers[] = {
        PROVIDER_GL_MESA_window_pos,
        PROVIDER_Desktop_OpenGL_1_4,
        PROVIDER_GL_ARB_window_pos,
        gl_provider_terminator
    };
    static const uint32_t entrypoints[] = {
        69348 /* "glWindowPos3svMESA" */,
        69315 /* "glWindowPos3sv" */,
        69330 /* "glWindowPos3svARB" */,
    };
    return gl_provider_resolver(entrypoint_strings + 69348 /* "glWindowPos3svMESA" */,
                                providers, entrypoints);
}

static PFNGLWINDOWPOS4DMESAPROC
epoxy_glWindowPos4dMESA_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_MESA_window_pos, 69367 /* glWindowPos4dMESA */);
}

static PFNGLWINDOWPOS4DVMESAPROC
epoxy_glWindowPos4dvMESA_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_MESA_window_pos, 69385 /* glWindowPos4dvMESA */);
}

static PFNGLWINDOWPOS4FMESAPROC
epoxy_glWindowPos4fMESA_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_MESA_window_pos, 69404 /* glWindowPos4fMESA */);
}

static PFNGLWINDOWPOS4FVMESAPROC
epoxy_glWindowPos4fvMESA_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_MESA_window_pos, 69422 /* glWindowPos4fvMESA */);
}

static PFNGLWINDOWPOS4IMESAPROC
epoxy_glWindowPos4iMESA_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_MESA_window_pos, 69441 /* glWindowPos4iMESA */);
}

static PFNGLWINDOWPOS4IVMESAPROC
epoxy_glWindowPos4ivMESA_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_MESA_window_pos, 69459 /* glWindowPos4ivMESA */);
}

static PFNGLWINDOWPOS4SMESAPROC
epoxy_glWindowPos4sMESA_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_MESA_window_pos, 69478 /* glWindowPos4sMESA */);
}

static PFNGLWINDOWPOS4SVMESAPROC
epoxy_glWindowPos4svMESA_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_MESA_window_pos, 69496 /* glWindowPos4svMESA */);
}

static PFNGLWINDOWRECTANGLESEXTPROC
epoxy_glWindowRectanglesEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_window_rectangles, 69515 /* glWindowRectanglesEXT */);
}

static PFNGLWRITEMASKEXTPROC
epoxy_glWriteMaskEXT_resolver(void)
{
    return gl_single_resolver(PROVIDER_GL_EXT_vertex_shader, 69537 /* glWriteMaskEXT */);
}

GEN_THUNKS(glAccum, (GLenum op, GLfloat value), (op, value))
GEN_THUNKS(glAccumxOES, (GLenum op, GLfixed value), (op, value))
GEN_THUNKS_RET(GLboolean, glAcquireKeyedMutexWin32EXT, (GLuint memory, GLuint64 key, GLuint timeout), (memory, key, timeout))
GEN_THUNKS(glActiveProgramEXT, (GLuint program), (program))
GEN_THUNKS(glActiveShaderProgram, (GLuint pipeline, GLuint program), (pipeline, program))
GEN_THUNKS(glActiveShaderProgramEXT, (GLuint pipeline, GLuint program), (pipeline, program))
GEN_THUNKS(glActiveStencilFaceEXT, (GLenum face), (face))
GEN_THUNKS(glActiveTexture, (GLenum texture), (texture))
GEN_THUNKS(glActiveTextureARB, (GLenum texture), (texture))
GEN_THUNKS(glActiveVaryingNV, (GLuint program, const GLchar * name), (program, name))
GEN_THUNKS(glAlphaFragmentOp1ATI, (GLenum op, GLuint dst, GLuint dstMod, GLuint arg1, GLuint arg1Rep, GLuint arg1Mod), (op, dst, dstMod, arg1, arg1Rep, arg1Mod))
GEN_THUNKS(glAlphaFragmentOp2ATI, (GLenum op, GLuint dst, GLuint dstMod, GLuint arg1, GLuint arg1Rep, GLuint arg1Mod, GLuint arg2, GLuint arg2Rep, GLuint arg2Mod), (op, dst, dstMod, arg1, arg1Rep, arg1Mod, arg2, arg2Rep, arg2Mod))
GEN_THUNKS(glAlphaFragmentOp3ATI, (GLenum op, GLuint dst, GLuint dstMod, GLuint arg1, GLuint arg1Rep, GLuint arg1Mod, GLuint arg2, GLuint arg2Rep, GLuint arg2Mod, GLuint arg3, GLuint arg3Rep, GLuint arg3Mod), (op, dst, dstMod, arg1, arg1Rep, arg1Mod, arg2, arg2Rep, arg2Mod, arg3, arg3Rep, arg3Mod))
GEN_THUNKS(glAlphaFunc, (GLenum func, GLfloat ref), (func, ref))
GEN_THUNKS(glAlphaFuncQCOM, (GLenum func, GLclampf ref), (func, ref))
GEN_THUNKS(glAlphaFuncx, (GLenum func, GLfixed ref), (func, ref))
GEN_THUNKS(glAlphaFuncxOES, (GLenum func, GLfixed ref), (func, ref))
GEN_THUNKS(glAlphaToCoverageDitherControlNV, (GLenum mode), (mode))
GEN_THUNKS(glApplyFramebufferAttachmentCMAAINTEL, (void), ())
GEN_THUNKS(glApplyTextureEXT, (GLenum mode), (mode))
GEN_THUNKS_RET(GLboolean, glAreProgramsResidentNV, (GLsizei n, const GLuint * programs, GLboolean * residences), (n, programs, residences))
GEN_THUNKS_RET(GLboolean, glAreTexturesResident, (GLsizei n, const GLuint * textures, GLboolean * residences), (n, textures, residences))
GEN_THUNKS_RET(GLboolean, glAreTexturesResidentEXT, (GLsizei n, const GLuint * textures, GLboolean * residences), (n, textures, residences))
GEN_THUNKS(glArrayElement, (GLint i), (i))
GEN_THUNKS(glArrayElementEXT, (GLint i), (i))
GEN_THUNKS(glArrayObjectATI, (GLenum array, GLint size, GLenum type, GLsizei stride, GLuint buffer, GLuint offset), (array, size, type, stride, buffer, offset))
GEN_THUNKS_RET(GLuint, glAsyncCopyBufferSubDataNVX, (GLsizei waitSemaphoreCount, const GLuint * waitSemaphoreArray, const GLuint64 * fenceValueArray, GLuint readGpu, GLbitfield writeGpuMask, GLuint readBuffer, GLuint writeBuffer, GLintptr readOffset, GLintptr writeOffset, GLsizeiptr size, GLsizei signalSemaphoreCount, const GLuint * signalSemaphoreArray, const GLuint64 * signalValueArray), (waitSemaphoreCount, waitSemaphoreArray, fenceValueArray, readGpu, writeGpuMask, readBuffer, writeBuffer, readOffset, writeOffset, size, signalSemaphoreCount, signalSemaphoreArray, signalValueArray))
GEN_THUNKS_RET(GLuint, glAsyncCopyImageSubDataNVX, (GLsizei waitSemaphoreCount, const GLuint * waitSemaphoreArray, const GLuint64 * waitValueArray, GLuint srcGpu, GLbitfield dstGpuMask, GLuint srcName, GLenum srcTarget, GLint srcLevel, GLint srcX, GLint srcY, GLint srcZ, GLuint dstName, GLenum dstTarget, GLint dstLevel, GLint dstX, GLint dstY, GLint dstZ, GLsizei srcWidth, GLsizei srcHeight, GLsizei srcDepth, GLsizei signalSemaphoreCount, const GLuint * signalSemaphoreArray, const GLuint64 * signalValueArray), (waitSemaphoreCount, waitSemaphoreArray, waitValueArray, srcGpu, dstGpuMask, srcName, srcTarget, srcLevel, srcX, srcY, srcZ, dstName, dstTarget, dstLevel, dstX, dstY, dstZ, srcWidth, srcHeight, srcDepth, signalSemaphoreCount, signalSemaphoreArray, signalValueArray))
GEN_THUNKS(glAsyncMarkerSGIX, (GLuint marker), (marker))
GEN_THUNKS(glAttachObjectARB, (GLhandleARB containerObj, GLhandleARB obj), ((uintptr_t)containerObj, (uintptr_t)obj))
GEN_THUNKS(glAttachShader, (GLuint program, GLuint shader), (program, shader))
GEN_THUNKS(glBegin_unwrapped, (GLenum mode), (mode))
GEN_THUNKS(glBeginConditionalRender, (GLuint id, GLenum mode), (id, mode))
GEN_THUNKS(glBeginConditionalRenderNV, (GLuint id, GLenum mode), (id, mode))
GEN_THUNKS(glBeginConditionalRenderNVX, (GLuint id), (id))
GEN_THUNKS(glBeginFragmentShaderATI, (void), ())
GEN_THUNKS(glBeginOcclusionQueryNV, (GLuint id), (id))
GEN_THUNKS(glBeginPerfMonitorAMD, (GLuint monitor), (monitor))
GEN_THUNKS(glBeginPerfQueryINTEL, (GLuint queryHandle), (queryHandle))
GEN_THUNKS(glBeginQuery, (GLenum target, GLuint id), (target, id))
GEN_THUNKS(glBeginQueryARB, (GLenum target, GLuint id), (target, id))
GEN_THUNKS(glBeginQueryEXT, (GLenum target, GLuint id), (target, id))
GEN_THUNKS(glBeginQueryIndexed, (GLenum target, GLuint index, GLuint id), (target, index, id))
GEN_THUNKS(glBeginTransformFeedback, (GLenum primitiveMode), (primitiveMode))
GEN_THUNKS(glBeginTransformFeedbackEXT, (GLenum primitiveMode), (primitiveMode))
GEN_THUNKS(glBeginTransformFeedbackNV, (GLenum primitiveMode), (primitiveMode))
GEN_THUNKS(glBeginVertexShaderEXT, (void), ())
GEN_THUNKS(glBeginVideoCaptureNV, (GLuint video_capture_slot), (video_capture_slot))
GEN_THUNKS(glBindAttribLocation, (GLuint program, GLuint index, const GLchar * name), (program, index, name))
GEN_THUNKS(glBindAttribLocationARB, (GLhandleARB programObj, GLuint index, const GLcharARB * name), ((uintptr_t)programObj, index, name))
GEN_THUNKS(glBindBuffer, (GLenum target, GLuint buffer), (target, buffer))
GEN_THUNKS(glBindBufferARB, (GLenum target, GLuint buffer), (target, buffer))
GEN_THUNKS(glBindBufferBase, (GLenum target, GLuint index, GLuint buffer), (target, index, buffer))
GEN_THUNKS(glBindBufferBaseEXT, (GLenum target, GLuint index, GLuint buffer), (target, index, buffer))
GEN_THUNKS(glBindBufferBaseNV, (GLenum target, GLuint index, GLuint buffer), (target, index, buffer))
GEN_THUNKS(glBindBufferOffsetEXT, (GLenum target, GLuint index, GLuint buffer, GLintptr offset), (target, index, buffer, offset))
GEN_THUNKS(glBindBufferOffsetNV, (GLenum target, GLuint index, GLuint buffer, GLintptr offset), (target, index, buffer, offset))
GEN_THUNKS(glBindBufferRange, (GLenum target, GLuint index, GLuint buffer, GLintptr offset, GLsizeiptr size), (target, index, buffer, offset, size))
GEN_THUNKS(glBindBufferRangeEXT, (GLenum target, GLuint index, GLuint buffer, GLintptr offset, GLsizeiptr size), (target, index, buffer, offset, size))
GEN_THUNKS(glBindBufferRangeNV, (GLenum target, GLuint index, GLuint buffer, GLintptr offset, GLsizeiptr size), (target, index, buffer, offset, size))
GEN_THUNKS(glBindBuffersBase, (GLenum target, GLuint first, GLsizei count, const GLuint * buffers), (target, first, count, buffers))
GEN_THUNKS(glBindBuffersRange, (GLenum target, GLuint first, GLsizei count, const GLuint * buffers, const GLintptr * offsets, const GLsizeiptr * sizes), (target, first, count, buffers, offsets, sizes))
GEN_THUNKS(glBindFragDataLocation, (GLuint program, GLuint color, const GLchar * name), (program, color, name))
GEN_THUNKS(glBindFragDataLocationEXT, (GLuint program, GLuint color, const GLchar * name), (program, color, name))
GEN_THUNKS(glBindFragDataLocationIndexed, (GLuint program, GLuint colorNumber, GLuint index, const GLchar * name), (program, colorNumber, index, name))
GEN_THUNKS(glBindFragDataLocationIndexedEXT, (GLuint program, GLuint colorNumber, GLuint index, const GLchar * name), (program, colorNumber, index, name))
GEN_THUNKS(glBindFragmentShaderATI, (GLuint id), (id))
GEN_THUNKS(glBindFramebuffer, (GLenum target, GLuint framebuffer), (target, framebuffer))
GEN_THUNKS(glBindFramebufferEXT, (GLenum target, GLuint framebuffer), (target, framebuffer))
GEN_THUNKS(glBindFramebufferOES, (GLenum target, GLuint framebuffer), (target, framebuffer))
GEN_THUNKS(glBindImageTexture, (GLuint unit, GLuint texture, GLint level, GLboolean layered, GLint layer, GLenum access, GLenum format), (unit, texture, level, layered, layer, access, format))
GEN_THUNKS(glBindImageTextureEXT, (GLuint index, GLuint texture, GLint level, GLboolean layered, GLint layer, GLenum access, GLint format), (index, texture, level, layered, layer, access, format))
GEN_THUNKS(glBindImageTextures, (GLuint first, GLsizei count, const GLuint * textures), (first, count, textures))
GEN_THUNKS_RET(GLuint, glBindLightParameterEXT, (GLenum light, GLenum value), (light, value))
GEN_THUNKS_RET(GLuint, glBindMaterialParameterEXT, (GLenum face, GLenum value), (face, value))
GEN_THUNKS(glBindMultiTextureEXT, (GLenum texunit, GLenum target, GLuint texture), (texunit, target, texture))
GEN_THUNKS_RET(GLuint, glBindParameterEXT, (GLenum value), (value))
GEN_THUNKS(glBindProgramARB, (GLenum target, GLuint program), (target, program))
GEN_THUNKS(glBindProgramNV, (GLenum target, GLuint id), (target, id))
GEN_THUNKS(glBindProgramPipeline, (GLuint pipeline), (pipeline))
GEN_THUNKS(glBindProgramPipelineEXT, (GLuint pipeline), (pipeline))
GEN_THUNKS(glBindRenderbuffer, (GLenum target, GLuint renderbuffer), (target, renderbuffer))
GEN_THUNKS(glBindRenderbufferEXT, (GLenum target, GLuint renderbuffer), (target, renderbuffer))
GEN_THUNKS(glBindRenderbufferOES, (GLenum target, GLuint renderbuffer), (target, renderbuffer))
GEN_THUNKS(glBindSampler, (GLuint unit, GLuint sampler), (unit, sampler))
GEN_THUNKS(glBindSamplers, (GLuint first, GLsizei count, const GLuint * samplers), (first, count, samplers))
GEN_THUNKS(glBindShadingRateImageNV, (GLuint texture), (texture))
GEN_THUNKS_RET(GLuint, glBindTexGenParameterEXT, (GLenum unit, GLenum coord, GLenum value), (unit, coord, value))
GEN_THUNKS(glBindTexture, (GLenum target, GLuint texture), (target, texture))
GEN_THUNKS(glBindTextureEXT, (GLenum target, GLuint texture), (target, texture))
GEN_THUNKS(glBindTextureUnit, (GLuint unit, GLuint texture), (unit, texture))
GEN_THUNKS_RET(GLuint, glBindTextureUnitParameterEXT, (GLenum unit, GLenum value), (unit, value))
GEN_THUNKS(glBindTextures, (GLuint first, GLsizei count, const GLuint * textures), (first, count, textures))
GEN_THUNKS(glBindTransformFeedback, (GLenum target, GLuint id), (target, id))
GEN_THUNKS(glBindTransformFeedbackNV, (GLenum target, GLuint id), (target, id))
GEN_THUNKS(glBindVertexArray, (GLuint array), (array))
GEN_THUNKS(glBindVertexArrayAPPLE, (GLuint array), (array))
GEN_THUNKS(glBindVertexArrayOES, (GLuint array), (array))
GEN_THUNKS(glBindVertexBuffer, (GLuint bindingindex, GLuint buffer, GLintptr offset, GLsizei stride), (bindingindex, buffer, offset, stride))
GEN_THUNKS(glBindVertexBuffers, (GLuint first, GLsizei count, const GLuint * buffers, const GLintptr * offsets, const GLsizei * strides), (first, count, buffers, offsets, strides))
GEN_THUNKS(glBindVertexShaderEXT, (GLuint id), (id))
GEN_THUNKS(glBindVideoCaptureStreamBufferNV, (GLuint video_capture_slot, GLuint stream, GLenum frame_region, GLintptrARB offset), (video_capture_slot, stream, frame_region, offset))
GEN_THUNKS(glBindVideoCaptureStreamTextureNV, (GLuint video_capture_slot, GLuint stream, GLenum frame_region, GLenum target, GLuint texture), (video_capture_slot, stream, frame_region, target, texture))
GEN_THUNKS(glBinormal3bEXT, (GLbyte bx, GLbyte by, GLbyte bz), (bx, by, bz))
GEN_THUNKS(glBinormal3bvEXT, (const GLbyte * v), (v))
GEN_THUNKS(glBinormal3dEXT, (GLdouble bx, GLdouble by, GLdouble bz), (bx, by, bz))
GEN_THUNKS(glBinormal3dvEXT, (const GLdouble * v), (v))
GEN_THUNKS(glBinormal3fEXT, (GLfloat bx, GLfloat by, GLfloat bz), (bx, by, bz))
GEN_THUNKS(glBinormal3fvEXT, (const GLfloat * v), (v))
GEN_THUNKS(glBinormal3iEXT, (GLint bx, GLint by, GLint bz), (bx, by, bz))
GEN_THUNKS(glBinormal3ivEXT, (const GLint * v), (v))
GEN_THUNKS(glBinormal3sEXT, (GLshort bx, GLshort by, GLshort bz), (bx, by, bz))
GEN_THUNKS(glBinormal3svEXT, (const GLshort * v), (v))
GEN_THUNKS(glBinormalPointerEXT, (GLenum type, GLsizei stride, const void * pointer), (type, stride, pointer))
GEN_THUNKS(glBitmap, (GLsizei width, GLsizei height, GLfloat xorig, GLfloat yorig, GLfloat xmove, GLfloat ymove, const GLubyte * bitmap), (width, height, xorig, yorig, xmove, ymove, bitmap))
GEN_THUNKS(glBitmapxOES, (GLsizei width, GLsizei height, GLfixed xorig, GLfixed yorig, GLfixed xmove, GLfixed ymove, const GLubyte * bitmap), (width, height, xorig, yorig, xmove, ymove, bitmap))
GEN_THUNKS(glBlendBarrier, (void), ())
GEN_THUNKS(glBlendBarrierKHR, (void), ())
GEN_THUNKS(glBlendBarrierNV, (void), ())
GEN_THUNKS(glBlendColor, (GLfloat red, GLfloat green, GLfloat blue, GLfloat alpha), (red, green, blue, alpha))
GEN_THUNKS(glBlendColorEXT, (GLfloat red, GLfloat green, GLfloat blue, GLfloat alpha), (red, green, blue, alpha))
GEN_THUNKS(glBlendColorxOES, (GLfixed red, GLfixed green, GLfixed blue, GLfixed alpha), (red, green, blue, alpha))
GEN_THUNKS(glBlendEquation, (GLenum mode), (mode))
GEN_THUNKS(glBlendEquationEXT, (GLenum mode), (mode))
GEN_THUNKS(glBlendEquationIndexedAMD, (GLuint buf, GLenum mode), (buf, mode))
GEN_THUNKS(glBlendEquationOES, (GLenum mode), (mode))
GEN_THUNKS(glBlendEquationSeparate, (GLenum modeRGB, GLenum modeAlpha), (modeRGB, modeAlpha))
GEN_THUNKS(glBlendEquationSeparateEXT, (GLenum modeRGB, GLenum modeAlpha), (modeRGB, modeAlpha))
GEN_THUNKS(glBlendEquationSeparateIndexedAMD, (GLuint buf, GLenum modeRGB, GLenum modeAlpha), (buf, modeRGB, modeAlpha))
GEN_THUNKS(glBlendEquationSeparateOES, (GLenum modeRGB, GLenum modeAlpha), (modeRGB, modeAlpha))
GEN_THUNKS(glBlendEquationSeparatei, (GLuint buf, GLenum modeRGB, GLenum modeAlpha), (buf, modeRGB, modeAlpha))
GEN_THUNKS(glBlendEquationSeparateiARB, (GLuint buf, GLenum modeRGB, GLenum modeAlpha), (buf, modeRGB, modeAlpha))
GEN_THUNKS(glBlendEquationSeparateiEXT, (GLuint buf, GLenum modeRGB, GLenum modeAlpha), (buf, modeRGB, modeAlpha))
GEN_THUNKS(glBlendEquationSeparateiOES, (GLuint buf, GLenum modeRGB, GLenum modeAlpha), (buf, modeRGB, modeAlpha))
GEN_THUNKS(glBlendEquationi, (GLuint buf, GLenum mode), (buf, mode))
GEN_THUNKS(glBlendEquationiARB, (GLuint buf, GLenum mode), (buf, mode))
GEN_THUNKS(glBlendEquationiEXT, (GLuint buf, GLenum mode), (buf, mode))
GEN_THUNKS(glBlendEquationiOES, (GLuint buf, GLenum mode), (buf, mode))
GEN_THUNKS(glBlendFunc, (GLenum sfactor, GLenum dfactor), (sfactor, dfactor))
GEN_THUNKS(glBlendFuncIndexedAMD, (GLuint buf, GLenum src, GLenum dst), (buf, src, dst))
GEN_THUNKS(glBlendFuncSeparate, (GLenum sfactorRGB, GLenum dfactorRGB, GLenum sfactorAlpha, GLenum dfactorAlpha), (sfactorRGB, dfactorRGB, sfactorAlpha, dfactorAlpha))
GEN_THUNKS(glBlendFuncSeparateEXT, (GLenum sfactorRGB, GLenum dfactorRGB, GLenum sfactorAlpha, GLenum dfactorAlpha), (sfactorRGB, dfactorRGB, sfactorAlpha, dfactorAlpha))
GEN_THUNKS(glBlendFuncSeparateINGR, (GLenum sfactorRGB, GLenum dfactorRGB, GLenum sfactorAlpha, GLenum dfactorAlpha), (sfactorRGB, dfactorRGB, sfactorAlpha, dfactorAlpha))
GEN_THUNKS(glBlendFuncSeparateIndexedAMD, (GLuint buf, GLenum srcRGB, GLenum dstRGB, GLenum srcAlpha, GLenum dstAlpha), (buf, srcRGB, dstRGB, srcAlpha, dstAlpha))
GEN_THUNKS(glBlendFuncSeparateOES, (GLenum srcRGB, GLenum dstRGB, GLenum srcAlpha, GLenum dstAlpha), (srcRGB, dstRGB, srcAlpha, dstAlpha))
GEN_THUNKS(glBlendFuncSeparatei, (GLuint buf, GLenum srcRGB, GLenum dstRGB, GLenum srcAlpha, GLenum dstAlpha), (buf, srcRGB, dstRGB, srcAlpha, dstAlpha))
GEN_THUNKS(glBlendFuncSeparateiARB, (GLuint buf, GLenum srcRGB, GLenum dstRGB, GLenum srcAlpha, GLenum dstAlpha), (buf, srcRGB, dstRGB, srcAlpha, dstAlpha))
GEN_THUNKS(glBlendFuncSeparateiEXT, (GLuint buf, GLenum srcRGB, GLenum dstRGB, GLenum srcAlpha, GLenum dstAlpha), (buf, srcRGB, dstRGB, srcAlpha, dstAlpha))
GEN_THUNKS(glBlendFuncSeparateiOES, (GLuint buf, GLenum srcRGB, GLenum dstRGB, GLenum srcAlpha, GLenum dstAlpha), (buf, srcRGB, dstRGB, srcAlpha, dstAlpha))
GEN_THUNKS(glBlendFunci, (GLuint buf, GLenum src, GLenum dst), (buf, src, dst))
GEN_THUNKS(glBlendFunciARB, (GLuint buf, GLenum src, GLenum dst), (buf, src, dst))
GEN_THUNKS(glBlendFunciEXT, (GLuint buf, GLenum src, GLenum dst), (buf, src, dst))
GEN_THUNKS(glBlendFunciOES, (GLuint buf, GLenum src, GLenum dst), (buf, src, dst))
GEN_THUNKS(glBlendParameteriNV, (GLenum pname, GLint value), (pname, value))
GEN_THUNKS(glBlitFramebuffer, (GLint srcX0, GLint srcY0, GLint srcX1, GLint srcY1, GLint dstX0, GLint dstY0, GLint dstX1, GLint dstY1, GLbitfield mask, GLenum filter), (srcX0, srcY0, srcX1, srcY1, dstX0, dstY0, dstX1, dstY1, mask, filter))
GEN_THUNKS(glBlitFramebufferANGLE, (GLint srcX0, GLint srcY0, GLint srcX1, GLint srcY1, GLint dstX0, GLint dstY0, GLint dstX1, GLint dstY1, GLbitfield mask, GLenum filter), (srcX0, srcY0, srcX1, srcY1, dstX0, dstY0, dstX1, dstY1, mask, filter))
GEN_THUNKS(glBlitFramebufferEXT, (GLint srcX0, GLint srcY0, GLint srcX1, GLint srcY1, GLint dstX0, GLint dstY0, GLint dstX1, GLint dstY1, GLbitfield mask, GLenum filter), (srcX0, srcY0, srcX1, srcY1, dstX0, dstY0, dstX1, dstY1, mask, filter))
GEN_THUNKS(glBlitFramebufferNV, (GLint srcX0, GLint srcY0, GLint srcX1, GLint srcY1, GLint dstX0, GLint dstY0, GLint dstX1, GLint dstY1, GLbitfield mask, GLenum filter), (srcX0, srcY0, srcX1, srcY1, dstX0, dstY0, dstX1, dstY1, mask, filter))
GEN_THUNKS(glBlitNamedFramebuffer, (GLuint readFramebuffer, GLuint drawFramebuffer, GLint srcX0, GLint srcY0, GLint srcX1, GLint srcY1, GLint dstX0, GLint dstY0, GLint dstX1, GLint dstY1, GLbitfield mask, GLenum filter), (readFramebuffer, drawFramebuffer, srcX0, srcY0, srcX1, srcY1, dstX0, dstY0, dstX1, dstY1, mask, filter))
GEN_THUNKS(glBufferAddressRangeNV, (GLenum pname, GLuint index, GLuint64EXT address, GLsizeiptr length), (pname, index, address, length))
GEN_THUNKS(glBufferAttachMemoryNV, (GLenum target, GLuint memory, GLuint64 offset), (target, memory, offset))
GEN_THUNKS(glBufferData, (GLenum target, GLsizeiptr size, const void * data, GLenum usage), (target, size, data, usage))
GEN_THUNKS(glBufferDataARB, (GLenum target, GLsizeiptrARB size, const void * data, GLenum usage), (target, size, data, usage))
GEN_THUNKS(glBufferPageCommitmentARB, (GLenum target, GLintptr offset, GLsizeiptr size, GLboolean commit), (target, offset, size, commit))
GEN_THUNKS(glBufferParameteriAPPLE, (GLenum target, GLenum pname, GLint param), (target, pname, param))
GEN_THUNKS(glBufferStorage, (GLenum target, GLsizeiptr size, const void * data, GLbitfield flags), (target, size, data, flags))
GEN_THUNKS(glBufferStorageEXT, (GLenum target, GLsizeiptr size, const void * data, GLbitfield flags), (target, size, data, flags))
GEN_THUNKS(glBufferStorageExternalEXT, (GLenum target, GLintptr offset, GLsizeiptr size, GLeglClientBufferEXT clientBuffer, GLbitfield flags), (target, offset, size, clientBuffer, flags))
GEN_THUNKS(glBufferStorageMemEXT, (GLenum target, GLsizeiptr size, GLuint memory, GLuint64 offset), (target, size, memory, offset))
GEN_THUNKS(glBufferSubData, (GLenum target, GLintptr offset, GLsizeiptr size, const void * data), (target, offset, size, data))
GEN_THUNKS(glBufferSubDataARB, (GLenum target, GLintptrARB offset, GLsizeiptrARB size, const void * data), (target, offset, size, data))
GEN_THUNKS(glCallCommandListNV, (GLuint list), (list))
GEN_THUNKS(glCallList, (GLuint list), (list))
GEN_THUNKS(glCallLists, (GLsizei n, GLenum type, const void * lists), (n, type, lists))
GEN_THUNKS_RET(GLenum, glCheckFramebufferStatus, (GLenum target), (target))
GEN_THUNKS_RET(GLenum, glCheckFramebufferStatusEXT, (GLenum target), (target))
GEN_THUNKS_RET(GLenum, glCheckFramebufferStatusOES, (GLenum target), (target))
GEN_THUNKS_RET(GLenum, glCheckNamedFramebufferStatus, (GLuint framebuffer, GLenum target), (framebuffer, target))
GEN_THUNKS_RET(GLenum, glCheckNamedFramebufferStatusEXT, (GLuint framebuffer, GLenum target), (framebuffer, target))
GEN_THUNKS(glClampColor, (GLenum target, GLenum clamp), (target, clamp))
GEN_THUNKS(glClampColorARB, (GLenum target, GLenum clamp), (target, clamp))
GEN_THUNKS(glClear, (GLbitfield mask), (mask))
GEN_THUNKS(glClearAccum, (GLfloat red, GLfloat green, GLfloat blue, GLfloat alpha), (red, green, blue, alpha))
GEN_THUNKS(glClearAccumxOES, (GLfixed red, GLfixed green, GLfixed blue, GLfixed alpha), (red, green, blue, alpha))
GEN_THUNKS(glClearBufferData, (GLenum target, GLenum internalformat, GLenum format, GLenum type, const void * data), (target, internalformat, format, type, data))
GEN_THUNKS(glClearBufferSubData, (GLenum target, GLenum internalformat, GLintptr offset, GLsizeiptr size, GLenum format, GLenum type, const void * data), (target, internalformat, offset, size, format, type, data))
GEN_THUNKS(glClearBufferfi, (GLenum buffer, GLint drawbuffer, GLfloat depth, GLint stencil), (buffer, drawbuffer, depth, stencil))
GEN_THUNKS(glClearBufferfv, (GLenum buffer, GLint drawbuffer, const GLfloat * value), (buffer, drawbuffer, value))
GEN_THUNKS(glClearBufferiv, (GLenum buffer, GLint drawbuffer, const GLint * value), (buffer, drawbuffer, value))
GEN_THUNKS(glClearBufferuiv, (GLenum buffer, GLint drawbuffer, const GLuint * value), (buffer, drawbuffer, value))
GEN_THUNKS(glClearColor, (GLfloat red, GLfloat green, GLfloat blue, GLfloat alpha), (red, green, blue, alpha))
GEN_THUNKS(glClearColorIiEXT, (GLint red, GLint green, GLint blue, GLint alpha), (red, green, blue, alpha))
GEN_THUNKS(glClearColorIuiEXT, (GLuint red, GLuint green, GLuint blue, GLuint alpha), (red, green, blue, alpha))
GEN_THUNKS(glClearColorx, (GLfixed red, GLfixed green, GLfixed blue, GLfixed alpha), (red, green, blue, alpha))
GEN_THUNKS(glClearColorxOES, (GLfixed red, GLfixed green, GLfixed blue, GLfixed alpha), (red, green, blue, alpha))
GEN_THUNKS(glClearDepth, (GLdouble depth), (depth))
GEN_THUNKS(glClearDepthdNV, (GLdouble depth), (depth))
GEN_THUNKS(glClearDepthf, (GLfloat d), (d))
GEN_THUNKS(glClearDepthfOES, (GLclampf depth), (depth))
GEN_THUNKS(glClearDepthx, (GLfixed depth), (depth))
GEN_THUNKS(glClearDepthxOES, (GLfixed depth), (depth))
GEN_THUNKS(glClearIndex, (GLfloat c), (c))
GEN_THUNKS(glClearNamedBufferData, (GLuint buffer, GLenum internalformat, GLenum format, GLenum type, const void * data), (buffer, internalformat, format, type, data))
GEN_THUNKS(glClearNamedBufferDataEXT, (GLuint buffer, GLenum internalformat, GLenum format, GLenum type, const void * data), (buffer, internalformat, format, type, data))
GEN_THUNKS(glClearNamedBufferSubData, (GLuint buffer, GLenum internalformat, GLintptr offset, GLsizeiptr size, GLenum format, GLenum type, const void * data), (buffer, internalformat, offset, size, format, type, data))
GEN_THUNKS(glClearNamedBufferSubDataEXT, (GLuint buffer, GLenum internalformat, GLsizeiptr offset, GLsizeiptr size, GLenum format, GLenum type, const void * data), (buffer, internalformat, offset, size, format, type, data))
GEN_THUNKS(glClearNamedFramebufferfi, (GLuint framebuffer, GLenum buffer, GLint drawbuffer, GLfloat depth, GLint stencil), (framebuffer, buffer, drawbuffer, depth, stencil))
GEN_THUNKS(glClearNamedFramebufferfv, (GLuint framebuffer, GLenum buffer, GLint drawbuffer, const GLfloat * value), (framebuffer, buffer, drawbuffer, value))
GEN_THUNKS(glClearNamedFramebufferiv, (GLuint framebuffer, GLenum buffer, GLint drawbuffer, const GLint * value), (framebuffer, buffer, drawbuffer, value))
GEN_THUNKS(glClearNamedFramebufferuiv, (GLuint framebuffer, GLenum buffer, GLint drawbuffer, const GLuint * value), (framebuffer, buffer, drawbuffer, value))
GEN_THUNKS(glClearPixelLocalStorageuiEXT, (GLsizei offset, GLsizei n, const GLuint * values), (offset, n, values))
GEN_THUNKS(glClearStencil, (GLint s), (s))
GEN_THUNKS(glClearTexImage, (GLuint texture, GLint level, GLenum format, GLenum type, const void * data), (texture, level, format, type, data))
GEN_THUNKS(glClearTexImageEXT, (GLuint texture, GLint level, GLenum format, GLenum type, const void * data), (texture, level, format, type, data))
GEN_THUNKS(glClearTexSubImage, (GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void * data), (texture, level, xoffset, yoffset, zoffset, width, height, depth, format, type, data))
GEN_THUNKS(glClearTexSubImageEXT, (GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void * data), (texture, level, xoffset, yoffset, zoffset, width, height, depth, format, type, data))
GEN_THUNKS(glClientActiveTexture, (GLenum texture), (texture))
GEN_THUNKS(glClientActiveTextureARB, (GLenum texture), (texture))
GEN_THUNKS(glClientActiveVertexStreamATI, (GLenum stream), (stream))
GEN_THUNKS(glClientAttribDefaultEXT, (GLbitfield mask), (mask))
GEN_THUNKS(glClientWaitSemaphoreui64NVX, (GLsizei fenceObjectCount, const GLuint * semaphoreArray, const GLuint64 * fenceValueArray), (fenceObjectCount, semaphoreArray, fenceValueArray))
GEN_THUNKS_RET(GLenum, glClientWaitSync, (GLsync sync, GLbitfield flags, GLuint64 timeout), (sync, flags, timeout))
GEN_THUNKS_RET(GLenum, glClientWaitSyncAPPLE, (GLsync sync, GLbitfield flags, GLuint64 timeout), (sync, flags, timeout))
GEN_THUNKS(glClipControl, (GLenum origin, GLenum depth), (origin, depth))
GEN_THUNKS(glClipControlEXT, (GLenum origin, GLenum depth), (origin, depth))
GEN_THUNKS(glClipPlane, (GLenum plane, const GLdouble * equation), (plane, equation))
GEN_THUNKS(glClipPlanef, (GLenum p, const GLfloat * eqn), (p, eqn))
GEN_THUNKS(glClipPlanefIMG, (GLenum p, const GLfloat * eqn), (p, eqn))
GEN_THUNKS(glClipPlanefOES, (GLenum plane, const GLfloat * equation), (plane, equation))
GEN_THUNKS(glClipPlanex, (GLenum plane, const GLfixed * equation), (plane, equation))
GEN_THUNKS(glClipPlanexIMG, (GLenum p, const GLfixed * eqn), (p, eqn))
GEN_THUNKS(glClipPlanexOES, (GLenum plane, const GLfixed * equation), (plane, equation))
GEN_THUNKS(glColor3b, (GLbyte red, GLbyte green, GLbyte blue), (red, green, blue))
GEN_THUNKS(glColor3bv, (const GLbyte * v), (v))
GEN_THUNKS(glColor3d, (GLdouble red, GLdouble green, GLdouble blue), (red, green, blue))
GEN_THUNKS(glColor3dv, (const GLdouble * v), (v))
GEN_THUNKS(glColor3f, (GLfloat red, GLfloat green, GLfloat blue), (red, green, blue))
GEN_THUNKS(glColor3fVertex3fSUN, (GLfloat r, GLfloat g, GLfloat b, GLfloat x, GLfloat y, GLfloat z), (r, g, b, x, y, z))
GEN_THUNKS(glColor3fVertex3fvSUN, (const GLfloat * c, const GLfloat * v), (c, v))
GEN_THUNKS(glColor3fv, (const GLfloat * v), (v))
GEN_THUNKS(glColor3hNV, (GLhalfNV red, GLhalfNV green, GLhalfNV blue), (red, green, blue))
GEN_THUNKS(glColor3hvNV, (const GLhalfNV * v), (v))
GEN_THUNKS(glColor3i, (GLint red, GLint green, GLint blue), (red, green, blue))
GEN_THUNKS(glColor3iv, (const GLint * v), (v))
GEN_THUNKS(glColor3s, (GLshort red, GLshort green, GLshort blue), (red, green, blue))
GEN_THUNKS(glColor3sv, (const GLshort * v), (v))
GEN_THUNKS(glColor3ub, (GLubyte red, GLubyte green, GLubyte blue), (red, green, blue))
GEN_THUNKS(glColor3ubv, (const GLubyte * v), (v))
GEN_THUNKS(glColor3ui, (GLuint red, GLuint green, GLuint blue), (red, green, blue))
GEN_THUNKS(glColor3uiv, (const GLuint * v), (v))
GEN_THUNKS(glColor3us, (GLushort red, GLushort green, GLushort blue), (red, green, blue))
GEN_THUNKS(glColor3usv, (const GLushort * v), (v))
GEN_THUNKS(glColor3xOES, (GLfixed red, GLfixed green, GLfixed blue), (red, green, blue))
GEN_THUNKS(glColor3xvOES, (const GLfixed * components), (components))
GEN_THUNKS(glColor4b, (GLbyte red, GLbyte green, GLbyte blue, GLbyte alpha), (red, green, blue, alpha))
GEN_THUNKS(glColor4bv, (const GLbyte * v), (v))
GEN_THUNKS(glColor4d, (GLdouble red, GLdouble green, GLdouble blue, GLdouble alpha), (red, green, blue, alpha))
GEN_THUNKS(glColor4dv, (const GLdouble * v), (v))
GEN_THUNKS(glColor4f, (GLfloat red, GLfloat green, GLfloat blue, GLfloat alpha), (red, green, blue, alpha))
GEN_THUNKS(glColor4fNormal3fVertex3fSUN, (GLfloat r, GLfloat g, GLfloat b, GLfloat a, GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z), (r, g, b, a, nx, ny, nz, x, y, z))
GEN_THUNKS(glColor4fNormal3fVertex3fvSUN, (const GLfloat * c, const GLfloat * n, const GLfloat * v), (c, n, v))
GEN_THUNKS(glColor4fv, (const GLfloat * v), (v))
GEN_THUNKS(glColor4hNV, (GLhalfNV red, GLhalfNV green, GLhalfNV blue, GLhalfNV alpha), (red, green, blue, alpha))
GEN_THUNKS(glColor4hvNV, (const GLhalfNV * v), (v))
GEN_THUNKS(glColor4i, (GLint red, GLint green, GLint blue, GLint alpha), (red, green, blue, alpha))
GEN_THUNKS(glColor4iv, (const GLint * v), (v))
GEN_THUNKS(glColor4s, (GLshort red, GLshort green, GLshort blue, GLshort alpha), (red, green, blue, alpha))
GEN_THUNKS(glColor4sv, (const GLshort * v), (v))
GEN_THUNKS(glColor4ub, (GLubyte red, GLubyte green, GLubyte blue, GLubyte alpha), (red, green, blue, alpha))
GEN_THUNKS(glColor4ubVertex2fSUN, (GLubyte r, GLubyte g, GLubyte b, GLubyte a, GLfloat x, GLfloat y), (r, g, b, a, x, y))
GEN_THUNKS(glColor4ubVertex2fvSUN, (const GLubyte * c, const GLfloat * v), (c, v))
GEN_THUNKS(glColor4ubVertex3fSUN, (GLubyte r, GLubyte g, GLubyte b, GLubyte a, GLfloat x, GLfloat y, GLfloat z), (r, g, b, a, x, y, z))
GEN_THUNKS(glColor4ubVertex3fvSUN, (const GLubyte * c, const GLfloat * v), (c, v))
GEN_THUNKS(glColor4ubv, (const GLubyte * v), (v))
GEN_THUNKS(glColor4ui, (GLuint red, GLuint green, GLuint blue, GLuint alpha), (red, green, blue, alpha))
GEN_THUNKS(glColor4uiv, (const GLuint * v), (v))
GEN_THUNKS(glColor4us, (GLushort red, GLushort green, GLushort blue, GLushort alpha), (red, green, blue, alpha))
GEN_THUNKS(glColor4usv, (const GLushort * v), (v))
GEN_THUNKS(glColor4x, (GLfixed red, GLfixed green, GLfixed blue, GLfixed alpha), (red, green, blue, alpha))
GEN_THUNKS(glColor4xOES, (GLfixed red, GLfixed green, GLfixed blue, GLfixed alpha), (red, green, blue, alpha))
GEN_THUNKS(glColor4xvOES, (const GLfixed * components), (components))
GEN_THUNKS(glColorFormatNV, (GLint size, GLenum type, GLsizei stride), (size, type, stride))
GEN_THUNKS(glColorFragmentOp1ATI, (GLenum op, GLuint dst, GLuint dstMask, GLuint dstMod, GLuint arg1, GLuint arg1Rep, GLuint arg1Mod), (op, dst, dstMask, dstMod, arg1, arg1Rep, arg1Mod))
GEN_THUNKS(glColorFragmentOp2ATI, (GLenum op, GLuint dst, GLuint dstMask, GLuint dstMod, GLuint arg1, GLuint arg1Rep, GLuint arg1Mod, GLuint arg2, GLuint arg2Rep, GLuint arg2Mod), (op, dst, dstMask, dstMod, arg1, arg1Rep, arg1Mod, arg2, arg2Rep, arg2Mod))
GEN_THUNKS(glColorFragmentOp3ATI, (GLenum op, GLuint dst, GLuint dstMask, GLuint dstMod, GLuint arg1, GLuint arg1Rep, GLuint arg1Mod, GLuint arg2, GLuint arg2Rep, GLuint arg2Mod, GLuint arg3, GLuint arg3Rep, GLuint arg3Mod), (op, dst, dstMask, dstMod, arg1, arg1Rep, arg1Mod, arg2, arg2Rep, arg2Mod, arg3, arg3Rep, arg3Mod))
GEN_THUNKS(glColorMask, (GLboolean red, GLboolean green, GLboolean blue, GLboolean alpha), (red, green, blue, alpha))
GEN_THUNKS(glColorMaskIndexedEXT, (GLuint index, GLboolean r, GLboolean g, GLboolean b, GLboolean a), (index, r, g, b, a))
GEN_THUNKS(glColorMaski, (GLuint index, GLboolean r, GLboolean g, GLboolean b, GLboolean a), (index, r, g, b, a))
GEN_THUNKS(glColorMaskiEXT, (GLuint index, GLboolean r, GLboolean g, GLboolean b, GLboolean a), (index, r, g, b, a))
GEN_THUNKS(glColorMaskiOES, (GLuint index, GLboolean r, GLboolean g, GLboolean b, GLboolean a), (index, r, g, b, a))
GEN_THUNKS(glColorMaterial, (GLenum face, GLenum mode), (face, mode))
GEN_THUNKS(glColorP3ui, (GLenum type, GLuint color), (type, color))
GEN_THUNKS(glColorP3uiv, (GLenum type, const GLuint * color), (type, color))
GEN_THUNKS(glColorP4ui, (GLenum type, GLuint color), (type, color))
GEN_THUNKS(glColorP4uiv, (GLenum type, const GLuint * color), (type, color))
GEN_THUNKS(glColorPointer, (GLint size, GLenum type, GLsizei stride, const void * pointer), (size, type, stride, pointer))
GEN_THUNKS(glColorPointerEXT, (GLint size, GLenum type, GLsizei stride, GLsizei count, const void * pointer), (size, type, stride, count, pointer))
GEN_THUNKS(glColorPointerListIBM, (GLint size, GLenum type, GLint stride, const void ** pointer, GLint ptrstride), (size, type, stride, pointer, ptrstride))
GEN_THUNKS(glColorPointervINTEL, (GLint size, GLenum type, const void ** pointer), (size, type, pointer))
GEN_THUNKS(glColorSubTable, (GLenum target, GLsizei start, GLsizei count, GLenum format, GLenum type, const void * data), (target, start, count, format, type, data))
GEN_THUNKS(glColorSubTableEXT, (GLenum target, GLsizei start, GLsizei count, GLenum format, GLenum type, const void * data), (target, start, count, format, type, data))
GEN_THUNKS(glColorTable, (GLenum target, GLenum internalformat, GLsizei width, GLenum format, GLenum type, const void * table), (target, internalformat, width, format, type, table))
GEN_THUNKS(glColorTableEXT, (GLenum target, GLenum internalFormat, GLsizei width, GLenum format, GLenum type, const void * table), (target, internalFormat, width, format, type, table))
GEN_THUNKS(glColorTableParameterfv, (GLenum target, GLenum pname, const GLfloat * params), (target, pname, params))
GEN_THUNKS(glColorTableParameterfvSGI, (GLenum target, GLenum pname, const GLfloat * params), (target, pname, params))
GEN_THUNKS(glColorTableParameteriv, (GLenum target, GLenum pname, const GLint * params), (target, pname, params))
GEN_THUNKS(glColorTableParameterivSGI, (GLenum target, GLenum pname, const GLint * params), (target, pname, params))
GEN_THUNKS(glColorTableSGI, (GLenum target, GLenum internalformat, GLsizei width, GLenum format, GLenum type, const void * table), (target, internalformat, width, format, type, table))
GEN_THUNKS(glCombinerInputNV, (GLenum stage, GLenum portion, GLenum variable, GLenum input, GLenum mapping, GLenum componentUsage), (stage, portion, variable, input, mapping, componentUsage))
GEN_THUNKS(glCombinerOutputNV, (GLenum stage, GLenum portion, GLenum abOutput, GLenum cdOutput, GLenum sumOutput, GLenum scale, GLenum bias, GLboolean abDotProduct, GLboolean cdDotProduct, GLboolean muxSum), (stage, portion, abOutput, cdOutput, sumOutput, scale, bias, abDotProduct, cdDotProduct, muxSum))
GEN_THUNKS(glCombinerParameterfNV, (GLenum pname, GLfloat param), (pname, param))
GEN_THUNKS(glCombinerParameterfvNV, (GLenum pname, const GLfloat * params), (pname, params))
GEN_THUNKS(glCombinerParameteriNV, (GLenum pname, GLint param), (pname, param))
GEN_THUNKS(glCombinerParameterivNV, (GLenum pname, const GLint * params), (pname, params))
GEN_THUNKS(glCombinerStageParameterfvNV, (GLenum stage, GLenum pname, const GLfloat * params), (stage, pname, params))
GEN_THUNKS(glCommandListSegmentsNV, (GLuint list, GLuint segments), (list, segments))
GEN_THUNKS(glCompileCommandListNV, (GLuint list), (list))
GEN_THUNKS(glCompileShader, (GLuint shader), (shader))
GEN_THUNKS(glCompileShaderARB, (GLhandleARB shaderObj), ((uintptr_t)shaderObj))
GEN_THUNKS(glCompileShaderIncludeARB, (GLuint shader, GLsizei count, const GLchar *const* path, const GLint * length), (shader, count, path, length))
GEN_THUNKS(glCompressedMultiTexImage1DEXT, (GLenum texunit, GLenum target, GLint level, GLenum internalformat, GLsizei width, GLint border, GLsizei imageSize, const void * bits), (texunit, target, level, internalformat, width, border, imageSize, bits))
GEN_THUNKS(glCompressedMultiTexImage2DEXT, (GLenum texunit, GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLint border, GLsizei imageSize, const void * bits), (texunit, target, level, internalformat, width, height, border, imageSize, bits))
GEN_THUNKS(glCompressedMultiTexImage3DEXT, (GLenum texunit, GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLsizei imageSize, const void * bits), (texunit, target, level, internalformat, width, height, depth, border, imageSize, bits))
GEN_THUNKS(glCompressedMultiTexSubImage1DEXT, (GLenum texunit, GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLsizei imageSize, const void * bits), (texunit, target, level, xoffset, width, format, imageSize, bits))
GEN_THUNKS(glCompressedMultiTexSubImage2DEXT, (GLenum texunit, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLsizei imageSize, const void * bits), (texunit, target, level, xoffset, yoffset, width, height, format, imageSize, bits))
GEN_THUNKS(glCompressedMultiTexSubImage3DEXT, (GLenum texunit, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLsizei imageSize, const void * bits), (texunit, target, level, xoffset, yoffset, zoffset, width, height, depth, format, imageSize, bits))
GEN_THUNKS(glCompressedTexImage1D, (GLenum target, GLint level, GLenum internalformat, GLsizei width, GLint border, GLsizei imageSize, const void * data), (target, level, internalformat, width, border, imageSize, data))
GEN_THUNKS(glCompressedTexImage1DARB, (GLenum target, GLint level, GLenum internalformat, GLsizei width, GLint border, GLsizei imageSize, const void * data), (target, level, internalformat, width, border, imageSize, data))
GEN_THUNKS(glCompressedTexImage2D, (GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLint border, GLsizei imageSize, const void * data), (target, level, internalformat, width, height, border, imageSize, data))
GEN_THUNKS(glCompressedTexImage2DARB, (GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLint border, GLsizei imageSize, const void * data), (target, level, internalformat, width, height, border, imageSize, data))
GEN_THUNKS(glCompressedTexImage3D, (GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLsizei imageSize, const void * data), (target, level, internalformat, width, height, depth, border, imageSize, data))
GEN_THUNKS(glCompressedTexImage3DARB, (GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLsizei imageSize, const void * data), (target, level, internalformat, width, height, depth, border, imageSize, data))
GEN_THUNKS(glCompressedTexImage3DOES, (GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLsizei imageSize, const void * data), (target, level, internalformat, width, height, depth, border, imageSize, data))
GEN_THUNKS(glCompressedTexSubImage1D, (GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLsizei imageSize, const void * data), (target, level, xoffset, width, format, imageSize, data))
GEN_THUNKS(glCompressedTexSubImage1DARB, (GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLsizei imageSize, const void * data), (target, level, xoffset, width, format, imageSize, data))
GEN_THUNKS(glCompressedTexSubImage2D, (GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLsizei imageSize, const void * data), (target, level, xoffset, yoffset, width, height, format, imageSize, data))
GEN_THUNKS(glCompressedTexSubImage2DARB, (GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLsizei imageSize, const void * data), (target, level, xoffset, yoffset, width, height, format, imageSize, data))
GEN_THUNKS(glCompressedTexSubImage3D, (GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLsizei imageSize, const void * data), (target, level, xoffset, yoffset, zoffset, width, height, depth, format, imageSize, data))
GEN_THUNKS(glCompressedTexSubImage3DARB, (GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLsizei imageSize, const void * data), (target, level, xoffset, yoffset, zoffset, width, height, depth, format, imageSize, data))
GEN_THUNKS(glCompressedTexSubImage3DOES, (GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLsizei imageSize, const void * data), (target, level, xoffset, yoffset, zoffset, width, height, depth, format, imageSize, data))
GEN_THUNKS(glCompressedTextureImage1DEXT, (GLuint texture, GLenum target, GLint level, GLenum internalformat, GLsizei width, GLint border, GLsizei imageSize, const void * bits), (texture, target, level, internalformat, width, border, imageSize, bits))
GEN_THUNKS(glCompressedTextureImage2DEXT, (GLuint texture, GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLint border, GLsizei imageSize, const void * bits), (texture, target, level, internalformat, width, height, border, imageSize, bits))
GEN_THUNKS(glCompressedTextureImage3DEXT, (GLuint texture, GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLsizei imageSize, const void * bits), (texture, target, level, internalformat, width, height, depth, border, imageSize, bits))
GEN_THUNKS(glCompressedTextureSubImage1D, (GLuint texture, GLint level, GLint xoffset, GLsizei width, GLenum format, GLsizei imageSize, const void * data), (texture, level, xoffset, width, format, imageSize, data))
GEN_THUNKS(glCompressedTextureSubImage1DEXT, (GLuint texture, GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLsizei imageSize, const void * bits), (texture, target, level, xoffset, width, format, imageSize, bits))
GEN_THUNKS(glCompressedTextureSubImage2D, (GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLsizei imageSize, const void * data), (texture, level, xoffset, yoffset, width, height, format, imageSize, data))
GEN_THUNKS(glCompressedTextureSubImage2DEXT, (GLuint texture, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLsizei imageSize, const void * bits), (texture, target, level, xoffset, yoffset, width, height, format, imageSize, bits))
GEN_THUNKS(glCompressedTextureSubImage3D, (GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLsizei imageSize, const void * data), (texture, level, xoffset, yoffset, zoffset, width, height, depth, format, imageSize, data))
GEN_THUNKS(glCompressedTextureSubImage3DEXT, (GLuint texture, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLsizei imageSize, const void * bits), (texture, target, level, xoffset, yoffset, zoffset, width, height, depth, format, imageSize, bits))
GEN_THUNKS(glConservativeRasterParameterfNV, (GLenum pname, GLfloat value), (pname, value))
GEN_THUNKS(glConservativeRasterParameteriNV, (GLenum pname, GLint param), (pname, param))
GEN_THUNKS(glConvolutionFilter1D, (GLenum target, GLenum internalformat, GLsizei width, GLenum format, GLenum type, const void * image), (target, internalformat, width, format, type, image))
GEN_THUNKS(glConvolutionFilter1DEXT, (GLenum target, GLenum internalformat, GLsizei width, GLenum format, GLenum type, const void * image), (target, internalformat, width, format, type, image))
GEN_THUNKS(glConvolutionFilter2D, (GLenum target, GLenum internalformat, GLsizei width, GLsizei height, GLenum format, GLenum type, const void * image), (target, internalformat, width, height, format, type, image))
GEN_THUNKS(glConvolutionFilter2DEXT, (GLenum target, GLenum internalformat, GLsizei width, GLsizei height, GLenum format, GLenum type, const void * image), (target, internalformat, width, height, format, type, image))
GEN_THUNKS(glConvolutionParameterf, (GLenum target, GLenum pname, GLfloat params), (target, pname, params))
GEN_THUNKS(glConvolutionParameterfEXT, (GLenum target, GLenum pname, GLfloat params), (target, pname, params))
GEN_THUNKS(glConvolutionParameterfv, (GLenum target, GLenum pname, const GLfloat * params), (target, pname, params))
GEN_THUNKS(glConvolutionParameterfvEXT, (GLenum target, GLenum pname, const GLfloat * params), (target, pname, params))
GEN_THUNKS(glConvolutionParameteri, (GLenum target, GLenum pname, GLint params), (target, pname, params))
GEN_THUNKS(glConvolutionParameteriEXT, (GLenum target, GLenum pname, GLint params), (target, pname, params))
GEN_THUNKS(glConvolutionParameteriv, (GLenum target, GLenum pname, const GLint * params), (target, pname, params))
GEN_THUNKS(glConvolutionParameterivEXT, (GLenum target, GLenum pname, const GLint * params), (target, pname, params))
GEN_THUNKS(glConvolutionParameterxOES, (GLenum target, GLenum pname, GLfixed param), (target, pname, param))
GEN_THUNKS(glConvolutionParameterxvOES, (GLenum target, GLenum pname, const GLfixed * params), (target, pname, params))
GEN_THUNKS(glCopyBufferSubData, (GLenum readTarget, GLenum writeTarget, GLintptr readOffset, GLintptr writeOffset, GLsizeiptr size), (readTarget, writeTarget, readOffset, writeOffset, size))
GEN_THUNKS(glCopyBufferSubDataNV, (GLenum readTarget, GLenum writeTarget, GLintptr readOffset, GLintptr writeOffset, GLsizeiptr size), (readTarget, writeTarget, readOffset, writeOffset, size))
GEN_THUNKS(glCopyColorSubTable, (GLenum target, GLsizei start, GLint x, GLint y, GLsizei width), (target, start, x, y, width))
GEN_THUNKS(glCopyColorSubTableEXT, (GLenum target, GLsizei start, GLint x, GLint y, GLsizei width), (target, start, x, y, width))
GEN_THUNKS(glCopyColorTable, (GLenum target, GLenum internalformat, GLint x, GLint y, GLsizei width), (target, internalformat, x, y, width))
GEN_THUNKS(glCopyColorTableSGI, (GLenum target, GLenum internalformat, GLint x, GLint y, GLsizei width), (target, internalformat, x, y, width))
GEN_THUNKS(glCopyConvolutionFilter1D, (GLenum target, GLenum internalformat, GLint x, GLint y, GLsizei width), (target, internalformat, x, y, width))
GEN_THUNKS(glCopyConvolutionFilter1DEXT, (GLenum target, GLenum internalformat, GLint x, GLint y, GLsizei width), (target, internalformat, x, y, width))
GEN_THUNKS(glCopyConvolutionFilter2D, (GLenum target, GLenum internalformat, GLint x, GLint y, GLsizei width, GLsizei height), (target, internalformat, x, y, width, height))
GEN_THUNKS(glCopyConvolutionFilter2DEXT, (GLenum target, GLenum internalformat, GLint x, GLint y, GLsizei width, GLsizei height), (target, internalformat, x, y, width, height))
GEN_THUNKS(glCopyImageSubData, (GLuint srcName, GLenum srcTarget, GLint srcLevel, GLint srcX, GLint srcY, GLint srcZ, GLuint dstName, GLenum dstTarget, GLint dstLevel, GLint dstX, GLint dstY, GLint dstZ, GLsizei srcWidth, GLsizei srcHeight, GLsizei srcDepth), (srcName, srcTarget, srcLevel, srcX, srcY, srcZ, dstName, dstTarget, dstLevel, dstX, dstY, dstZ, srcWidth, srcHeight, srcDepth))
GEN_THUNKS(glCopyImageSubDataEXT, (GLuint srcName, GLenum srcTarget, GLint srcLevel, GLint srcX, GLint srcY, GLint srcZ, GLuint dstName, GLenum dstTarget, GLint dstLevel, GLint dstX, GLint dstY, GLint dstZ, GLsizei srcWidth, GLsizei srcHeight, GLsizei srcDepth), (srcName, srcTarget, srcLevel, srcX, srcY, srcZ, dstName, dstTarget, dstLevel, dstX, dstY, dstZ, srcWidth, srcHeight, srcDepth))
GEN_THUNKS(glCopyImageSubDataNV, (GLuint srcName, GLenum srcTarget, GLint srcLevel, GLint srcX, GLint srcY, GLint srcZ, GLuint dstName, GLenum dstTarget, GLint dstLevel, GLint dstX, GLint dstY, GLint dstZ, GLsizei width, GLsizei height, GLsizei depth), (srcName, srcTarget, srcLevel, srcX, srcY, srcZ, dstName, dstTarget, dstLevel, dstX, dstY, dstZ, width, height, depth))
GEN_THUNKS(glCopyImageSubDataOES, (GLuint srcName, GLenum srcTarget, GLint srcLevel, GLint srcX, GLint srcY, GLint srcZ, GLuint dstName, GLenum dstTarget, GLint dstLevel, GLint dstX, GLint dstY, GLint dstZ, GLsizei srcWidth, GLsizei srcHeight, GLsizei srcDepth), (srcName, srcTarget, srcLevel, srcX, srcY, srcZ, dstName, dstTarget, dstLevel, dstX, dstY, dstZ, srcWidth, srcHeight, srcDepth))
GEN_THUNKS(glCopyMultiTexImage1DEXT, (GLenum texunit, GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLint border), (texunit, target, level, internalformat, x, y, width, border))
GEN_THUNKS(glCopyMultiTexImage2DEXT, (GLenum texunit, GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLsizei height, GLint border), (texunit, target, level, internalformat, x, y, width, height, border))
GEN_THUNKS(glCopyMultiTexSubImage1DEXT, (GLenum texunit, GLenum target, GLint level, GLint xoffset, GLint x, GLint y, GLsizei width), (texunit, target, level, xoffset, x, y, width))
GEN_THUNKS(glCopyMultiTexSubImage2DEXT, (GLenum texunit, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint x, GLint y, GLsizei width, GLsizei height), (texunit, target, level, xoffset, yoffset, x, y, width, height))
GEN_THUNKS(glCopyMultiTexSubImage3DEXT, (GLenum texunit, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height), (texunit, target, level, xoffset, yoffset, zoffset, x, y, width, height))
GEN_THUNKS(glCopyNamedBufferSubData, (GLuint readBuffer, GLuint writeBuffer, GLintptr readOffset, GLintptr writeOffset, GLsizeiptr size), (readBuffer, writeBuffer, readOffset, writeOffset, size))
GEN_THUNKS(glCopyPathNV, (GLuint resultPath, GLuint srcPath), (resultPath, srcPath))
GEN_THUNKS(glCopyPixels, (GLint x, GLint y, GLsizei width, GLsizei height, GLenum type), (x, y, width, height, type))
GEN_THUNKS(glCopyTexImage1D, (GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLint border), (target, level, internalformat, x, y, width, border))
GEN_THUNKS(glCopyTexImage1DEXT, (GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLint border), (target, level, internalformat, x, y, width, border))
GEN_THUNKS(glCopyTexImage2D, (GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLsizei height, GLint border), (target, level, internalformat, x, y, width, height, border))
GEN_THUNKS(glCopyTexImage2DEXT, (GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLsizei height, GLint border), (target, level, internalformat, x, y, width, height, border))
GEN_THUNKS(glCopyTexSubImage1D, (GLenum target, GLint level, GLint xoffset, GLint x, GLint y, GLsizei width), (target, level, xoffset, x, y, width))
GEN_THUNKS(glCopyTexSubImage1DEXT, (GLenum target, GLint level, GLint xoffset, GLint x, GLint y, GLsizei width), (target, level, xoffset, x, y, width))
GEN_THUNKS(glCopyTexSubImage2D, (GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint x, GLint y, GLsizei width, GLsizei height), (target, level, xoffset, yoffset, x, y, width, height))
GEN_THUNKS(glCopyTexSubImage2DEXT, (GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint x, GLint y, GLsizei width, GLsizei height), (target, level, xoffset, yoffset, x, y, width, height))
GEN_THUNKS(glCopyTexSubImage3D, (GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height), (target, level, xoffset, yoffset, zoffset, x, y, width, height))
GEN_THUNKS(glCopyTexSubImage3DEXT, (GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height), (target, level, xoffset, yoffset, zoffset, x, y, width, height))
GEN_THUNKS(glCopyTexSubImage3DOES, (GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height), (target, level, xoffset, yoffset, zoffset, x, y, width, height))
GEN_THUNKS(glCopyTextureImage1DEXT, (GLuint texture, GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLint border), (texture, target, level, internalformat, x, y, width, border))
GEN_THUNKS(glCopyTextureImage2DEXT, (GLuint texture, GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLsizei height, GLint border), (texture, target, level, internalformat, x, y, width, height, border))
GEN_THUNKS(glCopyTextureLevelsAPPLE, (GLuint destinationTexture, GLuint sourceTexture, GLint sourceBaseLevel, GLsizei sourceLevelCount), (destinationTexture, sourceTexture, sourceBaseLevel, sourceLevelCount))
GEN_THUNKS(glCopyTextureSubImage1D, (GLuint texture, GLint level, GLint xoffset, GLint x, GLint y, GLsizei width), (texture, level, xoffset, x, y, width))
GEN_THUNKS(glCopyTextureSubImage1DEXT, (GLuint texture, GLenum target, GLint level, GLint xoffset, GLint x, GLint y, GLsizei width), (texture, target, level, xoffset, x, y, width))
GEN_THUNKS(glCopyTextureSubImage2D, (GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint x, GLint y, GLsizei width, GLsizei height), (texture, level, xoffset, yoffset, x, y, width, height))
GEN_THUNKS(glCopyTextureSubImage2DEXT, (GLuint texture, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint x, GLint y, GLsizei width, GLsizei height), (texture, target, level, xoffset, yoffset, x, y, width, height))
GEN_THUNKS(glCopyTextureSubImage3D, (GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height), (texture, level, xoffset, yoffset, zoffset, x, y, width, height))
GEN_THUNKS(glCopyTextureSubImage3DEXT, (GLuint texture, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height), (texture, target, level, xoffset, yoffset, zoffset, x, y, width, height))
GEN_THUNKS(glCoverFillPathInstancedNV, (GLsizei numPaths, GLenum pathNameType, const void * paths, GLuint pathBase, GLenum coverMode, GLenum transformType, const GLfloat * transformValues), (numPaths, pathNameType, paths, pathBase, coverMode, transformType, transformValues))
GEN_THUNKS(glCoverFillPathNV, (GLuint path, GLenum coverMode), (path, coverMode))
GEN_THUNKS(glCoverStrokePathInstancedNV, (GLsizei numPaths, GLenum pathNameType, const void * paths, GLuint pathBase, GLenum coverMode, GLenum transformType, const GLfloat * transformValues), (numPaths, pathNameType, paths, pathBase, coverMode, transformType, transformValues))
GEN_THUNKS(glCoverStrokePathNV, (GLuint path, GLenum coverMode), (path, coverMode))
GEN_THUNKS(glCoverageMaskNV, (GLboolean mask), (mask))
GEN_THUNKS(glCoverageModulationNV, (GLenum components), (components))
GEN_THUNKS(glCoverageModulationTableNV, (GLsizei n, const GLfloat * v), (n, v))
GEN_THUNKS(glCoverageOperationNV, (GLenum operation), (operation))
GEN_THUNKS(glCreateBuffers, (GLsizei n, GLuint * buffers), (n, buffers))
GEN_THUNKS(glCreateCommandListsNV, (GLsizei n, GLuint * lists), (n, lists))
GEN_THUNKS(glCreateFramebuffers, (GLsizei n, GLuint * framebuffers), (n, framebuffers))
GEN_THUNKS(glCreateMemoryObjectsEXT, (GLsizei n, GLuint * memoryObjects), (n, memoryObjects))
GEN_THUNKS(glCreatePerfQueryINTEL, (GLuint queryId, GLuint * queryHandle), (queryId, queryHandle))
GEN_THUNKS_RET(GLuint, glCreateProgram, (void), ())
GEN_THUNKS_RET(GLhandleARB, glCreateProgramObjectARB, (void), ())
GEN_THUNKS(glCreateProgramPipelines, (GLsizei n, GLuint * pipelines), (n, pipelines))
GEN_THUNKS_RET(GLuint, glCreateProgressFenceNVX, (void), ())
GEN_THUNKS(glCreateQueries, (GLenum target, GLsizei n, GLuint * ids), (target, n, ids))
GEN_THUNKS(glCreateRenderbuffers, (GLsizei n, GLuint * renderbuffers), (n, renderbuffers))
GEN_THUNKS(glCreateSamplers, (GLsizei n, GLuint * samplers), (n, samplers))
GEN_THUNKS_RET(GLuint, glCreateShader, (GLenum type), (type))
GEN_THUNKS_RET(GLhandleARB, glCreateShaderObjectARB, (GLenum shaderType), (shaderType))
GEN_THUNKS_RET(GLuint, glCreateShaderProgramEXT, (GLenum type, const GLchar * string), (type, string))
GEN_THUNKS_RET(GLuint, glCreateShaderProgramv, (GLenum type, GLsizei count, const GLchar *const* strings), (type, count, strings))
GEN_THUNKS_RET(GLuint, glCreateShaderProgramvEXT, (GLenum type, GLsizei count, const GLchar ** strings), (type, count, strings))
GEN_THUNKS(glCreateStatesNV, (GLsizei n, GLuint * states), (n, states))
GEN_THUNKS_RET(GLsync, glCreateSyncFromCLeventARB, (struct _cl_context * context, struct _cl_event * event, GLbitfield flags), (context, event, flags))
GEN_THUNKS(glCreateTextures, (GLenum target, GLsizei n, GLuint * textures), (target, n, textures))
GEN_THUNKS(glCreateTransformFeedbacks, (GLsizei n, GLuint * ids), (n, ids))
GEN_THUNKS(glCreateVertexArrays, (GLsizei n, GLuint * arrays), (n, arrays))
GEN_THUNKS(glCullFace, (GLenum mode), (mode))
GEN_THUNKS(glCullParameterdvEXT, (GLenum pname, GLdouble * params), (pname, params))
GEN_THUNKS(glCullParameterfvEXT, (GLenum pname, GLfloat * params), (pname, params))
GEN_THUNKS(glCurrentPaletteMatrixARB, (GLint index), (index))
GEN_THUNKS(glCurrentPaletteMatrixOES, (GLuint matrixpaletteindex), (matrixpaletteindex))
GEN_THUNKS(glDebugMessageCallback, (GLDEBUGPROC callback, const void * userParam), (callback, userParam))
GEN_THUNKS(glDebugMessageCallbackAMD, (GLDEBUGPROCAMD callback, void * userParam), (callback, userParam))
GEN_THUNKS(glDebugMessageCallbackARB, (GLDEBUGPROCARB callback, const void * userParam), (callback, userParam))
GEN_THUNKS(glDebugMessageCallbackKHR, (GLDEBUGPROCKHR callback, const void * userParam), (callback, userParam))
GEN_THUNKS(glDebugMessageControl, (GLenum source, GLenum type, GLenum severity, GLsizei count, const GLuint * ids, GLboolean enabled), (source, type, severity, count, ids, enabled))
GEN_THUNKS(glDebugMessageControlARB, (GLenum source, GLenum type, GLenum severity, GLsizei count, const GLuint * ids, GLboolean enabled), (source, type, severity, count, ids, enabled))
GEN_THUNKS(glDebugMessageControlKHR, (GLenum source, GLenum type, GLenum severity, GLsizei count, const GLuint * ids, GLboolean enabled), (source, type, severity, count, ids, enabled))
GEN_THUNKS(glDebugMessageEnableAMD, (GLenum category, GLenum severity, GLsizei count, const GLuint * ids, GLboolean enabled), (category, severity, count, ids, enabled))
GEN_THUNKS(glDebugMessageInsert, (GLenum source, GLenum type, GLuint id, GLenum severity, GLsizei length, const GLchar * buf), (source, type, id, severity, length, buf))
GEN_THUNKS(glDebugMessageInsertAMD, (GLenum category, GLenum severity, GLuint id, GLsizei length, const GLchar * buf), (category, severity, id, length, buf))
GEN_THUNKS(glDebugMessageInsertARB, (GLenum source, GLenum type, GLuint id, GLenum severity, GLsizei length, const GLchar * buf), (source, type, id, severity, length, buf))
GEN_THUNKS(glDebugMessageInsertKHR, (GLenum source, GLenum type, GLuint id, GLenum severity, GLsizei length, const GLchar * buf), (source, type, id, severity, length, buf))
GEN_THUNKS(glDeformSGIX, (GLbitfield mask), (mask))
GEN_THUNKS(glDeformationMap3dSGIX, (GLenum target, GLdouble u1, GLdouble u2, GLint ustride, GLint uorder, GLdouble v1, GLdouble v2, GLint vstride, GLint vorder, GLdouble w1, GLdouble w2, GLint wstride, GLint worder, const GLdouble * points), (target, u1, u2, ustride, uorder, v1, v2, vstride, vorder, w1, w2, wstride, worder, points))
GEN_THUNKS(glDeformationMap3fSGIX, (GLenum target, GLfloat u1, GLfloat u2, GLint ustride, GLint uorder, GLfloat v1, GLfloat v2, GLint vstride, GLint vorder, GLfloat w1, GLfloat w2, GLint wstride, GLint worder, const GLfloat * points), (target, u1, u2, ustride, uorder, v1, v2, vstride, vorder, w1, w2, wstride, worder, points))
GEN_THUNKS(glDeleteAsyncMarkersSGIX, (GLuint marker, GLsizei range), (marker, range))
GEN_THUNKS(glDeleteBuffers, (GLsizei n, const GLuint * buffers), (n, buffers))
GEN_THUNKS(glDeleteBuffersARB, (GLsizei n, const GLuint * buffers), (n, buffers))
GEN_THUNKS(glDeleteCommandListsNV, (GLsizei n, const GLuint * lists), (n, lists))
GEN_THUNKS(glDeleteFencesAPPLE, (GLsizei n, const GLuint * fences), (n, fences))
GEN_THUNKS(glDeleteFencesNV, (GLsizei n, const GLuint * fences), (n, fences))
GEN_THUNKS(glDeleteFragmentShaderATI, (GLuint id), (id))
GEN_THUNKS(glDeleteFramebuffers, (GLsizei n, const GLuint * framebuffers), (n, framebuffers))
GEN_THUNKS(glDeleteFramebuffersEXT, (GLsizei n, const GLuint * framebuffers), (n, framebuffers))
GEN_THUNKS(glDeleteFramebuffersOES, (GLsizei n, const GLuint * framebuffers), (n, framebuffers))
GEN_THUNKS(glDeleteLists, (GLuint list, GLsizei range), (list, range))
GEN_THUNKS(glDeleteMemoryObjectsEXT, (GLsizei n, const GLuint * memoryObjects), (n, memoryObjects))
GEN_THUNKS(glDeleteNamedStringARB, (GLint namelen, const GLchar * name), (namelen, name))
GEN_THUNKS(glDeleteNamesAMD, (GLenum identifier, GLuint num, const GLuint * names), (identifier, num, names))
GEN_THUNKS(glDeleteObjectARB, (GLhandleARB obj), ((uintptr_t)obj))
GEN_THUNKS(glDeleteOcclusionQueriesNV, (GLsizei n, const GLuint * ids), (n, ids))
GEN_THUNKS(glDeletePathsNV, (GLuint path, GLsizei range), (path, range))
GEN_THUNKS(glDeletePerfMonitorsAMD, (GLsizei n, GLuint * monitors), (n, monitors))
GEN_THUNKS(glDeletePerfQueryINTEL, (GLuint queryHandle), (queryHandle))
GEN_THUNKS(glDeleteProgram, (GLuint program), (program))
GEN_THUNKS(glDeleteProgramPipelines, (GLsizei n, const GLuint * pipelines), (n, pipelines))
GEN_THUNKS(glDeleteProgramPipelinesEXT, (GLsizei n, const GLuint * pipelines), (n, pipelines))
GEN_THUNKS(glDeleteProgramsARB, (GLsizei n, const GLuint * programs), (n, programs))
GEN_THUNKS(glDeleteProgramsNV, (GLsizei n, const GLuint * programs), (n, programs))
GEN_THUNKS(glDeleteQueries, (GLsizei n, const GLuint * ids), (n, ids))
GEN_THUNKS(glDeleteQueriesARB, (GLsizei n, const GLuint * ids), (n, ids))
GEN_THUNKS(glDeleteQueriesEXT, (GLsizei n, const GLuint * ids), (n, ids))
GEN_THUNKS(glDeleteQueryResourceTagNV, (GLsizei n, const GLint * tagIds), (n, tagIds))
GEN_THUNKS(glDeleteRenderbuffers, (GLsizei n, const GLuint * renderbuffers), (n, renderbuffers))
GEN_THUNKS(glDeleteRenderbuffersEXT, (GLsizei n, const GLuint * renderbuffers), (n, renderbuffers))
GEN_THUNKS(glDeleteRenderbuffersOES, (GLsizei n, const GLuint * renderbuffers), (n, renderbuffers))
GEN_THUNKS(glDeleteSamplers, (GLsizei count, const GLuint * samplers), (count, samplers))
GEN_THUNKS(glDeleteSemaphoresEXT, (GLsizei n, const GLuint * semaphores), (n, semaphores))
GEN_THUNKS(glDeleteShader, (GLuint shader), (shader))
GEN_THUNKS(glDeleteStatesNV, (GLsizei n, const GLuint * states), (n, states))
GEN_THUNKS(glDeleteSync, (GLsync sync), (sync))
GEN_THUNKS(glDeleteSyncAPPLE, (GLsync sync), (sync))
GEN_THUNKS(glDeleteTextures, (GLsizei n, const GLuint * textures), (n, textures))
GEN_THUNKS(glDeleteTexturesEXT, (GLsizei n, const GLuint * textures), (n, textures))
GEN_THUNKS(glDeleteTransformFeedbacks, (GLsizei n, const GLuint * ids), (n, ids))
GEN_THUNKS(glDeleteTransformFeedbacksNV, (GLsizei n, const GLuint * ids), (n, ids))
GEN_THUNKS(glDeleteVertexArrays, (GLsizei n, const GLuint * arrays), (n, arrays))
GEN_THUNKS(glDeleteVertexArraysAPPLE, (GLsizei n, const GLuint * arrays), (n, arrays))
GEN_THUNKS(glDeleteVertexArraysOES, (GLsizei n, const GLuint * arrays), (n, arrays))
GEN_THUNKS(glDeleteVertexShaderEXT, (GLuint id), (id))
GEN_THUNKS(glDepthBoundsEXT, (GLclampd zmin, GLclampd zmax), (zmin, zmax))
GEN_THUNKS(glDepthBoundsdNV, (GLdouble zmin, GLdouble zmax), (zmin, zmax))
GEN_THUNKS(glDepthFunc, (GLenum func), (func))
GEN_THUNKS(glDepthMask, (GLboolean flag), (flag))
GEN_THUNKS(glDepthRange, (GLdouble n, GLdouble f), (n, f))
GEN_THUNKS(glDepthRangeArrayfvNV, (GLuint first, GLsizei count, const GLfloat * v), (first, count, v))
GEN_THUNKS(glDepthRangeArrayfvOES, (GLuint first, GLsizei count, const GLfloat * v), (first, count, v))
GEN_THUNKS(glDepthRangeArrayv, (GLuint first, GLsizei count, const GLdouble * v), (first, count, v))
GEN_THUNKS(glDepthRangeIndexed, (GLuint index, GLdouble n, GLdouble f), (index, n, f))
GEN_THUNKS(glDepthRangeIndexedfNV, (GLuint index, GLfloat n, GLfloat f), (index, n, f))
GEN_THUNKS(glDepthRangeIndexedfOES, (GLuint index, GLfloat n, GLfloat f), (index, n, f))
GEN_THUNKS(glDepthRangedNV, (GLdouble zNear, GLdouble zFar), (zNear, zFar))
GEN_THUNKS(glDepthRangef, (GLfloat n, GLfloat f), (n, f))
GEN_THUNKS(glDepthRangefOES, (GLclampf n, GLclampf f), (n, f))
GEN_THUNKS(glDepthRangex, (GLfixed n, GLfixed f), (n, f))
GEN_THUNKS(glDepthRangexOES, (GLfixed n, GLfixed f), (n, f))
GEN_THUNKS(glDetachObjectARB, (GLhandleARB containerObj, GLhandleARB attachedObj), ((uintptr_t)containerObj, (uintptr_t)attachedObj))
GEN_THUNKS(glDetachShader, (GLuint program, GLuint shader), (program, shader))
GEN_THUNKS(glDetailTexFuncSGIS, (GLenum target, GLsizei n, const GLfloat * points), (target, n, points))
GEN_THUNKS(glDisable, (GLenum cap), (cap))
GEN_THUNKS(glDisableClientState, (GLenum array), (array))
GEN_THUNKS(glDisableClientStateIndexedEXT, (GLenum array, GLuint index), (array, index))
GEN_THUNKS(glDisableClientStateiEXT, (GLenum array, GLuint index), (array, index))
GEN_THUNKS(glDisableDriverControlQCOM, (GLuint driverControl), (driverControl))
GEN_THUNKS(glDisableIndexedEXT, (GLenum target, GLuint index), (target, index))
GEN_THUNKS(glDisableVariantClientStateEXT, (GLuint id), (id))
GEN_THUNKS(glDisableVertexArrayAttrib, (GLuint vaobj, GLuint index), (vaobj, index))
GEN_THUNKS(glDisableVertexArrayAttribEXT, (GLuint vaobj, GLuint index), (vaobj, index))
GEN_THUNKS(glDisableVertexArrayEXT, (GLuint vaobj, GLenum array), (vaobj, array))
GEN_THUNKS(glDisableVertexAttribAPPLE, (GLuint index, GLenum pname), (index, pname))
GEN_THUNKS(glDisableVertexAttribArray, (GLuint index), (index))
GEN_THUNKS(glDisableVertexAttribArrayARB, (GLuint index), (index))
GEN_THUNKS(glDisablei, (GLenum target, GLuint index), (target, index))
GEN_THUNKS(glDisableiEXT, (GLenum target, GLuint index), (target, index))
GEN_THUNKS(glDisableiNV, (GLenum target, GLuint index), (target, index))
GEN_THUNKS(glDisableiOES, (GLenum target, GLuint index), (target, index))
GEN_THUNKS(glDiscardFramebufferEXT, (GLenum target, GLsizei numAttachments, const GLenum * attachments), (target, numAttachments, attachments))
GEN_THUNKS(glDispatchCompute, (GLuint num_groups_x, GLuint num_groups_y, GLuint num_groups_z), (num_groups_x, num_groups_y, num_groups_z))
GEN_THUNKS(glDispatchComputeGroupSizeARB, (GLuint num_groups_x, GLuint num_groups_y, GLuint num_groups_z, GLuint group_size_x, GLuint group_size_y, GLuint group_size_z), (num_groups_x, num_groups_y, num_groups_z, group_size_x, group_size_y, group_size_z))
GEN_THUNKS(glDispatchComputeIndirect, (GLintptr indirect), (indirect))
GEN_THUNKS(glDrawArrays, (GLenum mode, GLint first, GLsizei count), (mode, first, count))
GEN_THUNKS(glDrawArraysEXT, (GLenum mode, GLint first, GLsizei count), (mode, first, count))
GEN_THUNKS(glDrawArraysIndirect, (GLenum mode, const void * indirect), (mode, indirect))
GEN_THUNKS(glDrawArraysInstanced, (GLenum mode, GLint first, GLsizei count, GLsizei instancecount), (mode, first, count, instancecount))
GEN_THUNKS(glDrawArraysInstancedANGLE, (GLenum mode, GLint first, GLsizei count, GLsizei primcount), (mode, first, count, primcount))
GEN_THUNKS(glDrawArraysInstancedARB, (GLenum mode, GLint first, GLsizei count, GLsizei primcount), (mode, first, count, primcount))
GEN_THUNKS(glDrawArraysInstancedBaseInstance, (GLenum mode, GLint first, GLsizei count, GLsizei instancecount, GLuint baseinstance), (mode, first, count, instancecount, baseinstance))
GEN_THUNKS(glDrawArraysInstancedBaseInstanceEXT, (GLenum mode, GLint first, GLsizei count, GLsizei instancecount, GLuint baseinstance), (mode, first, count, instancecount, baseinstance))
GEN_THUNKS(glDrawArraysInstancedEXT, (GLenum mode, GLint start, GLsizei count, GLsizei primcount), (mode, start, count, primcount))
GEN_THUNKS(glDrawArraysInstancedNV, (GLenum mode, GLint first, GLsizei count, GLsizei primcount), (mode, first, count, primcount))
GEN_THUNKS(glDrawBuffer, (GLenum buf), (buf))
GEN_THUNKS(glDrawBuffers, (GLsizei n, const GLenum * bufs), (n, bufs))
GEN_THUNKS(glDrawBuffersARB, (GLsizei n, const GLenum * bufs), (n, bufs))
GEN_THUNKS(glDrawBuffersATI, (GLsizei n, const GLenum * bufs), (n, bufs))
GEN_THUNKS(glDrawBuffersEXT, (GLsizei n, const GLenum * bufs), (n, bufs))
GEN_THUNKS(glDrawBuffersIndexedEXT, (GLint n, const GLenum * location, const GLint * indices), (n, location, indices))
GEN_THUNKS(glDrawBuffersNV, (GLsizei n, const GLenum * bufs), (n, bufs))
GEN_THUNKS(glDrawCommandsAddressNV, (GLenum primitiveMode, const GLuint64 * indirects, const GLsizei * sizes, GLuint count), (primitiveMode, indirects, sizes, count))
GEN_THUNKS(glDrawCommandsNV, (GLenum primitiveMode, GLuint buffer, const GLintptr * indirects, const GLsizei * sizes, GLuint count), (primitiveMode, buffer, indirects, sizes, count))
GEN_THUNKS(glDrawCommandsStatesAddressNV, (const GLuint64 * indirects, const GLsizei * sizes, const GLuint * states, const GLuint * fbos, GLuint count), (indirects, sizes, states, fbos, count))
GEN_THUNKS(glDrawCommandsStatesNV, (GLuint buffer, const GLintptr * indirects, const GLsizei * sizes, const GLuint * states, const GLuint * fbos, GLuint count), (buffer, indirects, sizes, states, fbos, count))
GEN_THUNKS(glDrawElementArrayAPPLE, (GLenum mode, GLint first, GLsizei count), (mode, first, count))
GEN_THUNKS(glDrawElementArrayATI, (GLenum mode, GLsizei count), (mode, count))
GEN_THUNKS(glDrawElements, (GLenum mode, GLsizei count, GLenum type, const void * indices), (mode, count, type, indices))
GEN_THUNKS(glDrawElementsBaseVertex, (GLenum mode, GLsizei count, GLenum type, const void * indices, GLint basevertex), (mode, count, type, indices, basevertex))
GEN_THUNKS(glDrawElementsBaseVertexEXT, (GLenum mode, GLsizei count, GLenum type, const void * indices, GLint basevertex), (mode, count, type, indices, basevertex))
GEN_THUNKS(glDrawElementsBaseVertexOES, (GLenum mode, GLsizei count, GLenum type, const void * indices, GLint basevertex), (mode, count, type, indices, basevertex))
GEN_THUNKS(glDrawElementsIndirect, (GLenum mode, GLenum type, const void * indirect), (mode, type, indirect))
GEN_THUNKS(glDrawElementsInstanced, (GLenum mode, GLsizei count, GLenum type, const void * indices, GLsizei instancecount), (mode, count, type, indices, instancecount))
GEN_THUNKS(glDrawElementsInstancedANGLE, (GLenum mode, GLsizei count, GLenum type, const void * indices, GLsizei primcount), (mode, count, type, indices, primcount))
GEN_THUNKS(glDrawElementsInstancedARB, (GLenum mode, GLsizei count, GLenum type, const void * indices, GLsizei primcount), (mode, count, type, indices, primcount))
GEN_THUNKS(glDrawElementsInstancedBaseInstance, (GLenum mode, GLsizei count, GLenum type, const void * indices, GLsizei instancecount, GLuint baseinstance), (mode, count, type, indices, instancecount, baseinstance))
GEN_THUNKS(glDrawElementsInstancedBaseInstanceEXT, (GLenum mode, GLsizei count, GLenum type, const void * indices, GLsizei instancecount, GLuint baseinstance), (mode, count, type, indices, instancecount, baseinstance))
GEN_THUNKS(glDrawElementsInstancedBaseVertex, (GLenum mode, GLsizei count, GLenum type, const void * indices, GLsizei instancecount, GLint basevertex), (mode, count, type, indices, instancecount, basevertex))
GEN_THUNKS(glDrawElementsInstancedBaseVertexBaseInstance, (GLenum mode, GLsizei count, GLenum type, const void * indices, GLsizei instancecount, GLint basevertex, GLuint baseinstance), (mode, count, type, indices, instancecount, basevertex, baseinstance))
GEN_THUNKS(glDrawElementsInstancedBaseVertexBaseInstanceEXT, (GLenum mode, GLsizei count, GLenum type, const void * indices, GLsizei instancecount, GLint basevertex, GLuint baseinstance), (mode, count, type, indices, instancecount, basevertex, baseinstance))
GEN_THUNKS(glDrawElementsInstancedBaseVertexEXT, (GLenum mode, GLsizei count, GLenum type, const void * indices, GLsizei instancecount, GLint basevertex), (mode, count, type, indices, instancecount, basevertex))
GEN_THUNKS(glDrawElementsInstancedBaseVertexOES, (GLenum mode, GLsizei count, GLenum type, const void * indices, GLsizei instancecount, GLint basevertex), (mode, count, type, indices, instancecount, basevertex))
GEN_THUNKS(glDrawElementsInstancedEXT, (GLenum mode, GLsizei count, GLenum type, const void * indices, GLsizei primcount), (mode, count, type, indices, primcount))
GEN_THUNKS(glDrawElementsInstancedNV, (GLenum mode, GLsizei count, GLenum type, const void * indices, GLsizei primcount), (mode, count, type, indices, primcount))
GEN_THUNKS(glDrawMeshArraysSUN, (GLenum mode, GLint first, GLsizei count, GLsizei width), (mode, first, count, width))
GEN_THUNKS(glDrawMeshTasksIndirectNV, (GLintptr indirect), (indirect))
GEN_THUNKS(glDrawMeshTasksNV, (GLuint first, GLuint count), (first, count))
GEN_THUNKS(glDrawPixels, (GLsizei width, GLsizei height, GLenum format, GLenum type, const void * pixels), (width, height, format, type, pixels))
GEN_THUNKS(glDrawRangeElementArrayAPPLE, (GLenum mode, GLuint start, GLuint end, GLint first, GLsizei count), (mode, start, end, first, count))
GEN_THUNKS(glDrawRangeElementArrayATI, (GLenum mode, GLuint start, GLuint end, GLsizei count), (mode, start, end, count))
GEN_THUNKS(glDrawRangeElements, (GLenum mode, GLuint start, GLuint end, GLsizei count, GLenum type, const void * indices), (mode, start, end, count, type, indices))
GEN_THUNKS(glDrawRangeElementsBaseVertex, (GLenum mode, GLuint start, GLuint end, GLsizei count, GLenum type, const void * indices, GLint basevertex), (mode, start, end, count, type, indices, basevertex))
GEN_THUNKS(glDrawRangeElementsBaseVertexEXT, (GLenum mode, GLuint start, GLuint end, GLsizei count, GLenum type, const void * indices, GLint basevertex), (mode, start, end, count, type, indices, basevertex))
GEN_THUNKS(glDrawRangeElementsBaseVertexOES, (GLenum mode, GLuint start, GLuint end, GLsizei count, GLenum type, const void * indices, GLint basevertex), (mode, start, end, count, type, indices, basevertex))
GEN_THUNKS(glDrawRangeElementsEXT, (GLenum mode, GLuint start, GLuint end, GLsizei count, GLenum type, const void * indices), (mode, start, end, count, type, indices))
GEN_THUNKS(glDrawTexfOES, (GLfloat x, GLfloat y, GLfloat z, GLfloat width, GLfloat height), (x, y, z, width, height))
GEN_THUNKS(glDrawTexfvOES, (const GLfloat * coords), (coords))
GEN_THUNKS(glDrawTexiOES, (GLint x, GLint y, GLint z, GLint width, GLint height), (x, y, z, width, height))
GEN_THUNKS(glDrawTexivOES, (const GLint * coords), (coords))
GEN_THUNKS(glDrawTexsOES, (GLshort x, GLshort y, GLshort z, GLshort width, GLshort height), (x, y, z, width, height))
GEN_THUNKS(glDrawTexsvOES, (const GLshort * coords), (coords))
GEN_THUNKS(glDrawTextureNV, (GLuint texture, GLuint sampler, GLfloat x0, GLfloat y0, GLfloat x1, GLfloat y1, GLfloat z, GLfloat s0, GLfloat t0, GLfloat s1, GLfloat t1), (texture, sampler, x0, y0, x1, y1, z, s0, t0, s1, t1))
GEN_THUNKS(glDrawTexxOES, (GLfixed x, GLfixed y, GLfixed z, GLfixed width, GLfixed height), (x, y, z, width, height))
GEN_THUNKS(glDrawTexxvOES, (const GLfixed * coords), (coords))
GEN_THUNKS(glDrawTransformFeedback, (GLenum mode, GLuint id), (mode, id))
GEN_THUNKS(glDrawTransformFeedbackEXT, (GLenum mode, GLuint id), (mode, id))
GEN_THUNKS(glDrawTransformFeedbackInstanced, (GLenum mode, GLuint id, GLsizei instancecount), (mode, id, instancecount))
GEN_THUNKS(glDrawTransformFeedbackInstancedEXT, (GLenum mode, GLuint id, GLsizei instancecount), (mode, id, instancecount))
GEN_THUNKS(glDrawTransformFeedbackNV, (GLenum mode, GLuint id), (mode, id))
GEN_THUNKS(glDrawTransformFeedbackStream, (GLenum mode, GLuint id, GLuint stream), (mode, id, stream))
GEN_THUNKS(glDrawTransformFeedbackStreamInstanced, (GLenum mode, GLuint id, GLuint stream, GLsizei instancecount), (mode, id, stream, instancecount))
GEN_THUNKS(glDrawVkImageNV, (GLuint64 vkImage, GLuint sampler, GLfloat x0, GLfloat y0, GLfloat x1, GLfloat y1, GLfloat z, GLfloat s0, GLfloat t0, GLfloat s1, GLfloat t1), (vkImage, sampler, x0, y0, x1, y1, z, s0, t0, s1, t1))
GEN_THUNKS(glEGLImageTargetRenderbufferStorageOES, (GLenum target, GLeglImageOES image), (target, image))
GEN_THUNKS(glEGLImageTargetTexStorageEXT, (GLenum target, GLeglImageOES image, const GLint* attrib_list), (target, image, attrib_list))
GEN_THUNKS(glEGLImageTargetTexture2DOES, (GLenum target, GLeglImageOES image), (target, image))
GEN_THUNKS(glEGLImageTargetTextureStorageEXT, (GLuint texture, GLeglImageOES image, const GLint* attrib_list), (texture, image, attrib_list))
GEN_THUNKS(glEdgeFlag, (GLboolean flag), (flag))
GEN_THUNKS(glEdgeFlagFormatNV, (GLsizei stride), (stride))
GEN_THUNKS(glEdgeFlagPointer, (GLsizei stride, const void * pointer), (stride, pointer))
GEN_THUNKS(glEdgeFlagPointerEXT, (GLsizei stride, GLsizei count, const GLboolean * pointer), (stride, count, pointer))
GEN_THUNKS(glEdgeFlagPointerListIBM, (GLint stride, const GLboolean ** pointer, GLint ptrstride), (stride, pointer, ptrstride))
GEN_THUNKS(glEdgeFlagv, (const GLboolean * flag), (flag))
GEN_THUNKS(glElementPointerAPPLE, (GLenum type, const void * pointer), (type, pointer))
GEN_THUNKS(glElementPointerATI, (GLenum type, const void * pointer), (type, pointer))
GEN_THUNKS(glEnable, (GLenum cap), (cap))
GEN_THUNKS(glEnableClientState, (GLenum array), (array))
GEN_THUNKS(glEnableClientStateIndexedEXT, (GLenum array, GLuint index), (array, index))
GEN_THUNKS(glEnableClientStateiEXT, (GLenum array, GLuint index), (array, index))
GEN_THUNKS(glEnableDriverControlQCOM, (GLuint driverControl), (driverControl))
GEN_THUNKS(glEnableIndexedEXT, (GLenum target, GLuint index), (target, index))
GEN_THUNKS(glEnableVariantClientStateEXT, (GLuint id), (id))
GEN_THUNKS(glEnableVertexArrayAttrib, (GLuint vaobj, GLuint index), (vaobj, index))
GEN_THUNKS(glEnableVertexArrayAttribEXT, (GLuint vaobj, GLuint index), (vaobj, index))
GEN_THUNKS(glEnableVertexArrayEXT, (GLuint vaobj, GLenum array), (vaobj, array))
GEN_THUNKS(glEnableVertexAttribAPPLE, (GLuint index, GLenum pname), (index, pname))
GEN_THUNKS(glEnableVertexAttribArray, (GLuint index), (index))
GEN_THUNKS(glEnableVertexAttribArrayARB, (GLuint index), (index))
GEN_THUNKS(glEnablei, (GLenum target, GLuint index), (target, index))
GEN_THUNKS(glEnableiEXT, (GLenum target, GLuint index), (target, index))
GEN_THUNKS(glEnableiNV, (GLenum target, GLuint index), (target, index))
GEN_THUNKS(glEnableiOES, (GLenum target, GLuint index), (target, index))
GEN_THUNKS(glEnd_unwrapped, (void), ())
GEN_THUNKS(glEndConditionalRender, (void), ())
GEN_THUNKS(glEndConditionalRenderNV, (void), ())
GEN_THUNKS(glEndConditionalRenderNVX, (void), ())
GEN_THUNKS(glEndFragmentShaderATI, (void), ())
GEN_THUNKS(glEndList, (void), ())
GEN_THUNKS(glEndOcclusionQueryNV, (void), ())
GEN_THUNKS(glEndPerfMonitorAMD, (GLuint monitor), (monitor))
GEN_THUNKS(glEndPerfQueryINTEL, (GLuint queryHandle), (queryHandle))
GEN_THUNKS(glEndQuery, (GLenum target), (target))
GEN_THUNKS(glEndQueryARB, (GLenum target), (target))
GEN_THUNKS(glEndQueryEXT, (GLenum target), (target))
GEN_THUNKS(glEndQueryIndexed, (GLenum target, GLuint index), (target, index))
GEN_THUNKS(glEndTilingQCOM, (GLbitfield preserveMask), (preserveMask))
GEN_THUNKS(glEndTransformFeedback, (void), ())
GEN_THUNKS(glEndTransformFeedbackEXT, (void), ())
GEN_THUNKS(glEndTransformFeedbackNV, (void), ())
GEN_THUNKS(glEndVertexShaderEXT, (void), ())
GEN_THUNKS(glEndVideoCaptureNV, (GLuint video_capture_slot), (video_capture_slot))
GEN_THUNKS(glEvalCoord1d, (GLdouble u), (u))
GEN_THUNKS(glEvalCoord1dv, (const GLdouble * u), (u))
GEN_THUNKS(glEvalCoord1f, (GLfloat u), (u))
GEN_THUNKS(glEvalCoord1fv, (const GLfloat * u), (u))
GEN_THUNKS(glEvalCoord1xOES, (GLfixed u), (u))
GEN_THUNKS(glEvalCoord1xvOES, (const GLfixed * coords), (coords))
GEN_THUNKS(glEvalCoord2d, (GLdouble u, GLdouble v), (u, v))
GEN_THUNKS(glEvalCoord2dv, (const GLdouble * u), (u))
GEN_THUNKS(glEvalCoord2f, (GLfloat u, GLfloat v), (u, v))
GEN_THUNKS(glEvalCoord2fv, (const GLfloat * u), (u))
GEN_THUNKS(glEvalCoord2xOES, (GLfixed u, GLfixed v), (u, v))
GEN_THUNKS(glEvalCoord2xvOES, (const GLfixed * coords), (coords))
GEN_THUNKS(glEvalMapsNV, (GLenum target, GLenum mode), (target, mode))
GEN_THUNKS(glEvalMesh1, (GLenum mode, GLint i1, GLint i2), (mode, i1, i2))
GEN_THUNKS(glEvalMesh2, (GLenum mode, GLint i1, GLint i2, GLint j1, GLint j2), (mode, i1, i2, j1, j2))
GEN_THUNKS(glEvalPoint1, (GLint i), (i))
GEN_THUNKS(glEvalPoint2, (GLint i, GLint j), (i, j))
GEN_THUNKS(glEvaluateDepthValuesARB, (void), ())
GEN_THUNKS(glExecuteProgramNV, (GLenum target, GLuint id, const GLfloat * params), (target, id, params))
GEN_THUNKS(glExtGetBufferPointervQCOM, (GLenum target, void ** params), (target, params))
GEN_THUNKS(glExtGetBuffersQCOM, (GLuint * buffers, GLint maxBuffers, GLint * numBuffers), (buffers, maxBuffers, numBuffers))
GEN_THUNKS(glExtGetFramebuffersQCOM, (GLuint * framebuffers, GLint maxFramebuffers, GLint * numFramebuffers), (framebuffers, maxFramebuffers, numFramebuffers))
GEN_THUNKS(glExtGetProgramBinarySourceQCOM, (GLuint program, GLenum shadertype, GLchar * source, GLint * length), (program, shadertype, source, length))
GEN_THUNKS(glExtGetProgramsQCOM, (GLuint * programs, GLint maxPrograms, GLint * numPrograms), (programs, maxPrograms, numPrograms))
GEN_THUNKS(glExtGetRenderbuffersQCOM, (GLuint * renderbuffers, GLint maxRenderbuffers, GLint * numRenderbuffers), (renderbuffers, maxRenderbuffers, numRenderbuffers))
GEN_THUNKS(glExtGetShadersQCOM, (GLuint * shaders, GLint maxShaders, GLint * numShaders), (shaders, maxShaders, numShaders))
GEN_THUNKS(glExtGetTexLevelParameterivQCOM, (GLuint texture, GLenum face, GLint level, GLenum pname, GLint * params), (texture, face, level, pname, params))
GEN_THUNKS(glExtGetTexSubImageQCOM, (GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, void * texels), (target, level, xoffset, yoffset, zoffset, width, height, depth, format, type, texels))
GEN_THUNKS(glExtGetTexturesQCOM, (GLuint * textures, GLint maxTextures, GLint * numTextures), (textures, maxTextures, numTextures))
GEN_THUNKS_RET(GLboolean, glExtIsProgramBinaryQCOM, (GLuint program), (program))
GEN_THUNKS(glExtTexObjectStateOverrideiQCOM, (GLenum target, GLenum pname, GLint param), (target, pname, param))
GEN_THUNKS(glExtractComponentEXT, (GLuint res, GLuint src, GLuint num), (res, src, num))
GEN_THUNKS(glFeedbackBuffer, (GLsizei size, GLenum type, GLfloat * buffer), (size, type, buffer))
GEN_THUNKS(glFeedbackBufferxOES, (GLsizei n, GLenum type, const GLfixed * buffer), (n, type, buffer))
GEN_THUNKS_RET(GLsync, glFenceSync, (GLenum condition, GLbitfield flags), (condition, flags))
GEN_THUNKS_RET(GLsync, glFenceSyncAPPLE, (GLenum condition, GLbitfield flags), (condition, flags))
GEN_THUNKS(glFinalCombinerInputNV, (GLenum variable, GLenum input, GLenum mapping, GLenum componentUsage), (variable, input, mapping, componentUsage))
GEN_THUNKS(glFinish, (void), ())
GEN_THUNKS_RET(GLint, glFinishAsyncSGIX, (GLuint * markerp), (markerp))
GEN_THUNKS(glFinishFenceAPPLE, (GLuint fence), (fence))
GEN_THUNKS(glFinishFenceNV, (GLuint fence), (fence))
GEN_THUNKS(glFinishObjectAPPLE, (GLenum object, GLint name), (object, name))
GEN_THUNKS(glFinishTextureSUNX, (void), ())
GEN_THUNKS(glFlush, (void), ())
GEN_THUNKS(glFlushMappedBufferRange, (GLenum target, GLintptr offset, GLsizeiptr length), (target, offset, length))
GEN_THUNKS(glFlushMappedBufferRangeAPPLE, (GLenum target, GLintptr offset, GLsizeiptr size), (target, offset, size))
GEN_THUNKS(glFlushMappedBufferRangeEXT, (GLenum target, GLintptr offset, GLsizeiptr length), (target, offset, length))
GEN_THUNKS(glFlushMappedNamedBufferRange, (GLuint buffer, GLintptr offset, GLsizeiptr length), (buffer, offset, length))
GEN_THUNKS(glFlushMappedNamedBufferRangeEXT, (GLuint buffer, GLintptr offset, GLsizeiptr length), (buffer, offset, length))
GEN_THUNKS(glFlushPixelDataRangeNV, (GLenum target), (target))
GEN_THUNKS(glFlushRasterSGIX, (void), ())
GEN_THUNKS(glFlushStaticDataIBM, (GLenum target), (target))
GEN_THUNKS(glFlushVertexArrayRangeAPPLE, (GLsizei length, void * pointer), (length, pointer))
GEN_THUNKS(glFlushVertexArrayRangeNV, (void), ())
GEN_THUNKS(glFogCoordFormatNV, (GLenum type, GLsizei stride), (type, stride))
GEN_THUNKS(glFogCoordPointer, (GLenum type, GLsizei stride, const void * pointer), (type, stride, pointer))
GEN_THUNKS(glFogCoordPointerEXT, (GLenum type, GLsizei stride, const void * pointer), (type, stride, pointer))
GEN_THUNKS(glFogCoordPointerListIBM, (GLenum type, GLint stride, const void ** pointer, GLint ptrstride), (type, stride, pointer, ptrstride))
GEN_THUNKS(glFogCoordd, (GLdouble coord), (coord))
GEN_THUNKS(glFogCoorddEXT, (GLdouble coord), (coord))
GEN_THUNKS(glFogCoorddv, (const GLdouble * coord), (coord))
GEN_THUNKS(glFogCoorddvEXT, (const GLdouble * coord), (coord))
GEN_THUNKS(glFogCoordf, (GLfloat coord), (coord))
GEN_THUNKS(glFogCoordfEXT, (GLfloat coord), (coord))
GEN_THUNKS(glFogCoordfv, (const GLfloat * coord), (coord))
GEN_THUNKS(glFogCoordfvEXT, (const GLfloat * coord), (coord))
GEN_THUNKS(glFogCoordhNV, (GLhalfNV fog), (fog))
GEN_THUNKS(glFogCoordhvNV, (const GLhalfNV * fog), (fog))
GEN_THUNKS(glFogFuncSGIS, (GLsizei n, const GLfloat * points), (n, points))
GEN_THUNKS(glFogf, (GLenum pname, GLfloat param), (pname, param))
GEN_THUNKS(glFogfv, (GLenum pname, const GLfloat * params), (pname, params))
GEN_THUNKS(glFogi, (GLenum pname, GLint param), (pname, param))
GEN_THUNKS(glFogiv, (GLenum pname, const GLint * params), (pname, params))
GEN_THUNKS(glFogx, (GLenum pname, GLfixed param), (pname, param))
GEN_THUNKS(glFogxOES, (GLenum pname, GLfixed param), (pname, param))
GEN_THUNKS(glFogxv, (GLenum pname, const GLfixed * param), (pname, param))
GEN_THUNKS(glFogxvOES, (GLenum pname, const GLfixed * param), (pname, param))
GEN_THUNKS(glFragmentColorMaterialSGIX, (GLenum face, GLenum mode), (face, mode))
GEN_THUNKS(glFragmentCoverageColorNV, (GLuint color), (color))
GEN_THUNKS(glFragmentLightModelfSGIX, (GLenum pname, GLfloat param), (pname, param))
GEN_THUNKS(glFragmentLightModelfvSGIX, (GLenum pname, const GLfloat * params), (pname, params))
GEN_THUNKS(glFragmentLightModeliSGIX, (GLenum pname, GLint param), (pname, param))
GEN_THUNKS(glFragmentLightModelivSGIX, (GLenum pname, const GLint * params), (pname, params))
GEN_THUNKS(glFragmentLightfSGIX, (GLenum light, GLenum pname, GLfloat param), (light, pname, param))
GEN_THUNKS(glFragmentLightfvSGIX, (GLenum light, GLenum pname, const GLfloat * params), (light, pname, params))
GEN_THUNKS(glFragmentLightiSGIX, (GLenum light, GLenum pname, GLint param), (light, pname, param))
GEN_THUNKS(glFragmentLightivSGIX, (GLenum light, GLenum pname, const GLint * params), (light, pname, params))
GEN_THUNKS(glFragmentMaterialfSGIX, (GLenum face, GLenum pname, GLfloat param), (face, pname, param))
GEN_THUNKS(glFragmentMaterialfvSGIX, (GLenum face, GLenum pname, const GLfloat * params), (face, pname, params))
GEN_THUNKS(glFragmentMaterialiSGIX, (GLenum face, GLenum pname, GLint param), (face, pname, param))
GEN_THUNKS(glFragmentMaterialivSGIX, (GLenum face, GLenum pname, const GLint * params), (face, pname, params))
GEN_THUNKS(glFrameTerminatorGREMEDY, (void), ())
GEN_THUNKS(glFrameZoomSGIX, (GLint factor), (factor))
GEN_THUNKS(glFramebufferDrawBufferEXT, (GLuint framebuffer, GLenum mode), (framebuffer, mode))
GEN_THUNKS(glFramebufferDrawBuffersEXT, (GLuint framebuffer, GLsizei n, const GLenum * bufs), (framebuffer, n, bufs))
GEN_THUNKS(glFramebufferFetchBarrierEXT, (void), ())
GEN_THUNKS(glFramebufferFetchBarrierQCOM, (void), ())
GEN_THUNKS(glFramebufferFoveationConfigQCOM, (GLuint framebuffer, GLuint numLayers, GLuint focalPointsPerLayer, GLuint requestedFeatures, GLuint * providedFeatures), (framebuffer, numLayers, focalPointsPerLayer, requestedFeatures, providedFeatures))
GEN_THUNKS(glFramebufferFoveationParametersQCOM, (GLuint framebuffer, GLuint layer, GLuint focalPoint, GLfloat focalX, GLfloat focalY, GLfloat gainX, GLfloat gainY, GLfloat foveaArea), (framebuffer, layer, focalPoint, focalX, focalY, gainX, gainY, foveaArea))
GEN_THUNKS(glFramebufferParameteri, (GLenum target, GLenum pname, GLint param), (target, pname, param))
GEN_THUNKS(glFramebufferParameteriMESA, (GLenum target, GLenum pname, GLint param), (target, pname, param))
GEN_THUNKS(glFramebufferPixelLocalStorageSizeEXT, (GLuint target, GLsizei size), (target, size))
GEN_THUNKS(glFramebufferReadBufferEXT, (GLuint framebuffer, GLenum mode), (framebuffer, mode))
GEN_THUNKS(glFramebufferRenderbuffer, (GLenum target, GLenum attachment, GLenum renderbuffertarget, GLuint renderbuffer), (target, attachment, renderbuffertarget, renderbuffer))
GEN_THUNKS(glFramebufferRenderbufferEXT, (GLenum target, GLenum attachment, GLenum renderbuffertarget, GLuint renderbuffer), (target, attachment, renderbuffertarget, renderbuffer))
GEN_THUNKS(glFramebufferRenderbufferOES, (GLenum target, GLenum attachment, GLenum renderbuffertarget, GLuint renderbuffer), (target, attachment, renderbuffertarget, renderbuffer))
GEN_THUNKS(glFramebufferSampleLocationsfvARB, (GLenum target, GLuint start, GLsizei count, const GLfloat * v), (target, start, count, v))
GEN_THUNKS(glFramebufferSampleLocationsfvNV, (GLenum target, GLuint start, GLsizei count, const GLfloat * v), (target, start, count, v))
GEN_THUNKS(glFramebufferSamplePositionsfvAMD, (GLenum target, GLuint numsamples, GLuint pixelindex, const GLfloat * values), (target, numsamples, pixelindex, values))
GEN_THUNKS(glFramebufferTexture, (GLenum target, GLenum attachment, GLuint texture, GLint level), (target, attachment, texture, level))
GEN_THUNKS(glFramebufferTexture1D, (GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level), (target, attachment, textarget, texture, level))
GEN_THUNKS(glFramebufferTexture1DEXT, (GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level), (target, attachment, textarget, texture, level))
GEN_THUNKS(glFramebufferTexture2D, (GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level), (target, attachment, textarget, texture, level))
GEN_THUNKS(glFramebufferTexture2DDownsampleIMG, (GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level, GLint xscale, GLint yscale), (target, attachment, textarget, texture, level, xscale, yscale))
GEN_THUNKS(glFramebufferTexture2DEXT, (GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level), (target, attachment, textarget, texture, level))
GEN_THUNKS(glFramebufferTexture2DMultisampleEXT, (GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level, GLsizei samples), (target, attachment, textarget, texture, level, samples))
GEN_THUNKS(glFramebufferTexture2DMultisampleIMG, (GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level, GLsizei samples), (target, attachment, textarget, texture, level, samples))
GEN_THUNKS(glFramebufferTexture2DOES, (GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level), (target, attachment, textarget, texture, level))
GEN_THUNKS(glFramebufferTexture3D, (GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level, GLint zoffset), (target, attachment, textarget, texture, level, zoffset))
GEN_THUNKS(glFramebufferTexture3DEXT, (GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level, GLint zoffset), (target, attachment, textarget, texture, level, zoffset))
GEN_THUNKS(glFramebufferTexture3DOES, (GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level, GLint zoffset), (target, attachment, textarget, texture, level, zoffset))
GEN_THUNKS(glFramebufferTextureARB, (GLenum target, GLenum attachment, GLuint texture, GLint level), (target, attachment, texture, level))
GEN_THUNKS(glFramebufferTextureEXT, (GLenum target, GLenum attachment, GLuint texture, GLint level), (target, attachment, texture, level))
GEN_THUNKS(glFramebufferTextureFaceARB, (GLenum target, GLenum attachment, GLuint texture, GLint level, GLenum face), (target, attachment, texture, level, face))
GEN_THUNKS(glFramebufferTextureFaceEXT, (GLenum target, GLenum attachment, GLuint texture, GLint level, GLenum face), (target, attachment, texture, level, face))
GEN_THUNKS(glFramebufferTextureLayer, (GLenum target, GLenum attachment, GLuint texture, GLint level, GLint layer), (target, attachment, texture, level, layer))
GEN_THUNKS(glFramebufferTextureLayerARB, (GLenum target, GLenum attachment, GLuint texture, GLint level, GLint layer), (target, attachment, texture, level, layer))
GEN_THUNKS(glFramebufferTextureLayerDownsampleIMG, (GLenum target, GLenum attachment, GLuint texture, GLint level, GLint layer, GLint xscale, GLint yscale), (target, attachment, texture, level, layer, xscale, yscale))
GEN_THUNKS(glFramebufferTextureLayerEXT, (GLenum target, GLenum attachment, GLuint texture, GLint level, GLint layer), (target, attachment, texture, level, layer))
GEN_THUNKS(glFramebufferTextureMultisampleMultiviewOVR, (GLenum target, GLenum attachment, GLuint texture, GLint level, GLsizei samples, GLint baseViewIndex, GLsizei numViews), (target, attachment, texture, level, samples, baseViewIndex, numViews))
GEN_THUNKS(glFramebufferTextureMultiviewOVR, (GLenum target, GLenum attachment, GLuint texture, GLint level, GLint baseViewIndex, GLsizei numViews), (target, attachment, texture, level, baseViewIndex, numViews))
GEN_THUNKS(glFramebufferTextureOES, (GLenum target, GLenum attachment, GLuint texture, GLint level), (target, attachment, texture, level))
GEN_THUNKS(glFreeObjectBufferATI, (GLuint buffer), (buffer))
GEN_THUNKS(glFrontFace, (GLenum mode), (mode))
GEN_THUNKS(glFrustum, (GLdouble left, GLdouble right, GLdouble bottom, GLdouble top, GLdouble zNear, GLdouble zFar), (left, right, bottom, top, zNear, zFar))
GEN_THUNKS(glFrustumf, (GLfloat l, GLfloat r, GLfloat b, GLfloat t, GLfloat n, GLfloat f), (l, r, b, t, n, f))
GEN_THUNKS(glFrustumfOES, (GLfloat l, GLfloat r, GLfloat b, GLfloat t, GLfloat n, GLfloat f), (l, r, b, t, n, f))
GEN_THUNKS(glFrustumx, (GLfixed l, GLfixed r, GLfixed b, GLfixed t, GLfixed n, GLfixed f), (l, r, b, t, n, f))
GEN_THUNKS(glFrustumxOES, (GLfixed l, GLfixed r, GLfixed b, GLfixed t, GLfixed n, GLfixed f), (l, r, b, t, n, f))
GEN_THUNKS_RET(GLuint, glGenAsyncMarkersSGIX, (GLsizei range), (range))
GEN_THUNKS(glGenBuffers, (GLsizei n, GLuint * buffers), (n, buffers))
GEN_THUNKS(glGenBuffersARB, (GLsizei n, GLuint * buffers), (n, buffers))
GEN_THUNKS(glGenFencesAPPLE, (GLsizei n, GLuint * fences), (n, fences))
GEN_THUNKS(glGenFencesNV, (GLsizei n, GLuint * fences), (n, fences))
GEN_THUNKS_RET(GLuint, glGenFragmentShadersATI, (GLuint range), (range))
GEN_THUNKS(glGenFramebuffers, (GLsizei n, GLuint * framebuffers), (n, framebuffers))
GEN_THUNKS(glGenFramebuffersEXT, (GLsizei n, GLuint * framebuffers), (n, framebuffers))
GEN_THUNKS(glGenFramebuffersOES, (GLsizei n, GLuint * framebuffers), (n, framebuffers))
GEN_THUNKS_RET(GLuint, glGenLists, (GLsizei range), (range))
GEN_THUNKS(glGenNamesAMD, (GLenum identifier, GLuint num, GLuint * names), (identifier, num, names))
GEN_THUNKS(glGenOcclusionQueriesNV, (GLsizei n, GLuint * ids), (n, ids))
GEN_THUNKS_RET(GLuint, glGenPathsNV, (GLsizei range), (range))
GEN_THUNKS(glGenPerfMonitorsAMD, (GLsizei n, GLuint * monitors), (n, monitors))
GEN_THUNKS(glGenProgramPipelines, (GLsizei n, GLuint * pipelines), (n, pipelines))
GEN_THUNKS(glGenProgramPipelinesEXT, (GLsizei n, GLuint * pipelines), (n, pipelines))
GEN_THUNKS(glGenProgramsARB, (GLsizei n, GLuint * programs), (n, programs))
GEN_THUNKS(glGenProgramsNV, (GLsizei n, GLuint * programs), (n, programs))
GEN_THUNKS(glGenQueries, (GLsizei n, GLuint * ids), (n, ids))
GEN_THUNKS(glGenQueriesARB, (GLsizei n, GLuint * ids), (n, ids))
GEN_THUNKS(glGenQueriesEXT, (GLsizei n, GLuint * ids), (n, ids))
GEN_THUNKS(glGenQueryResourceTagNV, (GLsizei n, GLint * tagIds), (n, tagIds))
GEN_THUNKS(glGenRenderbuffers, (GLsizei n, GLuint * renderbuffers), (n, renderbuffers))
GEN_THUNKS(glGenRenderbuffersEXT, (GLsizei n, GLuint * renderbuffers), (n, renderbuffers))
GEN_THUNKS(glGenRenderbuffersOES, (GLsizei n, GLuint * renderbuffers), (n, renderbuffers))
GEN_THUNKS(glGenSamplers, (GLsizei count, GLuint * samplers), (count, samplers))
GEN_THUNKS(glGenSemaphoresEXT, (GLsizei n, GLuint * semaphores), (n, semaphores))
GEN_THUNKS_RET(GLuint, glGenSymbolsEXT, (GLenum datatype, GLenum storagetype, GLenum range, GLuint components), (datatype, storagetype, range, components))
GEN_THUNKS(glGenTextures, (GLsizei n, GLuint * textures), (n, textures))
GEN_THUNKS(glGenTexturesEXT, (GLsizei n, GLuint * textures), (n, textures))
GEN_THUNKS(glGenTransformFeedbacks, (GLsizei n, GLuint * ids), (n, ids))
GEN_THUNKS(glGenTransformFeedbacksNV, (GLsizei n, GLuint * ids), (n, ids))
GEN_THUNKS(glGenVertexArrays, (GLsizei n, GLuint * arrays), (n, arrays))
GEN_THUNKS(glGenVertexArraysAPPLE, (GLsizei n, GLuint * arrays), (n, arrays))
GEN_THUNKS(glGenVertexArraysOES, (GLsizei n, GLuint * arrays), (n, arrays))
GEN_THUNKS_RET(GLuint, glGenVertexShadersEXT, (GLuint range), (range))
GEN_THUNKS(glGenerateMipmap, (GLenum target), (target))
GEN_THUNKS(glGenerateMipmapEXT, (GLenum target), (target))
GEN_THUNKS(glGenerateMipmapOES, (GLenum target), (target))
GEN_THUNKS(glGenerateMultiTexMipmapEXT, (GLenum texunit, GLenum target), (texunit, target))
GEN_THUNKS(glGenerateTextureMipmap, (GLuint texture), (texture))
GEN_THUNKS(glGenerateTextureMipmapEXT, (GLuint texture, GLenum target), (texture, target))
GEN_THUNKS(glGetActiveAtomicCounterBufferiv, (GLuint program, GLuint bufferIndex, GLenum pname, GLint * params), (program, bufferIndex, pname, params))
GEN_THUNKS(glGetActiveAttrib, (GLuint program, GLuint index, GLsizei bufSize, GLsizei * length, GLint * size, GLenum * type, GLchar * name), (program, index, bufSize, length, size, type, name))
GEN_THUNKS(glGetActiveAttribARB, (GLhandleARB programObj, GLuint index, GLsizei maxLength, GLsizei * length, GLint * size, GLenum * type, GLcharARB * name), ((uintptr_t)programObj, index, maxLength, length, size, type, name))
GEN_THUNKS(glGetActiveSubroutineName, (GLuint program, GLenum shadertype, GLuint index, GLsizei bufsize, GLsizei * length, GLchar * name), (program, shadertype, index, bufsize, length, name))
GEN_THUNKS(glGetActiveSubroutineUniformName, (GLuint program, GLenum shadertype, GLuint index, GLsizei bufsize, GLsizei * length, GLchar * name), (program, shadertype, index, bufsize, length, name))
GEN_THUNKS(glGetActiveSubroutineUniformiv, (GLuint program, GLenum shadertype, GLuint index, GLenum pname, GLint * values), (program, shadertype, index, pname, values))
GEN_THUNKS(glGetActiveUniform, (GLuint program, GLuint index, GLsizei bufSize, GLsizei * length, GLint * size, GLenum * type, GLchar * name), (program, index, bufSize, length, size, type, name))
GEN_THUNKS(glGetActiveUniformARB, (GLhandleARB programObj, GLuint index, GLsizei maxLength, GLsizei * length, GLint * size, GLenum * type, GLcharARB * name), ((uintptr_t)programObj, index, maxLength, length, size, type, name))
GEN_THUNKS(glGetActiveUniformBlockName, (GLuint program, GLuint uniformBlockIndex, GLsizei bufSize, GLsizei * length, GLchar * uniformBlockName), (program, uniformBlockIndex, bufSize, length, uniformBlockName))
GEN_THUNKS(glGetActiveUniformBlockiv, (GLuint program, GLuint uniformBlockIndex, GLenum pname, GLint * params), (program, uniformBlockIndex, pname, params))
GEN_THUNKS(glGetActiveUniformName, (GLuint program, GLuint uniformIndex, GLsizei bufSize, GLsizei * length, GLchar * uniformName), (program, uniformIndex, bufSize, length, uniformName))
GEN_THUNKS(glGetActiveUniformsiv, (GLuint program, GLsizei uniformCount, const GLuint * uniformIndices, GLenum pname, GLint * params), (program, uniformCount, uniformIndices, pname, params))
GEN_THUNKS(glGetActiveVaryingNV, (GLuint program, GLuint index, GLsizei bufSize, GLsizei * length, GLsizei * size, GLenum * type, GLchar * name), (program, index, bufSize, length, size, type, name))
GEN_THUNKS(glGetArrayObjectfvATI, (GLenum array, GLenum pname, GLfloat * params), (array, pname, params))
GEN_THUNKS(glGetArrayObjectivATI, (GLenum array, GLenum pname, GLint * params), (array, pname, params))
GEN_THUNKS(glGetAttachedObjectsARB, (GLhandleARB containerObj, GLsizei maxCount, GLsizei * count, GLhandleARB * obj), ((uintptr_t)containerObj, maxCount, count, obj))
GEN_THUNKS(glGetAttachedShaders, (GLuint program, GLsizei maxCount, GLsizei * count, GLuint * shaders), (program, maxCount, count, shaders))
GEN_THUNKS_RET(GLint, glGetAttribLocation, (GLuint program, const GLchar * name), (program, name))
GEN_THUNKS_RET(GLint, glGetAttribLocationARB, (GLhandleARB programObj, const GLcharARB * name), ((uintptr_t)programObj, name))
GEN_THUNKS(glGetBooleanIndexedvEXT, (GLenum target, GLuint index, GLboolean * data), (target, index, data))
GEN_THUNKS(glGetBooleani_v, (GLenum target, GLuint index, GLboolean * data), (target, index, data))
GEN_THUNKS(glGetBooleanv, (GLenum pname, GLboolean * data), (pname, data))
GEN_THUNKS(glGetBufferParameteri64v, (GLenum target, GLenum pname, GLint64 * params), (target, pname, params))
GEN_THUNKS(glGetBufferParameteriv, (GLenum target, GLenum pname, GLint * params), (target, pname, params))
GEN_THUNKS(glGetBufferParameterivARB, (GLenum target, GLenum pname, GLint * params), (target, pname, params))
GEN_THUNKS(glGetBufferParameterui64vNV, (GLenum target, GLenum pname, GLuint64EXT * params), (target, pname, params))
GEN_THUNKS(glGetBufferPointerv, (GLenum target, GLenum pname, void ** params), (target, pname, params))
GEN_THUNKS(glGetBufferPointervARB, (GLenum target, GLenum pname, void ** params), (target, pname, params))
GEN_THUNKS(glGetBufferPointervOES, (GLenum target, GLenum pname, void ** params), (target, pname, params))
GEN_THUNKS(glGetBufferSubData, (GLenum target, GLintptr offset, GLsizeiptr size, void * data), (target, offset, size, data))
GEN_THUNKS(glGetBufferSubDataARB, (GLenum target, GLintptrARB offset, GLsizeiptrARB size, void * data), (target, offset, size, data))
GEN_THUNKS(glGetClipPlane, (GLenum plane, GLdouble * equation), (plane, equation))
GEN_THUNKS(glGetClipPlanef, (GLenum plane, GLfloat * equation), (plane, equation))
GEN_THUNKS(glGetClipPlanefOES, (GLenum plane, GLfloat * equation), (plane, equation))
GEN_THUNKS(glGetClipPlanex, (GLenum plane, GLfixed * equation), (plane, equation))
GEN_THUNKS(glGetClipPlanexOES, (GLenum plane, GLfixed * equation), (plane, equation))
GEN_THUNKS(glGetColorTable, (GLenum target, GLenum format, GLenum type, void * table), (target, format, type, table))
GEN_THUNKS(glGetColorTableEXT, (GLenum target, GLenum format, GLenum type, void * data), (target, format, type, data))
GEN_THUNKS(glGetColorTableParameterfv, (GLenum target, GLenum pname, GLfloat * params), (target, pname, params))
GEN_THUNKS(glGetColorTableParameterfvEXT, (GLenum target, GLenum pname, GLfloat * params), (target, pname, params))
GEN_THUNKS(glGetColorTableParameterfvSGI, (GLenum target, GLenum pname, GLfloat * params), (target, pname, params))
GEN_THUNKS(glGetColorTableParameteriv, (GLenum target, GLenum pname, GLint * params), (target, pname, params))
GEN_THUNKS(glGetColorTableParameterivEXT, (GLenum target, GLenum pname, GLint * params), (target, pname, params))
GEN_THUNKS(glGetColorTableParameterivSGI, (GLenum target, GLenum pname, GLint * params), (target, pname, params))
GEN_THUNKS(glGetColorTableSGI, (GLenum target, GLenum format, GLenum type, void * table), (target, format, type, table))
GEN_THUNKS(glGetCombinerInputParameterfvNV, (GLenum stage, GLenum portion, GLenum variable, GLenum pname, GLfloat * params), (stage, portion, variable, pname, params))
GEN_THUNKS(glGetCombinerInputParameterivNV, (GLenum stage, GLenum portion, GLenum variable, GLenum pname, GLint * params), (stage, portion, variable, pname, params))
GEN_THUNKS(glGetCombinerOutputParameterfvNV, (GLenum stage, GLenum portion, GLenum pname, GLfloat * params), (stage, portion, pname, params))
GEN_THUNKS(glGetCombinerOutputParameterivNV, (GLenum stage, GLenum portion, GLenum pname, GLint * params), (stage, portion, pname, params))
GEN_THUNKS(glGetCombinerStageParameterfvNV, (GLenum stage, GLenum pname, GLfloat * params), (stage, pname, params))
GEN_THUNKS_RET(GLuint, glGetCommandHeaderNV, (GLenum tokenID, GLuint size), (tokenID, size))
GEN_THUNKS(glGetCompressedMultiTexImageEXT, (GLenum texunit, GLenum target, GLint lod, void * img), (texunit, target, lod, img))
GEN_THUNKS(glGetCompressedTexImage, (GLenum target, GLint level, void * img), (target, level, img))
GEN_THUNKS(glGetCompressedTexImageARB, (GLenum target, GLint level, void * img), (target, level, img))
GEN_THUNKS(glGetCompressedTextureImage, (GLuint texture, GLint level, GLsizei bufSize, void * pixels), (texture, level, bufSize, pixels))
GEN_THUNKS(glGetCompressedTextureImageEXT, (GLuint texture, GLenum target, GLint lod, void * img), (texture, target, lod, img))
GEN_THUNKS(glGetCompressedTextureSubImage, (GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLsizei bufSize, void * pixels), (texture, level, xoffset, yoffset, zoffset, width, height, depth, bufSize, pixels))
GEN_THUNKS(glGetConvolutionFilter, (GLenum target, GLenum format, GLenum type, void * image), (target, format, type, image))
GEN_THUNKS(glGetConvolutionFilterEXT, (GLenum target, GLenum format, GLenum type, void * image), (target, format, type, image))
GEN_THUNKS(glGetConvolutionParameterfv, (GLenum target, GLenum pname, GLfloat * params), (target, pname, params))
GEN_THUNKS(glGetConvolutionParameterfvEXT, (GLenum target, GLenum pname, GLfloat * params), (target, pname, params))
GEN_THUNKS(glGetConvolutionParameteriv, (GLenum target, GLenum pname, GLint * params), (target, pname, params))
GEN_THUNKS(glGetConvolutionParameterivEXT, (GLenum target, GLenum pname, GLint * params), (target, pname, params))
GEN_THUNKS(glGetConvolutionParameterxvOES, (GLenum target, GLenum pname, GLfixed * params), (target, pname, params))
GEN_THUNKS(glGetCoverageModulationTableNV, (GLsizei bufsize, GLfloat * v), (bufsize, v))
GEN_THUNKS_RET(GLuint, glGetDebugMessageLog, (GLuint count, GLsizei bufSize, GLenum * sources, GLenum * types, GLuint * ids, GLenum * severities, GLsizei * lengths, GLchar * messageLog), (count, bufSize, sources, types, ids, severities, lengths, messageLog))
GEN_THUNKS_RET(GLuint, glGetDebugMessageLogAMD, (GLuint count, GLsizei bufsize, GLenum * categories, GLuint * severities, GLuint * ids, GLsizei * lengths, GLchar * message), (count, bufsize, categories, severities, ids, lengths, message))
GEN_THUNKS_RET(GLuint, glGetDebugMessageLogARB, (GLuint count, GLsizei bufSize, GLenum * sources, GLenum * types, GLuint * ids, GLenum * severities, GLsizei * lengths, GLchar * messageLog), (count, bufSize, sources, types, ids, severities, lengths, messageLog))
GEN_THUNKS_RET(GLuint, glGetDebugMessageLogKHR, (GLuint count, GLsizei bufSize, GLenum * sources, GLenum * types, GLuint * ids, GLenum * severities, GLsizei * lengths, GLchar * messageLog), (count, bufSize, sources, types, ids, severities, lengths, messageLog))
GEN_THUNKS(glGetDetailTexFuncSGIS, (GLenum target, GLfloat * points), (target, points))
GEN_THUNKS(glGetDoubleIndexedvEXT, (GLenum target, GLuint index, GLdouble * data), (target, index, data))
GEN_THUNKS(glGetDoublei_v, (GLenum target, GLuint index, GLdouble * data), (target, index, data))
GEN_THUNKS(glGetDoublei_vEXT, (GLenum pname, GLuint index, GLdouble * params), (pname, index, params))
GEN_THUNKS(glGetDoublev, (GLenum pname, GLdouble * data), (pname, data))
GEN_THUNKS(glGetDriverControlStringQCOM, (GLuint driverControl, GLsizei bufSize, GLsizei * length, GLchar * driverControlString), (driverControl, bufSize, length, driverControlString))
GEN_THUNKS(glGetDriverControlsQCOM, (GLint * num, GLsizei size, GLuint * driverControls), (num, size, driverControls))
GEN_THUNKS_RET(GLenum, glGetError, (void), ())
GEN_THUNKS(glGetFenceivNV, (GLuint fence, GLenum pname, GLint * params), (fence, pname, params))
GEN_THUNKS(glGetFinalCombinerInputParameterfvNV, (GLenum variable, GLenum pname, GLfloat * params), (variable, pname, params))
GEN_THUNKS(glGetFinalCombinerInputParameterivNV, (GLenum variable, GLenum pname, GLint * params), (variable, pname, params))
GEN_THUNKS(glGetFirstPerfQueryIdINTEL, (GLuint * queryId), (queryId))
GEN_THUNKS(glGetFixedv, (GLenum pname, GLfixed * params), (pname, params))
GEN_THUNKS(glGetFixedvOES, (GLenum pname, GLfixed * params), (pname, params))
GEN_THUNKS(glGetFloatIndexedvEXT, (GLenum target, GLuint index, GLfloat * data), (target, index, data))
GEN_THUNKS(glGetFloati_v, (GLenum target, GLuint index, GLfloat * data), (target, index, data))
GEN_THUNKS(glGetFloati_vEXT, (GLenum pname, GLuint index, GLfloat * params), (pname, index, params))
GEN_THUNKS(glGetFloati_vNV, (GLenum target, GLuint index, GLfloat * data), (target, index, data))
GEN_THUNKS(glGetFloati_vOES, (GLenum target, GLuint index, GLfloat * data), (target, index, data))
GEN_THUNKS(glGetFloatv, (GLenum pname, GLfloat * data), (pname, data))
GEN_THUNKS(glGetFogFuncSGIS, (GLfloat * points), (points))
GEN_THUNKS_RET(GLint, glGetFragDataIndex, (GLuint program, const GLchar * name), (program, name))
GEN_THUNKS_RET(GLint, glGetFragDataIndexEXT, (GLuint program, const GLchar * name), (program, name))
GEN_THUNKS_RET(GLint, glGetFragDataLocation, (GLuint program, const GLchar * name), (program, name))
GEN_THUNKS_RET(GLint, glGetFragDataLocationEXT, (GLuint program, const GLchar * name), (program, name))
GEN_THUNKS(glGetFragmentLightfvSGIX, (GLenum light, GLenum pname, GLfloat * params), (light, pname, params))
GEN_THUNKS(glGetFragmentLightivSGIX, (GLenum light, GLenum pname, GLint * params), (light, pname, params))
GEN_THUNKS(glGetFragmentMaterialfvSGIX, (GLenum face, GLenum pname, GLfloat * params), (face, pname, params))
GEN_THUNKS(glGetFragmentMaterialivSGIX, (GLenum face, GLenum pname, GLint * params), (face, pname, params))
GEN_THUNKS(glGetFramebufferAttachmentParameteriv, (GLenum target, GLenum attachment, GLenum pname, GLint * params), (target, attachment, pname, params))
GEN_THUNKS(glGetFramebufferAttachmentParameterivEXT, (GLenum target, GLenum attachment, GLenum pname, GLint * params), (target, attachment, pname, params))
GEN_THUNKS(glGetFramebufferAttachmentParameterivOES, (GLenum target, GLenum attachment, GLenum pname, GLint * params), (target, attachment, pname, params))
GEN_THUNKS(glGetFramebufferParameterfvAMD, (GLenum target, GLenum pname, GLuint numsamples, GLuint pixelindex, GLsizei size, GLfloat * values), (target, pname, numsamples, pixelindex, size, values))
GEN_THUNKS(glGetFramebufferParameteriv, (GLenum target, GLenum pname, GLint * params), (target, pname, params))
GEN_THUNKS(glGetFramebufferParameterivEXT, (GLuint framebuffer, GLenum pname, GLint * params), (framebuffer, pname, params))
GEN_THUNKS(glGetFramebufferParameterivMESA, (GLenum target, GLenum pname, GLint * params), (target, pname, params))
GEN_THUNKS_RET(GLsizei, glGetFramebufferPixelLocalStorageSizeEXT, (GLuint target), (target))
GEN_THUNKS_RET(GLenum, glGetGraphicsResetStatus, (void), ())
GEN_THUNKS_RET(GLenum, glGetGraphicsResetStatusARB, (void), ())
GEN_THUNKS_RET(GLenum, glGetGraphicsResetStatusEXT, (void), ())
GEN_THUNKS_RET(GLenum, glGetGraphicsResetStatusKHR, (void), ())
GEN_THUNKS_RET(GLhandleARB, glGetHandleARB, (GLenum pname), (pname))
GEN_THUNKS(glGetHistogram, (GLenum target, GLboolean reset, GLenum format, GLenum type, void * values), (target, reset, format, type, values))
GEN_THUNKS(glGetHistogramEXT, (GLenum target, GLboolean reset, GLenum format, GLenum type, void * values), (target, reset, format, type, values))
GEN_THUNKS(glGetHistogramParameterfv, (GLenum target, GLenum pname, GLfloat * params), (target, pname, params))
GEN_THUNKS(glGetHistogramParameterfvEXT, (GLenum target, GLenum pname, GLfloat * params), (target, pname, params))
GEN_THUNKS(glGetHistogramParameteriv, (GLenum target, GLenum pname, GLint * params), (target, pname, params))
GEN_THUNKS(glGetHistogramParameterivEXT, (GLenum target, GLenum pname, GLint * params), (target, pname, params))
GEN_THUNKS(glGetHistogramParameterxvOES, (GLenum target, GLenum pname, GLfixed * params), (target, pname, params))
GEN_THUNKS_RET(GLuint64, glGetImageHandleARB, (GLuint texture, GLint level, GLboolean layered, GLint layer, GLenum format), (texture, level, layered, layer, format))
GEN_THUNKS_RET(GLuint64, glGetImageHandleNV, (GLuint texture, GLint level, GLboolean layered, GLint layer, GLenum format), (texture, level, layered, layer, format))
GEN_THUNKS(glGetImageTransformParameterfvHP, (GLenum target, GLenum pname, GLfloat * params), (target, pname, params))
GEN_THUNKS(glGetImageTransformParameterivHP, (GLenum target, GLenum pname, GLint * params), (target, pname, params))
GEN_THUNKS(glGetInfoLogARB, (GLhandleARB obj, GLsizei maxLength, GLsizei * length, GLcharARB * infoLog), ((uintptr_t)obj, maxLength, length, infoLog))
GEN_THUNKS_RET(GLint, glGetInstrumentsSGIX, (void), ())
GEN_THUNKS(glGetInteger64i_v, (GLenum target, GLuint index, GLint64 * data), (target, index, data))
GEN_THUNKS(glGetInteger64v, (GLenum pname, GLint64 * data), (pname, data))
GEN_THUNKS(glGetInteger64vAPPLE, (GLenum pname, GLint64 * params), (pname, params))
GEN_THUNKS(glGetIntegerIndexedvEXT, (GLenum target, GLuint index, GLint * data), (target, index, data))
GEN_THUNKS(glGetIntegeri_v, (GLenum target, GLuint index, GLint * data), (target, index, data))
GEN_THUNKS(glGetIntegeri_vEXT, (GLenum target, GLuint index, GLint * data), (target, index, data))
GEN_THUNKS(glGetIntegerui64i_vNV, (GLenum value, GLuint index, GLuint64EXT * result), (value, index, result))
GEN_THUNKS(glGetIntegerui64vNV, (GLenum value, GLuint64EXT * result), (value, result))
GEN_THUNKS(glGetIntegerv, (GLenum pname, GLint * data), (pname, data))
GEN_THUNKS(glGetInternalformatSampleivNV, (GLenum target, GLenum internalformat, GLsizei samples, GLenum pname, GLsizei bufSize, GLint * params), (target, internalformat, samples, pname, bufSize, params))
GEN_THUNKS(glGetInternalformati64v, (GLenum target, GLenum internalformat, GLenum pname, GLsizei bufSize, GLint64 * params), (target, internalformat, pname, bufSize, params))
GEN_THUNKS(glGetInternalformativ, (GLenum target, GLenum internalformat, GLenum pname, GLsizei bufSize, GLint * params), (target, internalformat, pname, bufSize, params))
GEN_THUNKS(glGetInvariantBooleanvEXT, (GLuint id, GLenum value, GLboolean * data), (id, value, data))
GEN_THUNKS(glGetInvariantFloatvEXT, (GLuint id, GLenum value, GLfloat * data), (id, value, data))
GEN_THUNKS(glGetInvariantIntegervEXT, (GLuint id, GLenum value, GLint * data), (id, value, data))
GEN_THUNKS(glGetLightfv, (GLenum light, GLenum pname, GLfloat * params), (light, pname, params))
GEN_THUNKS(glGetLightiv, (GLenum light, GLenum pname, GLint * params), (light, pname, params))
GEN_THUNKS(glGetLightxOES, (GLenum light, GLenum pname, GLfixed * params), (light, pname, params))
GEN_THUNKS(glGetLightxv, (GLenum light, GLenum pname, GLfixed * params), (light, pname, params))
GEN_THUNKS(glGetLightxvOES, (GLenum light, GLenum pname, GLfixed * params), (light, pname, params))
GEN_THUNKS(glGetListParameterfvSGIX, (GLuint list, GLenum pname, GLfloat * params), (list, pname, params))
GEN_THUNKS(glGetListParameterivSGIX, (GLuint list, GLenum pname, GLint * params), (list, pname, params))
GEN_THUNKS(glGetLocalConstantBooleanvEXT, (GLuint id, GLenum value, GLboolean * data), (id, value, data))
GEN_THUNKS(glGetLocalConstantFloatvEXT, (GLuint id, GLenum value, GLfloat * data), (id, value, data))
GEN_THUNKS(glGetLocalConstantIntegervEXT, (GLuint id, GLenum value, GLint * data), (id, value, data))
GEN_THUNKS(glGetMapAttribParameterfvNV, (GLenum target, GLuint index, GLenum pname, GLfloat * params), (target, index, pname, params))
GEN_THUNKS(glGetMapAttribParameterivNV, (GLenum target, GLuint index, GLenum pname, GLint * params), (target, index, pname, params))
GEN_THUNKS(glGetMapControlPointsNV, (GLenum target, GLuint index, GLenum type, GLsizei ustride, GLsizei vstride, GLboolean packed, void * points), (target, index, type, ustride, vstride, packed, points))
GEN_THUNKS(glGetMapParameterfvNV, (GLenum target, GLenum pname, GLfloat * params), (target, pname, params))
GEN_THUNKS(glGetMapParameterivNV, (GLenum target, GLenum pname, GLint * params), (target, pname, params))
GEN_THUNKS(glGetMapdv, (GLenum target, GLenum query, GLdouble * v), (target, query, v))
GEN_THUNKS(glGetMapfv, (GLenum target, GLenum query, GLfloat * v), (target, query, v))
GEN_THUNKS(glGetMapiv, (GLenum target, GLenum query, GLint * v), (target, query, v))
GEN_THUNKS(glGetMapxvOES, (GLenum target, GLenum query, GLfixed * v), (target, query, v))
GEN_THUNKS(glGetMaterialfv, (GLenum face, GLenum pname, GLfloat * params), (face, pname, params))
GEN_THUNKS(glGetMaterialiv, (GLenum face, GLenum pname, GLint * params), (face, pname, params))
GEN_THUNKS(glGetMaterialxOES, (GLenum face, GLenum pname, GLfixed param), (face, pname, param))
GEN_THUNKS(glGetMaterialxv, (GLenum face, GLenum pname, GLfixed * params), (face, pname, params))
GEN_THUNKS(glGetMaterialxvOES, (GLenum face, GLenum pname, GLfixed * params), (face, pname, params))
GEN_THUNKS(glGetMemoryObjectDetachedResourcesuivNV, (GLuint memory, GLenum pname, GLint first, GLsizei count, GLuint * params), (memory, pname, first, count, params))
GEN_THUNKS(glGetMemoryObjectParameterivEXT, (GLuint memoryObject, GLenum pname, GLint * params), (memoryObject, pname, params))
GEN_THUNKS(glGetMinmax, (GLenum target, GLboolean reset, GLenum format, GLenum type, void * values), (target, reset, format, type, values))
GEN_THUNKS(glGetMinmaxEXT, (GLenum target, GLboolean reset, GLenum format, GLenum type, void * values), (target, reset, format, type, values))
GEN_THUNKS(glGetMinmaxParameterfv, (GLenum target, GLenum pname, GLfloat * params), (target, pname, params))
GEN_THUNKS(glGetMinmaxParameterfvEXT, (GLenum target, GLenum pname, GLfloat * params), (target, pname, params))
GEN_THUNKS(glGetMinmaxParameteriv, (GLenum target, GLenum pname, GLint * params), (target, pname, params))
GEN_THUNKS(glGetMinmaxParameterivEXT, (GLenum target, GLenum pname, GLint * params), (target, pname, params))
GEN_THUNKS(glGetMultiTexEnvfvEXT, (GLenum texunit, GLenum target, GLenum pname, GLfloat * params), (texunit, target, pname, params))
GEN_THUNKS(glGetMultiTexEnvivEXT, (GLenum texunit, GLenum target, GLenum pname, GLint * params), (texunit, target, pname, params))
GEN_THUNKS(glGetMultiTexGendvEXT, (GLenum texunit, GLenum coord, GLenum pname, GLdouble * params), (texunit, coord, pname, params))
GEN_THUNKS(glGetMultiTexGenfvEXT, (GLenum texunit, GLenum coord, GLenum pname, GLfloat * params), (texunit, coord, pname, params))
GEN_THUNKS(glGetMultiTexGenivEXT, (GLenum texunit, GLenum coord, GLenum pname, GLint * params), (texunit, coord, pname, params))
GEN_THUNKS(glGetMultiTexImageEXT, (GLenum texunit, GLenum target, GLint level, GLenum format, GLenum type, void * pixels), (texunit, target, level, format, type, pixels))
GEN_THUNKS(glGetMultiTexLevelParameterfvEXT, (GLenum texunit, GLenum target, GLint level, GLenum pname, GLfloat * params), (texunit, target, level, pname, params))
GEN_THUNKS(glGetMultiTexLevelParameterivEXT, (GLenum texunit, GLenum target, GLint level, GLenum pname, GLint * params), (texunit, target, level, pname, params))
GEN_THUNKS(glGetMultiTexParameterIivEXT, (GLenum texunit, GLenum target, GLenum pname, GLint * params), (texunit, target, pname, params))
GEN_THUNKS(glGetMultiTexParameterIuivEXT, (GLenum texunit, GLenum target, GLenum pname, GLuint * params), (texunit, target, pname, params))
GEN_THUNKS(glGetMultiTexParameterfvEXT, (GLenum texunit, GLenum target, GLenum pname, GLfloat * params), (texunit, target, pname, params))
GEN_THUNKS(glGetMultiTexParameterivEXT, (GLenum texunit, GLenum target, GLenum pname, GLint * params), (texunit, target, pname, params))
GEN_THUNKS(glGetMultisamplefv, (GLenum pname, GLuint index, GLfloat * val), (pname, index, val))
GEN_THUNKS(glGetMultisamplefvNV, (GLenum pname, GLuint index, GLfloat * val), (pname, index, val))
GEN_THUNKS(glGetNamedBufferParameteri64v, (GLuint buffer, GLenum pname, GLint64 * params), (buffer, pname, params))
GEN_THUNKS(glGetNamedBufferParameteriv, (GLuint buffer, GLenum pname, GLint * params), (buffer, pname, params))
GEN_THUNKS(glGetNamedBufferParameterivEXT, (GLuint buffer, GLenum pname, GLint * params), (buffer, pname, params))
GEN_THUNKS(glGetNamedBufferParameterui64vNV, (GLuint buffer, GLenum pname, GLuint64EXT * params), (buffer, pname, params))
GEN_THUNKS(glGetNamedBufferPointerv, (GLuint buffer, GLenum pname, void ** params), (buffer, pname, params))
GEN_THUNKS(glGetNamedBufferPointervEXT, (GLuint buffer, GLenum pname, void ** params), (buffer, pname, params))
GEN_THUNKS(glGetNamedBufferSubData, (GLuint buffer, GLintptr offset, GLsizeiptr size, void * data), (buffer, offset, size, data))
GEN_THUNKS(glGetNamedBufferSubDataEXT, (GLuint buffer, GLintptr offset, GLsizeiptr size, void * data), (buffer, offset, size, data))
GEN_THUNKS(glGetNamedFramebufferAttachmentParameteriv, (GLuint framebuffer, GLenum attachment, GLenum pname, GLint * params), (framebuffer, attachment, pname, params))
GEN_THUNKS(glGetNamedFramebufferAttachmentParameterivEXT, (GLuint framebuffer, GLenum attachment, GLenum pname, GLint * params), (framebuffer, attachment, pname, params))
GEN_THUNKS(glGetNamedFramebufferParameterfvAMD, (GLuint framebuffer, GLenum pname, GLuint numsamples, GLuint pixelindex, GLsizei size, GLfloat * values), (framebuffer, pname, numsamples, pixelindex, size, values))
GEN_THUNKS(glGetNamedFramebufferParameteriv, (GLuint framebuffer, GLenum pname, GLint * param), (framebuffer, pname, param))
GEN_THUNKS(glGetNamedFramebufferParameterivEXT, (GLuint framebuffer, GLenum pname, GLint * params), (framebuffer, pname, params))
GEN_THUNKS(glGetNamedProgramLocalParameterIivEXT, (GLuint program, GLenum target, GLuint index, GLint * params), (program, target, index, params))
GEN_THUNKS(glGetNamedProgramLocalParameterIuivEXT, (GLuint program, GLenum target, GLuint index, GLuint * params), (program, target, index, params))
GEN_THUNKS(glGetNamedProgramLocalParameterdvEXT, (GLuint program, GLenum target, GLuint index, GLdouble * params), (program, target, index, params))
GEN_THUNKS(glGetNamedProgramLocalParameterfvEXT, (GLuint program, GLenum target, GLuint index, GLfloat * params), (program, target, index, params))
GEN_THUNKS(glGetNamedProgramStringEXT, (GLuint program, GLenum target, GLenum pname, void * string), (program, target, pname, string))
GEN_THUNKS(glGetNamedProgramivEXT, (GLuint program, GLenum target, GLenum pname, GLint * params), (program, target, pname, params))
GEN_THUNKS(glGetNamedRenderbufferParameteriv, (GLuint renderbuffer, GLenum pname, GLint * params), (renderbuffer, pname, params))
GEN_THUNKS(glGetNamedRenderbufferParameterivEXT, (GLuint renderbuffer, GLenum pname, GLint * params), (renderbuffer, pname, params))
GEN_THUNKS(glGetNamedStringARB, (GLint namelen, const GLchar * name, GLsizei bufSize, GLint * stringlen, GLchar * string), (namelen, name, bufSize, stringlen, string))
GEN_THUNKS(glGetNamedStringivARB, (GLint namelen, const GLchar * name, GLenum pname, GLint * params), (namelen, name, pname, params))
GEN_THUNKS(glGetNextPerfQueryIdINTEL, (GLuint queryId, GLuint * nextQueryId), (queryId, nextQueryId))
GEN_THUNKS(glGetObjectBufferfvATI, (GLuint buffer, GLenum pname, GLfloat * params), (buffer, pname, params))
GEN_THUNKS(glGetObjectBufferivATI, (GLuint buffer, GLenum pname, GLint * params), (buffer, pname, params))
GEN_THUNKS(glGetObjectLabel, (GLenum identifier, GLuint name, GLsizei bufSize, GLsizei * length, GLchar * label), (identifier, name, bufSize, length, label))
GEN_THUNKS(glGetObjectLabelEXT, (GLenum type, GLuint object, GLsizei bufSize, GLsizei * length, GLchar * label), (type, object, bufSize, length, label))
GEN_THUNKS(glGetObjectLabelKHR, (GLenum identifier, GLuint name, GLsizei bufSize, GLsizei * length, GLchar * label), (identifier, name, bufSize, length, label))
GEN_THUNKS(glGetObjectParameterfvARB, (GLhandleARB obj, GLenum pname, GLfloat * params), ((uintptr_t)obj, pname, params))
GEN_THUNKS(glGetObjectParameterivAPPLE, (GLenum objectType, GLuint name, GLenum pname, GLint * params), (objectType, name, pname, params))
GEN_THUNKS(glGetObjectParameterivARB, (GLhandleARB obj, GLenum pname, GLint * params), ((uintptr_t)obj, pname, params))
GEN_THUNKS(glGetObjectPtrLabel, (const void * ptr, GLsizei bufSize, GLsizei * length, GLchar * label), (ptr, bufSize, length, label))
GEN_THUNKS(glGetObjectPtrLabelKHR, (const void * ptr, GLsizei bufSize, GLsizei * length, GLchar * label), (ptr, bufSize, length, label))
GEN_THUNKS(glGetOcclusionQueryivNV, (GLuint id, GLenum pname, GLint * params), (id, pname, params))
GEN_THUNKS(glGetOcclusionQueryuivNV, (GLuint id, GLenum pname, GLuint * params), (id, pname, params))
GEN_THUNKS(glGetPathColorGenfvNV, (GLenum color, GLenum pname, GLfloat * value), (color, pname, value))
GEN_THUNKS(glGetPathColorGenivNV, (GLenum color, GLenum pname, GLint * value), (color, pname, value))
GEN_THUNKS(glGetPathCommandsNV, (GLuint path, GLubyte * commands), (path, commands))
GEN_THUNKS(glGetPathCoordsNV, (GLuint path, GLfloat * coords), (path, coords))
GEN_THUNKS(glGetPathDashArrayNV, (GLuint path, GLfloat * dashArray), (path, dashArray))
GEN_THUNKS_RET(GLfloat, glGetPathLengthNV, (GLuint path, GLsizei startSegment, GLsizei numSegments), (path, startSegment, numSegments))
GEN_THUNKS(glGetPathMetricRangeNV, (GLbitfield metricQueryMask, GLuint firstPathName, GLsizei numPaths, GLsizei stride, GLfloat * metrics), (metricQueryMask, firstPathName, numPaths, stride, metrics))
GEN_THUNKS(glGetPathMetricsNV, (GLbitfield metricQueryMask, GLsizei numPaths, GLenum pathNameType, const void * paths, GLuint pathBase, GLsizei stride, GLfloat * metrics), (metricQueryMask, numPaths, pathNameType, paths, pathBase, stride, metrics))
GEN_THUNKS(glGetPathParameterfvNV, (GLuint path, GLenum pname, GLfloat * value), (path, pname, value))
GEN_THUNKS(glGetPathParameterivNV, (GLuint path, GLenum pname, GLint * value), (path, pname, value))
GEN_THUNKS(glGetPathSpacingNV, (GLenum pathListMode, GLsizei numPaths, GLenum pathNameType, const void * paths, GLuint pathBase, GLfloat advanceScale, GLfloat kerningScale, GLenum transformType, GLfloat * returnedSpacing), (pathListMode, numPaths, pathNameType, paths, pathBase, advanceScale, kerningScale, transformType, returnedSpacing))
GEN_THUNKS(glGetPathTexGenfvNV, (GLenum texCoordSet, GLenum pname, GLfloat * value), (texCoordSet, pname, value))
GEN_THUNKS(glGetPathTexGenivNV, (GLenum texCoordSet, GLenum pname, GLint * value), (texCoordSet, pname, value))
GEN_THUNKS(glGetPerfCounterInfoINTEL, (GLuint queryId, GLuint counterId, GLuint counterNameLength, GLchar * counterName, GLuint counterDescLength, GLchar * counterDesc, GLuint * counterOffset, GLuint * counterDataSize, GLuint * counterTypeEnum, GLuint * counterDataTypeEnum, GLuint64 * rawCounterMaxValue), (queryId, counterId, counterNameLength, counterName, counterDescLength, counterDesc, counterOffset, counterDataSize, counterTypeEnum, counterDataTypeEnum, rawCounterMaxValue))
GEN_THUNKS(glGetPerfMonitorCounterDataAMD, (GLuint monitor, GLenum pname, GLsizei dataSize, GLuint * data, GLint * bytesWritten), (monitor, pname, dataSize, data, bytesWritten))
GEN_THUNKS(glGetPerfMonitorCounterInfoAMD, (GLuint group, GLuint counter, GLenum pname, void * data), (group, counter, pname, data))
GEN_THUNKS(glGetPerfMonitorCounterStringAMD, (GLuint group, GLuint counter, GLsizei bufSize, GLsizei * length, GLchar * counterString), (group, counter, bufSize, length, counterString))
GEN_THUNKS(glGetPerfMonitorCountersAMD, (GLuint group, GLint * numCounters, GLint * maxActiveCounters, GLsizei counterSize, GLuint * counters), (group, numCounters, maxActiveCounters, counterSize, counters))
GEN_THUNKS(glGetPerfMonitorGroupStringAMD, (GLuint group, GLsizei bufSize, GLsizei * length, GLchar * groupString), (group, bufSize, length, groupString))
GEN_THUNKS(glGetPerfMonitorGroupsAMD, (GLint * numGroups, GLsizei groupsSize, GLuint * groups), (numGroups, groupsSize, groups))
GEN_THUNKS(glGetPerfQueryDataINTEL, (GLuint queryHandle, GLuint flags, GLsizei dataSize, void * data, GLuint * bytesWritten), (queryHandle, flags, dataSize, data, bytesWritten))
GEN_THUNKS(glGetPerfQueryIdByNameINTEL, (GLchar * queryName, GLuint * queryId), (queryName, queryId))
GEN_THUNKS(glGetPerfQueryInfoINTEL, (GLuint queryId, GLuint queryNameLength, GLchar * queryName, GLuint * dataSize, GLuint * noCounters, GLuint * noInstances, GLuint * capsMask), (queryId, queryNameLength, queryName, dataSize, noCounters, noInstances, capsMask))
GEN_THUNKS(glGetPixelMapfv, (GLenum map, GLfloat * values), (map, values))
GEN_THUNKS(glGetPixelMapuiv, (GLenum map, GLuint * values), (map, values))
GEN_THUNKS(glGetPixelMapusv, (GLenum map, GLushort * values), (map, values))
GEN_THUNKS(glGetPixelMapxv, (GLenum map, GLint size, GLfixed * values), (map, size, values))
GEN_THUNKS(glGetPixelTexGenParameterfvSGIS, (GLenum pname, GLfloat * params), (pname, params))
GEN_THUNKS(glGetPixelTexGenParameterivSGIS, (GLenum pname, GLint * params), (pname, params))
GEN_THUNKS(glGetPixelTransformParameterfvEXT, (GLenum target, GLenum pname, GLfloat * params), (target, pname, params))
GEN_THUNKS(glGetPixelTransformParameterivEXT, (GLenum target, GLenum pname, GLint * params), (target, pname, params))
GEN_THUNKS(glGetPointerIndexedvEXT, (GLenum target, GLuint index, void ** data), (target, index, data))
GEN_THUNKS(glGetPointeri_vEXT, (GLenum pname, GLuint index, void ** params), (pname, index, params))
GEN_THUNKS(glGetPointerv, (GLenum pname, void ** params), (pname, params))
GEN_THUNKS(glGetPointervEXT, (GLenum pname, void ** params), (pname, params))
GEN_THUNKS(glGetPointervKHR, (GLenum pname, void ** params), (pname, params))
GEN_THUNKS(glGetPolygonStipple, (GLubyte * mask), (mask))
GEN_THUNKS(glGetProgramBinary, (GLuint program, GLsizei bufSize, GLsizei * length, GLenum * binaryFormat, void * binary), (program, bufSize, length, binaryFormat, binary))
GEN_THUNKS(glGetProgramBinaryOES, (GLuint program, GLsizei bufSize, GLsizei * length, GLenum * binaryFormat, void * binary), (program, bufSize, length, binaryFormat, binary))
GEN_THUNKS(glGetProgramEnvParameterIivNV, (GLenum target, GLuint index, GLint * params), (target, index, params))
GEN_THUNKS(glGetProgramEnvParameterIuivNV, (GLenum target, GLuint index, GLuint * params), (target, index, params))
GEN_THUNKS(glGetProgramEnvParameterdvARB, (GLenum target, GLuint index, GLdouble * params), (target, index, params))
GEN_THUNKS(glGetProgramEnvParameterfvARB, (GLenum target, GLuint index, GLfloat * params), (target, index, params))
GEN_THUNKS(glGetProgramInfoLog, (GLuint program, GLsizei bufSize, GLsizei * length, GLchar * infoLog), (program, bufSize, length, infoLog))
GEN_THUNKS(glGetProgramInterfaceiv, (GLuint program, GLenum programInterface, GLenum pname, GLint * params), (program, programInterface, pname, params))
GEN_THUNKS(glGetProgramLocalParameterIivNV, (GLenum target, GLuint index, GLint * params), (target, index, params))
GEN_THUNKS(glGetProgramLocalParameterIuivNV, (GLenum target, GLuint index, GLuint * params), (target, index, params))
GEN_THUNKS(glGetProgramLocalParameterdvARB, (GLenum target, GLuint index, GLdouble * params), (target, index, params))
GEN_THUNKS(glGetProgramLocalParameterfvARB, (GLenum target, GLuint index, GLfloat * params), (target, index, params))
GEN_THUNKS(glGetProgramNamedParameterdvNV, (GLuint id, GLsizei len, const GLubyte * name, GLdouble * params), (id, len, name, params))
GEN_THUNKS(glGetProgramNamedParameterfvNV, (GLuint id, GLsizei len, const GLubyte * name, GLfloat * params), (id, len, name, params))
GEN_THUNKS(glGetProgramParameterdvNV, (GLenum target, GLuint index, GLenum pname, GLdouble * params), (target, index, pname, params))
GEN_THUNKS(glGetProgramParameterfvNV, (GLenum target, GLuint index, GLenum pname, GLfloat * params), (target, index, pname, params))
GEN_THUNKS(glGetProgramPipelineInfoLog, (GLuint pipeline, GLsizei bufSize, GLsizei * length, GLchar * infoLog), (pipeline, bufSize, length, infoLog))
GEN_THUNKS(glGetProgramPipelineInfoLogEXT, (GLuint pipeline, GLsizei bufSize, GLsizei * length, GLchar * infoLog), (pipeline, bufSize, length, infoLog))
GEN_THUNKS(glGetProgramPipelineiv, (GLuint pipeline, GLenum pname, GLint * params), (pipeline, pname, params))
GEN_THUNKS(glGetProgramPipelineivEXT, (GLuint pipeline, GLenum pname, GLint * params), (pipeline, pname, params))
GEN_THUNKS_RET(GLuint, glGetProgramResourceIndex, (GLuint program, GLenum programInterface, const GLchar * name), (program, programInterface, name))
GEN_THUNKS_RET(GLint, glGetProgramResourceLocation, (GLuint program, GLenum programInterface, const GLchar * name), (program, programInterface, name))
GEN_THUNKS_RET(GLint, glGetProgramResourceLocationIndex, (GLuint program, GLenum programInterface, const GLchar * name), (program, programInterface, name))
GEN_THUNKS_RET(GLint, glGetProgramResourceLocationIndexEXT, (GLuint program, GLenum programInterface, const GLchar * name), (program, programInterface, name))
GEN_THUNKS(glGetProgramResourceName, (GLuint program, GLenum programInterface, GLuint index, GLsizei bufSize, GLsizei * length, GLchar * name), (program, programInterface, index, bufSize, length, name))
GEN_THUNKS(glGetProgramResourcefvNV, (GLuint program, GLenum programInterface, GLuint index, GLsizei propCount, const GLenum * props, GLsizei bufSize, GLsizei * length, GLfloat * params), (program, programInterface, index, propCount, props, bufSize, length, params))
GEN_THUNKS(glGetProgramResourceiv, (GLuint program, GLenum programInterface, GLuint index, GLsizei propCount, const GLenum * props, GLsizei bufSize, GLsizei * length, GLint * params), (program, programInterface, index, propCount, props, bufSize, length, params))
GEN_THUNKS(glGetProgramStageiv, (GLuint program, GLenum shadertype, GLenum pname, GLint * values), (program, shadertype, pname, values))
GEN_THUNKS(glGetProgramStringARB, (GLenum target, GLenum pname, void * string), (target, pname, string))
GEN_THUNKS(glGetProgramStringNV, (GLuint id, GLenum pname, GLubyte * program), (id, pname, program))
GEN_THUNKS(glGetProgramSubroutineParameteruivNV, (GLenum target, GLuint index, GLuint * param), (target, index, param))
GEN_THUNKS(glGetProgramiv, (GLuint program, GLenum pname, GLint * params), (program, pname, params))
GEN_THUNKS(glGetProgramivARB, (GLenum target, GLenum pname, GLint * params), (target, pname, params))
GEN_THUNKS(glGetProgramivNV, (GLuint id, GLenum pname, GLint * params), (id, pname, params))
GEN_THUNKS(glGetQueryBufferObjecti64v, (GLuint id, GLuint buffer, GLenum pname, GLintptr offset), (id, buffer, pname, offset))
GEN_THUNKS(glGetQueryBufferObjectiv, (GLuint id, GLuint buffer, GLenum pname, GLintptr offset), (id, buffer, pname, offset))
GEN_THUNKS(glGetQueryBufferObjectui64v, (GLuint id, GLuint buffer, GLenum pname, GLintptr offset), (id, buffer, pname, offset))
GEN_THUNKS(glGetQueryBufferObjectuiv, (GLuint id, GLuint buffer, GLenum pname, GLintptr offset), (id, buffer, pname, offset))
GEN_THUNKS(glGetQueryIndexediv, (GLenum target, GLuint index, GLenum pname, GLint * params), (target, index, pname, params))
GEN_THUNKS(glGetQueryObjecti64v, (GLuint id, GLenum pname, GLint64 * params), (id, pname, params))
GEN_THUNKS(glGetQueryObjecti64vEXT, (GLuint id, GLenum pname, GLint64 * params), (id, pname, params))
GEN_THUNKS(glGetQueryObjectiv, (GLuint id, GLenum pname, GLint * params), (id, pname, params))
GEN_THUNKS(glGetQueryObjectivARB, (GLuint id, GLenum pname, GLint * params), (id, pname, params))
GEN_THUNKS(glGetQueryObjectivEXT, (GLuint id, GLenum pname, GLint * params), (id, pname, params))
GEN_THUNKS(glGetQueryObjectui64v, (GLuint id, GLenum pname, GLuint64 * params), (id, pname, params))
GEN_THUNKS(glGetQueryObjectui64vEXT, (GLuint id, GLenum pname, GLuint64 * params), (id, pname, params))
GEN_THUNKS(glGetQueryObjectuiv, (GLuint id, GLenum pname, GLuint * params), (id, pname, params))
GEN_THUNKS(glGetQueryObjectuivARB, (GLuint id, GLenum pname, GLuint * params), (id, pname, params))
GEN_THUNKS(glGetQueryObjectuivEXT, (GLuint id, GLenum pname, GLuint * params), (id, pname, params))
GEN_THUNKS(glGetQueryiv, (GLenum target, GLenum pname, GLint * params), (target, pname, params))
GEN_THUNKS(glGetQueryivARB, (GLenum target, GLenum pname, GLint * params), (target, pname, params))
GEN_THUNKS(glGetQueryivEXT, (GLenum target, GLenum pname, GLint * params), (target, pname, params))
GEN_THUNKS(glGetRenderbufferParameteriv, (GLenum target, GLenum pname, GLint * params), (target, pname, params))
GEN_THUNKS(glGetRenderbufferParameterivEXT, (GLenum target, GLenum pname, GLint * params), (target, pname, params))
GEN_THUNKS(glGetRenderbufferParameterivOES, (GLenum target, GLenum pname, GLint * params), (target, pname, params))
GEN_THUNKS(glGetSamplerParameterIiv, (GLuint sampler, GLenum pname, GLint * params), (sampler, pname, params))
GEN_THUNKS(glGetSamplerParameterIivEXT, (GLuint sampler, GLenum pname, GLint * params), (sampler, pname, params))
GEN_THUNKS(glGetSamplerParameterIivOES, (GLuint sampler, GLenum pname, GLint * params), (sampler, pname, params))
GEN_THUNKS(glGetSamplerParameterIuiv, (GLuint sampler, GLenum pname, GLuint * params), (sampler, pname, params))
GEN_THUNKS(glGetSamplerParameterIuivEXT, (GLuint sampler, GLenum pname, GLuint * params), (sampler, pname, params))
GEN_THUNKS(glGetSamplerParameterIuivOES, (GLuint sampler, GLenum pname, GLuint * params), (sampler, pname, params))
GEN_THUNKS(glGetSamplerParameterfv, (GLuint sampler, GLenum pname, GLfloat * params), (sampler, pname, params))
GEN_THUNKS(glGetSamplerParameteriv, (GLuint sampler, GLenum pname, GLint * params), (sampler, pname, params))
GEN_THUNKS(glGetSemaphoreParameterui64vEXT, (GLuint semaphore, GLenum pname, GLuint64 * params), (semaphore, pname, params))
GEN_THUNKS(glGetSeparableFilter, (GLenum target, GLenum format, GLenum type, void * row, void * column, void * span), (target, format, type, row, column, span))
GEN_THUNKS(glGetSeparableFilterEXT, (GLenum target, GLenum format, GLenum type, void * row, void * column, void * span), (target, format, type, row, column, span))
GEN_THUNKS(glGetShaderInfoLog, (GLuint shader, GLsizei bufSize, GLsizei * length, GLchar * infoLog), (shader, bufSize, length, infoLog))
GEN_THUNKS(glGetShaderPrecisionFormat, (GLenum shadertype, GLenum precisiontype, GLint * range, GLint * precision), (shadertype, precisiontype, range, precision))
GEN_THUNKS(glGetShaderSource, (GLuint shader, GLsizei bufSize, GLsizei * length, GLchar * source), (shader, bufSize, length, source))
GEN_THUNKS(glGetShaderSourceARB, (GLhandleARB obj, GLsizei maxLength, GLsizei * length, GLcharARB * source), ((uintptr_t)obj, maxLength, length, source))
GEN_THUNKS(glGetShaderiv, (GLuint shader, GLenum pname, GLint * params), (shader, pname, params))
GEN_THUNKS(glGetShadingRateImagePaletteNV, (GLuint viewport, GLuint entry, GLenum * rate), (viewport, entry, rate))
GEN_THUNKS(glGetShadingRateSampleLocationivNV, (GLenum rate, GLuint samples, GLuint index, GLint * location), (rate, samples, index, location))
GEN_THUNKS(glGetSharpenTexFuncSGIS, (GLenum target, GLfloat * points), (target, points))
GEN_THUNKS_RET(GLushort, glGetStageIndexNV, (GLenum shadertype), (shadertype))
GEN_THUNKS_RET(const GLubyte *, glGetString, (GLenum name), (name))
GEN_THUNKS_RET(const GLubyte *, glGetStringi, (GLenum name, GLuint index), (name, index))
GEN_THUNKS_RET(GLuint, glGetSubroutineIndex, (GLuint program, GLenum shadertype, const GLchar * name), (program, shadertype, name))
GEN_THUNKS_RET(GLint, glGetSubroutineUniformLocation, (GLuint program, GLenum shadertype, const GLchar * name), (program, shadertype, name))
GEN_THUNKS(glGetSynciv, (GLsync sync, GLenum pname, GLsizei bufSize, GLsizei * length, GLint * values), (sync, pname, bufSize, length, values))
GEN_THUNKS(glGetSyncivAPPLE, (GLsync sync, GLenum pname, GLsizei bufSize, GLsizei * length, GLint * values), (sync, pname, bufSize, length, values))
GEN_THUNKS(glGetTexBumpParameterfvATI, (GLenum pname, GLfloat * param), (pname, param))
GEN_THUNKS(glGetTexBumpParameterivATI, (GLenum pname, GLint * param), (pname, param))
GEN_THUNKS(glGetTexEnvfv, (GLenum target, GLenum pname, GLfloat * params), (target, pname, params))
GEN_THUNKS(glGetTexEnviv, (GLenum target, GLenum pname, GLint * params), (target, pname, params))
GEN_THUNKS(glGetTexEnvxv, (GLenum target, GLenum pname, GLfixed * params), (target, pname, params))
GEN_THUNKS(glGetTexEnvxvOES, (GLenum target, GLenum pname, GLfixed * params), (target, pname, params))
GEN_THUNKS(glGetTexFilterFuncSGIS, (GLenum target, GLenum filter, GLfloat * weights), (target, filter, weights))
GEN_THUNKS(glGetTexGendv, (GLenum coord, GLenum pname, GLdouble * params), (coord, pname, params))
GEN_THUNKS(glGetTexGenfv, (GLenum coord, GLenum pname, GLfloat * params), (coord, pname, params))
GEN_THUNKS(glGetTexGenfvOES, (GLenum coord, GLenum pname, GLfloat * params), (coord, pname, params))
GEN_THUNKS(glGetTexGeniv, (GLenum coord, GLenum pname, GLint * params), (coord, pname, params))
GEN_THUNKS(glGetTexGenivOES, (GLenum coord, GLenum pname, GLint * params), (coord, pname, params))
GEN_THUNKS(glGetTexGenxvOES, (GLenum coord, GLenum pname, GLfixed * params), (coord, pname, params))
GEN_THUNKS(glGetTexImage, (GLenum target, GLint level, GLenum format, GLenum type, void * pixels), (target, level, format, type, pixels))
GEN_THUNKS(glGetTexLevelParameterfv, (GLenum target, GLint level, GLenum pname, GLfloat * params), (target, level, pname, params))
GEN_THUNKS(glGetTexLevelParameteriv, (GLenum target, GLint level, GLenum pname, GLint * params), (target, level, pname, params))
GEN_THUNKS(glGetTexLevelParameterxvOES, (GLenum target, GLint level, GLenum pname, GLfixed * params), (target, level, pname, params))
GEN_THUNKS(glGetTexParameterIiv, (GLenum target, GLenum pname, GLint * params), (target, pname, params))
GEN_THUNKS(glGetTexParameterIivEXT, (GLenum target, GLenum pname, GLint * params), (target, pname, params))
GEN_THUNKS(glGetTexParameterIivOES, (GLenum target, GLenum pname, GLint * params), (target, pname, params))
GEN_THUNKS(glGetTexParameterIuiv, (GLenum target, GLenum pname, GLuint * params), (target, pname, params))
GEN_THUNKS(glGetTexParameterIuivEXT, (GLenum target, GLenum pname, GLuint * params), (target, pname, params))
GEN_THUNKS(glGetTexParameterIuivOES, (GLenum target, GLenum pname, GLuint * params), (target, pname, params))
GEN_THUNKS(glGetTexParameterPointervAPPLE, (GLenum target, GLenum pname, void ** params), (target, pname, params))
GEN_THUNKS(glGetTexParameterfv, (GLenum target, GLenum pname, GLfloat * params), (target, pname, params))
GEN_THUNKS(glGetTexParameteriv, (GLenum target, GLenum pname, GLint * params), (target, pname, params))
GEN_THUNKS(glGetTexParameterxv, (GLenum target, GLenum pname, GLfixed * params), (target, pname, params))
GEN_THUNKS(glGetTexParameterxvOES, (GLenum target, GLenum pname, GLfixed * params), (target, pname, params))
GEN_THUNKS_RET(GLuint64, glGetTextureHandleARB, (GLuint texture), (texture))
GEN_THUNKS_RET(GLuint64, glGetTextureHandleIMG, (GLuint texture), (texture))
GEN_THUNKS_RET(GLuint64, glGetTextureHandleNV, (GLuint texture), (texture))
GEN_THUNKS(glGetTextureImage, (GLuint texture, GLint level, GLenum format, GLenum type, GLsizei bufSize, void * pixels), (texture, level, format, type, bufSize, pixels))
GEN_THUNKS(glGetTextureImageEXT, (GLuint texture, GLenum target, GLint level, GLenum format, GLenum type, void * pixels), (texture, target, level, format, type, pixels))
GEN_THUNKS(glGetTextureLevelParameterfv, (GLuint texture, GLint level, GLenum pname, GLfloat * params), (texture, level, pname, params))
GEN_THUNKS(glGetTextureLevelParameterfvEXT, (GLuint texture, GLenum target, GLint level, GLenum pname, GLfloat * params), (texture, target, level, pname, params))
GEN_THUNKS(glGetTextureLevelParameteriv, (GLuint texture, GLint level, GLenum pname, GLint * params), (texture, level, pname, params))
GEN_THUNKS(glGetTextureLevelParameterivEXT, (GLuint texture, GLenum target, GLint level, GLenum pname, GLint * params), (texture, target, level, pname, params))
GEN_THUNKS(glGetTextureParameterIiv, (GLuint texture, GLenum pname, GLint * params), (texture, pname, params))
GEN_THUNKS(glGetTextureParameterIivEXT, (GLuint texture, GLenum target, GLenum pname, GLint * params), (texture, target, pname, params))
GEN_THUNKS(glGetTextureParameterIuiv, (GLuint texture, GLenum pname, GLuint * params), (texture, pname, params))
GEN_THUNKS(glGetTextureParameterIuivEXT, (GLuint texture, GLenum target, GLenum pname, GLuint * params), (texture, target, pname, params))
GEN_THUNKS(glGetTextureParameterfv, (GLuint texture, GLenum pname, GLfloat * params), (texture, pname, params))
GEN_THUNKS(glGetTextureParameterfvEXT, (GLuint texture, GLenum target, GLenum pname, GLfloat * params), (texture, target, pname, params))
GEN_THUNKS(glGetTextureParameteriv, (GLuint texture, GLenum pname, GLint * params), (texture, pname, params))
GEN_THUNKS(glGetTextureParameterivEXT, (GLuint texture, GLenum target, GLenum pname, GLint * params), (texture, target, pname, params))
GEN_THUNKS_RET(GLuint64, glGetTextureSamplerHandleARB, (GLuint texture, GLuint sampler), (texture, sampler))
GEN_THUNKS_RET(GLuint64, glGetTextureSamplerHandleIMG, (GLuint texture, GLuint sampler), (texture, sampler))
GEN_THUNKS_RET(GLuint64, glGetTextureSamplerHandleNV, (GLuint texture, GLuint sampler), (texture, sampler))
GEN_THUNKS(glGetTextureSubImage, (GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, GLsizei bufSize, void * pixels), (texture, level, xoffset, yoffset, zoffset, width, height, depth, format, type, bufSize, pixels))
GEN_THUNKS(glGetTrackMatrixivNV, (GLenum target, GLuint address, GLenum pname, GLint * params), (target, address, pname, params))
GEN_THUNKS(glGetTransformFeedbackVarying, (GLuint program, GLuint index, GLsizei bufSize, GLsizei * length, GLsizei * size, GLenum * type, GLchar * name), (program, index, bufSize, length, size, type, name))
GEN_THUNKS(glGetTransformFeedbackVaryingEXT, (GLuint program, GLuint index, GLsizei bufSize, GLsizei * length, GLsizei * size, GLenum * type, GLchar * name), (program, index, bufSize, length, size, type, name))
GEN_THUNKS(glGetTransformFeedbackVaryingNV, (GLuint program, GLuint index, GLint * location), (program, index, location))
GEN_THUNKS(glGetTransformFeedbacki64_v, (GLuint xfb, GLenum pname, GLuint index, GLint64 * param), (xfb, pname, index, param))
GEN_THUNKS(glGetTransformFeedbacki_v, (GLuint xfb, GLenum pname, GLuint index, GLint * param), (xfb, pname, index, param))
GEN_THUNKS(glGetTransformFeedbackiv, (GLuint xfb, GLenum pname, GLint * param), (xfb, pname, param))
GEN_THUNKS(glGetTranslatedShaderSourceANGLE, (GLuint shader, GLsizei bufsize, GLsizei * length, GLchar * source), (shader, bufsize, length, source))
GEN_THUNKS_RET(GLuint, glGetUniformBlockIndex, (GLuint program, const GLchar * uniformBlockName), (program, uniformBlockName))
GEN_THUNKS_RET(GLint, glGetUniformBufferSizeEXT, (GLuint program, GLint location), (program, location))
GEN_THUNKS(glGetUniformIndices, (GLuint program, GLsizei uniformCount, const GLchar *const* uniformNames, GLuint * uniformIndices), (program, uniformCount, uniformNames, uniformIndices))
GEN_THUNKS_RET(GLint, glGetUniformLocation, (GLuint program, const GLchar * name), (program, name))
GEN_THUNKS_RET(GLint, glGetUniformLocationARB, (GLhandleARB programObj, const GLcharARB * name), ((uintptr_t)programObj, name))
GEN_THUNKS_RET(GLintptr, glGetUniformOffsetEXT, (GLuint program, GLint location), (program, location))
GEN_THUNKS(glGetUniformSubroutineuiv, (GLenum shadertype, GLint location, GLuint * params), (shadertype, location, params))
GEN_THUNKS(glGetUniformdv, (GLuint program, GLint location, GLdouble * params), (program, location, params))
GEN_THUNKS(glGetUniformfv, (GLuint program, GLint location, GLfloat * params), (program, location, params))
GEN_THUNKS(glGetUniformfvARB, (GLhandleARB programObj, GLint location, GLfloat * params), ((uintptr_t)programObj, location, params))
GEN_THUNKS(glGetUniformi64vARB, (GLuint program, GLint location, GLint64 * params), (program, location, params))
GEN_THUNKS(glGetUniformi64vNV, (GLuint program, GLint location, GLint64EXT * params), (program, location, params))
GEN_THUNKS(glGetUniformiv, (GLuint program, GLint location, GLint * params), (program, location, params))
GEN_THUNKS(glGetUniformivARB, (GLhandleARB programObj, GLint location, GLint * params), ((uintptr_t)programObj, location, params))
GEN_THUNKS(glGetUniformui64vARB, (GLuint program, GLint location, GLuint64 * params), (program, location, params))
GEN_THUNKS(glGetUniformui64vNV, (GLuint program, GLint location, GLuint64EXT * params), (program, location, params))
GEN_THUNKS(glGetUniformuiv, (GLuint program, GLint location, GLuint * params), (program, location, params))
GEN_THUNKS(glGetUniformuivEXT, (GLuint program, GLint location, GLuint * params), (program, location, params))
GEN_THUNKS(glGetUnsignedBytei_vEXT, (GLenum target, GLuint index, GLubyte * data), (target, index, data))
GEN_THUNKS(glGetUnsignedBytevEXT, (GLenum pname, GLubyte * data), (pname, data))
GEN_THUNKS(glGetVariantArrayObjectfvATI, (GLuint id, GLenum pname, GLfloat * params), (id, pname, params))
GEN_THUNKS(glGetVariantArrayObjectivATI, (GLuint id, GLenum pname, GLint * params), (id, pname, params))
GEN_THUNKS(glGetVariantBooleanvEXT, (GLuint id, GLenum value, GLboolean * data), (id, value, data))
GEN_THUNKS(glGetVariantFloatvEXT, (GLuint id, GLenum value, GLfloat * data), (id, value, data))
GEN_THUNKS(glGetVariantIntegervEXT, (GLuint id, GLenum value, GLint * data), (id, value, data))
GEN_THUNKS(glGetVariantPointervEXT, (GLuint id, GLenum value, void ** data), (id, value, data))
GEN_THUNKS_RET(GLint, glGetVaryingLocationNV, (GLuint program, const GLchar * name), (program, name))
GEN_THUNKS(glGetVertexArrayIndexed64iv, (GLuint vaobj, GLuint index, GLenum pname, GLint64 * param), (vaobj, index, pname, param))
GEN_THUNKS(glGetVertexArrayIndexediv, (GLuint vaobj, GLuint index, GLenum pname, GLint * param), (vaobj, index, pname, param))
GEN_THUNKS(glGetVertexArrayIntegeri_vEXT, (GLuint vaobj, GLuint index, GLenum pname, GLint * param), (vaobj, index, pname, param))
GEN_THUNKS(glGetVertexArrayIntegervEXT, (GLuint vaobj, GLenum pname, GLint * param), (vaobj, pname, param))
GEN_THUNKS(glGetVertexArrayPointeri_vEXT, (GLuint vaobj, GLuint index, GLenum pname, void ** param), (vaobj, index, pname, param))
GEN_THUNKS(glGetVertexArrayPointervEXT, (GLuint vaobj, GLenum pname, void ** param), (vaobj, pname, param))
GEN_THUNKS(glGetVertexArrayiv, (GLuint vaobj, GLenum pname, GLint * param), (vaobj, pname, param))
GEN_THUNKS(glGetVertexAttribArrayObjectfvATI, (GLuint index, GLenum pname, GLfloat * params), (index, pname, params))
GEN_THUNKS(glGetVertexAttribArrayObjectivATI, (GLuint index, GLenum pname, GLint * params), (index, pname, params))
GEN_THUNKS(glGetVertexAttribIiv, (GLuint index, GLenum pname, GLint * params), (index, pname, params))
GEN_THUNKS(glGetVertexAttribIivEXT, (GLuint index, GLenum pname, GLint * params), (index, pname, params))
GEN_THUNKS(glGetVertexAttribIuiv, (GLuint index, GLenum pname, GLuint * params), (index, pname, params))
GEN_THUNKS(glGetVertexAttribIuivEXT, (GLuint index, GLenum pname, GLuint * params), (index, pname, params))
GEN_THUNKS(glGetVertexAttribLdv, (GLuint index, GLenum pname, GLdouble * params), (index, pname, params))
GEN_THUNKS(glGetVertexAttribLdvEXT, (GLuint index, GLenum pname, GLdouble * params), (index, pname, params))
GEN_THUNKS(glGetVertexAttribLi64vNV, (GLuint index, GLenum pname, GLint64EXT * params), (index, pname, params))
GEN_THUNKS(glGetVertexAttribLui64vARB, (GLuint index, GLenum pname, GLuint64EXT * params), (index, pname, params))
GEN_THUNKS(glGetVertexAttribLui64vNV, (GLuint index, GLenum pname, GLuint64EXT * params), (index, pname, params))
GEN_THUNKS(glGetVertexAttribPointerv, (GLuint index, GLenum pname, void ** pointer), (index, pname, pointer))
GEN_THUNKS(glGetVertexAttribPointervARB, (GLuint index, GLenum pname, void ** pointer), (index, pname, pointer))
GEN_THUNKS(glGetVertexAttribPointervNV, (GLuint index, GLenum pname, void ** pointer), (index, pname, pointer))
GEN_THUNKS(glGetVertexAttribdv, (GLuint index, GLenum pname, GLdouble * params), (index, pname, params))
GEN_THUNKS(glGetVertexAttribdvARB, (GLuint index, GLenum pname, GLdouble * params), (index, pname, params))
GEN_THUNKS(glGetVertexAttribdvNV, (GLuint index, GLenum pname, GLdouble * params), (index, pname, params))
GEN_THUNKS(glGetVertexAttribfv, (GLuint index, GLenum pname, GLfloat * params), (index, pname, params))
GEN_THUNKS(glGetVertexAttribfvARB, (GLuint index, GLenum pname, GLfloat * params), (index, pname, params))
GEN_THUNKS(glGetVertexAttribfvNV, (GLuint index, GLenum pname, GLfloat * params), (index, pname, params))
GEN_THUNKS(glGetVertexAttribiv, (GLuint index, GLenum pname, GLint * params), (index, pname, params))
GEN_THUNKS(glGetVertexAttribivARB, (GLuint index, GLenum pname, GLint * params), (index, pname, params))
GEN_THUNKS(glGetVertexAttribivNV, (GLuint index, GLenum pname, GLint * params), (index, pname, params))
GEN_THUNKS(glGetVideoCaptureStreamdvNV, (GLuint video_capture_slot, GLuint stream, GLenum pname, GLdouble * params), (video_capture_slot, stream, pname, params))
GEN_THUNKS(glGetVideoCaptureStreamfvNV, (GLuint video_capture_slot, GLuint stream, GLenum pname, GLfloat * params), (video_capture_slot, stream, pname, params))
GEN_THUNKS(glGetVideoCaptureStreamivNV, (GLuint video_capture_slot, GLuint stream, GLenum pname, GLint * params), (video_capture_slot, stream, pname, params))
GEN_THUNKS(glGetVideoCaptureivNV, (GLuint video_capture_slot, GLenum pname, GLint * params), (video_capture_slot, pname, params))
GEN_THUNKS(glGetVideoi64vNV, (GLuint video_slot, GLenum pname, GLint64EXT * params), (video_slot, pname, params))
GEN_THUNKS(glGetVideoivNV, (GLuint video_slot, GLenum pname, GLint * params), (video_slot, pname, params))
GEN_THUNKS(glGetVideoui64vNV, (GLuint video_slot, GLenum pname, GLuint64EXT * params), (video_slot, pname, params))
GEN_THUNKS(glGetVideouivNV, (GLuint video_slot, GLenum pname, GLuint * params), (video_slot, pname, params))
GEN_THUNKS_RET(GLVULKANPROCNV, glGetVkProcAddrNV, (const GLchar * name), (name))
GEN_THUNKS(glGetnColorTable, (GLenum target, GLenum format, GLenum type, GLsizei bufSize, void * table), (target, format, type, bufSize, table))
GEN_THUNKS(glGetnColorTableARB, (GLenum target, GLenum format, GLenum type, GLsizei bufSize, void * table), (target, format, type, bufSize, table))
GEN_THUNKS(glGetnCompressedTexImage, (GLenum target, GLint lod, GLsizei bufSize, void * pixels), (target, lod, bufSize, pixels))
GEN_THUNKS(glGetnCompressedTexImageARB, (GLenum target, GLint lod, GLsizei bufSize, void * img), (target, lod, bufSize, img))
GEN_THUNKS(glGetnConvolutionFilter, (GLenum target, GLenum format, GLenum type, GLsizei bufSize, void * image), (target, format, type, bufSize, image))
GEN_THUNKS(glGetnConvolutionFilterARB, (GLenum target, GLenum format, GLenum type, GLsizei bufSize, void * image), (target, format, type, bufSize, image))
GEN_THUNKS(glGetnHistogram, (GLenum target, GLboolean reset, GLenum format, GLenum type, GLsizei bufSize, void * values), (target, reset, format, type, bufSize, values))
GEN_THUNKS(glGetnHistogramARB, (GLenum target, GLboolean reset, GLenum format, GLenum type, GLsizei bufSize, void * values), (target, reset, format, type, bufSize, values))
GEN_THUNKS(glGetnMapdv, (GLenum target, GLenum query, GLsizei bufSize, GLdouble * v), (target, query, bufSize, v))
GEN_THUNKS(glGetnMapdvARB, (GLenum target, GLenum query, GLsizei bufSize, GLdouble * v), (target, query, bufSize, v))
GEN_THUNKS(glGetnMapfv, (GLenum target, GLenum query, GLsizei bufSize, GLfloat * v), (target, query, bufSize, v))
GEN_THUNKS(glGetnMapfvARB, (GLenum target, GLenum query, GLsizei bufSize, GLfloat * v), (target, query, bufSize, v))
GEN_THUNKS(glGetnMapiv, (GLenum target, GLenum query, GLsizei bufSize, GLint * v), (target, query, bufSize, v))
GEN_THUNKS(glGetnMapivARB, (GLenum target, GLenum query, GLsizei bufSize, GLint * v), (target, query, bufSize, v))
GEN_THUNKS(glGetnMinmax, (GLenum target, GLboolean reset, GLenum format, GLenum type, GLsizei bufSize, void * values), (target, reset, format, type, bufSize, values))
GEN_THUNKS(glGetnMinmaxARB, (GLenum target, GLboolean reset, GLenum format, GLenum type, GLsizei bufSize, void * values), (target, reset, format, type, bufSize, values))
GEN_THUNKS(glGetnPixelMapfv, (GLenum map, GLsizei bufSize, GLfloat * values), (map, bufSize, values))
GEN_THUNKS(glGetnPixelMapfvARB, (GLenum map, GLsizei bufSize, GLfloat * values), (map, bufSize, values))
GEN_THUNKS(glGetnPixelMapuiv, (GLenum map, GLsizei bufSize, GLuint * values), (map, bufSize, values))
GEN_THUNKS(glGetnPixelMapuivARB, (GLenum map, GLsizei bufSize, GLuint * values), (map, bufSize, values))
GEN_THUNKS(glGetnPixelMapusv, (GLenum map, GLsizei bufSize, GLushort * values), (map, bufSize, values))
GEN_THUNKS(glGetnPixelMapusvARB, (GLenum map, GLsizei bufSize, GLushort * values), (map, bufSize, values))
GEN_THUNKS(glGetnPolygonStipple, (GLsizei bufSize, GLubyte * pattern), (bufSize, pattern))
GEN_THUNKS(glGetnPolygonStippleARB, (GLsizei bufSize, GLubyte * pattern), (bufSize, pattern))
GEN_THUNKS(glGetnSeparableFilter, (GLenum target, GLenum format, GLenum type, GLsizei rowBufSize, void * row, GLsizei columnBufSize, void * column, void * span), (target, format, type, rowBufSize, row, columnBufSize, column, span))
GEN_THUNKS(glGetnSeparableFilterARB, (GLenum target, GLenum format, GLenum type, GLsizei rowBufSize, void * row, GLsizei columnBufSize, void * column, void * span), (target, format, type, rowBufSize, row, columnBufSize, column, span))
GEN_THUNKS(glGetnTexImage, (GLenum target, GLint level, GLenum format, GLenum type, GLsizei bufSize, void * pixels), (target, level, format, type, bufSize, pixels))
GEN_THUNKS(glGetnTexImageARB, (GLenum target, GLint level, GLenum format, GLenum type, GLsizei bufSize, void * img), (target, level, format, type, bufSize, img))
GEN_THUNKS(glGetnUniformdv, (GLuint program, GLint location, GLsizei bufSize, GLdouble * params), (program, location, bufSize, params))
GEN_THUNKS(glGetnUniformdvARB, (GLuint program, GLint location, GLsizei bufSize, GLdouble * params), (program, location, bufSize, params))
GEN_THUNKS(glGetnUniformfv, (GLuint program, GLint location, GLsizei bufSize, GLfloat * params), (program, location, bufSize, params))
GEN_THUNKS(glGetnUniformfvARB, (GLuint program, GLint location, GLsizei bufSize, GLfloat * params), (program, location, bufSize, params))
GEN_THUNKS(glGetnUniformfvEXT, (GLuint program, GLint location, GLsizei bufSize, GLfloat * params), (program, location, bufSize, params))
GEN_THUNKS(glGetnUniformfvKHR, (GLuint program, GLint location, GLsizei bufSize, GLfloat * params), (program, location, bufSize, params))
GEN_THUNKS(glGetnUniformi64vARB, (GLuint program, GLint location, GLsizei bufSize, GLint64 * params), (program, location, bufSize, params))
GEN_THUNKS(glGetnUniformiv, (GLuint program, GLint location, GLsizei bufSize, GLint * params), (program, location, bufSize, params))
GEN_THUNKS(glGetnUniformivARB, (GLuint program, GLint location, GLsizei bufSize, GLint * params), (program, location, bufSize, params))
GEN_THUNKS(glGetnUniformivEXT, (GLuint program, GLint location, GLsizei bufSize, GLint * params), (program, location, bufSize, params))
GEN_THUNKS(glGetnUniformivKHR, (GLuint program, GLint location, GLsizei bufSize, GLint * params), (program, location, bufSize, params))
GEN_THUNKS(glGetnUniformui64vARB, (GLuint program, GLint location, GLsizei bufSize, GLuint64 * params), (program, location, bufSize, params))
GEN_THUNKS(glGetnUniformuiv, (GLuint program, GLint location, GLsizei bufSize, GLuint * params), (program, location, bufSize, params))
GEN_THUNKS(glGetnUniformuivARB, (GLuint program, GLint location, GLsizei bufSize, GLuint * params), (program, location, bufSize, params))
GEN_THUNKS(glGetnUniformuivKHR, (GLuint program, GLint location, GLsizei bufSize, GLuint * params), (program, location, bufSize, params))
GEN_THUNKS(glGlobalAlphaFactorbSUN, (GLbyte factor), (factor))
GEN_THUNKS(glGlobalAlphaFactordSUN, (GLdouble factor), (factor))
GEN_THUNKS(glGlobalAlphaFactorfSUN, (GLfloat factor), (factor))
GEN_THUNKS(glGlobalAlphaFactoriSUN, (GLint factor), (factor))
GEN_THUNKS(glGlobalAlphaFactorsSUN, (GLshort factor), (factor))
GEN_THUNKS(glGlobalAlphaFactorubSUN, (GLubyte factor), (factor))
GEN_THUNKS(glGlobalAlphaFactoruiSUN, (GLuint factor), (factor))
GEN_THUNKS(glGlobalAlphaFactorusSUN, (GLushort factor), (factor))
GEN_THUNKS(glHint, (GLenum target, GLenum mode), (target, mode))
GEN_THUNKS(glHintPGI, (GLenum target, GLint mode), (target, mode))
GEN_THUNKS(glHistogram, (GLenum target, GLsizei width, GLenum internalformat, GLboolean sink), (target, width, internalformat, sink))
GEN_THUNKS(glHistogramEXT, (GLenum target, GLsizei width, GLenum internalformat, GLboolean sink), (target, width, internalformat, sink))
GEN_THUNKS(glIglooInterfaceSGIX, (GLenum pname, const void * params), (pname, params))
GEN_THUNKS(glImageTransformParameterfHP, (GLenum target, GLenum pname, GLfloat param), (target, pname, param))
GEN_THUNKS(glImageTransformParameterfvHP, (GLenum target, GLenum pname, const GLfloat * params), (target, pname, params))
GEN_THUNKS(glImageTransformParameteriHP, (GLenum target, GLenum pname, GLint param), (target, pname, param))
GEN_THUNKS(glImageTransformParameterivHP, (GLenum target, GLenum pname, const GLint * params), (target, pname, params))
GEN_THUNKS(glImportMemoryFdEXT, (GLuint memory, GLuint64 size, GLenum handleType, GLint fd), (memory, size, handleType, fd))
GEN_THUNKS(glImportMemoryWin32HandleEXT, (GLuint memory, GLuint64 size, GLenum handleType, void * handle), (memory, size, handleType, handle))
GEN_THUNKS(glImportMemoryWin32NameEXT, (GLuint memory, GLuint64 size, GLenum handleType, const void * name), (memory, size, handleType, name))
GEN_THUNKS(glImportSemaphoreFdEXT, (GLuint semaphore, GLenum handleType, GLint fd), (semaphore, handleType, fd))
GEN_THUNKS(glImportSemaphoreWin32HandleEXT, (GLuint semaphore, GLenum handleType, void * handle), (semaphore, handleType, handle))
GEN_THUNKS(glImportSemaphoreWin32NameEXT, (GLuint semaphore, GLenum handleType, const void * name), (semaphore, handleType, name))
GEN_THUNKS_RET(GLsync, glImportSyncEXT, (GLenum external_sync_type, GLintptr external_sync, GLbitfield flags), (external_sync_type, external_sync, flags))
GEN_THUNKS(glIndexFormatNV, (GLenum type, GLsizei stride), (type, stride))
GEN_THUNKS(glIndexFuncEXT, (GLenum func, GLclampf ref), (func, ref))
GEN_THUNKS(glIndexMask, (GLuint mask), (mask))
GEN_THUNKS(glIndexMaterialEXT, (GLenum face, GLenum mode), (face, mode))
GEN_THUNKS(glIndexPointer, (GLenum type, GLsizei stride, const void * pointer), (type, stride, pointer))
GEN_THUNKS(glIndexPointerEXT, (GLenum type, GLsizei stride, GLsizei count, const void * pointer), (type, stride, count, pointer))
GEN_THUNKS(glIndexPointerListIBM, (GLenum type, GLint stride, const void ** pointer, GLint ptrstride), (type, stride, pointer, ptrstride))
GEN_THUNKS(glIndexd, (GLdouble c), (c))
GEN_THUNKS(glIndexdv, (const GLdouble * c), (c))
GEN_THUNKS(glIndexf, (GLfloat c), (c))
GEN_THUNKS(glIndexfv, (const GLfloat * c), (c))
GEN_THUNKS(glIndexi, (GLint c), (c))
GEN_THUNKS(glIndexiv, (const GLint * c), (c))
GEN_THUNKS(glIndexs, (GLshort c), (c))
GEN_THUNKS(glIndexsv, (const GLshort * c), (c))
GEN_THUNKS(glIndexub, (GLubyte c), (c))
GEN_THUNKS(glIndexubv, (const GLubyte * c), (c))
GEN_THUNKS(glIndexxOES, (GLfixed component), (component))
GEN_THUNKS(glIndexxvOES, (const GLfixed * component), (component))
GEN_THUNKS(glInitNames, (void), ())
GEN_THUNKS(glInsertComponentEXT, (GLuint res, GLuint src, GLuint num), (res, src, num))
GEN_THUNKS(glInsertEventMarkerEXT, (GLsizei length, const GLchar * marker), (length, marker))
GEN_THUNKS(glInstrumentsBufferSGIX, (GLsizei size, GLint * buffer), (size, buffer))
GEN_THUNKS(glInterleavedArrays, (GLenum format, GLsizei stride, const void * pointer), (format, stride, pointer))
GEN_THUNKS(glInterpolatePathsNV, (GLuint resultPath, GLuint pathA, GLuint pathB, GLfloat weight), (resultPath, pathA, pathB, weight))
GEN_THUNKS(glInvalidateBufferData, (GLuint buffer), (buffer))
GEN_THUNKS(glInvalidateBufferSubData, (GLuint buffer, GLintptr offset, GLsizeiptr length), (buffer, offset, length))
GEN_THUNKS(glInvalidateFramebuffer, (GLenum target, GLsizei numAttachments, const GLenum * attachments), (target, numAttachments, attachments))
GEN_THUNKS(glInvalidateNamedFramebufferData, (GLuint framebuffer, GLsizei numAttachments, const GLenum * attachments), (framebuffer, numAttachments, attachments))
GEN_THUNKS(glInvalidateNamedFramebufferSubData, (GLuint framebuffer, GLsizei numAttachments, const GLenum * attachments, GLint x, GLint y, GLsizei width, GLsizei height), (framebuffer, numAttachments, attachments, x, y, width, height))
GEN_THUNKS(glInvalidateSubFramebuffer, (GLenum target, GLsizei numAttachments, const GLenum * attachments, GLint x, GLint y, GLsizei width, GLsizei height), (target, numAttachments, attachments, x, y, width, height))
GEN_THUNKS(glInvalidateTexImage, (GLuint texture, GLint level), (texture, level))
GEN_THUNKS(glInvalidateTexSubImage, (GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth), (texture, level, xoffset, yoffset, zoffset, width, height, depth))
GEN_THUNKS_RET(GLboolean, glIsAsyncMarkerSGIX, (GLuint marker), (marker))
GEN_THUNKS_RET(GLboolean, glIsBuffer, (GLuint buffer), (buffer))
GEN_THUNKS_RET(GLboolean, glIsBufferARB, (GLuint buffer), (buffer))
GEN_THUNKS_RET(GLboolean, glIsBufferResidentNV, (GLenum target), (target))
GEN_THUNKS_RET(GLboolean, glIsCommandListNV, (GLuint list), (list))
GEN_THUNKS_RET(GLboolean, glIsEnabled, (GLenum cap), (cap))
GEN_THUNKS_RET(GLboolean, glIsEnabledIndexedEXT, (GLenum target, GLuint index), (target, index))
GEN_THUNKS_RET(GLboolean, glIsEnabledi, (GLenum target, GLuint index), (target, index))
GEN_THUNKS_RET(GLboolean, glIsEnablediEXT, (GLenum target, GLuint index), (target, index))
GEN_THUNKS_RET(GLboolean, glIsEnablediNV, (GLenum target, GLuint index), (target, index))
GEN_THUNKS_RET(GLboolean, glIsEnablediOES, (GLenum target, GLuint index), (target, index))
GEN_THUNKS_RET(GLboolean, glIsFenceAPPLE, (GLuint fence), (fence))
GEN_THUNKS_RET(GLboolean, glIsFenceNV, (GLuint fence), (fence))
GEN_THUNKS_RET(GLboolean, glIsFramebuffer, (GLuint framebuffer), (framebuffer))
GEN_THUNKS_RET(GLboolean, glIsFramebufferEXT, (GLuint framebuffer), (framebuffer))
GEN_THUNKS_RET(GLboolean, glIsFramebufferOES, (GLuint framebuffer), (framebuffer))
GEN_THUNKS_RET(GLboolean, glIsImageHandleResidentARB, (GLuint64 handle), (handle))
GEN_THUNKS_RET(GLboolean, glIsImageHandleResidentNV, (GLuint64 handle), (handle))
GEN_THUNKS_RET(GLboolean, glIsList, (GLuint list), (list))
GEN_THUNKS_RET(GLboolean, glIsMemoryObjectEXT, (GLuint memoryObject), (memoryObject))
GEN_THUNKS_RET(GLboolean, glIsNameAMD, (GLenum identifier, GLuint name), (identifier, name))
GEN_THUNKS_RET(GLboolean, glIsNamedBufferResidentNV, (GLuint buffer), (buffer))
GEN_THUNKS_RET(GLboolean, glIsNamedStringARB, (GLint namelen, const GLchar * name), (namelen, name))
GEN_THUNKS_RET(GLboolean, glIsObjectBufferATI, (GLuint buffer), (buffer))
GEN_THUNKS_RET(GLboolean, glIsOcclusionQueryNV, (GLuint id), (id))
GEN_THUNKS_RET(GLboolean, glIsPathNV, (GLuint path), (path))
GEN_THUNKS_RET(GLboolean, glIsPointInFillPathNV, (GLuint path, GLuint mask, GLfloat x, GLfloat y), (path, mask, x, y))
GEN_THUNKS_RET(GLboolean, glIsPointInStrokePathNV, (GLuint path, GLfloat x, GLfloat y), (path, x, y))
GEN_THUNKS_RET(GLboolean, glIsProgram, (GLuint program), (program))
GEN_THUNKS_RET(GLboolean, glIsProgramARB, (GLuint program), (program))
GEN_THUNKS_RET(GLboolean, glIsProgramNV, (GLuint id), (id))
GEN_THUNKS_RET(GLboolean, glIsProgramPipeline, (GLuint pipeline), (pipeline))
GEN_THUNKS_RET(GLboolean, glIsProgramPipelineEXT, (GLuint pipeline), (pipeline))
GEN_THUNKS_RET(GLboolean, glIsQuery, (GLuint id), (id))
GEN_THUNKS_RET(GLboolean, glIsQueryARB, (GLuint id), (id))
GEN_THUNKS_RET(GLboolean, glIsQueryEXT, (GLuint id), (id))
GEN_THUNKS_RET(GLboolean, glIsRenderbuffer, (GLuint renderbuffer), (renderbuffer))
GEN_THUNKS_RET(GLboolean, glIsRenderbufferEXT, (GLuint renderbuffer), (renderbuffer))
GEN_THUNKS_RET(GLboolean, glIsRenderbufferOES, (GLuint renderbuffer), (renderbuffer))
GEN_THUNKS_RET(GLboolean, glIsSampler, (GLuint sampler), (sampler))
GEN_THUNKS_RET(GLboolean, glIsSemaphoreEXT, (GLuint semaphore), (semaphore))
GEN_THUNKS_RET(GLboolean, glIsShader, (GLuint shader), (shader))
GEN_THUNKS_RET(GLboolean, glIsStateNV, (GLuint state), (state))
GEN_THUNKS_RET(GLboolean, glIsSync, (GLsync sync), (sync))
GEN_THUNKS_RET(GLboolean, glIsSyncAPPLE, (GLsync sync), (sync))
GEN_THUNKS_RET(GLboolean, glIsTexture, (GLuint texture), (texture))
GEN_THUNKS_RET(GLboolean, glIsTextureEXT, (GLuint texture), (texture))
GEN_THUNKS_RET(GLboolean, glIsTextureHandleResidentARB, (GLuint64 handle), (handle))
GEN_THUNKS_RET(GLboolean, glIsTextureHandleResidentNV, (GLuint64 handle), (handle))
GEN_THUNKS_RET(GLboolean, glIsTransformFeedback, (GLuint id), (id))
GEN_THUNKS_RET(GLboolean, glIsTransformFeedbackNV, (GLuint id), (id))
GEN_THUNKS_RET(GLboolean, glIsVariantEnabledEXT, (GLuint id, GLenum cap), (id, cap))
GEN_THUNKS_RET(GLboolean, glIsVertexArray, (GLuint array), (array))
GEN_THUNKS_RET(GLboolean, glIsVertexArrayAPPLE, (GLuint array), (array))
GEN_THUNKS_RET(GLboolean, glIsVertexArrayOES, (GLuint array), (array))
GEN_THUNKS_RET(GLboolean, glIsVertexAttribEnabledAPPLE, (GLuint index, GLenum pname), (index, pname))
GEN_THUNKS(glLGPUCopyImageSubDataNVX, (GLuint sourceGpu, GLbitfield destinationGpuMask, GLuint srcName, GLenum srcTarget, GLint srcLevel, GLint srcX, GLint srxY, GLint srcZ, GLuint dstName, GLenum dstTarget, GLint dstLevel, GLint dstX, GLint dstY, GLint dstZ, GLsizei width, GLsizei height, GLsizei depth), (sourceGpu, destinationGpuMask, srcName, srcTarget, srcLevel, srcX, srxY, srcZ, dstName, dstTarget, dstLevel, dstX, dstY, dstZ, width, height, depth))
GEN_THUNKS(glLGPUInterlockNVX, (void), ())
GEN_THUNKS(glLGPUNamedBufferSubDataNVX, (GLbitfield gpuMask, GLuint buffer, GLintptr offset, GLsizeiptr size, const void * data), (gpuMask, buffer, offset, size, data))
GEN_THUNKS(glLabelObjectEXT, (GLenum type, GLuint object, GLsizei length, const GLchar * label), (type, object, length, label))
GEN_THUNKS(glLightEnviSGIX, (GLenum pname, GLint param), (pname, param))
GEN_THUNKS(glLightModelf, (GLenum pname, GLfloat param), (pname, param))
GEN_THUNKS(glLightModelfv, (GLenum pname, const GLfloat * params), (pname, params))
GEN_THUNKS(glLightModeli, (GLenum pname, GLint param), (pname, param))
GEN_THUNKS(glLightModeliv, (GLenum pname, const GLint * params), (pname, params))
GEN_THUNKS(glLightModelx, (GLenum pname, GLfixed param), (pname, param))
GEN_THUNKS(glLightModelxOES, (GLenum pname, GLfixed param), (pname, param))
GEN_THUNKS(glLightModelxv, (GLenum pname, const GLfixed * param), (pname, param))
GEN_THUNKS(glLightModelxvOES, (GLenum pname, const GLfixed * param), (pname, param))
GEN_THUNKS(glLightf, (GLenum light, GLenum pname, GLfloat param), (light, pname, param))
GEN_THUNKS(glLightfv, (GLenum light, GLenum pname, const GLfloat * params), (light, pname, params))
GEN_THUNKS(glLighti, (GLenum light, GLenum pname, GLint param), (light, pname, param))
GEN_THUNKS(glLightiv, (GLenum light, GLenum pname, const GLint * params), (light, pname, params))
GEN_THUNKS(glLightx, (GLenum light, GLenum pname, GLfixed param), (light, pname, param))
GEN_THUNKS(glLightxOES, (GLenum light, GLenum pname, GLfixed param), (light, pname, param))
GEN_THUNKS(glLightxv, (GLenum light, GLenum pname, const GLfixed * params), (light, pname, params))
GEN_THUNKS(glLightxvOES, (GLenum light, GLenum pname, const GLfixed * params), (light, pname, params))
GEN_THUNKS(glLineStipple, (GLint factor, GLushort pattern), (factor, pattern))
GEN_THUNKS(glLineWidth, (GLfloat width), (width))
GEN_THUNKS(glLineWidthx, (GLfixed width), (width))
GEN_THUNKS(glLineWidthxOES, (GLfixed width), (width))
GEN_THUNKS(glLinkProgram, (GLuint program), (program))
GEN_THUNKS(glLinkProgramARB, (GLhandleARB programObj), ((uintptr_t)programObj))
GEN_THUNKS(glListBase, (GLuint base), (base))
GEN_THUNKS(glListDrawCommandsStatesClientNV, (GLuint list, GLuint segment, const void ** indirects, const GLsizei * sizes, const GLuint * states, const GLuint * fbos, GLuint count), (list, segment, indirects, sizes, states, fbos, count))
GEN_THUNKS(glListParameterfSGIX, (GLuint list, GLenum pname, GLfloat param), (list, pname, param))
GEN_THUNKS(glListParameterfvSGIX, (GLuint list, GLenum pname, const GLfloat * params), (list, pname, params))
GEN_THUNKS(glListParameteriSGIX, (GLuint list, GLenum pname, GLint param), (list, pname, param))
GEN_THUNKS(glListParameterivSGIX, (GLuint list, GLenum pname, const GLint * params), (list, pname, params))
GEN_THUNKS(glLoadIdentity, (void), ())
GEN_THUNKS(glLoadIdentityDeformationMapSGIX, (GLbitfield mask), (mask))
GEN_THUNKS(glLoadMatrixd, (const GLdouble * m), (m))
GEN_THUNKS(glLoadMatrixf, (const GLfloat * m), (m))
GEN_THUNKS(glLoadMatrixx, (const GLfixed * m), (m))
GEN_THUNKS(glLoadMatrixxOES, (const GLfixed * m), (m))
GEN_THUNKS(glLoadName, (GLuint name), (name))
GEN_THUNKS(glLoadPaletteFromModelViewMatrixOES, (void), ())
GEN_THUNKS(glLoadProgramNV, (GLenum target, GLuint id, GLsizei len, const GLubyte * program), (target, id, len, program))
GEN_THUNKS(glLoadTransposeMatrixd, (const GLdouble * m), (m))
GEN_THUNKS(glLoadTransposeMatrixdARB, (const GLdouble * m), (m))
GEN_THUNKS(glLoadTransposeMatrixf, (const GLfloat * m), (m))
GEN_THUNKS(glLoadTransposeMatrixfARB, (const GLfloat * m), (m))
GEN_THUNKS(glLoadTransposeMatrixxOES, (const GLfixed * m), (m))
GEN_THUNKS(glLockArraysEXT, (GLint first, GLsizei count), (first, count))
GEN_THUNKS(glLogicOp, (GLenum opcode), (opcode))
GEN_THUNKS(glMakeBufferNonResidentNV, (GLenum target), (target))
GEN_THUNKS(glMakeBufferResidentNV, (GLenum target, GLenum access), (target, access))
GEN_THUNKS(glMakeImageHandleNonResidentARB, (GLuint64 handle), (handle))
GEN_THUNKS(glMakeImageHandleNonResidentNV, (GLuint64 handle), (handle))
GEN_THUNKS(glMakeImageHandleResidentARB, (GLuint64 handle, GLenum access), (handle, access))
GEN_THUNKS(glMakeImageHandleResidentNV, (GLuint64 handle, GLenum access), (handle, access))
GEN_THUNKS(glMakeNamedBufferNonResidentNV, (GLuint buffer), (buffer))
GEN_THUNKS(glMakeNamedBufferResidentNV, (GLuint buffer, GLenum access), (buffer, access))
GEN_THUNKS(glMakeTextureHandleNonResidentARB, (GLuint64 handle), (handle))
GEN_THUNKS(glMakeTextureHandleNonResidentNV, (GLuint64 handle), (handle))
GEN_THUNKS(glMakeTextureHandleResidentARB, (GLuint64 handle), (handle))
GEN_THUNKS(glMakeTextureHandleResidentNV, (GLuint64 handle), (handle))
GEN_THUNKS(glMap1d, (GLenum target, GLdouble u1, GLdouble u2, GLint stride, GLint order, const GLdouble * points), (target, u1, u2, stride, order, points))
GEN_THUNKS(glMap1f, (GLenum target, GLfloat u1, GLfloat u2, GLint stride, GLint order, const GLfloat * points), (target, u1, u2, stride, order, points))
GEN_THUNKS(glMap1xOES, (GLenum target, GLfixed u1, GLfixed u2, GLint stride, GLint order, GLfixed points), (target, u1, u2, stride, order, points))
GEN_THUNKS(glMap2d, (GLenum target, GLdouble u1, GLdouble u2, GLint ustride, GLint uorder, GLdouble v1, GLdouble v2, GLint vstride, GLint vorder, const GLdouble * points), (target, u1, u2, ustride, uorder, v1, v2, vstride, vorder, points))
GEN_THUNKS(glMap2f, (GLenum target, GLfloat u1, GLfloat u2, GLint ustride, GLint uorder, GLfloat v1, GLfloat v2, GLint vstride, GLint vorder, const GLfloat * points), (target, u1, u2, ustride, uorder, v1, v2, vstride, vorder, points))
GEN_THUNKS(glMap2xOES, (GLenum target, GLfixed u1, GLfixed u2, GLint ustride, GLint uorder, GLfixed v1, GLfixed v2, GLint vstride, GLint vorder, GLfixed points), (target, u1, u2, ustride, uorder, v1, v2, vstride, vorder, points))
GEN_THUNKS_RET(void *, glMapBuffer, (GLenum target, GLenum access), (target, access))
GEN_THUNKS_RET(void *, glMapBufferARB, (GLenum target, GLenum access), (target, access))
GEN_THUNKS_RET(void *, glMapBufferOES, (GLenum target, GLenum access), (target, access))
GEN_THUNKS_RET(void *, glMapBufferRange, (GLenum target, GLintptr offset, GLsizeiptr length, GLbitfield access), (target, offset, length, access))
GEN_THUNKS_RET(void *, glMapBufferRangeEXT, (GLenum target, GLintptr offset, GLsizeiptr length, GLbitfield access), (target, offset, length, access))
GEN_THUNKS(glMapControlPointsNV, (GLenum target, GLuint index, GLenum type, GLsizei ustride, GLsizei vstride, GLint uorder, GLint vorder, GLboolean packed, const void * points), (target, index, type, ustride, vstride, uorder, vorder, packed, points))
GEN_THUNKS(glMapGrid1d, (GLint un, GLdouble u1, GLdouble u2), (un, u1, u2))
GEN_THUNKS(glMapGrid1f, (GLint un, GLfloat u1, GLfloat u2), (un, u1, u2))
GEN_THUNKS(glMapGrid1xOES, (GLint n, GLfixed u1, GLfixed u2), (n, u1, u2))
GEN_THUNKS(glMapGrid2d, (GLint un, GLdouble u1, GLdouble u2, GLint vn, GLdouble v1, GLdouble v2), (un, u1, u2, vn, v1, v2))
GEN_THUNKS(glMapGrid2f, (GLint un, GLfloat u1, GLfloat u2, GLint vn, GLfloat v1, GLfloat v2), (un, u1, u2, vn, v1, v2))
GEN_THUNKS(glMapGrid2xOES, (GLint n, GLfixed u1, GLfixed u2, GLfixed v1, GLfixed v2), (n, u1, u2, v1, v2))
GEN_THUNKS_RET(void *, glMapNamedBuffer, (GLuint buffer, GLenum access), (buffer, access))
GEN_THUNKS_RET(void *, glMapNamedBufferEXT, (GLuint buffer, GLenum access), (buffer, access))
GEN_THUNKS_RET(void *, glMapNamedBufferRange, (GLuint buffer, GLintptr offset, GLsizeiptr length, GLbitfield access), (buffer, offset, length, access))
GEN_THUNKS_RET(void *, glMapNamedBufferRangeEXT, (GLuint buffer, GLintptr offset, GLsizeiptr length, GLbitfield access), (buffer, offset, length, access))
GEN_THUNKS_RET(void *, glMapObjectBufferATI, (GLuint buffer), (buffer))
GEN_THUNKS(glMapParameterfvNV, (GLenum target, GLenum pname, const GLfloat * params), (target, pname, params))
GEN_THUNKS(glMapParameterivNV, (GLenum target, GLenum pname, const GLint * params), (target, pname, params))
GEN_THUNKS_RET(void *, glMapTexture2DINTEL, (GLuint texture, GLint level, GLbitfield access, GLint * stride, GLenum * layout), (texture, level, access, stride, layout))
GEN_THUNKS(glMapVertexAttrib1dAPPLE, (GLuint index, GLuint size, GLdouble u1, GLdouble u2, GLint stride, GLint order, const GLdouble * points), (index, size, u1, u2, stride, order, points))
GEN_THUNKS(glMapVertexAttrib1fAPPLE, (GLuint index, GLuint size, GLfloat u1, GLfloat u2, GLint stride, GLint order, const GLfloat * points), (index, size, u1, u2, stride, order, points))
GEN_THUNKS(glMapVertexAttrib2dAPPLE, (GLuint index, GLuint size, GLdouble u1, GLdouble u2, GLint ustride, GLint uorder, GLdouble v1, GLdouble v2, GLint vstride, GLint vorder, const GLdouble * points), (index, size, u1, u2, ustride, uorder, v1, v2, vstride, vorder, points))
GEN_THUNKS(glMapVertexAttrib2fAPPLE, (GLuint index, GLuint size, GLfloat u1, GLfloat u2, GLint ustride, GLint uorder, GLfloat v1, GLfloat v2, GLint vstride, GLint vorder, const GLfloat * points), (index, size, u1, u2, ustride, uorder, v1, v2, vstride, vorder, points))
GEN_THUNKS(glMaterialf, (GLenum face, GLenum pname, GLfloat param), (face, pname, param))
GEN_THUNKS(glMaterialfv, (GLenum face, GLenum pname, const GLfloat * params), (face, pname, params))
GEN_THUNKS(glMateriali, (GLenum face, GLenum pname, GLint param), (face, pname, param))
GEN_THUNKS(glMaterialiv, (GLenum face, GLenum pname, const GLint * params), (face, pname, params))
GEN_THUNKS(glMaterialx, (GLenum face, GLenum pname, GLfixed param), (face, pname, param))
GEN_THUNKS(glMaterialxOES, (GLenum face, GLenum pname, GLfixed param), (face, pname, param))
GEN_THUNKS(glMaterialxv, (GLenum face, GLenum pname, const GLfixed * param), (face, pname, param))
GEN_THUNKS(glMaterialxvOES, (GLenum face, GLenum pname, const GLfixed * param), (face, pname, param))
GEN_THUNKS(glMatrixFrustumEXT, (GLenum mode, GLdouble left, GLdouble right, GLdouble bottom, GLdouble top, GLdouble zNear, GLdouble zFar), (mode, left, right, bottom, top, zNear, zFar))
GEN_THUNKS(glMatrixIndexPointerARB, (GLint size, GLenum type, GLsizei stride, const void * pointer), (size, type, stride, pointer))
GEN_THUNKS(glMatrixIndexPointerOES, (GLint size, GLenum type, GLsizei stride, const void * pointer), (size, type, stride, pointer))
GEN_THUNKS(glMatrixIndexubvARB, (GLint size, const GLubyte * indices), (size, indices))
GEN_THUNKS(glMatrixIndexuivARB, (GLint size, const GLuint * indices), (size, indices))
GEN_THUNKS(glMatrixIndexusvARB, (GLint size, const GLushort * indices), (size, indices))
GEN_THUNKS(glMatrixLoad3x2fNV, (GLenum matrixMode, const GLfloat * m), (matrixMode, m))
GEN_THUNKS(glMatrixLoad3x3fNV, (GLenum matrixMode, const GLfloat * m), (matrixMode, m))
GEN_THUNKS(glMatrixLoadIdentityEXT, (GLenum mode), (mode))
GEN_THUNKS(glMatrixLoadTranspose3x3fNV, (GLenum matrixMode, const GLfloat * m), (matrixMode, m))
GEN_THUNKS(glMatrixLoadTransposedEXT, (GLenum mode, const GLdouble * m), (mode, m))
GEN_THUNKS(glMatrixLoadTransposefEXT, (GLenum mode, const GLfloat * m), (mode, m))
GEN_THUNKS(glMatrixLoaddEXT, (GLenum mode, const GLdouble * m), (mode, m))
GEN_THUNKS(glMatrixLoadfEXT, (GLenum mode, const GLfloat * m), (mode, m))
GEN_THUNKS(glMatrixMode, (GLenum mode), (mode))
GEN_THUNKS(glMatrixMult3x2fNV, (GLenum matrixMode, const GLfloat * m), (matrixMode, m))
GEN_THUNKS(glMatrixMult3x3fNV, (GLenum matrixMode, const GLfloat * m), (matrixMode, m))
GEN_THUNKS(glMatrixMultTranspose3x3fNV, (GLenum matrixMode, const GLfloat * m), (matrixMode, m))
GEN_THUNKS(glMatrixMultTransposedEXT, (GLenum mode, const GLdouble * m), (mode, m))
GEN_THUNKS(glMatrixMultTransposefEXT, (GLenum mode, const GLfloat * m), (mode, m))
GEN_THUNKS(glMatrixMultdEXT, (GLenum mode, const GLdouble * m), (mode, m))
GEN_THUNKS(glMatrixMultfEXT, (GLenum mode, const GLfloat * m), (mode, m))
GEN_THUNKS(glMatrixOrthoEXT, (GLenum mode, GLdouble left, GLdouble right, GLdouble bottom, GLdouble top, GLdouble zNear, GLdouble zFar), (mode, left, right, bottom, top, zNear, zFar))
GEN_THUNKS(glMatrixPopEXT, (GLenum mode), (mode))
GEN_THUNKS(glMatrixPushEXT, (GLenum mode), (mode))
GEN_THUNKS(glMatrixRotatedEXT, (GLenum mode, GLdouble angle, GLdouble x, GLdouble y, GLdouble z), (mode, angle, x, y, z))
GEN_THUNKS(glMatrixRotatefEXT, (GLenum mode, GLfloat angle, GLfloat x, GLfloat y, GLfloat z), (mode, angle, x, y, z))
GEN_THUNKS(glMatrixScaledEXT, (GLenum mode, GLdouble x, GLdouble y, GLdouble z), (mode, x, y, z))
GEN_THUNKS(glMatrixScalefEXT, (GLenum mode, GLfloat x, GLfloat y, GLfloat z), (mode, x, y, z))
GEN_THUNKS(glMatrixTranslatedEXT, (GLenum mode, GLdouble x, GLdouble y, GLdouble z), (mode, x, y, z))
GEN_THUNKS(glMatrixTranslatefEXT, (GLenum mode, GLfloat x, GLfloat y, GLfloat z), (mode, x, y, z))
GEN_THUNKS(glMaxShaderCompilerThreadsARB, (GLuint count), (count))
GEN_THUNKS(glMaxShaderCompilerThreadsKHR, (GLuint count), (count))
GEN_THUNKS(glMemoryBarrier, (GLbitfield barriers), (barriers))
GEN_THUNKS(glMemoryBarrierByRegion, (GLbitfield barriers), (barriers))
GEN_THUNKS(glMemoryBarrierEXT, (GLbitfield barriers), (barriers))
GEN_THUNKS(glMemoryObjectParameterivEXT, (GLuint memoryObject, GLenum pname, const GLint * params), (memoryObject, pname, params))
GEN_THUNKS(glMinSampleShading, (GLfloat value), (value))
GEN_THUNKS(glMinSampleShadingARB, (GLfloat value), (value))
GEN_THUNKS(glMinSampleShadingOES, (GLfloat value), (value))
GEN_THUNKS(glMinmax, (GLenum target, GLenum internalformat, GLboolean sink), (target, internalformat, sink))
GEN_THUNKS(glMinmaxEXT, (GLenum target, GLenum internalformat, GLboolean sink), (target, internalformat, sink))
GEN_THUNKS(glMultMatrixd, (const GLdouble * m), (m))
GEN_THUNKS(glMultMatrixf, (const GLfloat * m), (m))
GEN_THUNKS(glMultMatrixx, (const GLfixed * m), (m))
GEN_THUNKS(glMultMatrixxOES, (const GLfixed * m), (m))
GEN_THUNKS(glMultTransposeMatrixd, (const GLdouble * m), (m))
GEN_THUNKS(glMultTransposeMatrixdARB, (const GLdouble * m), (m))
GEN_THUNKS(glMultTransposeMatrixf, (const GLfloat * m), (m))
GEN_THUNKS(glMultTransposeMatrixfARB, (const GLfloat * m), (m))
GEN_THUNKS(glMultTransposeMatrixxOES, (const GLfixed * m), (m))
GEN_THUNKS(glMultiDrawArrays, (GLenum mode, const GLint * first, const GLsizei * count, GLsizei drawcount), (mode, first, count, drawcount))
GEN_THUNKS(glMultiDrawArraysEXT, (GLenum mode, const GLint * first, const GLsizei * count, GLsizei primcount), (mode, first, count, primcount))
GEN_THUNKS(glMultiDrawArraysIndirect, (GLenum mode, const void * indirect, GLsizei drawcount, GLsizei stride), (mode, indirect, drawcount, stride))
GEN_THUNKS(glMultiDrawArraysIndirectAMD, (GLenum mode, const void * indirect, GLsizei primcount, GLsizei stride), (mode, indirect, primcount, stride))
GEN_THUNKS(glMultiDrawArraysIndirectBindlessCountNV, (GLenum mode, const void * indirect, GLsizei drawCount, GLsizei maxDrawCount, GLsizei stride, GLint vertexBufferCount), (mode, indirect, drawCount, maxDrawCount, stride, vertexBufferCount))
GEN_THUNKS(glMultiDrawArraysIndirectBindlessNV, (GLenum mode, const void * indirect, GLsizei drawCount, GLsizei stride, GLint vertexBufferCount), (mode, indirect, drawCount, stride, vertexBufferCount))
GEN_THUNKS(glMultiDrawArraysIndirectCount, (GLenum mode, const void * indirect, GLintptr drawcount, GLsizei maxdrawcount, GLsizei stride), (mode, indirect, drawcount, maxdrawcount, stride))
GEN_THUNKS(glMultiDrawArraysIndirectCountARB, (GLenum mode, const void * indirect, GLintptr drawcount, GLsizei maxdrawcount, GLsizei stride), (mode, indirect, drawcount, maxdrawcount, stride))
GEN_THUNKS(glMultiDrawArraysIndirectEXT, (GLenum mode, const void * indirect, GLsizei drawcount, GLsizei stride), (mode, indirect, drawcount, stride))
GEN_THUNKS(glMultiDrawElementArrayAPPLE, (GLenum mode, const GLint * first, const GLsizei * count, GLsizei primcount), (mode, first, count, primcount))
GEN_THUNKS(glMultiDrawElements, (GLenum mode, const GLsizei * count, GLenum type, const void *const* indices, GLsizei drawcount), (mode, count, type, indices, drawcount))
GEN_THUNKS(glMultiDrawElementsBaseVertex, (GLenum mode, const GLsizei * count, GLenum type, const void *const* indices, GLsizei drawcount, const GLint * basevertex), (mode, count, type, indices, drawcount, basevertex))
GEN_THUNKS(glMultiDrawElementsBaseVertexEXT, (GLenum mode, const GLsizei * count, GLenum type, const void *const* indices, GLsizei primcount, const GLint * basevertex), (mode, count, type, indices, primcount, basevertex))
GEN_THUNKS(glMultiDrawElementsEXT, (GLenum mode, const GLsizei * count, GLenum type, const void *const* indices, GLsizei primcount), (mode, count, type, indices, primcount))
GEN_THUNKS(glMultiDrawElementsIndirect, (GLenum mode, GLenum type, const void * indirect, GLsizei drawcount, GLsizei stride), (mode, type, indirect, drawcount, stride))
GEN_THUNKS(glMultiDrawElementsIndirectAMD, (GLenum mode, GLenum type, const void * indirect, GLsizei primcount, GLsizei stride), (mode, type, indirect, primcount, stride))
GEN_THUNKS(glMultiDrawElementsIndirectBindlessCountNV, (GLenum mode, GLenum type, const void * indirect, GLsizei drawCount, GLsizei maxDrawCount, GLsizei stride, GLint vertexBufferCount), (mode, type, indirect, drawCount, maxDrawCount, stride, vertexBufferCount))
GEN_THUNKS(glMultiDrawElementsIndirectBindlessNV, (GLenum mode, GLenum type, const void * indirect, GLsizei drawCount, GLsizei stride, GLint vertexBufferCount), (mode, type, indirect, drawCount, stride, vertexBufferCount))
GEN_THUNKS(glMultiDrawElementsIndirectCount, (GLenum mode, GLenum type, const void * indirect, GLintptr drawcount, GLsizei maxdrawcount, GLsizei stride), (mode, type, indirect, drawcount, maxdrawcount, stride))
GEN_THUNKS(glMultiDrawElementsIndirectCountARB, (GLenum mode, GLenum type, const void * indirect, GLintptr drawcount, GLsizei maxdrawcount, GLsizei stride), (mode, type, indirect, drawcount, maxdrawcount, stride))
GEN_THUNKS(glMultiDrawElementsIndirectEXT, (GLenum mode, GLenum type, const void * indirect, GLsizei drawcount, GLsizei stride), (mode, type, indirect, drawcount, stride))
GEN_THUNKS(glMultiDrawMeshTasksIndirectCountNV, (GLintptr indirect, GLintptr drawcount, GLsizei maxdrawcount, GLsizei stride), (indirect, drawcount, maxdrawcount, stride))
GEN_THUNKS(glMultiDrawMeshTasksIndirectNV, (GLintptr indirect, GLsizei drawcount, GLsizei stride), (indirect, drawcount, stride))
GEN_THUNKS(glMultiDrawRangeElementArrayAPPLE, (GLenum mode, GLuint start, GLuint end, const GLint * first, const GLsizei * count, GLsizei primcount), (mode, start, end, first, count, primcount))
GEN_THUNKS(glMultiModeDrawArraysIBM, (const GLenum * mode, const GLint * first, const GLsizei * count, GLsizei primcount, GLint modestride), (mode, first, count, primcount, modestride))
GEN_THUNKS(glMultiModeDrawElementsIBM, (const GLenum * mode, const GLsizei * count, GLenum type, const void *const* indices, GLsizei primcount, GLint modestride), (mode, count, type, indices, primcount, modestride))
GEN_THUNKS(glMultiTexBufferEXT, (GLenum texunit, GLenum target, GLenum internalformat, GLuint buffer), (texunit, target, internalformat, buffer))
GEN_THUNKS(glMultiTexCoord1bOES, (GLenum texture, GLbyte s), (texture, s))
GEN_THUNKS(glMultiTexCoord1bvOES, (GLenum texture, const GLbyte * coords), (texture, coords))
GEN_THUNKS(glMultiTexCoord1d, (GLenum target, GLdouble s), (target, s))
GEN_THUNKS(glMultiTexCoord1dARB, (GLenum target, GLdouble s), (target, s))
GEN_THUNKS(glMultiTexCoord1dv, (GLenum target, const GLdouble * v), (target, v))
GEN_THUNKS(glMultiTexCoord1dvARB, (GLenum target, const GLdouble * v), (target, v))
GEN_THUNKS(glMultiTexCoord1f, (GLenum target, GLfloat s), (target, s))
GEN_THUNKS(glMultiTexCoord1fARB, (GLenum target, GLfloat s), (target, s))
GEN_THUNKS(glMultiTexCoord1fv, (GLenum target, const GLfloat * v), (target, v))
GEN_THUNKS(glMultiTexCoord1fvARB, (GLenum target, const GLfloat * v), (target, v))
GEN_THUNKS(glMultiTexCoord1hNV, (GLenum target, GLhalfNV s), (target, s))
GEN_THUNKS(glMultiTexCoord1hvNV, (GLenum target, const GLhalfNV * v), (target, v))
GEN_THUNKS(glMultiTexCoord1i, (GLenum target, GLint s), (target, s))
GEN_THUNKS(glMultiTexCoord1iARB, (GLenum target, GLint s), (target, s))
GEN_THUNKS(glMultiTexCoord1iv, (GLenum target, const GLint * v), (target, v))
GEN_THUNKS(glMultiTexCoord1ivARB, (GLenum target, const GLint * v), (target, v))
GEN_THUNKS(glMultiTexCoord1s, (GLenum target, GLshort s), (target, s))
GEN_THUNKS(glMultiTexCoord1sARB, (GLenum target, GLshort s), (target, s))
GEN_THUNKS(glMultiTexCoord1sv, (GLenum target, const GLshort * v), (target, v))
GEN_THUNKS(glMultiTexCoord1svARB, (GLenum target, const GLshort * v), (target, v))
GEN_THUNKS(glMultiTexCoord1xOES, (GLenum texture, GLfixed s), (texture, s))
GEN_THUNKS(glMultiTexCoord1xvOES, (GLenum texture, const GLfixed * coords), (texture, coords))
GEN_THUNKS(glMultiTexCoord2bOES, (GLenum texture, GLbyte s, GLbyte t), (texture, s, t))
GEN_THUNKS(glMultiTexCoord2bvOES, (GLenum texture, const GLbyte * coords), (texture, coords))
GEN_THUNKS(glMultiTexCoord2d, (GLenum target, GLdouble s, GLdouble t), (target, s, t))
GEN_THUNKS(glMultiTexCoord2dARB, (GLenum target, GLdouble s, GLdouble t), (target, s, t))
GEN_THUNKS(glMultiTexCoord2dv, (GLenum target, const GLdouble * v), (target, v))
GEN_THUNKS(glMultiTexCoord2dvARB, (GLenum target, const GLdouble * v), (target, v))
GEN_THUNKS(glMultiTexCoord2f, (GLenum target, GLfloat s, GLfloat t), (target, s, t))
GEN_THUNKS(glMultiTexCoord2fARB, (GLenum target, GLfloat s, GLfloat t), (target, s, t))
GEN_THUNKS(glMultiTexCoord2fv, (GLenum target, const GLfloat * v), (target, v))
GEN_THUNKS(glMultiTexCoord2fvARB, (GLenum target, const GLfloat * v), (target, v))
GEN_THUNKS(glMultiTexCoord2hNV, (GLenum target, GLhalfNV s, GLhalfNV t), (target, s, t))
GEN_THUNKS(glMultiTexCoord2hvNV, (GLenum target, const GLhalfNV * v), (target, v))
GEN_THUNKS(glMultiTexCoord2i, (GLenum target, GLint s, GLint t), (target, s, t))
GEN_THUNKS(glMultiTexCoord2iARB, (GLenum target, GLint s, GLint t), (target, s, t))
GEN_THUNKS(glMultiTexCoord2iv, (GLenum target, const GLint * v), (target, v))
GEN_THUNKS(glMultiTexCoord2ivARB, (GLenum target, const GLint * v), (target, v))
GEN_THUNKS(glMultiTexCoord2s, (GLenum target, GLshort s, GLshort t), (target, s, t))
GEN_THUNKS(glMultiTexCoord2sARB, (GLenum target, GLshort s, GLshort t), (target, s, t))
GEN_THUNKS(glMultiTexCoord2sv, (GLenum target, const GLshort * v), (target, v))
GEN_THUNKS(glMultiTexCoord2svARB, (GLenum target, const GLshort * v), (target, v))
GEN_THUNKS(glMultiTexCoord2xOES, (GLenum texture, GLfixed s, GLfixed t), (texture, s, t))
GEN_THUNKS(glMultiTexCoord2xvOES, (GLenum texture, const GLfixed * coords), (texture, coords))
GEN_THUNKS(glMultiTexCoord3bOES, (GLenum texture, GLbyte s, GLbyte t, GLbyte r), (texture, s, t, r))
GEN_THUNKS(glMultiTexCoord3bvOES, (GLenum texture, const GLbyte * coords), (texture, coords))
GEN_THUNKS(glMultiTexCoord3d, (GLenum target, GLdouble s, GLdouble t, GLdouble r), (target, s, t, r))
GEN_THUNKS(glMultiTexCoord3dARB, (GLenum target, GLdouble s, GLdouble t, GLdouble r), (target, s, t, r))
GEN_THUNKS(glMultiTexCoord3dv, (GLenum target, const GLdouble * v), (target, v))
GEN_THUNKS(glMultiTexCoord3dvARB, (GLenum target, const GLdouble * v), (target, v))
GEN_THUNKS(glMultiTexCoord3f, (GLenum target, GLfloat s, GLfloat t, GLfloat r), (target, s, t, r))
GEN_THUNKS(glMultiTexCoord3fARB, (GLenum target, GLfloat s, GLfloat t, GLfloat r), (target, s, t, r))
GEN_THUNKS(glMultiTexCoord3fv, (GLenum target, const GLfloat * v), (target, v))
GEN_THUNKS(glMultiTexCoord3fvARB, (GLenum target, const GLfloat * v), (target, v))
GEN_THUNKS(glMultiTexCoord3hNV, (GLenum target, GLhalfNV s, GLhalfNV t, GLhalfNV r), (target, s, t, r))
GEN_THUNKS(glMultiTexCoord3hvNV, (GLenum target, const GLhalfNV * v), (target, v))
GEN_THUNKS(glMultiTexCoord3i, (GLenum target, GLint s, GLint t, GLint r), (target, s, t, r))
GEN_THUNKS(glMultiTexCoord3iARB, (GLenum target, GLint s, GLint t, GLint r), (target, s, t, r))
GEN_THUNKS(glMultiTexCoord3iv, (GLenum target, const GLint * v), (target, v))
GEN_THUNKS(glMultiTexCoord3ivARB, (GLenum target, const GLint * v), (target, v))
GEN_THUNKS(glMultiTexCoord3s, (GLenum target, GLshort s, GLshort t, GLshort r), (target, s, t, r))
GEN_THUNKS(glMultiTexCoord3sARB, (GLenum target, GLshort s, GLshort t, GLshort r), (target, s, t, r))
GEN_THUNKS(glMultiTexCoord3sv, (GLenum target, const GLshort * v), (target, v))
GEN_THUNKS(glMultiTexCoord3svARB, (GLenum target, const GLshort * v), (target, v))
GEN_THUNKS(glMultiTexCoord3xOES, (GLenum texture, GLfixed s, GLfixed t, GLfixed r), (texture, s, t, r))
GEN_THUNKS(glMultiTexCoord3xvOES, (GLenum texture, const GLfixed * coords), (texture, coords))
GEN_THUNKS(glMultiTexCoord4bOES, (GLenum texture, GLbyte s, GLbyte t, GLbyte r, GLbyte q), (texture, s, t, r, q))
GEN_THUNKS(glMultiTexCoord4bvOES, (GLenum texture, const GLbyte * coords), (texture, coords))
GEN_THUNKS(glMultiTexCoord4d, (GLenum target, GLdouble s, GLdouble t, GLdouble r, GLdouble q), (target, s, t, r, q))
GEN_THUNKS(glMultiTexCoord4dARB, (GLenum target, GLdouble s, GLdouble t, GLdouble r, GLdouble q), (target, s, t, r, q))
GEN_THUNKS(glMultiTexCoord4dv, (GLenum target, const GLdouble * v), (target, v))
GEN_THUNKS(glMultiTexCoord4dvARB, (GLenum target, const GLdouble * v), (target, v))
GEN_THUNKS(glMultiTexCoord4f, (GLenum target, GLfloat s, GLfloat t, GLfloat r, GLfloat q), (target, s, t, r, q))
GEN_THUNKS(glMultiTexCoord4fARB, (GLenum target, GLfloat s, GLfloat t, GLfloat r, GLfloat q), (target, s, t, r, q))
GEN_THUNKS(glMultiTexCoord4fv, (GLenum target, const GLfloat * v), (target, v))
GEN_THUNKS(glMultiTexCoord4fvARB, (GLenum target, const GLfloat * v), (target, v))
GEN_THUNKS(glMultiTexCoord4hNV, (GLenum target, GLhalfNV s, GLhalfNV t, GLhalfNV r, GLhalfNV q), (target, s, t, r, q))
GEN_THUNKS(glMultiTexCoord4hvNV, (GLenum target, const GLhalfNV * v), (target, v))
GEN_THUNKS(glMultiTexCoord4i, (GLenum target, GLint s, GLint t, GLint r, GLint q), (target, s, t, r, q))
GEN_THUNKS(glMultiTexCoord4iARB, (GLenum target, GLint s, GLint t, GLint r, GLint q), (target, s, t, r, q))
GEN_THUNKS(glMultiTexCoord4iv, (GLenum target, const GLint * v), (target, v))
GEN_THUNKS(glMultiTexCoord4ivARB, (GLenum target, const GLint * v), (target, v))
GEN_THUNKS(glMultiTexCoord4s, (GLenum target, GLshort s, GLshort t, GLshort r, GLshort q), (target, s, t, r, q))
GEN_THUNKS(glMultiTexCoord4sARB, (GLenum target, GLshort s, GLshort t, GLshort r, GLshort q), (target, s, t, r, q))
GEN_THUNKS(glMultiTexCoord4sv, (GLenum target, const GLshort * v), (target, v))
GEN_THUNKS(glMultiTexCoord4svARB, (GLenum target, const GLshort * v), (target, v))
GEN_THUNKS(glMultiTexCoord4x, (GLenum texture, GLfixed s, GLfixed t, GLfixed r, GLfixed q), (texture, s, t, r, q))
GEN_THUNKS(glMultiTexCoord4xOES, (GLenum texture, GLfixed s, GLfixed t, GLfixed r, GLfixed q), (texture, s, t, r, q))
GEN_THUNKS(glMultiTexCoord4xvOES, (GLenum texture, const GLfixed * coords), (texture, coords))
GEN_THUNKS(glMultiTexCoordP1ui, (GLenum texture, GLenum type, GLuint coords), (texture, type, coords))
GEN_THUNKS(glMultiTexCoordP1uiv, (GLenum texture, GLenum type, const GLuint * coords), (texture, type, coords))
GEN_THUNKS(glMultiTexCoordP2ui, (GLenum texture, GLenum type, GLuint coords), (texture, type, coords))
GEN_THUNKS(glMultiTexCoordP2uiv, (GLenum texture, GLenum type, const GLuint * coords), (texture, type, coords))
GEN_THUNKS(glMultiTexCoordP3ui, (GLenum texture, GLenum type, GLuint coords), (texture, type, coords))
GEN_THUNKS(glMultiTexCoordP3uiv, (GLenum texture, GLenum type, const GLuint * coords), (texture, type, coords))
GEN_THUNKS(glMultiTexCoordP4ui, (GLenum texture, GLenum type, GLuint coords), (texture, type, coords))
GEN_THUNKS(glMultiTexCoordP4uiv, (GLenum texture, GLenum type, const GLuint * coords), (texture, type, coords))
GEN_THUNKS(glMultiTexCoordPointerEXT, (GLenum texunit, GLint size, GLenum type, GLsizei stride, const void * pointer), (texunit, size, type, stride, pointer))
GEN_THUNKS(glMultiTexEnvfEXT, (GLenum texunit, GLenum target, GLenum pname, GLfloat param), (texunit, target, pname, param))
GEN_THUNKS(glMultiTexEnvfvEXT, (GLenum texunit, GLenum target, GLenum pname, const GLfloat * params), (texunit, target, pname, params))
GEN_THUNKS(glMultiTexEnviEXT, (GLenum texunit, GLenum target, GLenum pname, GLint param), (texunit, target, pname, param))
GEN_THUNKS(glMultiTexEnvivEXT, (GLenum texunit, GLenum target, GLenum pname, const GLint * params), (texunit, target, pname, params))
GEN_THUNKS(glMultiTexGendEXT, (GLenum texunit, GLenum coord, GLenum pname, GLdouble param), (texunit, coord, pname, param))
GEN_THUNKS(glMultiTexGendvEXT, (GLenum texunit, GLenum coord, GLenum pname, const GLdouble * params), (texunit, coord, pname, params))
GEN_THUNKS(glMultiTexGenfEXT, (GLenum texunit, GLenum coord, GLenum pname, GLfloat param), (texunit, coord, pname, param))
GEN_THUNKS(glMultiTexGenfvEXT, (GLenum texunit, GLenum coord, GLenum pname, const GLfloat * params), (texunit, coord, pname, params))
GEN_THUNKS(glMultiTexGeniEXT, (GLenum texunit, GLenum coord, GLenum pname, GLint param), (texunit, coord, pname, param))
GEN_THUNKS(glMultiTexGenivEXT, (GLenum texunit, GLenum coord, GLenum pname, const GLint * params), (texunit, coord, pname, params))
GEN_THUNKS(glMultiTexImage1DEXT, (GLenum texunit, GLenum target, GLint level, GLint internalformat, GLsizei width, GLint border, GLenum format, GLenum type, const void * pixels), (texunit, target, level, internalformat, width, border, format, type, pixels))
GEN_THUNKS(glMultiTexImage2DEXT, (GLenum texunit, GLenum target, GLint level, GLint internalformat, GLsizei width, GLsizei height, GLint border, GLenum format, GLenum type, const void * pixels), (texunit, target, level, internalformat, width, height, border, format, type, pixels))
GEN_THUNKS(glMultiTexImage3DEXT, (GLenum texunit, GLenum target, GLint level, GLint internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLenum format, GLenum type, const void * pixels), (texunit, target, level, internalformat, width, height, depth, border, format, type, pixels))
GEN_THUNKS(glMultiTexParameterIivEXT, (GLenum texunit, GLenum target, GLenum pname, const GLint * params), (texunit, target, pname, params))
GEN_THUNKS(glMultiTexParameterIuivEXT, (GLenum texunit, GLenum target, GLenum pname, const GLuint * params), (texunit, target, pname, params))
GEN_THUNKS(glMultiTexParameterfEXT, (GLenum texunit, GLenum target, GLenum pname, GLfloat param), (texunit, target, pname, param))
GEN_THUNKS(glMultiTexParameterfvEXT, (GLenum texunit, GLenum target, GLenum pname, const GLfloat * params), (texunit, target, pname, params))
GEN_THUNKS(glMultiTexParameteriEXT, (GLenum texunit, GLenum target, GLenum pname, GLint param), (texunit, target, pname, param))
GEN_THUNKS(glMultiTexParameterivEXT, (GLenum texunit, GLenum target, GLenum pname, const GLint * params), (texunit, target, pname, params))
GEN_THUNKS(glMultiTexRenderbufferEXT, (GLenum texunit, GLenum target, GLuint renderbuffer), (texunit, target, renderbuffer))
GEN_THUNKS(glMultiTexSubImage1DEXT, (GLenum texunit, GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLenum type, const void * pixels), (texunit, target, level, xoffset, width, format, type, pixels))
GEN_THUNKS(glMultiTexSubImage2DEXT, (GLenum texunit, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLenum type, const void * pixels), (texunit, target, level, xoffset, yoffset, width, height, format, type, pixels))
GEN_THUNKS(glMultiTexSubImage3DEXT, (GLenum texunit, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void * pixels), (texunit, target, level, xoffset, yoffset, zoffset, width, height, depth, format, type, pixels))
GEN_THUNKS(glMulticastBarrierNV, (void), ())
GEN_THUNKS(glMulticastBlitFramebufferNV, (GLuint srcGpu, GLuint dstGpu, GLint srcX0, GLint srcY0, GLint srcX1, GLint srcY1, GLint dstX0, GLint dstY0, GLint dstX1, GLint dstY1, GLbitfield mask, GLenum filter), (srcGpu, dstGpu, srcX0, srcY0, srcX1, srcY1, dstX0, dstY0, dstX1, dstY1, mask, filter))
GEN_THUNKS(glMulticastBufferSubDataNV, (GLbitfield gpuMask, GLuint buffer, GLintptr offset, GLsizeiptr size, const void * data), (gpuMask, buffer, offset, size, data))
GEN_THUNKS(glMulticastCopyBufferSubDataNV, (GLuint readGpu, GLbitfield writeGpuMask, GLuint readBuffer, GLuint writeBuffer, GLintptr readOffset, GLintptr writeOffset, GLsizeiptr size), (readGpu, writeGpuMask, readBuffer, writeBuffer, readOffset, writeOffset, size))
GEN_THUNKS(glMulticastCopyImageSubDataNV, (GLuint srcGpu, GLbitfield dstGpuMask, GLuint srcName, GLenum srcTarget, GLint srcLevel, GLint srcX, GLint srcY, GLint srcZ, GLuint dstName, GLenum dstTarget, GLint dstLevel, GLint dstX, GLint dstY, GLint dstZ, GLsizei srcWidth, GLsizei srcHeight, GLsizei srcDepth), (srcGpu, dstGpuMask, srcName, srcTarget, srcLevel, srcX, srcY, srcZ, dstName, dstTarget, dstLevel, dstX, dstY, dstZ, srcWidth, srcHeight, srcDepth))
GEN_THUNKS(glMulticastFramebufferSampleLocationsfvNV, (GLuint gpu, GLuint framebuffer, GLuint start, GLsizei count, const GLfloat * v), (gpu, framebuffer, start, count, v))
GEN_THUNKS(glMulticastGetQueryObjecti64vNV, (GLuint gpu, GLuint id, GLenum pname, GLint64 * params), (gpu, id, pname, params))
GEN_THUNKS(glMulticastGetQueryObjectivNV, (GLuint gpu, GLuint id, GLenum pname, GLint * params), (gpu, id, pname, params))
GEN_THUNKS(glMulticastGetQueryObjectui64vNV, (GLuint gpu, GLuint id, GLenum pname, GLuint64 * params), (gpu, id, pname, params))
GEN_THUNKS(glMulticastGetQueryObjectuivNV, (GLuint gpu, GLuint id, GLenum pname, GLuint * params), (gpu, id, pname, params))
GEN_THUNKS(glMulticastScissorArrayvNVX, (GLuint gpu, GLuint first, GLsizei count, const GLint * v), (gpu, first, count, v))
GEN_THUNKS(glMulticastViewportArrayvNVX, (GLuint gpu, GLuint first, GLsizei count, const GLfloat * v), (gpu, first, count, v))
GEN_THUNKS(glMulticastViewportPositionWScaleNVX, (GLuint gpu, GLuint index, GLfloat xcoeff, GLfloat ycoeff), (gpu, index, xcoeff, ycoeff))
GEN_THUNKS(glMulticastWaitSyncNV, (GLuint signalGpu, GLbitfield waitGpuMask), (signalGpu, waitGpuMask))
GEN_THUNKS(glNamedBufferAttachMemoryNV, (GLuint buffer, GLuint memory, GLuint64 offset), (buffer, memory, offset))
GEN_THUNKS(glNamedBufferData, (GLuint buffer, GLsizeiptr size, const void * data, GLenum usage), (buffer, size, data, usage))
GEN_THUNKS(glNamedBufferDataEXT, (GLuint buffer, GLsizeiptr size, const void * data, GLenum usage), (buffer, size, data, usage))
GEN_THUNKS(glNamedBufferPageCommitmentARB, (GLuint buffer, GLintptr offset, GLsizeiptr size, GLboolean commit), (buffer, offset, size, commit))
GEN_THUNKS(glNamedBufferPageCommitmentEXT, (GLuint buffer, GLintptr offset, GLsizeiptr size, GLboolean commit), (buffer, offset, size, commit))
GEN_THUNKS(glNamedBufferStorage, (GLuint buffer, GLsizeiptr size, const void * data, GLbitfield flags), (buffer, size, data, flags))
GEN_THUNKS(glNamedBufferStorageEXT, (GLuint buffer, GLsizeiptr size, const void * data, GLbitfield flags), (buffer, size, data, flags))
GEN_THUNKS(glNamedBufferStorageExternalEXT, (GLuint buffer, GLintptr offset, GLsizeiptr size, GLeglClientBufferEXT clientBuffer, GLbitfield flags), (buffer, offset, size, clientBuffer, flags))
GEN_THUNKS(glNamedBufferStorageMemEXT, (GLuint buffer, GLsizeiptr size, GLuint memory, GLuint64 offset), (buffer, size, memory, offset))
GEN_THUNKS(glNamedBufferSubData, (GLuint buffer, GLintptr offset, GLsizeiptr size, const void * data), (buffer, offset, size, data))
GEN_THUNKS(glNamedBufferSubDataEXT, (GLuint buffer, GLintptr offset, GLsizeiptr size, const void * data), (buffer, offset, size, data))
GEN_THUNKS(glNamedCopyBufferSubDataEXT, (GLuint readBuffer, GLuint writeBuffer, GLintptr readOffset, GLintptr writeOffset, GLsizeiptr size), (readBuffer, writeBuffer, readOffset, writeOffset, size))
GEN_THUNKS(glNamedFramebufferDrawBuffer, (GLuint framebuffer, GLenum buf), (framebuffer, buf))
GEN_THUNKS(glNamedFramebufferDrawBuffers, (GLuint framebuffer, GLsizei n, const GLenum * bufs), (framebuffer, n, bufs))
GEN_THUNKS(glNamedFramebufferParameteri, (GLuint framebuffer, GLenum pname, GLint param), (framebuffer, pname, param))
GEN_THUNKS(glNamedFramebufferParameteriEXT, (GLuint framebuffer, GLenum pname, GLint param), (framebuffer, pname, param))
GEN_THUNKS(glNamedFramebufferReadBuffer, (GLuint framebuffer, GLenum src), (framebuffer, src))
GEN_THUNKS(glNamedFramebufferRenderbuffer, (GLuint framebuffer, GLenum attachment, GLenum renderbuffertarget, GLuint renderbuffer), (framebuffer, attachment, renderbuffertarget, renderbuffer))
GEN_THUNKS(glNamedFramebufferRenderbufferEXT, (GLuint framebuffer, GLenum attachment, GLenum renderbuffertarget, GLuint renderbuffer), (framebuffer, attachment, renderbuffertarget, renderbuffer))
GEN_THUNKS(glNamedFramebufferSampleLocationsfvARB, (GLuint framebuffer, GLuint start, GLsizei count, const GLfloat * v), (framebuffer, start, count, v))
GEN_THUNKS(glNamedFramebufferSampleLocationsfvNV, (GLuint framebuffer, GLuint start, GLsizei count, const GLfloat * v), (framebuffer, start, count, v))
GEN_THUNKS(glNamedFramebufferSamplePositionsfvAMD, (GLuint framebuffer, GLuint numsamples, GLuint pixelindex, const GLfloat * values), (framebuffer, numsamples, pixelindex, values))
GEN_THUNKS(glNamedFramebufferTexture, (GLuint framebuffer, GLenum attachment, GLuint texture, GLint level), (framebuffer, attachment, texture, level))
GEN_THUNKS(glNamedFramebufferTexture1DEXT, (GLuint framebuffer, GLenum attachment, GLenum textarget, GLuint texture, GLint level), (framebuffer, attachment, textarget, texture, level))
GEN_THUNKS(glNamedFramebufferTexture2DEXT, (GLuint framebuffer, GLenum attachment, GLenum textarget, GLuint texture, GLint level), (framebuffer, attachment, textarget, texture, level))
GEN_THUNKS(glNamedFramebufferTexture3DEXT, (GLuint framebuffer, GLenum attachment, GLenum textarget, GLuint texture, GLint level, GLint zoffset), (framebuffer, attachment, textarget, texture, level, zoffset))
GEN_THUNKS(glNamedFramebufferTextureEXT, (GLuint framebuffer, GLenum attachment, GLuint texture, GLint level), (framebuffer, attachment, texture, level))
GEN_THUNKS(glNamedFramebufferTextureFaceEXT, (GLuint framebuffer, GLenum attachment, GLuint texture, GLint level, GLenum face), (framebuffer, attachment, texture, level, face))
GEN_THUNKS(glNamedFramebufferTextureLayer, (GLuint framebuffer, GLenum attachment, GLuint texture, GLint level, GLint layer), (framebuffer, attachment, texture, level, layer))
GEN_THUNKS(glNamedFramebufferTextureLayerEXT, (GLuint framebuffer, GLenum attachment, GLuint texture, GLint level, GLint layer), (framebuffer, attachment, texture, level, layer))
GEN_THUNKS(glNamedProgramLocalParameter4dEXT, (GLuint program, GLenum target, GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w), (program, target, index, x, y, z, w))
GEN_THUNKS(glNamedProgramLocalParameter4dvEXT, (GLuint program, GLenum target, GLuint index, const GLdouble * params), (program, target, index, params))
GEN_THUNKS(glNamedProgramLocalParameter4fEXT, (GLuint program, GLenum target, GLuint index, GLfloat x, GLfloat y, GLfloat z, GLfloat w), (program, target, index, x, y, z, w))
GEN_THUNKS(glNamedProgramLocalParameter4fvEXT, (GLuint program, GLenum target, GLuint index, const GLfloat * params), (program, target, index, params))
GEN_THUNKS(glNamedProgramLocalParameterI4iEXT, (GLuint program, GLenum target, GLuint index, GLint x, GLint y, GLint z, GLint w), (program, target, index, x, y, z, w))
GEN_THUNKS(glNamedProgramLocalParameterI4ivEXT, (GLuint program, GLenum target, GLuint index, const GLint * params), (program, target, index, params))
GEN_THUNKS(glNamedProgramLocalParameterI4uiEXT, (GLuint program, GLenum target, GLuint index, GLuint x, GLuint y, GLuint z, GLuint w), (program, target, index, x, y, z, w))
GEN_THUNKS(glNamedProgramLocalParameterI4uivEXT, (GLuint program, GLenum target, GLuint index, const GLuint * params), (program, target, index, params))
GEN_THUNKS(glNamedProgramLocalParameters4fvEXT, (GLuint program, GLenum target, GLuint index, GLsizei count, const GLfloat * params), (program, target, index, count, params))
GEN_THUNKS(glNamedProgramLocalParametersI4ivEXT, (GLuint program, GLenum target, GLuint index, GLsizei count, const GLint * params), (program, target, index, count, params))
GEN_THUNKS(glNamedProgramLocalParametersI4uivEXT, (GLuint program, GLenum target, GLuint index, GLsizei count, const GLuint * params), (program, target, index, count, params))
GEN_THUNKS(glNamedProgramStringEXT, (GLuint program, GLenum target, GLenum format, GLsizei len, const void * string), (program, target, format, len, string))
GEN_THUNKS(glNamedRenderbufferStorage, (GLuint renderbuffer, GLenum internalformat, GLsizei width, GLsizei height), (renderbuffer, internalformat, width, height))
GEN_THUNKS(glNamedRenderbufferStorageEXT, (GLuint renderbuffer, GLenum internalformat, GLsizei width, GLsizei height), (renderbuffer, internalformat, width, height))
GEN_THUNKS(glNamedRenderbufferStorageMultisample, (GLuint renderbuffer, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height), (renderbuffer, samples, internalformat, width, height))
GEN_THUNKS(glNamedRenderbufferStorageMultisampleAdvancedAMD, (GLuint renderbuffer, GLsizei samples, GLsizei storageSamples, GLenum internalformat, GLsizei width, GLsizei height), (renderbuffer, samples, storageSamples, internalformat, width, height))
GEN_THUNKS(glNamedRenderbufferStorageMultisampleCoverageEXT, (GLuint renderbuffer, GLsizei coverageSamples, GLsizei colorSamples, GLenum internalformat, GLsizei width, GLsizei height), (renderbuffer, coverageSamples, colorSamples, internalformat, width, height))
GEN_THUNKS(glNamedRenderbufferStorageMultisampleEXT, (GLuint renderbuffer, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height), (renderbuffer, samples, internalformat, width, height))
GEN_THUNKS(glNamedStringARB, (GLenum type, GLint namelen, const GLchar * name, GLint stringlen, const GLchar * string), (type, namelen, name, stringlen, string))
GEN_THUNKS(glNewList, (GLuint list, GLenum mode), (list, mode))
GEN_THUNKS_RET(GLuint, glNewObjectBufferATI, (GLsizei size, const void * pointer, GLenum usage), (size, pointer, usage))
GEN_THUNKS(glNormal3b, (GLbyte nx, GLbyte ny, GLbyte nz), (nx, ny, nz))
GEN_THUNKS(glNormal3bv, (const GLbyte * v), (v))
GEN_THUNKS(glNormal3d, (GLdouble nx, GLdouble ny, GLdouble nz), (nx, ny, nz))
GEN_THUNKS(glNormal3dv, (const GLdouble * v), (v))
GEN_THUNKS(glNormal3f, (GLfloat nx, GLfloat ny, GLfloat nz), (nx, ny, nz))
GEN_THUNKS(glNormal3fVertex3fSUN, (GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z), (nx, ny, nz, x, y, z))
GEN_THUNKS(glNormal3fVertex3fvSUN, (const GLfloat * n, const GLfloat * v), (n, v))
GEN_THUNKS(glNormal3fv, (const GLfloat * v), (v))
GEN_THUNKS(glNormal3hNV, (GLhalfNV nx, GLhalfNV ny, GLhalfNV nz), (nx, ny, nz))
GEN_THUNKS(glNormal3hvNV, (const GLhalfNV * v), (v))
GEN_THUNKS(glNormal3i, (GLint nx, GLint ny, GLint nz), (nx, ny, nz))
GEN_THUNKS(glNormal3iv, (const GLint * v), (v))
GEN_THUNKS(glNormal3s, (GLshort nx, GLshort ny, GLshort nz), (nx, ny, nz))
GEN_THUNKS(glNormal3sv, (const GLshort * v), (v))
GEN_THUNKS(glNormal3x, (GLfixed nx, GLfixed ny, GLfixed nz), (nx, ny, nz))
GEN_THUNKS(glNormal3xOES, (GLfixed nx, GLfixed ny, GLfixed nz), (nx, ny, nz))
GEN_THUNKS(glNormal3xvOES, (const GLfixed * coords), (coords))
GEN_THUNKS(glNormalFormatNV, (GLenum type, GLsizei stride), (type, stride))
GEN_THUNKS(glNormalP3ui, (GLenum type, GLuint coords), (type, coords))
GEN_THUNKS(glNormalP3uiv, (GLenum type, const GLuint * coords), (type, coords))
GEN_THUNKS(glNormalPointer, (GLenum type, GLsizei stride, const void * pointer), (type, stride, pointer))
GEN_THUNKS(glNormalPointerEXT, (GLenum type, GLsizei stride, GLsizei count, const void * pointer), (type, stride, count, pointer))
GEN_THUNKS(glNormalPointerListIBM, (GLenum type, GLint stride, const void ** pointer, GLint ptrstride), (type, stride, pointer, ptrstride))
GEN_THUNKS(glNormalPointervINTEL, (GLenum type, const void ** pointer), (type, pointer))
GEN_THUNKS(glNormalStream3bATI, (GLenum stream, GLbyte nx, GLbyte ny, GLbyte nz), (stream, nx, ny, nz))
GEN_THUNKS(glNormalStream3bvATI, (GLenum stream, const GLbyte * coords), (stream, coords))
GEN_THUNKS(glNormalStream3dATI, (GLenum stream, GLdouble nx, GLdouble ny, GLdouble nz), (stream, nx, ny, nz))
GEN_THUNKS(glNormalStream3dvATI, (GLenum stream, const GLdouble * coords), (stream, coords))
GEN_THUNKS(glNormalStream3fATI, (GLenum stream, GLfloat nx, GLfloat ny, GLfloat nz), (stream, nx, ny, nz))
GEN_THUNKS(glNormalStream3fvATI, (GLenum stream, const GLfloat * coords), (stream, coords))
GEN_THUNKS(glNormalStream3iATI, (GLenum stream, GLint nx, GLint ny, GLint nz), (stream, nx, ny, nz))
GEN_THUNKS(glNormalStream3ivATI, (GLenum stream, const GLint * coords), (stream, coords))
GEN_THUNKS(glNormalStream3sATI, (GLenum stream, GLshort nx, GLshort ny, GLshort nz), (stream, nx, ny, nz))
GEN_THUNKS(glNormalStream3svATI, (GLenum stream, const GLshort * coords), (stream, coords))
GEN_THUNKS(glObjectLabel, (GLenum identifier, GLuint name, GLsizei length, const GLchar * label), (identifier, name, length, label))
GEN_THUNKS(glObjectLabelKHR, (GLenum identifier, GLuint name, GLsizei length, const GLchar * label), (identifier, name, length, label))
GEN_THUNKS(glObjectPtrLabel, (const void * ptr, GLsizei length, const GLchar * label), (ptr, length, label))
GEN_THUNKS(glObjectPtrLabelKHR, (const void * ptr, GLsizei length, const GLchar * label), (ptr, length, label))
GEN_THUNKS_RET(GLenum, glObjectPurgeableAPPLE, (GLenum objectType, GLuint name, GLenum option), (objectType, name, option))
GEN_THUNKS_RET(GLenum, glObjectUnpurgeableAPPLE, (GLenum objectType, GLuint name, GLenum option), (objectType, name, option))
GEN_THUNKS(glOrtho, (GLdouble left, GLdouble right, GLdouble bottom, GLdouble top, GLdouble zNear, GLdouble zFar), (left, right, bottom, top, zNear, zFar))
GEN_THUNKS(glOrthof, (GLfloat l, GLfloat r, GLfloat b, GLfloat t, GLfloat n, GLfloat f), (l, r, b, t, n, f))
GEN_THUNKS(glOrthofOES, (GLfloat l, GLfloat r, GLfloat b, GLfloat t, GLfloat n, GLfloat f), (l, r, b, t, n, f))
GEN_THUNKS(glOrthox, (GLfixed l, GLfixed r, GLfixed b, GLfixed t, GLfixed n, GLfixed f), (l, r, b, t, n, f))
GEN_THUNKS(glOrthoxOES, (GLfixed l, GLfixed r, GLfixed b, GLfixed t, GLfixed n, GLfixed f), (l, r, b, t, n, f))
GEN_THUNKS(glPNTrianglesfATI, (GLenum pname, GLfloat param), (pname, param))
GEN_THUNKS(glPNTrianglesiATI, (GLenum pname, GLint param), (pname, param))
GEN_THUNKS(glPassTexCoordATI, (GLuint dst, GLuint coord, GLenum swizzle), (dst, coord, swizzle))
GEN_THUNKS(glPassThrough, (GLfloat token), (token))
GEN_THUNKS(glPassThroughxOES, (GLfixed token), (token))
GEN_THUNKS(glPatchParameterfv, (GLenum pname, const GLfloat * values), (pname, values))
GEN_THUNKS(glPatchParameteri, (GLenum pname, GLint value), (pname, value))
GEN_THUNKS(glPatchParameteriEXT, (GLenum pname, GLint value), (pname, value))
GEN_THUNKS(glPatchParameteriOES, (GLenum pname, GLint value), (pname, value))
GEN_THUNKS(glPathColorGenNV, (GLenum color, GLenum genMode, GLenum colorFormat, const GLfloat * coeffs), (color, genMode, colorFormat, coeffs))
GEN_THUNKS(glPathCommandsNV, (GLuint path, GLsizei numCommands, const GLubyte * commands, GLsizei numCoords, GLenum coordType, const void * coords), (path, numCommands, commands, numCoords, coordType, coords))
GEN_THUNKS(glPathCoordsNV, (GLuint path, GLsizei numCoords, GLenum coordType, const void * coords), (path, numCoords, coordType, coords))
GEN_THUNKS(glPathCoverDepthFuncNV, (GLenum func), (func))
GEN_THUNKS(glPathDashArrayNV, (GLuint path, GLsizei dashCount, const GLfloat * dashArray), (path, dashCount, dashArray))
GEN_THUNKS(glPathFogGenNV, (GLenum genMode), (genMode))
GEN_THUNKS_RET(GLenum, glPathGlyphIndexArrayNV, (GLuint firstPathName, GLenum fontTarget, const void * fontName, GLbitfield fontStyle, GLuint firstGlyphIndex, GLsizei numGlyphs, GLuint pathParameterTemplate, GLfloat emScale), (firstPathName, fontTarget, fontName, fontStyle, firstGlyphIndex, numGlyphs, pathParameterTemplate, emScale))
GEN_THUNKS_RET(GLenum, glPathGlyphIndexRangeNV, (GLenum fontTarget, const void * fontName, GLbitfield fontStyle, GLuint pathParameterTemplate, GLfloat emScale, GLuint baseAndCount), (fontTarget, fontName, fontStyle, pathParameterTemplate, emScale, baseAndCount))
GEN_THUNKS(glPathGlyphRangeNV, (GLuint firstPathName, GLenum fontTarget, const void * fontName, GLbitfield fontStyle, GLuint firstGlyph, GLsizei numGlyphs, GLenum handleMissingGlyphs, GLuint pathParameterTemplate, GLfloat emScale), (firstPathName, fontTarget, fontName, fontStyle, firstGlyph, numGlyphs, handleMissingGlyphs, pathParameterTemplate, emScale))
GEN_THUNKS(glPathGlyphsNV, (GLuint firstPathName, GLenum fontTarget, const void * fontName, GLbitfield fontStyle, GLsizei numGlyphs, GLenum type, const void * charcodes, GLenum handleMissingGlyphs, GLuint pathParameterTemplate, GLfloat emScale), (firstPathName, fontTarget, fontName, fontStyle, numGlyphs, type, charcodes, handleMissingGlyphs, pathParameterTemplate, emScale))
GEN_THUNKS_RET(GLenum, glPathMemoryGlyphIndexArrayNV, (GLuint firstPathName, GLenum fontTarget, GLsizeiptr fontSize, const void * fontData, GLsizei faceIndex, GLuint firstGlyphIndex, GLsizei numGlyphs, GLuint pathParameterTemplate, GLfloat emScale), (firstPathName, fontTarget, fontSize, fontData, faceIndex, firstGlyphIndex, numGlyphs, pathParameterTemplate, emScale))
GEN_THUNKS(glPathParameterfNV, (GLuint path, GLenum pname, GLfloat value), (path, pname, value))
GEN_THUNKS(glPathParameterfvNV, (GLuint path, GLenum pname, const GLfloat * value), (path, pname, value))
GEN_THUNKS(glPathParameteriNV, (GLuint path, GLenum pname, GLint value), (path, pname, value))
GEN_THUNKS(glPathParameterivNV, (GLuint path, GLenum pname, const GLint * value), (path, pname, value))
GEN_THUNKS(glPathStencilDepthOffsetNV, (GLfloat factor, GLfloat units), (factor, units))
GEN_THUNKS(glPathStencilFuncNV, (GLenum func, GLint ref, GLuint mask), (func, ref, mask))
GEN_THUNKS(glPathStringNV, (GLuint path, GLenum format, GLsizei length, const void * pathString), (path, format, length, pathString))
GEN_THUNKS(glPathSubCommandsNV, (GLuint path, GLsizei commandStart, GLsizei commandsToDelete, GLsizei numCommands, const GLubyte * commands, GLsizei numCoords, GLenum coordType, const void * coords), (path, commandStart, commandsToDelete, numCommands, commands, numCoords, coordType, coords))
GEN_THUNKS(glPathSubCoordsNV, (GLuint path, GLsizei coordStart, GLsizei numCoords, GLenum coordType, const void * coords), (path, coordStart, numCoords, coordType, coords))
GEN_THUNKS(glPathTexGenNV, (GLenum texCoordSet, GLenum genMode, GLint components, const GLfloat * coeffs), (texCoordSet, genMode, components, coeffs))
GEN_THUNKS(glPauseTransformFeedback, (void), ())
GEN_THUNKS(glPauseTransformFeedbackNV, (void), ())
GEN_THUNKS(glPixelDataRangeNV, (GLenum target, GLsizei length, const void * pointer), (target, length, pointer))
GEN_THUNKS(glPixelMapfv, (GLenum map, GLsizei mapsize, const GLfloat * values), (map, mapsize, values))
GEN_THUNKS(glPixelMapuiv, (GLenum map, GLsizei mapsize, const GLuint * values), (map, mapsize, values))
GEN_THUNKS(glPixelMapusv, (GLenum map, GLsizei mapsize, const GLushort * values), (map, mapsize, values))
GEN_THUNKS(glPixelMapx, (GLenum map, GLint size, const GLfixed * values), (map, size, values))
GEN_THUNKS(glPixelStoref, (GLenum pname, GLfloat param), (pname, param))
GEN_THUNKS(glPixelStorei, (GLenum pname, GLint param), (pname, param))
GEN_THUNKS(glPixelStorex, (GLenum pname, GLfixed param), (pname, param))
GEN_THUNKS(glPixelTexGenParameterfSGIS, (GLenum pname, GLfloat param), (pname, param))
GEN_THUNKS(glPixelTexGenParameterfvSGIS, (GLenum pname, const GLfloat * params), (pname, params))
GEN_THUNKS(glPixelTexGenParameteriSGIS, (GLenum pname, GLint param), (pname, param))
GEN_THUNKS(glPixelTexGenParameterivSGIS, (GLenum pname, const GLint * params), (pname, params))
GEN_THUNKS(glPixelTexGenSGIX, (GLenum mode), (mode))
GEN_THUNKS(glPixelTransferf, (GLenum pname, GLfloat param), (pname, param))
GEN_THUNKS(glPixelTransferi, (GLenum pname, GLint param), (pname, param))
GEN_THUNKS(glPixelTransferxOES, (GLenum pname, GLfixed param), (pname, param))
GEN_THUNKS(glPixelTransformParameterfEXT, (GLenum target, GLenum pname, GLfloat param), (target, pname, param))
GEN_THUNKS(glPixelTransformParameterfvEXT, (GLenum target, GLenum pname, const GLfloat * params), (target, pname, params))
GEN_THUNKS(glPixelTransformParameteriEXT, (GLenum target, GLenum pname, GLint param), (target, pname, param))
GEN_THUNKS(glPixelTransformParameterivEXT, (GLenum target, GLenum pname, const GLint * params), (target, pname, params))
GEN_THUNKS(glPixelZoom, (GLfloat xfactor, GLfloat yfactor), (xfactor, yfactor))
GEN_THUNKS(glPixelZoomxOES, (GLfixed xfactor, GLfixed yfactor), (xfactor, yfactor))
GEN_THUNKS_RET(GLboolean, glPointAlongPathNV, (GLuint path, GLsizei startSegment, GLsizei numSegments, GLfloat distance, GLfloat * x, GLfloat * y, GLfloat * tangentX, GLfloat * tangentY), (path, startSegment, numSegments, distance, x, y, tangentX, tangentY))
GEN_THUNKS(glPointParameterf, (GLenum pname, GLfloat param), (pname, param))
GEN_THUNKS(glPointParameterfARB, (GLenum pname, GLfloat param), (pname, param))
GEN_THUNKS(glPointParameterfEXT, (GLenum pname, GLfloat param), (pname, param))
GEN_THUNKS(glPointParameterfSGIS, (GLenum pname, GLfloat param), (pname, param))
GEN_THUNKS(glPointParameterfv, (GLenum pname, const GLfloat * params), (pname, params))
GEN_THUNKS(glPointParameterfvARB, (GLenum pname, const GLfloat * params), (pname, params))
GEN_THUNKS(glPointParameterfvEXT, (GLenum pname, const GLfloat * params), (pname, params))
GEN_THUNKS(glPointParameterfvSGIS, (GLenum pname, const GLfloat * params), (pname, params))
GEN_THUNKS(glPointParameteri, (GLenum pname, GLint param), (pname, param))
GEN_THUNKS(glPointParameteriNV, (GLenum pname, GLint param), (pname, param))
GEN_THUNKS(glPointParameteriv, (GLenum pname, const GLint * params), (pname, params))
GEN_THUNKS(glPointParameterivNV, (GLenum pname, const GLint * params), (pname, params))
GEN_THUNKS(glPointParameterx, (GLenum pname, GLfixed param), (pname, param))
GEN_THUNKS(glPointParameterxOES, (GLenum pname, GLfixed param), (pname, param))
GEN_THUNKS(glPointParameterxv, (GLenum pname, const GLfixed * params), (pname, params))
GEN_THUNKS(glPointParameterxvOES, (GLenum pname, const GLfixed * params), (pname, params))
GEN_THUNKS(glPointSize, (GLfloat size), (size))
GEN_THUNKS(glPointSizePointerOES, (GLenum type, GLsizei stride, const void * pointer), (type, stride, pointer))
GEN_THUNKS(glPointSizex, (GLfixed size), (size))
GEN_THUNKS(glPointSizexOES, (GLfixed size), (size))
GEN_THUNKS_RET(GLint, glPollAsyncSGIX, (GLuint * markerp), (markerp))
GEN_THUNKS_RET(GLint, glPollInstrumentsSGIX, (GLint * marker_p), (marker_p))
GEN_THUNKS(glPolygonMode, (GLenum face, GLenum mode), (face, mode))
GEN_THUNKS(glPolygonModeNV, (GLenum face, GLenum mode), (face, mode))
GEN_THUNKS(glPolygonOffset, (GLfloat factor, GLfloat units), (factor, units))
GEN_THUNKS(glPolygonOffsetClamp, (GLfloat factor, GLfloat units, GLfloat clamp), (factor, units, clamp))
GEN_THUNKS(glPolygonOffsetClampEXT, (GLfloat factor, GLfloat units, GLfloat clamp), (factor, units, clamp))
GEN_THUNKS(glPolygonOffsetEXT, (GLfloat factor, GLfloat bias), (factor, bias))
GEN_THUNKS(glPolygonOffsetx, (GLfixed factor, GLfixed units), (factor, units))
GEN_THUNKS(glPolygonOffsetxOES, (GLfixed factor, GLfixed units), (factor, units))
GEN_THUNKS(glPolygonStipple, (const GLubyte * mask), (mask))
GEN_THUNKS(glPopAttrib, (void), ())
GEN_THUNKS(glPopClientAttrib, (void), ())
GEN_THUNKS(glPopDebugGroup, (void), ())
GEN_THUNKS(glPopDebugGroupKHR, (void), ())
GEN_THUNKS(glPopGroupMarkerEXT, (void), ())
GEN_THUNKS(glPopMatrix, (void), ())
GEN_THUNKS(glPopName, (void), ())
GEN_THUNKS(glPresentFrameDualFillNV, (GLuint video_slot, GLuint64EXT minPresentTime, GLuint beginPresentTimeId, GLuint presentDurationId, GLenum type, GLenum target0, GLuint fill0, GLenum target1, GLuint fill1, GLenum target2, GLuint fill2, GLenum target3, GLuint fill3), (video_slot, minPresentTime, beginPresentTimeId, presentDurationId, type, target0, fill0, target1, fill1, target2, fill2, target3, fill3))
GEN_THUNKS(glPresentFrameKeyedNV, (GLuint video_slot, GLuint64EXT minPresentTime, GLuint beginPresentTimeId, GLuint presentDurationId, GLenum type, GLenum target0, GLuint fill0, GLuint key0, GLenum target1, GLuint fill1, GLuint key1), (video_slot, minPresentTime, beginPresentTimeId, presentDurationId, type, target0, fill0, key0, target1, fill1, key1))
GEN_THUNKS(glPrimitiveBoundingBox, (GLfloat minX, GLfloat minY, GLfloat minZ, GLfloat minW, GLfloat maxX, GLfloat maxY, GLfloat maxZ, GLfloat maxW), (minX, minY, minZ, minW, maxX, maxY, maxZ, maxW))
GEN_THUNKS(glPrimitiveBoundingBoxARB, (GLfloat minX, GLfloat minY, GLfloat minZ, GLfloat minW, GLfloat maxX, GLfloat maxY, GLfloat maxZ, GLfloat maxW), (minX, minY, minZ, minW, maxX, maxY, maxZ, maxW))
GEN_THUNKS(glPrimitiveBoundingBoxEXT, (GLfloat minX, GLfloat minY, GLfloat minZ, GLfloat minW, GLfloat maxX, GLfloat maxY, GLfloat maxZ, GLfloat maxW), (minX, minY, minZ, minW, maxX, maxY, maxZ, maxW))
GEN_THUNKS(glPrimitiveBoundingBoxOES, (GLfloat minX, GLfloat minY, GLfloat minZ, GLfloat minW, GLfloat maxX, GLfloat maxY, GLfloat maxZ, GLfloat maxW), (minX, minY, minZ, minW, maxX, maxY, maxZ, maxW))
GEN_THUNKS(glPrimitiveRestartIndex, (GLuint index), (index))
GEN_THUNKS(glPrimitiveRestartIndexNV, (GLuint index), (index))
GEN_THUNKS(glPrimitiveRestartNV, (void), ())
GEN_THUNKS(glPrioritizeTextures, (GLsizei n, const GLuint * textures, const GLfloat * priorities), (n, textures, priorities))
GEN_THUNKS(glPrioritizeTexturesEXT, (GLsizei n, const GLuint * textures, const GLclampf * priorities), (n, textures, priorities))
GEN_THUNKS(glPrioritizeTexturesxOES, (GLsizei n, const GLuint * textures, const GLfixed * priorities), (n, textures, priorities))
GEN_THUNKS(glProgramBinary, (GLuint program, GLenum binaryFormat, const void * binary, GLsizei length), (program, binaryFormat, binary, length))
GEN_THUNKS(glProgramBinaryOES, (GLuint program, GLenum binaryFormat, const void * binary, GLint length), (program, binaryFormat, binary, length))
GEN_THUNKS(glProgramBufferParametersIivNV, (GLenum target, GLuint bindingIndex, GLuint wordIndex, GLsizei count, const GLint * params), (target, bindingIndex, wordIndex, count, params))
GEN_THUNKS(glProgramBufferParametersIuivNV, (GLenum target, GLuint bindingIndex, GLuint wordIndex, GLsizei count, const GLuint * params), (target, bindingIndex, wordIndex, count, params))
GEN_THUNKS(glProgramBufferParametersfvNV, (GLenum target, GLuint bindingIndex, GLuint wordIndex, GLsizei count, const GLfloat * params), (target, bindingIndex, wordIndex, count, params))
GEN_THUNKS(glProgramEnvParameter4dARB, (GLenum target, GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w), (target, index, x, y, z, w))
GEN_THUNKS(glProgramEnvParameter4dvARB, (GLenum target, GLuint index, const GLdouble * params), (target, index, params))
GEN_THUNKS(glProgramEnvParameter4fARB, (GLenum target, GLuint index, GLfloat x, GLfloat y, GLfloat z, GLfloat w), (target, index, x, y, z, w))
GEN_THUNKS(glProgramEnvParameter4fvARB, (GLenum target, GLuint index, const GLfloat * params), (target, index, params))
GEN_THUNKS(glProgramEnvParameterI4iNV, (GLenum target, GLuint index, GLint x, GLint y, GLint z, GLint w), (target, index, x, y, z, w))
GEN_THUNKS(glProgramEnvParameterI4ivNV, (GLenum target, GLuint index, const GLint * params), (target, index, params))
GEN_THUNKS(glProgramEnvParameterI4uiNV, (GLenum target, GLuint index, GLuint x, GLuint y, GLuint z, GLuint w), (target, index, x, y, z, w))
GEN_THUNKS(glProgramEnvParameterI4uivNV, (GLenum target, GLuint index, const GLuint * params), (target, index, params))
GEN_THUNKS(glProgramEnvParameters4fvEXT, (GLenum target, GLuint index, GLsizei count, const GLfloat * params), (target, index, count, params))
GEN_THUNKS(glProgramEnvParametersI4ivNV, (GLenum target, GLuint index, GLsizei count, const GLint * params), (target, index, count, params))
GEN_THUNKS(glProgramEnvParametersI4uivNV, (GLenum target, GLuint index, GLsizei count, const GLuint * params), (target, index, count, params))
GEN_THUNKS(glProgramLocalParameter4dARB, (GLenum target, GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w), (target, index, x, y, z, w))
GEN_THUNKS(glProgramLocalParameter4dvARB, (GLenum target, GLuint index, const GLdouble * params), (target, index, params))
GEN_THUNKS(glProgramLocalParameter4fARB, (GLenum target, GLuint index, GLfloat x, GLfloat y, GLfloat z, GLfloat w), (target, index, x, y, z, w))
GEN_THUNKS(glProgramLocalParameter4fvARB, (GLenum target, GLuint index, const GLfloat * params), (target, index, params))
GEN_THUNKS(glProgramLocalParameterI4iNV, (GLenum target, GLuint index, GLint x, GLint y, GLint z, GLint w), (target, index, x, y, z, w))
GEN_THUNKS(glProgramLocalParameterI4ivNV, (GLenum target, GLuint index, const GLint * params), (target, index, params))
GEN_THUNKS(glProgramLocalParameterI4uiNV, (GLenum target, GLuint index, GLuint x, GLuint y, GLuint z, GLuint w), (target, index, x, y, z, w))
GEN_THUNKS(glProgramLocalParameterI4uivNV, (GLenum target, GLuint index, const GLuint * params), (target, index, params))
GEN_THUNKS(glProgramLocalParameters4fvEXT, (GLenum target, GLuint index, GLsizei count, const GLfloat * params), (target, index, count, params))
GEN_THUNKS(glProgramLocalParametersI4ivNV, (GLenum target, GLuint index, GLsizei count, const GLint * params), (target, index, count, params))
GEN_THUNKS(glProgramLocalParametersI4uivNV, (GLenum target, GLuint index, GLsizei count, const GLuint * params), (target, index, count, params))
GEN_THUNKS(glProgramNamedParameter4dNV, (GLuint id, GLsizei len, const GLubyte * name, GLdouble x, GLdouble y, GLdouble z, GLdouble w), (id, len, name, x, y, z, w))
GEN_THUNKS(glProgramNamedParameter4dvNV, (GLuint id, GLsizei len, const GLubyte * name, const GLdouble * v), (id, len, name, v))
GEN_THUNKS(glProgramNamedParameter4fNV, (GLuint id, GLsizei len, const GLubyte * name, GLfloat x, GLfloat y, GLfloat z, GLfloat w), (id, len, name, x, y, z, w))
GEN_THUNKS(glProgramNamedParameter4fvNV, (GLuint id, GLsizei len, const GLubyte * name, const GLfloat * v), (id, len, name, v))
GEN_THUNKS(glProgramParameter4dNV, (GLenum target, GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w), (target, index, x, y, z, w))
GEN_THUNKS(glProgramParameter4dvNV, (GLenum target, GLuint index, const GLdouble * v), (target, index, v))
GEN_THUNKS(glProgramParameter4fNV, (GLenum target, GLuint index, GLfloat x, GLfloat y, GLfloat z, GLfloat w), (target, index, x, y, z, w))
GEN_THUNKS(glProgramParameter4fvNV, (GLenum target, GLuint index, const GLfloat * v), (target, index, v))
GEN_THUNKS(glProgramParameteri, (GLuint program, GLenum pname, GLint value), (program, pname, value))
GEN_THUNKS(glProgramParameteriARB, (GLuint program, GLenum pname, GLint value), (program, pname, value))
GEN_THUNKS(glProgramParameteriEXT, (GLuint program, GLenum pname, GLint value), (program, pname, value))
GEN_THUNKS(glProgramParameters4dvNV, (GLenum target, GLuint index, GLsizei count, const GLdouble * v), (target, index, count, v))
GEN_THUNKS(glProgramParameters4fvNV, (GLenum target, GLuint index, GLsizei count, const GLfloat * v), (target, index, count, v))
GEN_THUNKS(glProgramPathFragmentInputGenNV, (GLuint program, GLint location, GLenum genMode, GLint components, const GLfloat * coeffs), (program, location, genMode, components, coeffs))
GEN_THUNKS(glProgramStringARB, (GLenum target, GLenum format, GLsizei len, const void * string), (target, format, len, string))
GEN_THUNKS(glProgramSubroutineParametersuivNV, (GLenum target, GLsizei count, const GLuint * params), (target, count, params))
GEN_THUNKS(glProgramUniform1d, (GLuint program, GLint location, GLdouble v0), (program, location, v0))
GEN_THUNKS(glProgramUniform1dEXT, (GLuint program, GLint location, GLdouble x), (program, location, x))
GEN_THUNKS(glProgramUniform1dv, (GLuint program, GLint location, GLsizei count, const GLdouble * value), (program, location, count, value))
GEN_THUNKS(glProgramUniform1dvEXT, (GLuint program, GLint location, GLsizei count, const GLdouble * value), (program, location, count, value))
GEN_THUNKS(glProgramUniform1f, (GLuint program, GLint location, GLfloat v0), (program, location, v0))
GEN_THUNKS(glProgramUniform1fEXT, (GLuint program, GLint location, GLfloat v0), (program, location, v0))
GEN_THUNKS(glProgramUniform1fv, (GLuint program, GLint location, GLsizei count, const GLfloat * value), (program, location, count, value))
GEN_THUNKS(glProgramUniform1fvEXT, (GLuint program, GLint location, GLsizei count, const GLfloat * value), (program, location, count, value))
GEN_THUNKS(glProgramUniform1i, (GLuint program, GLint location, GLint v0), (program, location, v0))
GEN_THUNKS(glProgramUniform1i64ARB, (GLuint program, GLint location, GLint64 x), (program, location, x))
GEN_THUNKS(glProgramUniform1i64NV, (GLuint program, GLint location, GLint64EXT x), (program, location, x))
GEN_THUNKS(glProgramUniform1i64vARB, (GLuint program, GLint location, GLsizei count, const GLint64 * value), (program, location, count, value))
GEN_THUNKS(glProgramUniform1i64vNV, (GLuint program, GLint location, GLsizei count, const GLint64EXT * value), (program, location, count, value))
GEN_THUNKS(glProgramUniform1iEXT, (GLuint program, GLint location, GLint v0), (program, location, v0))
GEN_THUNKS(glProgramUniform1iv, (GLuint program, GLint location, GLsizei count, const GLint * value), (program, location, count, value))
GEN_THUNKS(glProgramUniform1ivEXT, (GLuint program, GLint location, GLsizei count, const GLint * value), (program, location, count, value))
GEN_THUNKS(glProgramUniform1ui, (GLuint program, GLint location, GLuint v0), (program, location, v0))
GEN_THUNKS(glProgramUniform1ui64ARB, (GLuint program, GLint location, GLuint64 x), (program, location, x))
GEN_THUNKS(glProgramUniform1ui64NV, (GLuint program, GLint location, GLuint64EXT x), (program, location, x))
GEN_THUNKS(glProgramUniform1ui64vARB, (GLuint program, GLint location, GLsizei count, const GLuint64 * value), (program, location, count, value))
GEN_THUNKS(glProgramUniform1ui64vNV, (GLuint program, GLint location, GLsizei count, const GLuint64EXT * value), (program, location, count, value))
GEN_THUNKS(glProgramUniform1uiEXT, (GLuint program, GLint location, GLuint v0), (program, location, v0))
GEN_THUNKS(glProgramUniform1uiv, (GLuint program, GLint location, GLsizei count, const GLuint * value), (program, location, count, value))
GEN_THUNKS(glProgramUniform1uivEXT, (GLuint program, GLint location, GLsizei count, const GLuint * value), (program, location, count, value))
GEN_THUNKS(glProgramUniform2d, (GLuint program, GLint location, GLdouble v0, GLdouble v1), (program, location, v0, v1))
GEN_THUNKS(glProgramUniform2dEXT, (GLuint program, GLint location, GLdouble x, GLdouble y), (program, location, x, y))
GEN_THUNKS(glProgramUniform2dv, (GLuint program, GLint location, GLsizei count, const GLdouble * value), (program, location, count, value))
GEN_THUNKS(glProgramUniform2dvEXT, (GLuint program, GLint location, GLsizei count, const GLdouble * value), (program, location, count, value))
GEN_THUNKS(glProgramUniform2f, (GLuint program, GLint location, GLfloat v0, GLfloat v1), (program, location, v0, v1))
GEN_THUNKS(glProgramUniform2fEXT, (GLuint program, GLint location, GLfloat v0, GLfloat v1), (program, location, v0, v1))
GEN_THUNKS(glProgramUniform2fv, (GLuint program, GLint location, GLsizei count, const GLfloat * value), (program, location, count, value))
GEN_THUNKS(glProgramUniform2fvEXT, (GLuint program, GLint location, GLsizei count, const GLfloat * value), (program, location, count, value))
GEN_THUNKS(glProgramUniform2i, (GLuint program, GLint location, GLint v0, GLint v1), (program, location, v0, v1))
GEN_THUNKS(glProgramUniform2i64ARB, (GLuint program, GLint location, GLint64 x, GLint64 y), (program, location, x, y))
GEN_THUNKS(glProgramUniform2i64NV, (GLuint program, GLint location, GLint64EXT x, GLint64EXT y), (program, location, x, y))
GEN_THUNKS(glProgramUniform2i64vARB, (GLuint program, GLint location, GLsizei count, const GLint64 * value), (program, location, count, value))
GEN_THUNKS(glProgramUniform2i64vNV, (GLuint program, GLint location, GLsizei count, const GLint64EXT * value), (program, location, count, value))
GEN_THUNKS(glProgramUniform2iEXT, (GLuint program, GLint location, GLint v0, GLint v1), (program, location, v0, v1))
GEN_THUNKS(glProgramUniform2iv, (GLuint program, GLint location, GLsizei count, const GLint * value), (program, location, count, value))
GEN_THUNKS(glProgramUniform2ivEXT, (GLuint program, GLint location, GLsizei count, const GLint * value), (program, location, count, value))
GEN_THUNKS(glProgramUniform2ui, (GLuint program, GLint location, GLuint v0, GLuint v1), (program, location, v0, v1))
GEN_THUNKS(glProgramUniform2ui64ARB, (GLuint program, GLint location, GLuint64 x, GLuint64 y), (program, location, x, y))
GEN_THUNKS(glProgramUniform2ui64NV, (GLuint program, GLint location, GLuint64EXT x, GLuint64EXT y), (program, location, x, y))
GEN_THUNKS(glProgramUniform2ui64vARB, (GLuint program, GLint location, GLsizei count, const GLuint64 * value), (program, location, count, value))
GEN_THUNKS(glProgramUniform2ui64vNV, (GLuint program, GLint location, GLsizei count, const GLuint64EXT * value), (program, location, count, value))
GEN_THUNKS(glProgramUniform2uiEXT, (GLuint program, GLint location, GLuint v0, GLuint v1), (program, location, v0, v1))
GEN_THUNKS(glProgramUniform2uiv, (GLuint program, GLint location, GLsizei count, const GLuint * value), (program, location, count, value))
GEN_THUNKS(glProgramUniform2uivEXT, (GLuint program, GLint location, GLsizei count, const GLuint * value), (program, location, count, value))
GEN_THUNKS(glProgramUniform3d, (GLuint program, GLint location, GLdouble v0, GLdouble v1, GLdouble v2), (program, location, v0, v1, v2))
GEN_THUNKS(glProgramUniform3dEXT, (GLuint program, GLint location, GLdouble x, GLdouble y, GLdouble z), (program, location, x, y, z))
GEN_THUNKS(glProgramUniform3dv, (GLuint program, GLint location, GLsizei count, const GLdouble * value), (program, location, count, value))
GEN_THUNKS(glProgramUniform3dvEXT, (GLuint program, GLint location, GLsizei count, const GLdouble * value), (program, location, count, value))
GEN_THUNKS(glProgramUniform3f, (GLuint program, GLint location, GLfloat v0, GLfloat v1, GLfloat v2), (program, location, v0, v1, v2))
GEN_THUNKS(glProgramUniform3fEXT, (GLuint program, GLint location, GLfloat v0, GLfloat v1, GLfloat v2), (program, location, v0, v1, v2))
GEN_THUNKS(glProgramUniform3fv, (GLuint program, GLint location, GLsizei count, const GLfloat * value), (program, location, count, value))
GEN_THUNKS(glProgramUniform3fvEXT, (GLuint program, GLint location, GLsizei count, const GLfloat * value), (program, location, count, value))
GEN_THUNKS(glProgramUniform3i, (GLuint program, GLint location, GLint v0, GLint v1, GLint v2), (program, location, v0, v1, v2))
GEN_THUNKS(glProgramUniform3i64ARB, (GLuint program, GLint location, GLint64 x, GLint64 y, GLint64 z), (program, location, x, y, z))
GEN_THUNKS(glProgramUniform3i64NV, (GLuint program, GLint location, GLint64EXT x, GLint64EXT y, GLint64EXT z), (program, location, x, y, z))
GEN_THUNKS(glProgramUniform3i64vARB, (GLuint program, GLint location, GLsizei count, const GLint64 * value), (program, location, count, value))
GEN_THUNKS(glProgramUniform3i64vNV, (GLuint program, GLint location, GLsizei count, const GLint64EXT * value), (program, location, count, value))
GEN_THUNKS(glProgramUniform3iEXT, (GLuint program, GLint location, GLint v0, GLint v1, GLint v2), (program, location, v0, v1, v2))
GEN_THUNKS(glProgramUniform3iv, (GLuint program, GLint location, GLsizei count, const GLint * value), (program, location, count, value))
GEN_THUNKS(glProgramUniform3ivEXT, (GLuint program, GLint location, GLsizei count, const GLint * value), (program, location, count, value))
GEN_THUNKS(glProgramUniform3ui, (GLuint program, GLint location, GLuint v0, GLuint v1, GLuint v2), (program, location, v0, v1, v2))
GEN_THUNKS(glProgramUniform3ui64ARB, (GLuint program, GLint location, GLuint64 x, GLuint64 y, GLuint64 z), (program, location, x, y, z))
GEN_THUNKS(glProgramUniform3ui64NV, (GLuint program, GLint location, GLuint64EXT x, GLuint64EXT y, GLuint64EXT z), (program, location, x, y, z))
GEN_THUNKS(glProgramUniform3ui64vARB, (GLuint program, GLint location, GLsizei count, const GLuint64 * value), (program, location, count, value))
GEN_THUNKS(glProgramUniform3ui64vNV, (GLuint program, GLint location, GLsizei count, const GLuint64EXT * value), (program, location, count, value))
GEN_THUNKS(glProgramUniform3uiEXT, (GLuint program, GLint location, GLuint v0, GLuint v1, GLuint v2), (program, location, v0, v1, v2))
GEN_THUNKS(glProgramUniform3uiv, (GLuint program, GLint location, GLsizei count, const GLuint * value), (program, location, count, value))
GEN_THUNKS(glProgramUniform3uivEXT, (GLuint program, GLint location, GLsizei count, const GLuint * value), (program, location, count, value))
GEN_THUNKS(glProgramUniform4d, (GLuint program, GLint location, GLdouble v0, GLdouble v1, GLdouble v2, GLdouble v3), (program, location, v0, v1, v2, v3))
GEN_THUNKS(glProgramUniform4dEXT, (GLuint program, GLint location, GLdouble x, GLdouble y, GLdouble z, GLdouble w), (program, location, x, y, z, w))
GEN_THUNKS(glProgramUniform4dv, (GLuint program, GLint location, GLsizei count, const GLdouble * value), (program, location, count, value))
GEN_THUNKS(glProgramUniform4dvEXT, (GLuint program, GLint location, GLsizei count, const GLdouble * value), (program, location, count, value))
GEN_THUNKS(glProgramUniform4f, (GLuint program, GLint location, GLfloat v0, GLfloat v1, GLfloat v2, GLfloat v3), (program, location, v0, v1, v2, v3))
GEN_THUNKS(glProgramUniform4fEXT, (GLuint program, GLint location, GLfloat v0, GLfloat v1, GLfloat v2, GLfloat v3), (program, location, v0, v1, v2, v3))
GEN_THUNKS(glProgramUniform4fv, (GLuint program, GLint location, GLsizei count, const GLfloat * value), (program, location, count, value))
GEN_THUNKS(glProgramUniform4fvEXT, (GLuint program, GLint location, GLsizei count, const GLfloat * value), (program, location, count, value))
GEN_THUNKS(glProgramUniform4i, (GLuint program, GLint location, GLint v0, GLint v1, GLint v2, GLint v3), (program, location, v0, v1, v2, v3))
GEN_THUNKS(glProgramUniform4i64ARB, (GLuint program, GLint location, GLint64 x, GLint64 y, GLint64 z, GLint64 w), (program, location, x, y, z, w))
GEN_THUNKS(glProgramUniform4i64NV, (GLuint program, GLint location, GLint64EXT x, GLint64EXT y, GLint64EXT z, GLint64EXT w), (program, location, x, y, z, w))
GEN_THUNKS(glProgramUniform4i64vARB, (GLuint program, GLint location, GLsizei count, const GLint64 * value), (program, location, count, value))
GEN_THUNKS(glProgramUniform4i64vNV, (GLuint program, GLint location, GLsizei count, const GLint64EXT * value), (program, location, count, value))
GEN_THUNKS(glProgramUniform4iEXT, (GLuint program, GLint location, GLint v0, GLint v1, GLint v2, GLint v3), (program, location, v0, v1, v2, v3))
GEN_THUNKS(glProgramUniform4iv, (GLuint program, GLint location, GLsizei count, const GLint * value), (program, location, count, value))
GEN_THUNKS(glProgramUniform4ivEXT, (GLuint program, GLint location, GLsizei count, const GLint * value), (program, location, count, value))
GEN_THUNKS(glProgramUniform4ui, (GLuint program, GLint location, GLuint v0, GLuint v1, GLuint v2, GLuint v3), (program, location, v0, v1, v2, v3))
GEN_THUNKS(glProgramUniform4ui64ARB, (GLuint program, GLint location, GLuint64 x, GLuint64 y, GLuint64 z, GLuint64 w), (program, location, x, y, z, w))
GEN_THUNKS(glProgramUniform4ui64NV, (GLuint program, GLint location, GLuint64EXT x, GLuint64EXT y, GLuint64EXT z, GLuint64EXT w), (program, location, x, y, z, w))
GEN_THUNKS(glProgramUniform4ui64vARB, (GLuint program, GLint location, GLsizei count, const GLuint64 * value), (program, location, count, value))
GEN_THUNKS(glProgramUniform4ui64vNV, (GLuint program, GLint location, GLsizei count, const GLuint64EXT * value), (program, location, count, value))
GEN_THUNKS(glProgramUniform4uiEXT, (GLuint program, GLint location, GLuint v0, GLuint v1, GLuint v2, GLuint v3), (program, location, v0, v1, v2, v3))
GEN_THUNKS(glProgramUniform4uiv, (GLuint program, GLint location, GLsizei count, const GLuint * value), (program, location, count, value))
GEN_THUNKS(glProgramUniform4uivEXT, (GLuint program, GLint location, GLsizei count, const GLuint * value), (program, location, count, value))
GEN_THUNKS(glProgramUniformHandleui64ARB, (GLuint program, GLint location, GLuint64 value), (program, location, value))
GEN_THUNKS(glProgramUniformHandleui64IMG, (GLuint program, GLint location, GLuint64 value), (program, location, value))
GEN_THUNKS(glProgramUniformHandleui64NV, (GLuint program, GLint location, GLuint64 value), (program, location, value))
GEN_THUNKS(glProgramUniformHandleui64vARB, (GLuint program, GLint location, GLsizei count, const GLuint64 * values), (program, location, count, values))
GEN_THUNKS(glProgramUniformHandleui64vIMG, (GLuint program, GLint location, GLsizei count, const GLuint64 * values), (program, location, count, values))
GEN_THUNKS(glProgramUniformHandleui64vNV, (GLuint program, GLint location, GLsizei count, const GLuint64 * values), (program, location, count, values))
GEN_THUNKS(glProgramUniformMatrix2dv, (GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble * value), (program, location, count, transpose, value))
GEN_THUNKS(glProgramUniformMatrix2dvEXT, (GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble * value), (program, location, count, transpose, value))
GEN_THUNKS(glProgramUniformMatrix2fv, (GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat * value), (program, location, count, transpose, value))
GEN_THUNKS(glProgramUniformMatrix2fvEXT, (GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat * value), (program, location, count, transpose, value))
GEN_THUNKS(glProgramUniformMatrix2x3dv, (GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble * value), (program, location, count, transpose, value))
GEN_THUNKS(glProgramUniformMatrix2x3dvEXT, (GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble * value), (program, location, count, transpose, value))
GEN_THUNKS(glProgramUniformMatrix2x3fv, (GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat * value), (program, location, count, transpose, value))
GEN_THUNKS(glProgramUniformMatrix2x3fvEXT, (GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat * value), (program, location, count, transpose, value))
GEN_THUNKS(glProgramUniformMatrix2x4dv, (GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble * value), (program, location, count, transpose, value))
GEN_THUNKS(glProgramUniformMatrix2x4dvEXT, (GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble * value), (program, location, count, transpose, value))
GEN_THUNKS(glProgramUniformMatrix2x4fv, (GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat * value), (program, location, count, transpose, value))
GEN_THUNKS(glProgramUniformMatrix2x4fvEXT, (GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat * value), (program, location, count, transpose, value))
GEN_THUNKS(glProgramUniformMatrix3dv, (GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble * value), (program, location, count, transpose, value))
GEN_THUNKS(glProgramUniformMatrix3dvEXT, (GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble * value), (program, location, count, transpose, value))
GEN_THUNKS(glProgramUniformMatrix3fv, (GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat * value), (program, location, count, transpose, value))
GEN_THUNKS(glProgramUniformMatrix3fvEXT, (GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat * value), (program, location, count, transpose, value))
GEN_THUNKS(glProgramUniformMatrix3x2dv, (GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble * value), (program, location, count, transpose, value))
GEN_THUNKS(glProgramUniformMatrix3x2dvEXT, (GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble * value), (program, location, count, transpose, value))
GEN_THUNKS(glProgramUniformMatrix3x2fv, (GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat * value), (program, location, count, transpose, value))
GEN_THUNKS(glProgramUniformMatrix3x2fvEXT, (GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat * value), (program, location, count, transpose, value))
GEN_THUNKS(glProgramUniformMatrix3x4dv, (GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble * value), (program, location, count, transpose, value))
GEN_THUNKS(glProgramUniformMatrix3x4dvEXT, (GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble * value), (program, location, count, transpose, value))
GEN_THUNKS(glProgramUniformMatrix3x4fv, (GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat * value), (program, location, count, transpose, value))
GEN_THUNKS(glProgramUniformMatrix3x4fvEXT, (GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat * value), (program, location, count, transpose, value))
GEN_THUNKS(glProgramUniformMatrix4dv, (GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble * value), (program, location, count, transpose, value))
GEN_THUNKS(glProgramUniformMatrix4dvEXT, (GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble * value), (program, location, count, transpose, value))
GEN_THUNKS(glProgramUniformMatrix4fv, (GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat * value), (program, location, count, transpose, value))
GEN_THUNKS(glProgramUniformMatrix4fvEXT, (GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat * value), (program, location, count, transpose, value))
GEN_THUNKS(glProgramUniformMatrix4x2dv, (GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble * value), (program, location, count, transpose, value))
GEN_THUNKS(glProgramUniformMatrix4x2dvEXT, (GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble * value), (program, location, count, transpose, value))
GEN_THUNKS(glProgramUniformMatrix4x2fv, (GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat * value), (program, location, count, transpose, value))
GEN_THUNKS(glProgramUniformMatrix4x2fvEXT, (GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat * value), (program, location, count, transpose, value))
GEN_THUNKS(glProgramUniformMatrix4x3dv, (GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble * value), (program, location, count, transpose, value))
GEN_THUNKS(glProgramUniformMatrix4x3dvEXT, (GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble * value), (program, location, count, transpose, value))
GEN_THUNKS(glProgramUniformMatrix4x3fv, (GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat * value), (program, location, count, transpose, value))
GEN_THUNKS(glProgramUniformMatrix4x3fvEXT, (GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat * value), (program, location, count, transpose, value))
GEN_THUNKS(glProgramUniformui64NV, (GLuint program, GLint location, GLuint64EXT value), (program, location, value))
GEN_THUNKS(glProgramUniformui64vNV, (GLuint program, GLint location, GLsizei count, const GLuint64EXT * value), (program, location, count, value))
GEN_THUNKS(glProgramVertexLimitNV, (GLenum target, GLint limit), (target, limit))
GEN_THUNKS(glProvokingVertex, (GLenum mode), (mode))
GEN_THUNKS(glProvokingVertexEXT, (GLenum mode), (mode))
GEN_THUNKS(glPushAttrib, (GLbitfield mask), (mask))
GEN_THUNKS(glPushClientAttrib, (GLbitfield mask), (mask))
GEN_THUNKS(glPushClientAttribDefaultEXT, (GLbitfield mask), (mask))
GEN_THUNKS(glPushDebugGroup, (GLenum source, GLuint id, GLsizei length, const GLchar * message), (source, id, length, message))
GEN_THUNKS(glPushDebugGroupKHR, (GLenum source, GLuint id, GLsizei length, const GLchar * message), (source, id, length, message))
GEN_THUNKS(glPushGroupMarkerEXT, (GLsizei length, const GLchar * marker), (length, marker))
GEN_THUNKS(glPushMatrix, (void), ())
GEN_THUNKS(glPushName, (GLuint name), (name))
GEN_THUNKS(glQueryCounter, (GLuint id, GLenum target), (id, target))
GEN_THUNKS(glQueryCounterEXT, (GLuint id, GLenum target), (id, target))
GEN_THUNKS_RET(GLbitfield, glQueryMatrixxOES, (GLfixed * mantissa, GLint * exponent), (mantissa, exponent))
GEN_THUNKS(glQueryObjectParameteruiAMD, (GLenum target, GLuint id, GLenum pname, GLuint param), (target, id, pname, param))
GEN_THUNKS_RET(GLint, glQueryResourceNV, (GLenum queryType, GLint tagId, GLuint bufSize, GLint * buffer), (queryType, tagId, bufSize, buffer))
GEN_THUNKS(glQueryResourceTagNV, (GLint tagId, const GLchar * tagString), (tagId, tagString))
GEN_THUNKS(glRasterPos2d, (GLdouble x, GLdouble y), (x, y))
GEN_THUNKS(glRasterPos2dv, (const GLdouble * v), (v))
GEN_THUNKS(glRasterPos2f, (GLfloat x, GLfloat y), (x, y))
GEN_THUNKS(glRasterPos2fv, (const GLfloat * v), (v))
GEN_THUNKS(glRasterPos2i, (GLint x, GLint y), (x, y))
GEN_THUNKS(glRasterPos2iv, (const GLint * v), (v))
GEN_THUNKS(glRasterPos2s, (GLshort x, GLshort y), (x, y))
GEN_THUNKS(glRasterPos2sv, (const GLshort * v), (v))
GEN_THUNKS(glRasterPos2xOES, (GLfixed x, GLfixed y), (x, y))
GEN_THUNKS(glRasterPos2xvOES, (const GLfixed * coords), (coords))
GEN_THUNKS(glRasterPos3d, (GLdouble x, GLdouble y, GLdouble z), (x, y, z))
GEN_THUNKS(glRasterPos3dv, (const GLdouble * v), (v))
GEN_THUNKS(glRasterPos3f, (GLfloat x, GLfloat y, GLfloat z), (x, y, z))
GEN_THUNKS(glRasterPos3fv, (const GLfloat * v), (v))
GEN_THUNKS(glRasterPos3i, (GLint x, GLint y, GLint z), (x, y, z))
GEN_THUNKS(glRasterPos3iv, (const GLint * v), (v))
GEN_THUNKS(glRasterPos3s, (GLshort x, GLshort y, GLshort z), (x, y, z))
GEN_THUNKS(glRasterPos3sv, (const GLshort * v), (v))
GEN_THUNKS(glRasterPos3xOES, (GLfixed x, GLfixed y, GLfixed z), (x, y, z))
GEN_THUNKS(glRasterPos3xvOES, (const GLfixed * coords), (coords))
GEN_THUNKS(glRasterPos4d, (GLdouble x, GLdouble y, GLdouble z, GLdouble w), (x, y, z, w))
GEN_THUNKS(glRasterPos4dv, (const GLdouble * v), (v))
GEN_THUNKS(glRasterPos4f, (GLfloat x, GLfloat y, GLfloat z, GLfloat w), (x, y, z, w))
GEN_THUNKS(glRasterPos4fv, (const GLfloat * v), (v))
GEN_THUNKS(glRasterPos4i, (GLint x, GLint y, GLint z, GLint w), (x, y, z, w))
GEN_THUNKS(glRasterPos4iv, (const GLint * v), (v))
GEN_THUNKS(glRasterPos4s, (GLshort x, GLshort y, GLshort z, GLshort w), (x, y, z, w))
GEN_THUNKS(glRasterPos4sv, (const GLshort * v), (v))
GEN_THUNKS(glRasterPos4xOES, (GLfixed x, GLfixed y, GLfixed z, GLfixed w), (x, y, z, w))
GEN_THUNKS(glRasterPos4xvOES, (const GLfixed * coords), (coords))
GEN_THUNKS(glRasterSamplesEXT, (GLuint samples, GLboolean fixedsamplelocations), (samples, fixedsamplelocations))
GEN_THUNKS(glReadBuffer, (GLenum src), (src))
GEN_THUNKS(glReadBufferIndexedEXT, (GLenum src, GLint index), (src, index))
GEN_THUNKS(glReadBufferNV, (GLenum mode), (mode))
GEN_THUNKS(glReadInstrumentsSGIX, (GLint marker), (marker))
GEN_THUNKS(glReadPixels, (GLint x, GLint y, GLsizei width, GLsizei height, GLenum format, GLenum type, void * pixels), (x, y, width, height, format, type, pixels))
GEN_THUNKS(glReadnPixels, (GLint x, GLint y, GLsizei width, GLsizei height, GLenum format, GLenum type, GLsizei bufSize, void * data), (x, y, width, height, format, type, bufSize, data))
GEN_THUNKS(glReadnPixelsARB, (GLint x, GLint y, GLsizei width, GLsizei height, GLenum format, GLenum type, GLsizei bufSize, void * data), (x, y, width, height, format, type, bufSize, data))
GEN_THUNKS(glReadnPixelsEXT, (GLint x, GLint y, GLsizei width, GLsizei height, GLenum format, GLenum type, GLsizei bufSize, void * data), (x, y, width, height, format, type, bufSize, data))
GEN_THUNKS(glReadnPixelsKHR, (GLint x, GLint y, GLsizei width, GLsizei height, GLenum format, GLenum type, GLsizei bufSize, void * data), (x, y, width, height, format, type, bufSize, data))
GEN_THUNKS(glRectd, (GLdouble x1, GLdouble y1, GLdouble x2, GLdouble y2), (x1, y1, x2, y2))
GEN_THUNKS(glRectdv, (const GLdouble * v1, const GLdouble * v2), (v1, v2))
GEN_THUNKS(glRectf, (GLfloat x1, GLfloat y1, GLfloat x2, GLfloat y2), (x1, y1, x2, y2))
GEN_THUNKS(glRectfv, (const GLfloat * v1, const GLfloat * v2), (v1, v2))
GEN_THUNKS(glRecti, (GLint x1, GLint y1, GLint x2, GLint y2), (x1, y1, x2, y2))
GEN_THUNKS(glRectiv, (const GLint * v1, const GLint * v2), (v1, v2))
GEN_THUNKS(glRects, (GLshort x1, GLshort y1, GLshort x2, GLshort y2), (x1, y1, x2, y2))
GEN_THUNKS(glRectsv, (const GLshort * v1, const GLshort * v2), (v1, v2))
GEN_THUNKS(glRectxOES, (GLfixed x1, GLfixed y1, GLfixed x2, GLfixed y2), (x1, y1, x2, y2))
GEN_THUNKS(glRectxvOES, (const GLfixed * v1, const GLfixed * v2), (v1, v2))
GEN_THUNKS(glReferencePlaneSGIX, (const GLdouble * equation), (equation))
GEN_THUNKS_RET(GLboolean, glReleaseKeyedMutexWin32EXT, (GLuint memory, GLuint64 key), (memory, key))
GEN_THUNKS(glReleaseShaderCompiler, (void), ())
GEN_THUNKS(glRenderGpuMaskNV, (GLbitfield mask), (mask))
GEN_THUNKS_RET(GLint, glRenderMode, (GLenum mode), (mode))
GEN_THUNKS(glRenderbufferStorage, (GLenum target, GLenum internalformat, GLsizei width, GLsizei height), (target, internalformat, width, height))
GEN_THUNKS(glRenderbufferStorageEXT, (GLenum target, GLenum internalformat, GLsizei width, GLsizei height), (target, internalformat, width, height))
GEN_THUNKS(glRenderbufferStorageMultisample, (GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height), (target, samples, internalformat, width, height))
GEN_THUNKS(glRenderbufferStorageMultisampleANGLE, (GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height), (target, samples, internalformat, width, height))
GEN_THUNKS(glRenderbufferStorageMultisampleAPPLE, (GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height), (target, samples, internalformat, width, height))
GEN_THUNKS(glRenderbufferStorageMultisampleAdvancedAMD, (GLenum target, GLsizei samples, GLsizei storageSamples, GLenum internalformat, GLsizei width, GLsizei height), (target, samples, storageSamples, internalformat, width, height))
GEN_THUNKS(glRenderbufferStorageMultisampleCoverageNV, (GLenum target, GLsizei coverageSamples, GLsizei colorSamples, GLenum internalformat, GLsizei width, GLsizei height), (target, coverageSamples, colorSamples, internalformat, width, height))
GEN_THUNKS(glRenderbufferStorageMultisampleEXT, (GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height), (target, samples, internalformat, width, height))
GEN_THUNKS(glRenderbufferStorageMultisampleIMG, (GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height), (target, samples, internalformat, width, height))
GEN_THUNKS(glRenderbufferStorageMultisampleNV, (GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height), (target, samples, internalformat, width, height))
GEN_THUNKS(glRenderbufferStorageOES, (GLenum target, GLenum internalformat, GLsizei width, GLsizei height), (target, internalformat, width, height))
GEN_THUNKS(glReplacementCodePointerSUN, (GLenum type, GLsizei stride, const void ** pointer), (type, stride, pointer))
GEN_THUNKS(glReplacementCodeubSUN, (GLubyte code), (code))
GEN_THUNKS(glReplacementCodeubvSUN, (const GLubyte * code), (code))
GEN_THUNKS(glReplacementCodeuiColor3fVertex3fSUN, (GLuint rc, GLfloat r, GLfloat g, GLfloat b, GLfloat x, GLfloat y, GLfloat z), (rc, r, g, b, x, y, z))
GEN_THUNKS(glReplacementCodeuiColor3fVertex3fvSUN, (const GLuint * rc, const GLfloat * c, const GLfloat * v), (rc, c, v))
GEN_THUNKS(glReplacementCodeuiColor4fNormal3fVertex3fSUN, (GLuint rc, GLfloat r, GLfloat g, GLfloat b, GLfloat a, GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z), (rc, r, g, b, a, nx, ny, nz, x, y, z))
GEN_THUNKS(glReplacementCodeuiColor4fNormal3fVertex3fvSUN, (const GLuint * rc, const GLfloat * c, const GLfloat * n, const GLfloat * v), (rc, c, n, v))
GEN_THUNKS(glReplacementCodeuiColor4ubVertex3fSUN, (GLuint rc, GLubyte r, GLubyte g, GLubyte b, GLubyte a, GLfloat x, GLfloat y, GLfloat z), (rc, r, g, b, a, x, y, z))
GEN_THUNKS(glReplacementCodeuiColor4ubVertex3fvSUN, (const GLuint * rc, const GLubyte * c, const GLfloat * v), (rc, c, v))
GEN_THUNKS(glReplacementCodeuiNormal3fVertex3fSUN, (GLuint rc, GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z), (rc, nx, ny, nz, x, y, z))
GEN_THUNKS(glReplacementCodeuiNormal3fVertex3fvSUN, (const GLuint * rc, const GLfloat * n, const GLfloat * v), (rc, n, v))
GEN_THUNKS(glReplacementCodeuiSUN, (GLuint code), (code))
GEN_THUNKS(glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fSUN, (GLuint rc, GLfloat s, GLfloat t, GLfloat r, GLfloat g, GLfloat b, GLfloat a, GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z), (rc, s, t, r, g, b, a, nx, ny, nz, x, y, z))
GEN_THUNKS(glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fvSUN, (const GLuint * rc, const GLfloat * tc, const GLfloat * c, const GLfloat * n, const GLfloat * v), (rc, tc, c, n, v))
GEN_THUNKS(glReplacementCodeuiTexCoord2fNormal3fVertex3fSUN, (GLuint rc, GLfloat s, GLfloat t, GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z), (rc, s, t, nx, ny, nz, x, y, z))
GEN_THUNKS(glReplacementCodeuiTexCoord2fNormal3fVertex3fvSUN, (const GLuint * rc, const GLfloat * tc, const GLfloat * n, const GLfloat * v), (rc, tc, n, v))
GEN_THUNKS(glReplacementCodeuiTexCoord2fVertex3fSUN, (GLuint rc, GLfloat s, GLfloat t, GLfloat x, GLfloat y, GLfloat z), (rc, s, t, x, y, z))
GEN_THUNKS(glReplacementCodeuiTexCoord2fVertex3fvSUN, (const GLuint * rc, const GLfloat * tc, const GLfloat * v), (rc, tc, v))
GEN_THUNKS(glReplacementCodeuiVertex3fSUN, (GLuint rc, GLfloat x, GLfloat y, GLfloat z), (rc, x, y, z))
GEN_THUNKS(glReplacementCodeuiVertex3fvSUN, (const GLuint * rc, const GLfloat * v), (rc, v))
GEN_THUNKS(glReplacementCodeuivSUN, (const GLuint * code), (code))
GEN_THUNKS(glReplacementCodeusSUN, (GLushort code), (code))
GEN_THUNKS(glReplacementCodeusvSUN, (const GLushort * code), (code))
GEN_THUNKS(glRequestResidentProgramsNV, (GLsizei n, const GLuint * programs), (n, programs))
GEN_THUNKS(glResetHistogram, (GLenum target), (target))
GEN_THUNKS(glResetHistogramEXT, (GLenum target), (target))
GEN_THUNKS(glResetMemoryObjectParameterNV, (GLuint memory, GLenum pname), (memory, pname))
GEN_THUNKS(glResetMinmax, (GLenum target), (target))
GEN_THUNKS(glResetMinmaxEXT, (GLenum target), (target))
GEN_THUNKS(glResizeBuffersMESA, (void), ())
GEN_THUNKS(glResolveDepthValuesNV, (void), ())
GEN_THUNKS(glResolveMultisampleFramebufferAPPLE, (void), ())
GEN_THUNKS(glResumeTransformFeedback, (void), ())
GEN_THUNKS(glResumeTransformFeedbackNV, (void), ())
GEN_THUNKS(glRotated, (GLdouble angle, GLdouble x, GLdouble y, GLdouble z), (angle, x, y, z))
GEN_THUNKS(glRotatef, (GLfloat angle, GLfloat x, GLfloat y, GLfloat z), (angle, x, y, z))
GEN_THUNKS(glRotatex, (GLfixed angle, GLfixed x, GLfixed y, GLfixed z), (angle, x, y, z))
GEN_THUNKS(glRotatexOES, (GLfixed angle, GLfixed x, GLfixed y, GLfixed z), (angle, x, y, z))
GEN_THUNKS(glSampleCoverage, (GLfloat value, GLboolean invert), (value, invert))
GEN_THUNKS(glSampleCoverageARB, (GLfloat value, GLboolean invert), (value, invert))
GEN_THUNKS(glSampleCoveragex, (GLclampx value, GLboolean invert), (value, invert))
GEN_THUNKS(glSampleCoveragexOES, (GLclampx value, GLboolean invert), (value, invert))
GEN_THUNKS(glSampleMapATI, (GLuint dst, GLuint interp, GLenum swizzle), (dst, interp, swizzle))
GEN_THUNKS(glSampleMaskEXT, (GLclampf value, GLboolean invert), (value, invert))
GEN_THUNKS(glSampleMaskIndexedNV, (GLuint index, GLbitfield mask), (index, mask))
GEN_THUNKS(glSampleMaskSGIS, (GLclampf value, GLboolean invert), (value, invert))
GEN_THUNKS(glSampleMaski, (GLuint maskNumber, GLbitfield mask), (maskNumber, mask))
GEN_THUNKS(glSamplePatternEXT, (GLenum pattern), (pattern))
GEN_THUNKS(glSamplePatternSGIS, (GLenum pattern), (pattern))
GEN_THUNKS(glSamplerParameterIiv, (GLuint sampler, GLenum pname, const GLint * param), (sampler, pname, param))
GEN_THUNKS(glSamplerParameterIivEXT, (GLuint sampler, GLenum pname, const GLint * param), (sampler, pname, param))
GEN_THUNKS(glSamplerParameterIivOES, (GLuint sampler, GLenum pname, const GLint * param), (sampler, pname, param))
GEN_THUNKS(glSamplerParameterIuiv, (GLuint sampler, GLenum pname, const GLuint * param), (sampler, pname, param))
GEN_THUNKS(glSamplerParameterIuivEXT, (GLuint sampler, GLenum pname, const GLuint * param), (sampler, pname, param))
GEN_THUNKS(glSamplerParameterIuivOES, (GLuint sampler, GLenum pname, const GLuint * param), (sampler, pname, param))
GEN_THUNKS(glSamplerParameterf, (GLuint sampler, GLenum pname, GLfloat param), (sampler, pname, param))
GEN_THUNKS(glSamplerParameterfv, (GLuint sampler, GLenum pname, const GLfloat * param), (sampler, pname, param))
GEN_THUNKS(glSamplerParameteri, (GLuint sampler, GLenum pname, GLint param), (sampler, pname, param))
GEN_THUNKS(glSamplerParameteriv, (GLuint sampler, GLenum pname, const GLint * param), (sampler, pname, param))
GEN_THUNKS(glScaled, (GLdouble x, GLdouble y, GLdouble z), (x, y, z))
GEN_THUNKS(glScalef, (GLfloat x, GLfloat y, GLfloat z), (x, y, z))
GEN_THUNKS(glScalex, (GLfixed x, GLfixed y, GLfixed z), (x, y, z))
GEN_THUNKS(glScalexOES, (GLfixed x, GLfixed y, GLfixed z), (x, y, z))
GEN_THUNKS(glScissor, (GLint x, GLint y, GLsizei width, GLsizei height), (x, y, width, height))
GEN_THUNKS(glScissorArrayv, (GLuint first, GLsizei count, const GLint * v), (first, count, v))
GEN_THUNKS(glScissorArrayvNV, (GLuint first, GLsizei count, const GLint * v), (first, count, v))
GEN_THUNKS(glScissorArrayvOES, (GLuint first, GLsizei count, const GLint * v), (first, count, v))
GEN_THUNKS(glScissorExclusiveArrayvNV, (GLuint first, GLsizei count, const GLint * v), (first, count, v))
GEN_THUNKS(glScissorExclusiveNV, (GLint x, GLint y, GLsizei width, GLsizei height), (x, y, width, height))
GEN_THUNKS(glScissorIndexed, (GLuint index, GLint left, GLint bottom, GLsizei width, GLsizei height), (index, left, bottom, width, height))
GEN_THUNKS(glScissorIndexedNV, (GLuint index, GLint left, GLint bottom, GLsizei width, GLsizei height), (index, left, bottom, width, height))
GEN_THUNKS(glScissorIndexedOES, (GLuint index, GLint left, GLint bottom, GLsizei width, GLsizei height), (index, left, bottom, width, height))
GEN_THUNKS(glScissorIndexedv, (GLuint index, const GLint * v), (index, v))
GEN_THUNKS(glScissorIndexedvNV, (GLuint index, const GLint * v), (index, v))
GEN_THUNKS(glScissorIndexedvOES, (GLuint index, const GLint * v), (index, v))
GEN_THUNKS(glSecondaryColor3b, (GLbyte red, GLbyte green, GLbyte blue), (red, green, blue))
GEN_THUNKS(glSecondaryColor3bEXT, (GLbyte red, GLbyte green, GLbyte blue), (red, green, blue))
GEN_THUNKS(glSecondaryColor3bv, (const GLbyte * v), (v))
GEN_THUNKS(glSecondaryColor3bvEXT, (const GLbyte * v), (v))
GEN_THUNKS(glSecondaryColor3d, (GLdouble red, GLdouble green, GLdouble blue), (red, green, blue))
GEN_THUNKS(glSecondaryColor3dEXT, (GLdouble red, GLdouble green, GLdouble blue), (red, green, blue))
GEN_THUNKS(glSecondaryColor3dv, (const GLdouble * v), (v))
GEN_THUNKS(glSecondaryColor3dvEXT, (const GLdouble * v), (v))
GEN_THUNKS(glSecondaryColor3f, (GLfloat red, GLfloat green, GLfloat blue), (red, green, blue))
GEN_THUNKS(glSecondaryColor3fEXT, (GLfloat red, GLfloat green, GLfloat blue), (red, green, blue))
GEN_THUNKS(glSecondaryColor3fv, (const GLfloat * v), (v))
GEN_THUNKS(glSecondaryColor3fvEXT, (const GLfloat * v), (v))
GEN_THUNKS(glSecondaryColor3hNV, (GLhalfNV red, GLhalfNV green, GLhalfNV blue), (red, green, blue))
GEN_THUNKS(glSecondaryColor3hvNV, (const GLhalfNV * v), (v))
GEN_THUNKS(glSecondaryColor3i, (GLint red, GLint green, GLint blue), (red, green, blue))
GEN_THUNKS(glSecondaryColor3iEXT, (GLint red, GLint green, GLint blue), (red, green, blue))
GEN_THUNKS(glSecondaryColor3iv, (const GLint * v), (v))
GEN_THUNKS(glSecondaryColor3ivEXT, (const GLint * v), (v))
GEN_THUNKS(glSecondaryColor3s, (GLshort red, GLshort green, GLshort blue), (red, green, blue))
GEN_THUNKS(glSecondaryColor3sEXT, (GLshort red, GLshort green, GLshort blue), (red, green, blue))
GEN_THUNKS(glSecondaryColor3sv, (const GLshort * v), (v))
GEN_THUNKS(glSecondaryColor3svEXT, (const GLshort * v), (v))
GEN_THUNKS(glSecondaryColor3ub, (GLubyte red, GLubyte green, GLubyte blue), (red, green, blue))
GEN_THUNKS(glSecondaryColor3ubEXT, (GLubyte red, GLubyte green, GLubyte blue), (red, green, blue))
GEN_THUNKS(glSecondaryColor3ubv, (const GLubyte * v), (v))
GEN_THUNKS(glSecondaryColor3ubvEXT, (const GLubyte * v), (v))
GEN_THUNKS(glSecondaryColor3ui, (GLuint red, GLuint green, GLuint blue), (red, green, blue))
GEN_THUNKS(glSecondaryColor3uiEXT, (GLuint red, GLuint green, GLuint blue), (red, green, blue))
GEN_THUNKS(glSecondaryColor3uiv, (const GLuint * v), (v))
GEN_THUNKS(glSecondaryColor3uivEXT, (const GLuint * v), (v))
GEN_THUNKS(glSecondaryColor3us, (GLushort red, GLushort green, GLushort blue), (red, green, blue))
GEN_THUNKS(glSecondaryColor3usEXT, (GLushort red, GLushort green, GLushort blue), (red, green, blue))
GEN_THUNKS(glSecondaryColor3usv, (const GLushort * v), (v))
GEN_THUNKS(glSecondaryColor3usvEXT, (const GLushort * v), (v))
GEN_THUNKS(glSecondaryColorFormatNV, (GLint size, GLenum type, GLsizei stride), (size, type, stride))
GEN_THUNKS(glSecondaryColorP3ui, (GLenum type, GLuint color), (type, color))
GEN_THUNKS(glSecondaryColorP3uiv, (GLenum type, const GLuint * color), (type, color))
GEN_THUNKS(glSecondaryColorPointer, (GLint size, GLenum type, GLsizei stride, const void * pointer), (size, type, stride, pointer))
GEN_THUNKS(glSecondaryColorPointerEXT, (GLint size, GLenum type, GLsizei stride, const void * pointer), (size, type, stride, pointer))
GEN_THUNKS(glSecondaryColorPointerListIBM, (GLint size, GLenum type, GLint stride, const void ** pointer, GLint ptrstride), (size, type, stride, pointer, ptrstride))
GEN_THUNKS(glSelectBuffer, (GLsizei size, GLuint * buffer), (size, buffer))
GEN_THUNKS(glSelectPerfMonitorCountersAMD, (GLuint monitor, GLboolean enable, GLuint group, GLint numCounters, GLuint * counterList), (monitor, enable, group, numCounters, counterList))
GEN_THUNKS(glSemaphoreParameterui64vEXT, (GLuint semaphore, GLenum pname, const GLuint64 * params), (semaphore, pname, params))
GEN_THUNKS(glSeparableFilter2D, (GLenum target, GLenum internalformat, GLsizei width, GLsizei height, GLenum format, GLenum type, const void * row, const void * column), (target, internalformat, width, height, format, type, row, column))
GEN_THUNKS(glSeparableFilter2DEXT, (GLenum target, GLenum internalformat, GLsizei width, GLsizei height, GLenum format, GLenum type, const void * row, const void * column), (target, internalformat, width, height, format, type, row, column))
GEN_THUNKS(glSetFenceAPPLE, (GLuint fence), (fence))
GEN_THUNKS(glSetFenceNV, (GLuint fence, GLenum condition), (fence, condition))
GEN_THUNKS(glSetFragmentShaderConstantATI, (GLuint dst, const GLfloat * value), (dst, value))
GEN_THUNKS(glSetInvariantEXT, (GLuint id, GLenum type, const void * addr), (id, type, addr))
GEN_THUNKS(glSetLocalConstantEXT, (GLuint id, GLenum type, const void * addr), (id, type, addr))
GEN_THUNKS(glSetMultisamplefvAMD, (GLenum pname, GLuint index, const GLfloat * val), (pname, index, val))
GEN_THUNKS(glShadeModel, (GLenum mode), (mode))
GEN_THUNKS(glShaderBinary, (GLsizei count, const GLuint * shaders, GLenum binaryformat, const void * binary, GLsizei length), (count, shaders, binaryformat, binary, length))
GEN_THUNKS(glShaderOp1EXT, (GLenum op, GLuint res, GLuint arg1), (op, res, arg1))
GEN_THUNKS(glShaderOp2EXT, (GLenum op, GLuint res, GLuint arg1, GLuint arg2), (op, res, arg1, arg2))
GEN_THUNKS(glShaderOp3EXT, (GLenum op, GLuint res, GLuint arg1, GLuint arg2, GLuint arg3), (op, res, arg1, arg2, arg3))
GEN_THUNKS(glShaderSource, (GLuint shader, GLsizei count, const GLchar *const* string, const GLint * length), (shader, count, string, length))
GEN_THUNKS(glShaderSourceARB, (GLhandleARB shaderObj, GLsizei count, const GLcharARB ** string, const GLint * length), ((uintptr_t)shaderObj, count, string, length))
GEN_THUNKS(glShaderStorageBlockBinding, (GLuint program, GLuint storageBlockIndex, GLuint storageBlockBinding), (program, storageBlockIndex, storageBlockBinding))
GEN_THUNKS(glShadingRateImageBarrierNV, (GLboolean synchronize), (synchronize))
GEN_THUNKS(glShadingRateImagePaletteNV, (GLuint viewport, GLuint first, GLsizei count, const GLenum * rates), (viewport, first, count, rates))
GEN_THUNKS(glShadingRateSampleOrderCustomNV, (GLenum rate, GLuint samples, const GLint * locations), (rate, samples, locations))
GEN_THUNKS(glShadingRateSampleOrderNV, (GLenum order), (order))
GEN_THUNKS(glSharpenTexFuncSGIS, (GLenum target, GLsizei n, const GLfloat * points), (target, n, points))
GEN_THUNKS(glSignalSemaphoreEXT, (GLuint semaphore, GLuint numBufferBarriers, const GLuint * buffers, GLuint numTextureBarriers, const GLuint * textures, const GLenum * dstLayouts), (semaphore, numBufferBarriers, buffers, numTextureBarriers, textures, dstLayouts))
GEN_THUNKS(glSignalSemaphoreui64NVX, (GLuint signalGpu, GLsizei fenceObjectCount, const GLuint * semaphoreArray, const GLuint64 * fenceValueArray), (signalGpu, fenceObjectCount, semaphoreArray, fenceValueArray))
GEN_THUNKS(glSignalVkFenceNV, (GLuint64 vkFence), (vkFence))
GEN_THUNKS(glSignalVkSemaphoreNV, (GLuint64 vkSemaphore), (vkSemaphore))
GEN_THUNKS(glSpecializeShader, (GLuint shader, const GLchar * pEntryPoint, GLuint numSpecializationConstants, const GLuint * pConstantIndex, const GLuint * pConstantValue), (shader, pEntryPoint, numSpecializationConstants, pConstantIndex, pConstantValue))
GEN_THUNKS(glSpecializeShaderARB, (GLuint shader, const GLchar * pEntryPoint, GLuint numSpecializationConstants, const GLuint * pConstantIndex, const GLuint * pConstantValue), (shader, pEntryPoint, numSpecializationConstants, pConstantIndex, pConstantValue))
GEN_THUNKS(glSpriteParameterfSGIX, (GLenum pname, GLfloat param), (pname, param))
GEN_THUNKS(glSpriteParameterfvSGIX, (GLenum pname, const GLfloat * params), (pname, params))
GEN_THUNKS(glSpriteParameteriSGIX, (GLenum pname, GLint param), (pname, param))
GEN_THUNKS(glSpriteParameterivSGIX, (GLenum pname, const GLint * params), (pname, params))
GEN_THUNKS(glStartInstrumentsSGIX, (void), ())
GEN_THUNKS(glStartTilingQCOM, (GLuint x, GLuint y, GLuint width, GLuint height, GLbitfield preserveMask), (x, y, width, height, preserveMask))
GEN_THUNKS(glStateCaptureNV, (GLuint state, GLenum mode), (state, mode))
GEN_THUNKS(glStencilClearTagEXT, (GLsizei stencilTagBits, GLuint stencilClearTag), (stencilTagBits, stencilClearTag))
GEN_THUNKS(glStencilFillPathInstancedNV, (GLsizei numPaths, GLenum pathNameType, const void * paths, GLuint pathBase, GLenum fillMode, GLuint mask, GLenum transformType, const GLfloat * transformValues), (numPaths, pathNameType, paths, pathBase, fillMode, mask, transformType, transformValues))
GEN_THUNKS(glStencilFillPathNV, (GLuint path, GLenum fillMode, GLuint mask), (path, fillMode, mask))
GEN_THUNKS(glStencilFunc, (GLenum func, GLint ref, GLuint mask), (func, ref, mask))
GEN_THUNKS(glStencilFuncSeparate, (GLenum face, GLenum func, GLint ref, GLuint mask), (face, func, ref, mask))
GEN_THUNKS(glStencilFuncSeparateATI, (GLenum frontfunc, GLenum backfunc, GLint ref, GLuint mask), (frontfunc, backfunc, ref, mask))
GEN_THUNKS(glStencilMask, (GLuint mask), (mask))
GEN_THUNKS(glStencilMaskSeparate, (GLenum face, GLuint mask), (face, mask))
GEN_THUNKS(glStencilOp, (GLenum fail, GLenum zfail, GLenum zpass), (fail, zfail, zpass))
GEN_THUNKS(glStencilOpSeparate, (GLenum face, GLenum sfail, GLenum dpfail, GLenum dppass), (face, sfail, dpfail, dppass))
GEN_THUNKS(glStencilOpSeparateATI, (GLenum face, GLenum sfail, GLenum dpfail, GLenum dppass), (face, sfail, dpfail, dppass))
GEN_THUNKS(glStencilOpValueAMD, (GLenum face, GLuint value), (face, value))
GEN_THUNKS(glStencilStrokePathInstancedNV, (GLsizei numPaths, GLenum pathNameType, const void * paths, GLuint pathBase, GLint reference, GLuint mask, GLenum transformType, const GLfloat * transformValues), (numPaths, pathNameType, paths, pathBase, reference, mask, transformType, transformValues))
GEN_THUNKS(glStencilStrokePathNV, (GLuint path, GLint reference, GLuint mask), (path, reference, mask))
GEN_THUNKS(glStencilThenCoverFillPathInstancedNV, (GLsizei numPaths, GLenum pathNameType, const void * paths, GLuint pathBase, GLenum fillMode, GLuint mask, GLenum coverMode, GLenum transformType, const GLfloat * transformValues), (numPaths, pathNameType, paths, pathBase, fillMode, mask, coverMode, transformType, transformValues))
GEN_THUNKS(glStencilThenCoverFillPathNV, (GLuint path, GLenum fillMode, GLuint mask, GLenum coverMode), (path, fillMode, mask, coverMode))
GEN_THUNKS(glStencilThenCoverStrokePathInstancedNV, (GLsizei numPaths, GLenum pathNameType, const void * paths, GLuint pathBase, GLint reference, GLuint mask, GLenum coverMode, GLenum transformType, const GLfloat * transformValues), (numPaths, pathNameType, paths, pathBase, reference, mask, coverMode, transformType, transformValues))
GEN_THUNKS(glStencilThenCoverStrokePathNV, (GLuint path, GLint reference, GLuint mask, GLenum coverMode), (path, reference, mask, coverMode))
GEN_THUNKS(glStopInstrumentsSGIX, (GLint marker), (marker))
GEN_THUNKS(glStringMarkerGREMEDY, (GLsizei len, const void * string), (len, string))
GEN_THUNKS(glSubpixelPrecisionBiasNV, (GLuint xbits, GLuint ybits), (xbits, ybits))
GEN_THUNKS(glSwizzleEXT, (GLuint res, GLuint in, GLenum outX, GLenum outY, GLenum outZ, GLenum outW), (res, in, outX, outY, outZ, outW))
GEN_THUNKS(glSyncTextureINTEL, (GLuint texture), (texture))
GEN_THUNKS(glTagSampleBufferSGIX, (void), ())
GEN_THUNKS(glTangent3bEXT, (GLbyte tx, GLbyte ty, GLbyte tz), (tx, ty, tz))
GEN_THUNKS(glTangent3bvEXT, (const GLbyte * v), (v))
GEN_THUNKS(glTangent3dEXT, (GLdouble tx, GLdouble ty, GLdouble tz), (tx, ty, tz))
GEN_THUNKS(glTangent3dvEXT, (const GLdouble * v), (v))
GEN_THUNKS(glTangent3fEXT, (GLfloat tx, GLfloat ty, GLfloat tz), (tx, ty, tz))
GEN_THUNKS(glTangent3fvEXT, (const GLfloat * v), (v))
GEN_THUNKS(glTangent3iEXT, (GLint tx, GLint ty, GLint tz), (tx, ty, tz))
GEN_THUNKS(glTangent3ivEXT, (const GLint * v), (v))
GEN_THUNKS(glTangent3sEXT, (GLshort tx, GLshort ty, GLshort tz), (tx, ty, tz))
GEN_THUNKS(glTangent3svEXT, (const GLshort * v), (v))
GEN_THUNKS(glTangentPointerEXT, (GLenum type, GLsizei stride, const void * pointer), (type, stride, pointer))
GEN_THUNKS(glTbufferMask3DFX, (GLuint mask), (mask))
GEN_THUNKS(glTessellationFactorAMD, (GLfloat factor), (factor))
GEN_THUNKS(glTessellationModeAMD, (GLenum mode), (mode))
GEN_THUNKS_RET(GLboolean, glTestFenceAPPLE, (GLuint fence), (fence))
GEN_THUNKS_RET(GLboolean, glTestFenceNV, (GLuint fence), (fence))
GEN_THUNKS_RET(GLboolean, glTestObjectAPPLE, (GLenum object, GLuint name), (object, name))
GEN_THUNKS(glTexAttachMemoryNV, (GLenum target, GLuint memory, GLuint64 offset), (target, memory, offset))
GEN_THUNKS(glTexBuffer, (GLenum target, GLenum internalformat, GLuint buffer), (target, internalformat, buffer))
GEN_THUNKS(glTexBufferARB, (GLenum target, GLenum internalformat, GLuint buffer), (target, internalformat, buffer))
GEN_THUNKS(glTexBufferEXT, (GLenum target, GLenum internalformat, GLuint buffer), (target, internalformat, buffer))
GEN_THUNKS(glTexBufferOES, (GLenum target, GLenum internalformat, GLuint buffer), (target, internalformat, buffer))
GEN_THUNKS(glTexBufferRange, (GLenum target, GLenum internalformat, GLuint buffer, GLintptr offset, GLsizeiptr size), (target, internalformat, buffer, offset, size))
GEN_THUNKS(glTexBufferRangeEXT, (GLenum target, GLenum internalformat, GLuint buffer, GLintptr offset, GLsizeiptr size), (target, internalformat, buffer, offset, size))
GEN_THUNKS(glTexBufferRangeOES, (GLenum target, GLenum internalformat, GLuint buffer, GLintptr offset, GLsizeiptr size), (target, internalformat, buffer, offset, size))
GEN_THUNKS(glTexBumpParameterfvATI, (GLenum pname, const GLfloat * param), (pname, param))
GEN_THUNKS(glTexBumpParameterivATI, (GLenum pname, const GLint * param), (pname, param))
GEN_THUNKS(glTexCoord1bOES, (GLbyte s), (s))
GEN_THUNKS(glTexCoord1bvOES, (const GLbyte * coords), (coords))
GEN_THUNKS(glTexCoord1d, (GLdouble s), (s))
GEN_THUNKS(glTexCoord1dv, (const GLdouble * v), (v))
GEN_THUNKS(glTexCoord1f, (GLfloat s), (s))
GEN_THUNKS(glTexCoord1fv, (const GLfloat * v), (v))
GEN_THUNKS(glTexCoord1hNV, (GLhalfNV s), (s))
GEN_THUNKS(glTexCoord1hvNV, (const GLhalfNV * v), (v))
GEN_THUNKS(glTexCoord1i, (GLint s), (s))
GEN_THUNKS(glTexCoord1iv, (const GLint * v), (v))
GEN_THUNKS(glTexCoord1s, (GLshort s), (s))
GEN_THUNKS(glTexCoord1sv, (const GLshort * v), (v))
GEN_THUNKS(glTexCoord1xOES, (GLfixed s), (s))
GEN_THUNKS(glTexCoord1xvOES, (const GLfixed * coords), (coords))
GEN_THUNKS(glTexCoord2bOES, (GLbyte s, GLbyte t), (s, t))
GEN_THUNKS(glTexCoord2bvOES, (const GLbyte * coords), (coords))
GEN_THUNKS(glTexCoord2d, (GLdouble s, GLdouble t), (s, t))
GEN_THUNKS(glTexCoord2dv, (const GLdouble * v), (v))
GEN_THUNKS(glTexCoord2f, (GLfloat s, GLfloat t), (s, t))
GEN_THUNKS(glTexCoord2fColor3fVertex3fSUN, (GLfloat s, GLfloat t, GLfloat r, GLfloat g, GLfloat b, GLfloat x, GLfloat y, GLfloat z), (s, t, r, g, b, x, y, z))
GEN_THUNKS(glTexCoord2fColor3fVertex3fvSUN, (const GLfloat * tc, const GLfloat * c, const GLfloat * v), (tc, c, v))
GEN_THUNKS(glTexCoord2fColor4fNormal3fVertex3fSUN, (GLfloat s, GLfloat t, GLfloat r, GLfloat g, GLfloat b, GLfloat a, GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z), (s, t, r, g, b, a, nx, ny, nz, x, y, z))
GEN_THUNKS(glTexCoord2fColor4fNormal3fVertex3fvSUN, (const GLfloat * tc, const GLfloat * c, const GLfloat * n, const GLfloat * v), (tc, c, n, v))
GEN_THUNKS(glTexCoord2fColor4ubVertex3fSUN, (GLfloat s, GLfloat t, GLubyte r, GLubyte g, GLubyte b, GLubyte a, GLfloat x, GLfloat y, GLfloat z), (s, t, r, g, b, a, x, y, z))
GEN_THUNKS(glTexCoord2fColor4ubVertex3fvSUN, (const GLfloat * tc, const GLubyte * c, const GLfloat * v), (tc, c, v))
GEN_THUNKS(glTexCoord2fNormal3fVertex3fSUN, (GLfloat s, GLfloat t, GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z), (s, t, nx, ny, nz, x, y, z))
GEN_THUNKS(glTexCoord2fNormal3fVertex3fvSUN, (const GLfloat * tc, const GLfloat * n, const GLfloat * v), (tc, n, v))
GEN_THUNKS(glTexCoord2fVertex3fSUN, (GLfloat s, GLfloat t, GLfloat x, GLfloat y, GLfloat z), (s, t, x, y, z))
GEN_THUNKS(glTexCoord2fVertex3fvSUN, (const GLfloat * tc, const GLfloat * v), (tc, v))
GEN_THUNKS(glTexCoord2fv, (const GLfloat * v), (v))
GEN_THUNKS(glTexCoord2hNV, (GLhalfNV s, GLhalfNV t), (s, t))
GEN_THUNKS(glTexCoord2hvNV, (const GLhalfNV * v), (v))
GEN_THUNKS(glTexCoord2i, (GLint s, GLint t), (s, t))
GEN_THUNKS(glTexCoord2iv, (const GLint * v), (v))
GEN_THUNKS(glTexCoord2s, (GLshort s, GLshort t), (s, t))
GEN_THUNKS(glTexCoord2sv, (const GLshort * v), (v))
GEN_THUNKS(glTexCoord2xOES, (GLfixed s, GLfixed t), (s, t))
GEN_THUNKS(glTexCoord2xvOES, (const GLfixed * coords), (coords))
GEN_THUNKS(glTexCoord3bOES, (GLbyte s, GLbyte t, GLbyte r), (s, t, r))
GEN_THUNKS(glTexCoord3bvOES, (const GLbyte * coords), (coords))
GEN_THUNKS(glTexCoord3d, (GLdouble s, GLdouble t, GLdouble r), (s, t, r))
GEN_THUNKS(glTexCoord3dv, (const GLdouble * v), (v))
GEN_THUNKS(glTexCoord3f, (GLfloat s, GLfloat t, GLfloat r), (s, t, r))
GEN_THUNKS(glTexCoord3fv, (const GLfloat * v), (v))
GEN_THUNKS(glTexCoord3hNV, (GLhalfNV s, GLhalfNV t, GLhalfNV r), (s, t, r))
GEN_THUNKS(glTexCoord3hvNV, (const GLhalfNV * v), (v))
GEN_THUNKS(glTexCoord3i, (GLint s, GLint t, GLint r), (s, t, r))
GEN_THUNKS(glTexCoord3iv, (const GLint * v), (v))
GEN_THUNKS(glTexCoord3s, (GLshort s, GLshort t, GLshort r), (s, t, r))
GEN_THUNKS(glTexCoord3sv, (const GLshort * v), (v))
GEN_THUNKS(glTexCoord3xOES, (GLfixed s, GLfixed t, GLfixed r), (s, t, r))
GEN_THUNKS(glTexCoord3xvOES, (const GLfixed * coords), (coords))
GEN_THUNKS(glTexCoord4bOES, (GLbyte s, GLbyte t, GLbyte r, GLbyte q), (s, t, r, q))
GEN_THUNKS(glTexCoord4bvOES, (const GLbyte * coords), (coords))
GEN_THUNKS(glTexCoord4d, (GLdouble s, GLdouble t, GLdouble r, GLdouble q), (s, t, r, q))
GEN_THUNKS(glTexCoord4dv, (const GLdouble * v), (v))
GEN_THUNKS(glTexCoord4f, (GLfloat s, GLfloat t, GLfloat r, GLfloat q), (s, t, r, q))
GEN_THUNKS(glTexCoord4fColor4fNormal3fVertex4fSUN, (GLfloat s, GLfloat t, GLfloat p, GLfloat q, GLfloat r, GLfloat g, GLfloat b, GLfloat a, GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z, GLfloat w), (s, t, p, q, r, g, b, a, nx, ny, nz, x, y, z, w))
GEN_THUNKS(glTexCoord4fColor4fNormal3fVertex4fvSUN, (const GLfloat * tc, const GLfloat * c, const GLfloat * n, const GLfloat * v), (tc, c, n, v))
GEN_THUNKS(glTexCoord4fVertex4fSUN, (GLfloat s, GLfloat t, GLfloat p, GLfloat q, GLfloat x, GLfloat y, GLfloat z, GLfloat w), (s, t, p, q, x, y, z, w))
GEN_THUNKS(glTexCoord4fVertex4fvSUN, (const GLfloat * tc, const GLfloat * v), (tc, v))
GEN_THUNKS(glTexCoord4fv, (const GLfloat * v), (v))
GEN_THUNKS(glTexCoord4hNV, (GLhalfNV s, GLhalfNV t, GLhalfNV r, GLhalfNV q), (s, t, r, q))
GEN_THUNKS(glTexCoord4hvNV, (const GLhalfNV * v), (v))
GEN_THUNKS(glTexCoord4i, (GLint s, GLint t, GLint r, GLint q), (s, t, r, q))
GEN_THUNKS(glTexCoord4iv, (const GLint * v), (v))
GEN_THUNKS(glTexCoord4s, (GLshort s, GLshort t, GLshort r, GLshort q), (s, t, r, q))
GEN_THUNKS(glTexCoord4sv, (const GLshort * v), (v))
GEN_THUNKS(glTexCoord4xOES, (GLfixed s, GLfixed t, GLfixed r, GLfixed q), (s, t, r, q))
GEN_THUNKS(glTexCoord4xvOES, (const GLfixed * coords), (coords))
GEN_THUNKS(glTexCoordFormatNV, (GLint size, GLenum type, GLsizei stride), (size, type, stride))
GEN_THUNKS(glTexCoordP1ui, (GLenum type, GLuint coords), (type, coords))
GEN_THUNKS(glTexCoordP1uiv, (GLenum type, const GLuint * coords), (type, coords))
GEN_THUNKS(glTexCoordP2ui, (GLenum type, GLuint coords), (type, coords))
GEN_THUNKS(glTexCoordP2uiv, (GLenum type, const GLuint * coords), (type, coords))
GEN_THUNKS(glTexCoordP3ui, (GLenum type, GLuint coords), (type, coords))
GEN_THUNKS(glTexCoordP3uiv, (GLenum type, const GLuint * coords), (type, coords))
GEN_THUNKS(glTexCoordP4ui, (GLenum type, GLuint coords), (type, coords))
GEN_THUNKS(glTexCoordP4uiv, (GLenum type, const GLuint * coords), (type, coords))
GEN_THUNKS(glTexCoordPointer, (GLint size, GLenum type, GLsizei stride, const void * pointer), (size, type, stride, pointer))
GEN_THUNKS(glTexCoordPointerEXT, (GLint size, GLenum type, GLsizei stride, GLsizei count, const void * pointer), (size, type, stride, count, pointer))
GEN_THUNKS(glTexCoordPointerListIBM, (GLint size, GLenum type, GLint stride, const void ** pointer, GLint ptrstride), (size, type, stride, pointer, ptrstride))
GEN_THUNKS(glTexCoordPointervINTEL, (GLint size, GLenum type, const void ** pointer), (size, type, pointer))
GEN_THUNKS(glTexEnvf, (GLenum target, GLenum pname, GLfloat param), (target, pname, param))
GEN_THUNKS(glTexEnvfv, (GLenum target, GLenum pname, const GLfloat * params), (target, pname, params))
GEN_THUNKS(glTexEnvi, (GLenum target, GLenum pname, GLint param), (target, pname, param))
GEN_THUNKS(glTexEnviv, (GLenum target, GLenum pname, const GLint * params), (target, pname, params))
GEN_THUNKS(glTexEnvx, (GLenum target, GLenum pname, GLfixed param), (target, pname, param))
GEN_THUNKS(glTexEnvxOES, (GLenum target, GLenum pname, GLfixed param), (target, pname, param))
GEN_THUNKS(glTexEnvxv, (GLenum target, GLenum pname, const GLfixed * params), (target, pname, params))
GEN_THUNKS(glTexEnvxvOES, (GLenum target, GLenum pname, const GLfixed * params), (target, pname, params))
GEN_THUNKS(glTexFilterFuncSGIS, (GLenum target, GLenum filter, GLsizei n, const GLfloat * weights), (target, filter, n, weights))
GEN_THUNKS(glTexGend, (GLenum coord, GLenum pname, GLdouble param), (coord, pname, param))
GEN_THUNKS(glTexGendv, (GLenum coord, GLenum pname, const GLdouble * params), (coord, pname, params))
GEN_THUNKS(glTexGenf, (GLenum coord, GLenum pname, GLfloat param), (coord, pname, param))
GEN_THUNKS(glTexGenfOES, (GLenum coord, GLenum pname, GLfloat param), (coord, pname, param))
GEN_THUNKS(glTexGenfv, (GLenum coord, GLenum pname, const GLfloat * params), (coord, pname, params))
GEN_THUNKS(glTexGenfvOES, (GLenum coord, GLenum pname, const GLfloat * params), (coord, pname, params))
GEN_THUNKS(glTexGeni, (GLenum coord, GLenum pname, GLint param), (coord, pname, param))
GEN_THUNKS(glTexGeniOES, (GLenum coord, GLenum pname, GLint param), (coord, pname, param))
GEN_THUNKS(glTexGeniv, (GLenum coord, GLenum pname, const GLint * params), (coord, pname, params))
GEN_THUNKS(glTexGenivOES, (GLenum coord, GLenum pname, const GLint * params), (coord, pname, params))
GEN_THUNKS(glTexGenxOES, (GLenum coord, GLenum pname, GLfixed param), (coord, pname, param))
GEN_THUNKS(glTexGenxvOES, (GLenum coord, GLenum pname, const GLfixed * params), (coord, pname, params))
GEN_THUNKS(glTexImage1D, (GLenum target, GLint level, GLint internalformat, GLsizei width, GLint border, GLenum format, GLenum type, const void * pixels), (target, level, internalformat, width, border, format, type, pixels))
GEN_THUNKS(glTexImage2D, (GLenum target, GLint level, GLint internalformat, GLsizei width, GLsizei height, GLint border, GLenum format, GLenum type, const void * pixels), (target, level, internalformat, width, height, border, format, type, pixels))
GEN_THUNKS(glTexImage2DMultisample, (GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLboolean fixedsamplelocations), (target, samples, internalformat, width, height, fixedsamplelocations))
GEN_THUNKS(glTexImage2DMultisampleCoverageNV, (GLenum target, GLsizei coverageSamples, GLsizei colorSamples, GLint internalFormat, GLsizei width, GLsizei height, GLboolean fixedSampleLocations), (target, coverageSamples, colorSamples, internalFormat, width, height, fixedSampleLocations))
GEN_THUNKS(glTexImage3D, (GLenum target, GLint level, GLint internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLenum format, GLenum type, const void * pixels), (target, level, internalformat, width, height, depth, border, format, type, pixels))
GEN_THUNKS(glTexImage3DEXT, (GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLenum format, GLenum type, const void * pixels), (target, level, internalformat, width, height, depth, border, format, type, pixels))
GEN_THUNKS(glTexImage3DMultisample, (GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedsamplelocations), (target, samples, internalformat, width, height, depth, fixedsamplelocations))
GEN_THUNKS(glTexImage3DMultisampleCoverageNV, (GLenum target, GLsizei coverageSamples, GLsizei colorSamples, GLint internalFormat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedSampleLocations), (target, coverageSamples, colorSamples, internalFormat, width, height, depth, fixedSampleLocations))
GEN_THUNKS(glTexImage3DOES, (GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLenum format, GLenum type, const void * pixels), (target, level, internalformat, width, height, depth, border, format, type, pixels))
GEN_THUNKS(glTexImage4DSGIS, (GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLsizei size4d, GLint border, GLenum format, GLenum type, const void * pixels), (target, level, internalformat, width, height, depth, size4d, border, format, type, pixels))
GEN_THUNKS(glTexPageCommitmentARB, (GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLboolean commit), (target, level, xoffset, yoffset, zoffset, width, height, depth, commit))
GEN_THUNKS(glTexPageCommitmentEXT, (GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLboolean commit), (target, level, xoffset, yoffset, zoffset, width, height, depth, commit))
GEN_THUNKS(glTexParameterIiv, (GLenum target, GLenum pname, const GLint * params), (target, pname, params))
GEN_THUNKS(glTexParameterIivEXT, (GLenum target, GLenum pname, const GLint * params), (target, pname, params))
GEN_THUNKS(glTexParameterIivOES, (GLenum target, GLenum pname, const GLint * params), (target, pname, params))
GEN_THUNKS(glTexParameterIuiv, (GLenum target, GLenum pname, const GLuint * params), (target, pname, params))
GEN_THUNKS(glTexParameterIuivEXT, (GLenum target, GLenum pname, const GLuint * params), (target, pname, params))
GEN_THUNKS(glTexParameterIuivOES, (GLenum target, GLenum pname, const GLuint * params), (target, pname, params))
GEN_THUNKS(glTexParameterf, (GLenum target, GLenum pname, GLfloat param), (target, pname, param))
GEN_THUNKS(glTexParameterfv, (GLenum target, GLenum pname, const GLfloat * params), (target, pname, params))
GEN_THUNKS(glTexParameteri, (GLenum target, GLenum pname, GLint param), (target, pname, param))
GEN_THUNKS(glTexParameteriv, (GLenum target, GLenum pname, const GLint * params), (target, pname, params))
GEN_THUNKS(glTexParameterx, (GLenum target, GLenum pname, GLfixed param), (target, pname, param))
GEN_THUNKS(glTexParameterxOES, (GLenum target, GLenum pname, GLfixed param), (target, pname, param))
GEN_THUNKS(glTexParameterxv, (GLenum target, GLenum pname, const GLfixed * params), (target, pname, params))
GEN_THUNKS(glTexParameterxvOES, (GLenum target, GLenum pname, const GLfixed * params), (target, pname, params))
GEN_THUNKS(glTexRenderbufferNV, (GLenum target, GLuint renderbuffer), (target, renderbuffer))
GEN_THUNKS(glTexStorage1D, (GLenum target, GLsizei levels, GLenum internalformat, GLsizei width), (target, levels, internalformat, width))
GEN_THUNKS(glTexStorage1DEXT, (GLenum target, GLsizei levels, GLenum internalformat, GLsizei width), (target, levels, internalformat, width))
GEN_THUNKS(glTexStorage2D, (GLenum target, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height), (target, levels, internalformat, width, height))
GEN_THUNKS(glTexStorage2DEXT, (GLenum target, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height), (target, levels, internalformat, width, height))
GEN_THUNKS(glTexStorage2DMultisample, (GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLboolean fixedsamplelocations), (target, samples, internalformat, width, height, fixedsamplelocations))
GEN_THUNKS(glTexStorage3D, (GLenum target, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth), (target, levels, internalformat, width, height, depth))
GEN_THUNKS(glTexStorage3DEXT, (GLenum target, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth), (target, levels, internalformat, width, height, depth))
GEN_THUNKS(glTexStorage3DMultisample, (GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedsamplelocations), (target, samples, internalformat, width, height, depth, fixedsamplelocations))
GEN_THUNKS(glTexStorage3DMultisampleOES, (GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedsamplelocations), (target, samples, internalformat, width, height, depth, fixedsamplelocations))
GEN_THUNKS(glTexStorageMem1DEXT, (GLenum target, GLsizei levels, GLenum internalFormat, GLsizei width, GLuint memory, GLuint64 offset), (target, levels, internalFormat, width, memory, offset))
GEN_THUNKS(glTexStorageMem2DEXT, (GLenum target, GLsizei levels, GLenum internalFormat, GLsizei width, GLsizei height, GLuint memory, GLuint64 offset), (target, levels, internalFormat, width, height, memory, offset))
GEN_THUNKS(glTexStorageMem2DMultisampleEXT, (GLenum target, GLsizei samples, GLenum internalFormat, GLsizei width, GLsizei height, GLboolean fixedSampleLocations, GLuint memory, GLuint64 offset), (target, samples, internalFormat, width, height, fixedSampleLocations, memory, offset))
GEN_THUNKS(glTexStorageMem3DEXT, (GLenum target, GLsizei levels, GLenum internalFormat, GLsizei width, GLsizei height, GLsizei depth, GLuint memory, GLuint64 offset), (target, levels, internalFormat, width, height, depth, memory, offset))
GEN_THUNKS(glTexStorageMem3DMultisampleEXT, (GLenum target, GLsizei samples, GLenum internalFormat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedSampleLocations, GLuint memory, GLuint64 offset), (target, samples, internalFormat, width, height, depth, fixedSampleLocations, memory, offset))
GEN_THUNKS(glTexStorageSparseAMD, (GLenum target, GLenum internalFormat, GLsizei width, GLsizei height, GLsizei depth, GLsizei layers, GLbitfield flags), (target, internalFormat, width, height, depth, layers, flags))
GEN_THUNKS(glTexSubImage1D, (GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLenum type, const void * pixels), (target, level, xoffset, width, format, type, pixels))
GEN_THUNKS(glTexSubImage1DEXT, (GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLenum type, const void * pixels), (target, level, xoffset, width, format, type, pixels))
GEN_THUNKS(glTexSubImage2D, (GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLenum type, const void * pixels), (target, level, xoffset, yoffset, width, height, format, type, pixels))
GEN_THUNKS(glTexSubImage2DEXT, (GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLenum type, const void * pixels), (target, level, xoffset, yoffset, width, height, format, type, pixels))
GEN_THUNKS(glTexSubImage3D, (GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void * pixels), (target, level, xoffset, yoffset, zoffset, width, height, depth, format, type, pixels))
GEN_THUNKS(glTexSubImage3DEXT, (GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void * pixels), (target, level, xoffset, yoffset, zoffset, width, height, depth, format, type, pixels))
GEN_THUNKS(glTexSubImage3DOES, (GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void * pixels), (target, level, xoffset, yoffset, zoffset, width, height, depth, format, type, pixels))
GEN_THUNKS(glTexSubImage4DSGIS, (GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint woffset, GLsizei width, GLsizei height, GLsizei depth, GLsizei size4d, GLenum format, GLenum type, const void * pixels), (target, level, xoffset, yoffset, zoffset, woffset, width, height, depth, size4d, format, type, pixels))
GEN_THUNKS(glTextureAttachMemoryNV, (GLuint texture, GLuint memory, GLuint64 offset), (texture, memory, offset))
GEN_THUNKS(glTextureBarrier, (void), ())
GEN_THUNKS(glTextureBarrierNV, (void), ())
GEN_THUNKS(glTextureBuffer, (GLuint texture, GLenum internalformat, GLuint buffer), (texture, internalformat, buffer))
GEN_THUNKS(glTextureBufferEXT, (GLuint texture, GLenum target, GLenum internalformat, GLuint buffer), (texture, target, internalformat, buffer))
GEN_THUNKS(glTextureBufferRange, (GLuint texture, GLenum internalformat, GLuint buffer, GLintptr offset, GLsizeiptr size), (texture, internalformat, buffer, offset, size))
GEN_THUNKS(glTextureBufferRangeEXT, (GLuint texture, GLenum target, GLenum internalformat, GLuint buffer, GLintptr offset, GLsizeiptr size), (texture, target, internalformat, buffer, offset, size))
GEN_THUNKS(glTextureColorMaskSGIS, (GLboolean red, GLboolean green, GLboolean blue, GLboolean alpha), (red, green, blue, alpha))
GEN_THUNKS(glTextureFoveationParametersQCOM, (GLuint texture, GLuint layer, GLuint focalPoint, GLfloat focalX, GLfloat focalY, GLfloat gainX, GLfloat gainY, GLfloat foveaArea), (texture, layer, focalPoint, focalX, focalY, gainX, gainY, foveaArea))
GEN_THUNKS(glTextureImage1DEXT, (GLuint texture, GLenum target, GLint level, GLint internalformat, GLsizei width, GLint border, GLenum format, GLenum type, const void * pixels), (texture, target, level, internalformat, width, border, format, type, pixels))
GEN_THUNKS(glTextureImage2DEXT, (GLuint texture, GLenum target, GLint level, GLint internalformat, GLsizei width, GLsizei height, GLint border, GLenum format, GLenum type, const void * pixels), (texture, target, level, internalformat, width, height, border, format, type, pixels))
GEN_THUNKS(glTextureImage2DMultisampleCoverageNV, (GLuint texture, GLenum target, GLsizei coverageSamples, GLsizei colorSamples, GLint internalFormat, GLsizei width, GLsizei height, GLboolean fixedSampleLocations), (texture, target, coverageSamples, colorSamples, internalFormat, width, height, fixedSampleLocations))
GEN_THUNKS(glTextureImage2DMultisampleNV, (GLuint texture, GLenum target, GLsizei samples, GLint internalFormat, GLsizei width, GLsizei height, GLboolean fixedSampleLocations), (texture, target, samples, internalFormat, width, height, fixedSampleLocations))
GEN_THUNKS(glTextureImage3DEXT, (GLuint texture, GLenum target, GLint level, GLint internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLenum format, GLenum type, const void * pixels), (texture, target, level, internalformat, width, height, depth, border, format, type, pixels))
GEN_THUNKS(glTextureImage3DMultisampleCoverageNV, (GLuint texture, GLenum target, GLsizei coverageSamples, GLsizei colorSamples, GLint internalFormat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedSampleLocations), (texture, target, coverageSamples, colorSamples, internalFormat, width, height, depth, fixedSampleLocations))
GEN_THUNKS(glTextureImage3DMultisampleNV, (GLuint texture, GLenum target, GLsizei samples, GLint internalFormat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedSampleLocations), (texture, target, samples, internalFormat, width, height, depth, fixedSampleLocations))
GEN_THUNKS(glTextureLightEXT, (GLenum pname), (pname))
GEN_THUNKS(glTextureMaterialEXT, (GLenum face, GLenum mode), (face, mode))
GEN_THUNKS(glTextureNormalEXT, (GLenum mode), (mode))
GEN_THUNKS(glTexturePageCommitmentEXT, (GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLboolean commit), (texture, level, xoffset, yoffset, zoffset, width, height, depth, commit))
GEN_THUNKS(glTextureParameterIiv, (GLuint texture, GLenum pname, const GLint * params), (texture, pname, params))
GEN_THUNKS(glTextureParameterIivEXT, (GLuint texture, GLenum target, GLenum pname, const GLint * params), (texture, target, pname, params))
GEN_THUNKS(glTextureParameterIuiv, (GLuint texture, GLenum pname, const GLuint * params), (texture, pname, params))
GEN_THUNKS(glTextureParameterIuivEXT, (GLuint texture, GLenum target, GLenum pname, const GLuint * params), (texture, target, pname, params))
GEN_THUNKS(glTextureParameterf, (GLuint texture, GLenum pname, GLfloat param), (texture, pname, param))
GEN_THUNKS(glTextureParameterfEXT, (GLuint texture, GLenum target, GLenum pname, GLfloat param), (texture, target, pname, param))
GEN_THUNKS(glTextureParameterfv, (GLuint texture, GLenum pname, const GLfloat * param), (texture, pname, param))
GEN_THUNKS(glTextureParameterfvEXT, (GLuint texture, GLenum target, GLenum pname, const GLfloat * params), (texture, target, pname, params))
GEN_THUNKS(glTextureParameteri, (GLuint texture, GLenum pname, GLint param), (texture, pname, param))
GEN_THUNKS(glTextureParameteriEXT, (GLuint texture, GLenum target, GLenum pname, GLint param), (texture, target, pname, param))
GEN_THUNKS(glTextureParameteriv, (GLuint texture, GLenum pname, const GLint * param), (texture, pname, param))
GEN_THUNKS(glTextureParameterivEXT, (GLuint texture, GLenum target, GLenum pname, const GLint * params), (texture, target, pname, params))
GEN_THUNKS(glTextureRangeAPPLE, (GLenum target, GLsizei length, const void * pointer), (target, length, pointer))
GEN_THUNKS(glTextureRenderbufferEXT, (GLuint texture, GLenum target, GLuint renderbuffer), (texture, target, renderbuffer))
GEN_THUNKS(glTextureStorage1D, (GLuint texture, GLsizei levels, GLenum internalformat, GLsizei width), (texture, levels, internalformat, width))
GEN_THUNKS(glTextureStorage1DEXT, (GLuint texture, GLenum target, GLsizei levels, GLenum internalformat, GLsizei width), (texture, target, levels, internalformat, width))
GEN_THUNKS(glTextureStorage2D, (GLuint texture, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height), (texture, levels, internalformat, width, height))
GEN_THUNKS(glTextureStorage2DEXT, (GLuint texture, GLenum target, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height), (texture, target, levels, internalformat, width, height))
GEN_THUNKS(glTextureStorage2DMultisample, (GLuint texture, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLboolean fixedsamplelocations), (texture, samples, internalformat, width, height, fixedsamplelocations))
GEN_THUNKS(glTextureStorage2DMultisampleEXT, (GLuint texture, GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLboolean fixedsamplelocations), (texture, target, samples, internalformat, width, height, fixedsamplelocations))
GEN_THUNKS(glTextureStorage3D, (GLuint texture, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth), (texture, levels, internalformat, width, height, depth))
GEN_THUNKS(glTextureStorage3DEXT, (GLuint texture, GLenum target, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth), (texture, target, levels, internalformat, width, height, depth))
GEN_THUNKS(glTextureStorage3DMultisample, (GLuint texture, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedsamplelocations), (texture, samples, internalformat, width, height, depth, fixedsamplelocations))
GEN_THUNKS(glTextureStorage3DMultisampleEXT, (GLuint texture, GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedsamplelocations), (texture, target, samples, internalformat, width, height, depth, fixedsamplelocations))
GEN_THUNKS(glTextureStorageMem1DEXT, (GLuint texture, GLsizei levels, GLenum internalFormat, GLsizei width, GLuint memory, GLuint64 offset), (texture, levels, internalFormat, width, memory, offset))
GEN_THUNKS(glTextureStorageMem2DEXT, (GLuint texture, GLsizei levels, GLenum internalFormat, GLsizei width, GLsizei height, GLuint memory, GLuint64 offset), (texture, levels, internalFormat, width, height, memory, offset))
GEN_THUNKS(glTextureStorageMem2DMultisampleEXT, (GLuint texture, GLsizei samples, GLenum internalFormat, GLsizei width, GLsizei height, GLboolean fixedSampleLocations, GLuint memory, GLuint64 offset), (texture, samples, internalFormat, width, height, fixedSampleLocations, memory, offset))
GEN_THUNKS(glTextureStorageMem3DEXT, (GLuint texture, GLsizei levels, GLenum internalFormat, GLsizei width, GLsizei height, GLsizei depth, GLuint memory, GLuint64 offset), (texture, levels, internalFormat, width, height, depth, memory, offset))
GEN_THUNKS(glTextureStorageMem3DMultisampleEXT, (GLuint texture, GLsizei samples, GLenum internalFormat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedSampleLocations, GLuint memory, GLuint64 offset), (texture, samples, internalFormat, width, height, depth, fixedSampleLocations, memory, offset))
GEN_THUNKS(glTextureStorageSparseAMD, (GLuint texture, GLenum target, GLenum internalFormat, GLsizei width, GLsizei height, GLsizei depth, GLsizei layers, GLbitfield flags), (texture, target, internalFormat, width, height, depth, layers, flags))
GEN_THUNKS(glTextureSubImage1D, (GLuint texture, GLint level, GLint xoffset, GLsizei width, GLenum format, GLenum type, const void * pixels), (texture, level, xoffset, width, format, type, pixels))
GEN_THUNKS(glTextureSubImage1DEXT, (GLuint texture, GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLenum type, const void * pixels), (texture, target, level, xoffset, width, format, type, pixels))
GEN_THUNKS(glTextureSubImage2D, (GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLenum type, const void * pixels), (texture, level, xoffset, yoffset, width, height, format, type, pixels))
GEN_THUNKS(glTextureSubImage2DEXT, (GLuint texture, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLenum type, const void * pixels), (texture, target, level, xoffset, yoffset, width, height, format, type, pixels))
GEN_THUNKS(glTextureSubImage3D, (GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void * pixels), (texture, level, xoffset, yoffset, zoffset, width, height, depth, format, type, pixels))
GEN_THUNKS(glTextureSubImage3DEXT, (GLuint texture, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void * pixels), (texture, target, level, xoffset, yoffset, zoffset, width, height, depth, format, type, pixels))
GEN_THUNKS(glTextureView, (GLuint texture, GLenum target, GLuint origtexture, GLenum internalformat, GLuint minlevel, GLuint numlevels, GLuint minlayer, GLuint numlayers), (texture, target, origtexture, internalformat, minlevel, numlevels, minlayer, numlayers))
GEN_THUNKS(glTextureViewEXT, (GLuint texture, GLenum target, GLuint origtexture, GLenum internalformat, GLuint minlevel, GLuint numlevels, GLuint minlayer, GLuint numlayers), (texture, target, origtexture, internalformat, minlevel, numlevels, minlayer, numlayers))
GEN_THUNKS(glTextureViewOES, (GLuint texture, GLenum target, GLuint origtexture, GLenum internalformat, GLuint minlevel, GLuint numlevels, GLuint minlayer, GLuint numlayers), (texture, target, origtexture, internalformat, minlevel, numlevels, minlayer, numlayers))
GEN_THUNKS(glTrackMatrixNV, (GLenum target, GLuint address, GLenum matrix, GLenum transform), (target, address, matrix, transform))
GEN_THUNKS(glTransformFeedbackAttribsNV, (GLsizei count, const GLint * attribs, GLenum bufferMode), (count, attribs, bufferMode))
GEN_THUNKS(glTransformFeedbackBufferBase, (GLuint xfb, GLuint index, GLuint buffer), (xfb, index, buffer))
GEN_THUNKS(glTransformFeedbackBufferRange, (GLuint xfb, GLuint index, GLuint buffer, GLintptr offset, GLsizeiptr size), (xfb, index, buffer, offset, size))
GEN_THUNKS(glTransformFeedbackStreamAttribsNV, (GLsizei count, const GLint * attribs, GLsizei nbuffers, const GLint * bufstreams, GLenum bufferMode), (count, attribs, nbuffers, bufstreams, bufferMode))
GEN_THUNKS(glTransformFeedbackVaryings, (GLuint program, GLsizei count, const GLchar *const* varyings, GLenum bufferMode), (program, count, varyings, bufferMode))
GEN_THUNKS(glTransformFeedbackVaryingsEXT, (GLuint program, GLsizei count, const GLchar *const* varyings, GLenum bufferMode), (program, count, varyings, bufferMode))
GEN_THUNKS(glTransformFeedbackVaryingsNV, (GLuint program, GLsizei count, const GLint * locations, GLenum bufferMode), (program, count, locations, bufferMode))
GEN_THUNKS(glTransformPathNV, (GLuint resultPath, GLuint srcPath, GLenum transformType, const GLfloat * transformValues), (resultPath, srcPath, transformType, transformValues))
GEN_THUNKS(glTranslated, (GLdouble x, GLdouble y, GLdouble z), (x, y, z))
GEN_THUNKS(glTranslatef, (GLfloat x, GLfloat y, GLfloat z), (x, y, z))
GEN_THUNKS(glTranslatex, (GLfixed x, GLfixed y, GLfixed z), (x, y, z))
GEN_THUNKS(glTranslatexOES, (GLfixed x, GLfixed y, GLfixed z), (x, y, z))
GEN_THUNKS(glUniform1d, (GLint location, GLdouble x), (location, x))
GEN_THUNKS(glUniform1dv, (GLint location, GLsizei count, const GLdouble * value), (location, count, value))
GEN_THUNKS(glUniform1f, (GLint location, GLfloat v0), (location, v0))
GEN_THUNKS(glUniform1fARB, (GLint location, GLfloat v0), (location, v0))
GEN_THUNKS(glUniform1fv, (GLint location, GLsizei count, const GLfloat * value), (location, count, value))
GEN_THUNKS(glUniform1fvARB, (GLint location, GLsizei count, const GLfloat * value), (location, count, value))
GEN_THUNKS(glUniform1i, (GLint location, GLint v0), (location, v0))
GEN_THUNKS(glUniform1i64ARB, (GLint location, GLint64 x), (location, x))
GEN_THUNKS(glUniform1i64NV, (GLint location, GLint64EXT x), (location, x))
GEN_THUNKS(glUniform1i64vARB, (GLint location, GLsizei count, const GLint64 * value), (location, count, value))
GEN_THUNKS(glUniform1i64vNV, (GLint location, GLsizei count, const GLint64EXT * value), (location, count, value))
GEN_THUNKS(glUniform1iARB, (GLint location, GLint v0), (location, v0))
GEN_THUNKS(glUniform1iv, (GLint location, GLsizei count, const GLint * value), (location, count, value))
GEN_THUNKS(glUniform1ivARB, (GLint location, GLsizei count, const GLint * value), (location, count, value))
GEN_THUNKS(glUniform1ui, (GLint location, GLuint v0), (location, v0))
GEN_THUNKS(glUniform1ui64ARB, (GLint location, GLuint64 x), (location, x))
GEN_THUNKS(glUniform1ui64NV, (GLint location, GLuint64EXT x), (location, x))
GEN_THUNKS(glUniform1ui64vARB, (GLint location, GLsizei count, const GLuint64 * value), (location, count, value))
GEN_THUNKS(glUniform1ui64vNV, (GLint location, GLsizei count, const GLuint64EXT * value), (location, count, value))
GEN_THUNKS(glUniform1uiEXT, (GLint location, GLuint v0), (location, v0))
GEN_THUNKS(glUniform1uiv, (GLint location, GLsizei count, const GLuint * value), (location, count, value))
GEN_THUNKS(glUniform1uivEXT, (GLint location, GLsizei count, const GLuint * value), (location, count, value))
GEN_THUNKS(glUniform2d, (GLint location, GLdouble x, GLdouble y), (location, x, y))
GEN_THUNKS(glUniform2dv, (GLint location, GLsizei count, const GLdouble * value), (location, count, value))
GEN_THUNKS(glUniform2f, (GLint location, GLfloat v0, GLfloat v1), (location, v0, v1))
GEN_THUNKS(glUniform2fARB, (GLint location, GLfloat v0, GLfloat v1), (location, v0, v1))
GEN_THUNKS(glUniform2fv, (GLint location, GLsizei count, const GLfloat * value), (location, count, value))
GEN_THUNKS(glUniform2fvARB, (GLint location, GLsizei count, const GLfloat * value), (location, count, value))
GEN_THUNKS(glUniform2i, (GLint location, GLint v0, GLint v1), (location, v0, v1))
GEN_THUNKS(glUniform2i64ARB, (GLint location, GLint64 x, GLint64 y), (location, x, y))
GEN_THUNKS(glUniform2i64NV, (GLint location, GLint64EXT x, GLint64EXT y), (location, x, y))
GEN_THUNKS(glUniform2i64vARB, (GLint location, GLsizei count, const GLint64 * value), (location, count, value))
GEN_THUNKS(glUniform2i64vNV, (GLint location, GLsizei count, const GLint64EXT * value), (location, count, value))
GEN_THUNKS(glUniform2iARB, (GLint location, GLint v0, GLint v1), (location, v0, v1))
GEN_THUNKS(glUniform2iv, (GLint location, GLsizei count, const GLint * value), (location, count, value))
GEN_THUNKS(glUniform2ivARB, (GLint location, GLsizei count, const GLint * value), (location, count, value))
GEN_THUNKS(glUniform2ui, (GLint location, GLuint v0, GLuint v1), (location, v0, v1))
GEN_THUNKS(glUniform2ui64ARB, (GLint location, GLuint64 x, GLuint64 y), (location, x, y))
GEN_THUNKS(glUniform2ui64NV, (GLint location, GLuint64EXT x, GLuint64EXT y), (location, x, y))
GEN_THUNKS(glUniform2ui64vARB, (GLint location, GLsizei count, const GLuint64 * value), (location, count, value))
GEN_THUNKS(glUniform2ui64vNV, (GLint location, GLsizei count, const GLuint64EXT * value), (location, count, value))
GEN_THUNKS(glUniform2uiEXT, (GLint location, GLuint v0, GLuint v1), (location, v0, v1))
GEN_THUNKS(glUniform2uiv, (GLint location, GLsizei count, const GLuint * value), (location, count, value))
GEN_THUNKS(glUniform2uivEXT, (GLint location, GLsizei count, const GLuint * value), (location, count, value))
GEN_THUNKS(glUniform3d, (GLint location, GLdouble x, GLdouble y, GLdouble z), (location, x, y, z))
GEN_THUNKS(glUniform3dv, (GLint location, GLsizei count, const GLdouble * value), (location, count, value))
GEN_THUNKS(glUniform3f, (GLint location, GLfloat v0, GLfloat v1, GLfloat v2), (location, v0, v1, v2))
GEN_THUNKS(glUniform3fARB, (GLint location, GLfloat v0, GLfloat v1, GLfloat v2), (location, v0, v1, v2))
GEN_THUNKS(glUniform3fv, (GLint location, GLsizei count, const GLfloat * value), (location, count, value))
GEN_THUNKS(glUniform3fvARB, (GLint location, GLsizei count, const GLfloat * value), (location, count, value))
GEN_THUNKS(glUniform3i, (GLint location, GLint v0, GLint v1, GLint v2), (location, v0, v1, v2))
GEN_THUNKS(glUniform3i64ARB, (GLint location, GLint64 x, GLint64 y, GLint64 z), (location, x, y, z))
GEN_THUNKS(glUniform3i64NV, (GLint location, GLint64EXT x, GLint64EXT y, GLint64EXT z), (location, x, y, z))
GEN_THUNKS(glUniform3i64vARB, (GLint location, GLsizei count, const GLint64 * value), (location, count, value))
GEN_THUNKS(glUniform3i64vNV, (GLint location, GLsizei count, const GLint64EXT * value), (location, count, value))
GEN_THUNKS(glUniform3iARB, (GLint location, GLint v0, GLint v1, GLint v2), (location, v0, v1, v2))
GEN_THUNKS(glUniform3iv, (GLint location, GLsizei count, const GLint * value), (location, count, value))
GEN_THUNKS(glUniform3ivARB, (GLint location, GLsizei count, const GLint * value), (location, count, value))
GEN_THUNKS(glUniform3ui, (GLint location, GLuint v0, GLuint v1, GLuint v2), (location, v0, v1, v2))
GEN_THUNKS(glUniform3ui64ARB, (GLint location, GLuint64 x, GLuint64 y, GLuint64 z), (location, x, y, z))
GEN_THUNKS(glUniform3ui64NV, (GLint location, GLuint64EXT x, GLuint64EXT y, GLuint64EXT z), (location, x, y, z))
GEN_THUNKS(glUniform3ui64vARB, (GLint location, GLsizei count, const GLuint64 * value), (location, count, value))
GEN_THUNKS(glUniform3ui64vNV, (GLint location, GLsizei count, const GLuint64EXT * value), (location, count, value))
GEN_THUNKS(glUniform3uiEXT, (GLint location, GLuint v0, GLuint v1, GLuint v2), (location, v0, v1, v2))
GEN_THUNKS(glUniform3uiv, (GLint location, GLsizei count, const GLuint * value), (location, count, value))
GEN_THUNKS(glUniform3uivEXT, (GLint location, GLsizei count, const GLuint * value), (location, count, value))
GEN_THUNKS(glUniform4d, (GLint location, GLdouble x, GLdouble y, GLdouble z, GLdouble w), (location, x, y, z, w))
GEN_THUNKS(glUniform4dv, (GLint location, GLsizei count, const GLdouble * value), (location, count, value))
GEN_THUNKS(glUniform4f, (GLint location, GLfloat v0, GLfloat v1, GLfloat v2, GLfloat v3), (location, v0, v1, v2, v3))
GEN_THUNKS(glUniform4fARB, (GLint location, GLfloat v0, GLfloat v1, GLfloat v2, GLfloat v3), (location, v0, v1, v2, v3))
GEN_THUNKS(glUniform4fv, (GLint location, GLsizei count, const GLfloat * value), (location, count, value))
GEN_THUNKS(glUniform4fvARB, (GLint location, GLsizei count, const GLfloat * value), (location, count, value))
GEN_THUNKS(glUniform4i, (GLint location, GLint v0, GLint v1, GLint v2, GLint v3), (location, v0, v1, v2, v3))
GEN_THUNKS(glUniform4i64ARB, (GLint location, GLint64 x, GLint64 y, GLint64 z, GLint64 w), (location, x, y, z, w))
GEN_THUNKS(glUniform4i64NV, (GLint location, GLint64EXT x, GLint64EXT y, GLint64EXT z, GLint64EXT w), (location, x, y, z, w))
GEN_THUNKS(glUniform4i64vARB, (GLint location, GLsizei count, const GLint64 * value), (location, count, value))
GEN_THUNKS(glUniform4i64vNV, (GLint location, GLsizei count, const GLint64EXT * value), (location, count, value))
GEN_THUNKS(glUniform4iARB, (GLint location, GLint v0, GLint v1, GLint v2, GLint v3), (location, v0, v1, v2, v3))
GEN_THUNKS(glUniform4iv, (GLint location, GLsizei count, const GLint * value), (location, count, value))
GEN_THUNKS(glUniform4ivARB, (GLint location, GLsizei count, const GLint * value), (location, count, value))
GEN_THUNKS(glUniform4ui, (GLint location, GLuint v0, GLuint v1, GLuint v2, GLuint v3), (location, v0, v1, v2, v3))
GEN_THUNKS(glUniform4ui64ARB, (GLint location, GLuint64 x, GLuint64 y, GLuint64 z, GLuint64 w), (location, x, y, z, w))
GEN_THUNKS(glUniform4ui64NV, (GLint location, GLuint64EXT x, GLuint64EXT y, GLuint64EXT z, GLuint64EXT w), (location, x, y, z, w))
GEN_THUNKS(glUniform4ui64vARB, (GLint location, GLsizei count, const GLuint64 * value), (location, count, value))
GEN_THUNKS(glUniform4ui64vNV, (GLint location, GLsizei count, const GLuint64EXT * value), (location, count, value))
GEN_THUNKS(glUniform4uiEXT, (GLint location, GLuint v0, GLuint v1, GLuint v2, GLuint v3), (location, v0, v1, v2, v3))
GEN_THUNKS(glUniform4uiv, (GLint location, GLsizei count, const GLuint * value), (location, count, value))
GEN_THUNKS(glUniform4uivEXT, (GLint location, GLsizei count, const GLuint * value), (location, count, value))
GEN_THUNKS(glUniformBlockBinding, (GLuint program, GLuint uniformBlockIndex, GLuint uniformBlockBinding), (program, uniformBlockIndex, uniformBlockBinding))
GEN_THUNKS(glUniformBufferEXT, (GLuint program, GLint location, GLuint buffer), (program, location, buffer))
GEN_THUNKS(glUniformHandleui64ARB, (GLint location, GLuint64 value), (location, value))
GEN_THUNKS(glUniformHandleui64IMG, (GLint location, GLuint64 value), (location, value))
GEN_THUNKS(glUniformHandleui64NV, (GLint location, GLuint64 value), (location, value))
GEN_THUNKS(glUniformHandleui64vARB, (GLint location, GLsizei count, const GLuint64 * value), (location, count, value))
GEN_THUNKS(glUniformHandleui64vIMG, (GLint location, GLsizei count, const GLuint64 * value), (location, count, value))
GEN_THUNKS(glUniformHandleui64vNV, (GLint location, GLsizei count, const GLuint64 * value), (location, count, value))
GEN_THUNKS(glUniformMatrix2dv, (GLint location, GLsizei count, GLboolean transpose, const GLdouble * value), (location, count, transpose, value))
GEN_THUNKS(glUniformMatrix2fv, (GLint location, GLsizei count, GLboolean transpose, const GLfloat * value), (location, count, transpose, value))
GEN_THUNKS(glUniformMatrix2fvARB, (GLint location, GLsizei count, GLboolean transpose, const GLfloat * value), (location, count, transpose, value))
GEN_THUNKS(glUniformMatrix2x3dv, (GLint location, GLsizei count, GLboolean transpose, const GLdouble * value), (location, count, transpose, value))
GEN_THUNKS(glUniformMatrix2x3fv, (GLint location, GLsizei count, GLboolean transpose, const GLfloat * value), (location, count, transpose, value))
GEN_THUNKS(glUniformMatrix2x3fvNV, (GLint location, GLsizei count, GLboolean transpose, const GLfloat * value), (location, count, transpose, value))
GEN_THUNKS(glUniformMatrix2x4dv, (GLint location, GLsizei count, GLboolean transpose, const GLdouble * value), (location, count, transpose, value))
GEN_THUNKS(glUniformMatrix2x4fv, (GLint location, GLsizei count, GLboolean transpose, const GLfloat * value), (location, count, transpose, value))
GEN_THUNKS(glUniformMatrix2x4fvNV, (GLint location, GLsizei count, GLboolean transpose, const GLfloat * value), (location, count, transpose, value))
GEN_THUNKS(glUniformMatrix3dv, (GLint location, GLsizei count, GLboolean transpose, const GLdouble * value), (location, count, transpose, value))
GEN_THUNKS(glUniformMatrix3fv, (GLint location, GLsizei count, GLboolean transpose, const GLfloat * value), (location, count, transpose, value))
GEN_THUNKS(glUniformMatrix3fvARB, (GLint location, GLsizei count, GLboolean transpose, const GLfloat * value), (location, count, transpose, value))
GEN_THUNKS(glUniformMatrix3x2dv, (GLint location, GLsizei count, GLboolean transpose, const GLdouble * value), (location, count, transpose, value))
GEN_THUNKS(glUniformMatrix3x2fv, (GLint location, GLsizei count, GLboolean transpose, const GLfloat * value), (location, count, transpose, value))
GEN_THUNKS(glUniformMatrix3x2fvNV, (GLint location, GLsizei count, GLboolean transpose, const GLfloat * value), (location, count, transpose, value))
GEN_THUNKS(glUniformMatrix3x4dv, (GLint location, GLsizei count, GLboolean transpose, const GLdouble * value), (location, count, transpose, value))
GEN_THUNKS(glUniformMatrix3x4fv, (GLint location, GLsizei count, GLboolean transpose, const GLfloat * value), (location, count, transpose, value))
GEN_THUNKS(glUniformMatrix3x4fvNV, (GLint location, GLsizei count, GLboolean transpose, const GLfloat * value), (location, count, transpose, value))
GEN_THUNKS(glUniformMatrix4dv, (GLint location, GLsizei count, GLboolean transpose, const GLdouble * value), (location, count, transpose, value))
GEN_THUNKS(glUniformMatrix4fv, (GLint location, GLsizei count, GLboolean transpose, const GLfloat * value), (location, count, transpose, value))
GEN_THUNKS(glUniformMatrix4fvARB, (GLint location, GLsizei count, GLboolean transpose, const GLfloat * value), (location, count, transpose, value))
GEN_THUNKS(glUniformMatrix4x2dv, (GLint location, GLsizei count, GLboolean transpose, const GLdouble * value), (location, count, transpose, value))
GEN_THUNKS(glUniformMatrix4x2fv, (GLint location, GLsizei count, GLboolean transpose, const GLfloat * value), (location, count, transpose, value))
GEN_THUNKS(glUniformMatrix4x2fvNV, (GLint location, GLsizei count, GLboolean transpose, const GLfloat * value), (location, count, transpose, value))
GEN_THUNKS(glUniformMatrix4x3dv, (GLint location, GLsizei count, GLboolean transpose, const GLdouble * value), (location, count, transpose, value))
GEN_THUNKS(glUniformMatrix4x3fv, (GLint location, GLsizei count, GLboolean transpose, const GLfloat * value), (location, count, transpose, value))
GEN_THUNKS(glUniformMatrix4x3fvNV, (GLint location, GLsizei count, GLboolean transpose, const GLfloat * value), (location, count, transpose, value))
GEN_THUNKS(glUniformSubroutinesuiv, (GLenum shadertype, GLsizei count, const GLuint * indices), (shadertype, count, indices))
GEN_THUNKS(glUniformui64NV, (GLint location, GLuint64EXT value), (location, value))
GEN_THUNKS(glUniformui64vNV, (GLint location, GLsizei count, const GLuint64EXT * value), (location, count, value))
GEN_THUNKS(glUnlockArraysEXT, (void), ())
GEN_THUNKS_RET(GLboolean, glUnmapBuffer, (GLenum target), (target))
GEN_THUNKS_RET(GLboolean, glUnmapBufferARB, (GLenum target), (target))
GEN_THUNKS_RET(GLboolean, glUnmapBufferOES, (GLenum target), (target))
GEN_THUNKS_RET(GLboolean, glUnmapNamedBuffer, (GLuint buffer), (buffer))
GEN_THUNKS_RET(GLboolean, glUnmapNamedBufferEXT, (GLuint buffer), (buffer))
GEN_THUNKS(glUnmapObjectBufferATI, (GLuint buffer), (buffer))
GEN_THUNKS(glUnmapTexture2DINTEL, (GLuint texture, GLint level), (texture, level))
GEN_THUNKS(glUpdateObjectBufferATI, (GLuint buffer, GLuint offset, GLsizei size, const void * pointer, GLenum preserve), (buffer, offset, size, pointer, preserve))
GEN_THUNKS(glUploadGpuMaskNVX, (GLbitfield mask), (mask))
GEN_THUNKS(glUseProgram, (GLuint program), (program))
GEN_THUNKS(glUseProgramObjectARB, (GLhandleARB programObj), ((uintptr_t)programObj))
GEN_THUNKS(glUseProgramStages, (GLuint pipeline, GLbitfield stages, GLuint program), (pipeline, stages, program))
GEN_THUNKS(glUseProgramStagesEXT, (GLuint pipeline, GLbitfield stages, GLuint program), (pipeline, stages, program))
GEN_THUNKS(glUseShaderProgramEXT, (GLenum type, GLuint program), (type, program))
GEN_THUNKS(glVDPAUFiniNV, (void), ())
GEN_THUNKS(glVDPAUGetSurfaceivNV, (GLvdpauSurfaceNV surface, GLenum pname, GLsizei bufSize, GLsizei * length, GLint * values), (surface, pname, bufSize, length, values))
GEN_THUNKS(glVDPAUInitNV, (const void * vdpDevice, const void * getProcAddress), (vdpDevice, getProcAddress))
GEN_THUNKS_RET(GLboolean, glVDPAUIsSurfaceNV, (GLvdpauSurfaceNV surface), (surface))
GEN_THUNKS(glVDPAUMapSurfacesNV, (GLsizei numSurfaces, const GLvdpauSurfaceNV * surfaces), (numSurfaces, surfaces))
GEN_THUNKS_RET(GLvdpauSurfaceNV, glVDPAURegisterOutputSurfaceNV, (const void * vdpSurface, GLenum target, GLsizei numTextureNames, const GLuint * textureNames), (vdpSurface, target, numTextureNames, textureNames))
GEN_THUNKS_RET(GLvdpauSurfaceNV, glVDPAURegisterVideoSurfaceNV, (const void * vdpSurface, GLenum target, GLsizei numTextureNames, const GLuint * textureNames), (vdpSurface, target, numTextureNames, textureNames))
GEN_THUNKS_RET(GLvdpauSurfaceNV, glVDPAURegisterVideoSurfaceWithPictureStructureNV, (const void * vdpSurface, GLenum target, GLsizei numTextureNames, const GLuint * textureNames, GLboolean isFrameStructure), (vdpSurface, target, numTextureNames, textureNames, isFrameStructure))
GEN_THUNKS(glVDPAUSurfaceAccessNV, (GLvdpauSurfaceNV surface, GLenum access), (surface, access))
GEN_THUNKS(glVDPAUUnmapSurfacesNV, (GLsizei numSurface, const GLvdpauSurfaceNV * surfaces), (numSurface, surfaces))
GEN_THUNKS(glVDPAUUnregisterSurfaceNV, (GLvdpauSurfaceNV surface), (surface))
GEN_THUNKS(glValidateProgram, (GLuint program), (program))
GEN_THUNKS(glValidateProgramARB, (GLhandleARB programObj), ((uintptr_t)programObj))
GEN_THUNKS(glValidateProgramPipeline, (GLuint pipeline), (pipeline))
GEN_THUNKS(glValidateProgramPipelineEXT, (GLuint pipeline), (pipeline))
GEN_THUNKS(glVariantArrayObjectATI, (GLuint id, GLenum type, GLsizei stride, GLuint buffer, GLuint offset), (id, type, stride, buffer, offset))
GEN_THUNKS(glVariantPointerEXT, (GLuint id, GLenum type, GLuint stride, const void * addr), (id, type, stride, addr))
GEN_THUNKS(glVariantbvEXT, (GLuint id, const GLbyte * addr), (id, addr))
GEN_THUNKS(glVariantdvEXT, (GLuint id, const GLdouble * addr), (id, addr))
GEN_THUNKS(glVariantfvEXT, (GLuint id, const GLfloat * addr), (id, addr))
GEN_THUNKS(glVariantivEXT, (GLuint id, const GLint * addr), (id, addr))
GEN_THUNKS(glVariantsvEXT, (GLuint id, const GLshort * addr), (id, addr))
GEN_THUNKS(glVariantubvEXT, (GLuint id, const GLubyte * addr), (id, addr))
GEN_THUNKS(glVariantuivEXT, (GLuint id, const GLuint * addr), (id, addr))
GEN_THUNKS(glVariantusvEXT, (GLuint id, const GLushort * addr), (id, addr))
GEN_THUNKS(glVertex2bOES, (GLbyte x, GLbyte y), (x, y))
GEN_THUNKS(glVertex2bvOES, (const GLbyte * coords), (coords))
GEN_THUNKS(glVertex2d, (GLdouble x, GLdouble y), (x, y))
GEN_THUNKS(glVertex2dv, (const GLdouble * v), (v))
GEN_THUNKS(glVertex2f, (GLfloat x, GLfloat y), (x, y))
GEN_THUNKS(glVertex2fv, (const GLfloat * v), (v))
GEN_THUNKS(glVertex2hNV, (GLhalfNV x, GLhalfNV y), (x, y))
GEN_THUNKS(glVertex2hvNV, (const GLhalfNV * v), (v))
GEN_THUNKS(glVertex2i, (GLint x, GLint y), (x, y))
GEN_THUNKS(glVertex2iv, (const GLint * v), (v))
GEN_THUNKS(glVertex2s, (GLshort x, GLshort y), (x, y))
GEN_THUNKS(glVertex2sv, (const GLshort * v), (v))
GEN_THUNKS(glVertex2xOES, (GLfixed x), (x))
GEN_THUNKS(glVertex2xvOES, (const GLfixed * coords), (coords))
GEN_THUNKS(glVertex3bOES, (GLbyte x, GLbyte y, GLbyte z), (x, y, z))
GEN_THUNKS(glVertex3bvOES, (const GLbyte * coords), (coords))
GEN_THUNKS(glVertex3d, (GLdouble x, GLdouble y, GLdouble z), (x, y, z))
GEN_THUNKS(glVertex3dv, (const GLdouble * v), (v))
GEN_THUNKS(glVertex3f, (GLfloat x, GLfloat y, GLfloat z), (x, y, z))
GEN_THUNKS(glVertex3fv, (const GLfloat * v), (v))
GEN_THUNKS(glVertex3hNV, (GLhalfNV x, GLhalfNV y, GLhalfNV z), (x, y, z))
GEN_THUNKS(glVertex3hvNV, (const GLhalfNV * v), (v))
GEN_THUNKS(glVertex3i, (GLint x, GLint y, GLint z), (x, y, z))
GEN_THUNKS(glVertex3iv, (const GLint * v), (v))
GEN_THUNKS(glVertex3s, (GLshort x, GLshort y, GLshort z), (x, y, z))
GEN_THUNKS(glVertex3sv, (const GLshort * v), (v))
GEN_THUNKS(glVertex3xOES, (GLfixed x, GLfixed y), (x, y))
GEN_THUNKS(glVertex3xvOES, (const GLfixed * coords), (coords))
GEN_THUNKS(glVertex4bOES, (GLbyte x, GLbyte y, GLbyte z, GLbyte w), (x, y, z, w))
GEN_THUNKS(glVertex4bvOES, (const GLbyte * coords), (coords))
GEN_THUNKS(glVertex4d, (GLdouble x, GLdouble y, GLdouble z, GLdouble w), (x, y, z, w))
GEN_THUNKS(glVertex4dv, (const GLdouble * v), (v))
GEN_THUNKS(glVertex4f, (GLfloat x, GLfloat y, GLfloat z, GLfloat w), (x, y, z, w))
GEN_THUNKS(glVertex4fv, (const GLfloat * v), (v))
GEN_THUNKS(glVertex4hNV, (GLhalfNV x, GLhalfNV y, GLhalfNV z, GLhalfNV w), (x, y, z, w))
GEN_THUNKS(glVertex4hvNV, (const GLhalfNV * v), (v))
GEN_THUNKS(glVertex4i, (GLint x, GLint y, GLint z, GLint w), (x, y, z, w))
GEN_THUNKS(glVertex4iv, (const GLint * v), (v))
GEN_THUNKS(glVertex4s, (GLshort x, GLshort y, GLshort z, GLshort w), (x, y, z, w))
GEN_THUNKS(glVertex4sv, (const GLshort * v), (v))
GEN_THUNKS(glVertex4xOES, (GLfixed x, GLfixed y, GLfixed z), (x, y, z))
GEN_THUNKS(glVertex4xvOES, (const GLfixed * coords), (coords))
GEN_THUNKS(glVertexArrayAttribBinding, (GLuint vaobj, GLuint attribindex, GLuint bindingindex), (vaobj, attribindex, bindingindex))
GEN_THUNKS(glVertexArrayAttribFormat, (GLuint vaobj, GLuint attribindex, GLint size, GLenum type, GLboolean normalized, GLuint relativeoffset), (vaobj, attribindex, size, type, normalized, relativeoffset))
GEN_THUNKS(glVertexArrayAttribIFormat, (GLuint vaobj, GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset), (vaobj, attribindex, size, type, relativeoffset))
GEN_THUNKS(glVertexArrayAttribLFormat, (GLuint vaobj, GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset), (vaobj, attribindex, size, type, relativeoffset))
GEN_THUNKS(glVertexArrayBindVertexBufferEXT, (GLuint vaobj, GLuint bindingindex, GLuint buffer, GLintptr offset, GLsizei stride), (vaobj, bindingindex, buffer, offset, stride))
GEN_THUNKS(glVertexArrayBindingDivisor, (GLuint vaobj, GLuint bindingindex, GLuint divisor), (vaobj, bindingindex, divisor))
GEN_THUNKS(glVertexArrayColorOffsetEXT, (GLuint vaobj, GLuint buffer, GLint size, GLenum type, GLsizei stride, GLintptr offset), (vaobj, buffer, size, type, stride, offset))
GEN_THUNKS(glVertexArrayEdgeFlagOffsetEXT, (GLuint vaobj, GLuint buffer, GLsizei stride, GLintptr offset), (vaobj, buffer, stride, offset))
GEN_THUNKS(glVertexArrayElementBuffer, (GLuint vaobj, GLuint buffer), (vaobj, buffer))
GEN_THUNKS(glVertexArrayFogCoordOffsetEXT, (GLuint vaobj, GLuint buffer, GLenum type, GLsizei stride, GLintptr offset), (vaobj, buffer, type, stride, offset))
GEN_THUNKS(glVertexArrayIndexOffsetEXT, (GLuint vaobj, GLuint buffer, GLenum type, GLsizei stride, GLintptr offset), (vaobj, buffer, type, stride, offset))
GEN_THUNKS(glVertexArrayMultiTexCoordOffsetEXT, (GLuint vaobj, GLuint buffer, GLenum texunit, GLint size, GLenum type, GLsizei stride, GLintptr offset), (vaobj, buffer, texunit, size, type, stride, offset))
GEN_THUNKS(glVertexArrayNormalOffsetEXT, (GLuint vaobj, GLuint buffer, GLenum type, GLsizei stride, GLintptr offset), (vaobj, buffer, type, stride, offset))
GEN_THUNKS(glVertexArrayParameteriAPPLE, (GLenum pname, GLint param), (pname, param))
GEN_THUNKS(glVertexArrayRangeAPPLE, (GLsizei length, void * pointer), (length, pointer))
GEN_THUNKS(glVertexArrayRangeNV, (GLsizei length, const void * pointer), (length, pointer))
GEN_THUNKS(glVertexArraySecondaryColorOffsetEXT, (GLuint vaobj, GLuint buffer, GLint size, GLenum type, GLsizei stride, GLintptr offset), (vaobj, buffer, size, type, stride, offset))
GEN_THUNKS(glVertexArrayTexCoordOffsetEXT, (GLuint vaobj, GLuint buffer, GLint size, GLenum type, GLsizei stride, GLintptr offset), (vaobj, buffer, size, type, stride, offset))
GEN_THUNKS(glVertexArrayVertexAttribBindingEXT, (GLuint vaobj, GLuint attribindex, GLuint bindingindex), (vaobj, attribindex, bindingindex))
GEN_THUNKS(glVertexArrayVertexAttribDivisorEXT, (GLuint vaobj, GLuint index, GLuint divisor), (vaobj, index, divisor))
GEN_THUNKS(glVertexArrayVertexAttribFormatEXT, (GLuint vaobj, GLuint attribindex, GLint size, GLenum type, GLboolean normalized, GLuint relativeoffset), (vaobj, attribindex, size, type, normalized, relativeoffset))
GEN_THUNKS(glVertexArrayVertexAttribIFormatEXT, (GLuint vaobj, GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset), (vaobj, attribindex, size, type, relativeoffset))
GEN_THUNKS(glVertexArrayVertexAttribIOffsetEXT, (GLuint vaobj, GLuint buffer, GLuint index, GLint size, GLenum type, GLsizei stride, GLintptr offset), (vaobj, buffer, index, size, type, stride, offset))
GEN_THUNKS(glVertexArrayVertexAttribLFormatEXT, (GLuint vaobj, GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset), (vaobj, attribindex, size, type, relativeoffset))
GEN_THUNKS(glVertexArrayVertexAttribLOffsetEXT, (GLuint vaobj, GLuint buffer, GLuint index, GLint size, GLenum type, GLsizei stride, GLintptr offset), (vaobj, buffer, index, size, type, stride, offset))
GEN_THUNKS(glVertexArrayVertexAttribOffsetEXT, (GLuint vaobj, GLuint buffer, GLuint index, GLint size, GLenum type, GLboolean normalized, GLsizei stride, GLintptr offset), (vaobj, buffer, index, size, type, normalized, stride, offset))
GEN_THUNKS(glVertexArrayVertexBindingDivisorEXT, (GLuint vaobj, GLuint bindingindex, GLuint divisor), (vaobj, bindingindex, divisor))
GEN_THUNKS(glVertexArrayVertexBuffer, (GLuint vaobj, GLuint bindingindex, GLuint buffer, GLintptr offset, GLsizei stride), (vaobj, bindingindex, buffer, offset, stride))
GEN_THUNKS(glVertexArrayVertexBuffers, (GLuint vaobj, GLuint first, GLsizei count, const GLuint * buffers, const GLintptr * offsets, const GLsizei * strides), (vaobj, first, count, buffers, offsets, strides))
GEN_THUNKS(glVertexArrayVertexOffsetEXT, (GLuint vaobj, GLuint buffer, GLint size, GLenum type, GLsizei stride, GLintptr offset), (vaobj, buffer, size, type, stride, offset))
GEN_THUNKS(glVertexAttrib1d, (GLuint index, GLdouble x), (index, x))
GEN_THUNKS(glVertexAttrib1dARB, (GLuint index, GLdouble x), (index, x))
GEN_THUNKS(glVertexAttrib1dNV, (GLuint index, GLdouble x), (index, x))
GEN_THUNKS(glVertexAttrib1dv, (GLuint index, const GLdouble * v), (index, v))
GEN_THUNKS(glVertexAttrib1dvARB, (GLuint index, const GLdouble * v), (index, v))
GEN_THUNKS(glVertexAttrib1dvNV, (GLuint index, const GLdouble * v), (index, v))
GEN_THUNKS(glVertexAttrib1f, (GLuint index, GLfloat x), (index, x))
GEN_THUNKS(glVertexAttrib1fARB, (GLuint index, GLfloat x), (index, x))
GEN_THUNKS(glVertexAttrib1fNV, (GLuint index, GLfloat x), (index, x))
GEN_THUNKS(glVertexAttrib1fv, (GLuint index, const GLfloat * v), (index, v))
GEN_THUNKS(glVertexAttrib1fvARB, (GLuint index, const GLfloat * v), (index, v))
GEN_THUNKS(glVertexAttrib1fvNV, (GLuint index, const GLfloat * v), (index, v))
GEN_THUNKS(glVertexAttrib1hNV, (GLuint index, GLhalfNV x), (index, x))
GEN_THUNKS(glVertexAttrib1hvNV, (GLuint index, const GLhalfNV * v), (index, v))
GEN_THUNKS(glVertexAttrib1s, (GLuint index, GLshort x), (index, x))
GEN_THUNKS(glVertexAttrib1sARB, (GLuint index, GLshort x), (index, x))
GEN_THUNKS(glVertexAttrib1sNV, (GLuint index, GLshort x), (index, x))
GEN_THUNKS(glVertexAttrib1sv, (GLuint index, const GLshort * v), (index, v))
GEN_THUNKS(glVertexAttrib1svARB, (GLuint index, const GLshort * v), (index, v))
GEN_THUNKS(glVertexAttrib1svNV, (GLuint index, const GLshort * v), (index, v))
GEN_THUNKS(glVertexAttrib2d, (GLuint index, GLdouble x, GLdouble y), (index, x, y))
GEN_THUNKS(glVertexAttrib2dARB, (GLuint index, GLdouble x, GLdouble y), (index, x, y))
GEN_THUNKS(glVertexAttrib2dNV, (GLuint index, GLdouble x, GLdouble y), (index, x, y))
GEN_THUNKS(glVertexAttrib2dv, (GLuint index, const GLdouble * v), (index, v))
GEN_THUNKS(glVertexAttrib2dvARB, (GLuint index, const GLdouble * v), (index, v))
GEN_THUNKS(glVertexAttrib2dvNV, (GLuint index, const GLdouble * v), (index, v))
GEN_THUNKS(glVertexAttrib2f, (GLuint index, GLfloat x, GLfloat y), (index, x, y))
GEN_THUNKS(glVertexAttrib2fARB, (GLuint index, GLfloat x, GLfloat y), (index, x, y))
GEN_THUNKS(glVertexAttrib2fNV, (GLuint index, GLfloat x, GLfloat y), (index, x, y))
GEN_THUNKS(glVertexAttrib2fv, (GLuint index, const GLfloat * v), (index, v))
GEN_THUNKS(glVertexAttrib2fvARB, (GLuint index, const GLfloat * v), (index, v))
GEN_THUNKS(glVertexAttrib2fvNV, (GLuint index, const GLfloat * v), (index, v))
GEN_THUNKS(glVertexAttrib2hNV, (GLuint index, GLhalfNV x, GLhalfNV y), (index, x, y))
GEN_THUNKS(glVertexAttrib2hvNV, (GLuint index, const GLhalfNV * v), (index, v))
GEN_THUNKS(glVertexAttrib2s, (GLuint index, GLshort x, GLshort y), (index, x, y))
GEN_THUNKS(glVertexAttrib2sARB, (GLuint index, GLshort x, GLshort y), (index, x, y))
GEN_THUNKS(glVertexAttrib2sNV, (GLuint index, GLshort x, GLshort y), (index, x, y))
GEN_THUNKS(glVertexAttrib2sv, (GLuint index, const GLshort * v), (index, v))
GEN_THUNKS(glVertexAttrib2svARB, (GLuint index, const GLshort * v), (index, v))
GEN_THUNKS(glVertexAttrib2svNV, (GLuint index, const GLshort * v), (index, v))
GEN_THUNKS(glVertexAttrib3d, (GLuint index, GLdouble x, GLdouble y, GLdouble z), (index, x, y, z))
GEN_THUNKS(glVertexAttrib3dARB, (GLuint index, GLdouble x, GLdouble y, GLdouble z), (index, x, y, z))
GEN_THUNKS(glVertexAttrib3dNV, (GLuint index, GLdouble x, GLdouble y, GLdouble z), (index, x, y, z))
GEN_THUNKS(glVertexAttrib3dv, (GLuint index, const GLdouble * v), (index, v))
GEN_THUNKS(glVertexAttrib3dvARB, (GLuint index, const GLdouble * v), (index, v))
GEN_THUNKS(glVertexAttrib3dvNV, (GLuint index, const GLdouble * v), (index, v))
GEN_THUNKS(glVertexAttrib3f, (GLuint index, GLfloat x, GLfloat y, GLfloat z), (index, x, y, z))
GEN_THUNKS(glVertexAttrib3fARB, (GLuint index, GLfloat x, GLfloat y, GLfloat z), (index, x, y, z))
GEN_THUNKS(glVertexAttrib3fNV, (GLuint index, GLfloat x, GLfloat y, GLfloat z), (index, x, y, z))
GEN_THUNKS(glVertexAttrib3fv, (GLuint index, const GLfloat * v), (index, v))
GEN_THUNKS(glVertexAttrib3fvARB, (GLuint index, const GLfloat * v), (index, v))
GEN_THUNKS(glVertexAttrib3fvNV, (GLuint index, const GLfloat * v), (index, v))
GEN_THUNKS(glVertexAttrib3hNV, (GLuint index, GLhalfNV x, GLhalfNV y, GLhalfNV z), (index, x, y, z))
GEN_THUNKS(glVertexAttrib3hvNV, (GLuint index, const GLhalfNV * v), (index, v))
GEN_THUNKS(glVertexAttrib3s, (GLuint index, GLshort x, GLshort y, GLshort z), (index, x, y, z))
GEN_THUNKS(glVertexAttrib3sARB, (GLuint index, GLshort x, GLshort y, GLshort z), (index, x, y, z))
GEN_THUNKS(glVertexAttrib3sNV, (GLuint index, GLshort x, GLshort y, GLshort z), (index, x, y, z))
GEN_THUNKS(glVertexAttrib3sv, (GLuint index, const GLshort * v), (index, v))
GEN_THUNKS(glVertexAttrib3svARB, (GLuint index, const GLshort * v), (index, v))
GEN_THUNKS(glVertexAttrib3svNV, (GLuint index, const GLshort * v), (index, v))
GEN_THUNKS(glVertexAttrib4Nbv, (GLuint index, const GLbyte * v), (index, v))
GEN_THUNKS(glVertexAttrib4NbvARB, (GLuint index, const GLbyte * v), (index, v))
GEN_THUNKS(glVertexAttrib4Niv, (GLuint index, const GLint * v), (index, v))
GEN_THUNKS(glVertexAttrib4NivARB, (GLuint index, const GLint * v), (index, v))
GEN_THUNKS(glVertexAttrib4Nsv, (GLuint index, const GLshort * v), (index, v))
GEN_THUNKS(glVertexAttrib4NsvARB, (GLuint index, const GLshort * v), (index, v))
GEN_THUNKS(glVertexAttrib4Nub, (GLuint index, GLubyte x, GLubyte y, GLubyte z, GLubyte w), (index, x, y, z, w))
GEN_THUNKS(glVertexAttrib4NubARB, (GLuint index, GLubyte x, GLubyte y, GLubyte z, GLubyte w), (index, x, y, z, w))
GEN_THUNKS(glVertexAttrib4Nubv, (GLuint index, const GLubyte * v), (index, v))
GEN_THUNKS(glVertexAttrib4NubvARB, (GLuint index, const GLubyte * v), (index, v))
GEN_THUNKS(glVertexAttrib4Nuiv, (GLuint index, const GLuint * v), (index, v))
GEN_THUNKS(glVertexAttrib4NuivARB, (GLuint index, const GLuint * v), (index, v))
GEN_THUNKS(glVertexAttrib4Nusv, (GLuint index, const GLushort * v), (index, v))
GEN_THUNKS(glVertexAttrib4NusvARB, (GLuint index, const GLushort * v), (index, v))
GEN_THUNKS(glVertexAttrib4bv, (GLuint index, const GLbyte * v), (index, v))
GEN_THUNKS(glVertexAttrib4bvARB, (GLuint index, const GLbyte * v), (index, v))
GEN_THUNKS(glVertexAttrib4d, (GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w), (index, x, y, z, w))
GEN_THUNKS(glVertexAttrib4dARB, (GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w), (index, x, y, z, w))
GEN_THUNKS(glVertexAttrib4dNV, (GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w), (index, x, y, z, w))
GEN_THUNKS(glVertexAttrib4dv, (GLuint index, const GLdouble * v), (index, v))
GEN_THUNKS(glVertexAttrib4dvARB, (GLuint index, const GLdouble * v), (index, v))
GEN_THUNKS(glVertexAttrib4dvNV, (GLuint index, const GLdouble * v), (index, v))
GEN_THUNKS(glVertexAttrib4f, (GLuint index, GLfloat x, GLfloat y, GLfloat z, GLfloat w), (index, x, y, z, w))
GEN_THUNKS(glVertexAttrib4fARB, (GLuint index, GLfloat x, GLfloat y, GLfloat z, GLfloat w), (index, x, y, z, w))
GEN_THUNKS(glVertexAttrib4fNV, (GLuint index, GLfloat x, GLfloat y, GLfloat z, GLfloat w), (index, x, y, z, w))
GEN_THUNKS(glVertexAttrib4fv, (GLuint index, const GLfloat * v), (index, v))
GEN_THUNKS(glVertexAttrib4fvARB, (GLuint index, const GLfloat * v), (index, v))
GEN_THUNKS(glVertexAttrib4fvNV, (GLuint index, const GLfloat * v), (index, v))
GEN_THUNKS(glVertexAttrib4hNV, (GLuint index, GLhalfNV x, GLhalfNV y, GLhalfNV z, GLhalfNV w), (index, x, y, z, w))
GEN_THUNKS(glVertexAttrib4hvNV, (GLuint index, const GLhalfNV * v), (index, v))
GEN_THUNKS(glVertexAttrib4iv, (GLuint index, const GLint * v), (index, v))
GEN_THUNKS(glVertexAttrib4ivARB, (GLuint index, const GLint * v), (index, v))
GEN_THUNKS(glVertexAttrib4s, (GLuint index, GLshort x, GLshort y, GLshort z, GLshort w), (index, x, y, z, w))
GEN_THUNKS(glVertexAttrib4sARB, (GLuint index, GLshort x, GLshort y, GLshort z, GLshort w), (index, x, y, z, w))
GEN_THUNKS(glVertexAttrib4sNV, (GLuint index, GLshort x, GLshort y, GLshort z, GLshort w), (index, x, y, z, w))
GEN_THUNKS(glVertexAttrib4sv, (GLuint index, const GLshort * v), (index, v))
GEN_THUNKS(glVertexAttrib4svARB, (GLuint index, const GLshort * v), (index, v))
GEN_THUNKS(glVertexAttrib4svNV, (GLuint index, const GLshort * v), (index, v))
GEN_THUNKS(glVertexAttrib4ubNV, (GLuint index, GLubyte x, GLubyte y, GLubyte z, GLubyte w), (index, x, y, z, w))
GEN_THUNKS(glVertexAttrib4ubv, (GLuint index, const GLubyte * v), (index, v))
GEN_THUNKS(glVertexAttrib4ubvARB, (GLuint index, const GLubyte * v), (index, v))
GEN_THUNKS(glVertexAttrib4ubvNV, (GLuint index, const GLubyte * v), (index, v))
GEN_THUNKS(glVertexAttrib4uiv, (GLuint index, const GLuint * v), (index, v))
GEN_THUNKS(glVertexAttrib4uivARB, (GLuint index, const GLuint * v), (index, v))
GEN_THUNKS(glVertexAttrib4usv, (GLuint index, const GLushort * v), (index, v))
GEN_THUNKS(glVertexAttrib4usvARB, (GLuint index, const GLushort * v), (index, v))
GEN_THUNKS(glVertexAttribArrayObjectATI, (GLuint index, GLint size, GLenum type, GLboolean normalized, GLsizei stride, GLuint buffer, GLuint offset), (index, size, type, normalized, stride, buffer, offset))
GEN_THUNKS(glVertexAttribBinding, (GLuint attribindex, GLuint bindingindex), (attribindex, bindingindex))
GEN_THUNKS(glVertexAttribDivisor, (GLuint index, GLuint divisor), (index, divisor))
GEN_THUNKS(glVertexAttribDivisorANGLE, (GLuint index, GLuint divisor), (index, divisor))
GEN_THUNKS(glVertexAttribDivisorARB, (GLuint index, GLuint divisor), (index, divisor))
GEN_THUNKS(glVertexAttribDivisorEXT, (GLuint index, GLuint divisor), (index, divisor))
GEN_THUNKS(glVertexAttribDivisorNV, (GLuint index, GLuint divisor), (index, divisor))
GEN_THUNKS(glVertexAttribFormat, (GLuint attribindex, GLint size, GLenum type, GLboolean normalized, GLuint relativeoffset), (attribindex, size, type, normalized, relativeoffset))
GEN_THUNKS(glVertexAttribFormatNV, (GLuint index, GLint size, GLenum type, GLboolean normalized, GLsizei stride), (index, size, type, normalized, stride))
GEN_THUNKS(glVertexAttribI1i, (GLuint index, GLint x), (index, x))
GEN_THUNKS(glVertexAttribI1iEXT, (GLuint index, GLint x), (index, x))
GEN_THUNKS(glVertexAttribI1iv, (GLuint index, const GLint * v), (index, v))
GEN_THUNKS(glVertexAttribI1ivEXT, (GLuint index, const GLint * v), (index, v))
GEN_THUNKS(glVertexAttribI1ui, (GLuint index, GLuint x), (index, x))
GEN_THUNKS(glVertexAttribI1uiEXT, (GLuint index, GLuint x), (index, x))
GEN_THUNKS(glVertexAttribI1uiv, (GLuint index, const GLuint * v), (index, v))
GEN_THUNKS(glVertexAttribI1uivEXT, (GLuint index, const GLuint * v), (index, v))
GEN_THUNKS(glVertexAttribI2i, (GLuint index, GLint x, GLint y), (index, x, y))
GEN_THUNKS(glVertexAttribI2iEXT, (GLuint index, GLint x, GLint y), (index, x, y))
GEN_THUNKS(glVertexAttribI2iv, (GLuint index, const GLint * v), (index, v))
GEN_THUNKS(glVertexAttribI2ivEXT, (GLuint index, const GLint * v), (index, v))
GEN_THUNKS(glVertexAttribI2ui, (GLuint index, GLuint x, GLuint y), (index, x, y))
GEN_THUNKS(glVertexAttribI2uiEXT, (GLuint index, GLuint x, GLuint y), (index, x, y))
GEN_THUNKS(glVertexAttribI2uiv, (GLuint index, const GLuint * v), (index, v))
GEN_THUNKS(glVertexAttribI2uivEXT, (GLuint index, const GLuint * v), (index, v))
GEN_THUNKS(glVertexAttribI3i, (GLuint index, GLint x, GLint y, GLint z), (index, x, y, z))
GEN_THUNKS(glVertexAttribI3iEXT, (GLuint index, GLint x, GLint y, GLint z), (index, x, y, z))
GEN_THUNKS(glVertexAttribI3iv, (GLuint index, const GLint * v), (index, v))
GEN_THUNKS(glVertexAttribI3ivEXT, (GLuint index, const GLint * v), (index, v))
GEN_THUNKS(glVertexAttribI3ui, (GLuint index, GLuint x, GLuint y, GLuint z), (index, x, y, z))
GEN_THUNKS(glVertexAttribI3uiEXT, (GLuint index, GLuint x, GLuint y, GLuint z), (index, x, y, z))
GEN_THUNKS(glVertexAttribI3uiv, (GLuint index, const GLuint * v), (index, v))
GEN_THUNKS(glVertexAttribI3uivEXT, (GLuint index, const GLuint * v), (index, v))
GEN_THUNKS(glVertexAttribI4bv, (GLuint index, const GLbyte * v), (index, v))
GEN_THUNKS(glVertexAttribI4bvEXT, (GLuint index, const GLbyte * v), (index, v))
GEN_THUNKS(glVertexAttribI4i, (GLuint index, GLint x, GLint y, GLint z, GLint w), (index, x, y, z, w))
GEN_THUNKS(glVertexAttribI4iEXT, (GLuint index, GLint x, GLint y, GLint z, GLint w), (index, x, y, z, w))
GEN_THUNKS(glVertexAttribI4iv, (GLuint index, const GLint * v), (index, v))
GEN_THUNKS(glVertexAttribI4ivEXT, (GLuint index, const GLint * v), (index, v))
GEN_THUNKS(glVertexAttribI4sv, (GLuint index, const GLshort * v), (index, v))
GEN_THUNKS(glVertexAttribI4svEXT, (GLuint index, const GLshort * v), (index, v))
GEN_THUNKS(glVertexAttribI4ubv, (GLuint index, const GLubyte * v), (index, v))
GEN_THUNKS(glVertexAttribI4ubvEXT, (GLuint index, const GLubyte * v), (index, v))
GEN_THUNKS(glVertexAttribI4ui, (GLuint index, GLuint x, GLuint y, GLuint z, GLuint w), (index, x, y, z, w))
GEN_THUNKS(glVertexAttribI4uiEXT, (GLuint index, GLuint x, GLuint y, GLuint z, GLuint w), (index, x, y, z, w))
GEN_THUNKS(glVertexAttribI4uiv, (GLuint index, const GLuint * v), (index, v))
GEN_THUNKS(glVertexAttribI4uivEXT, (GLuint index, const GLuint * v), (index, v))
GEN_THUNKS(glVertexAttribI4usv, (GLuint index, const GLushort * v), (index, v))
GEN_THUNKS(glVertexAttribI4usvEXT, (GLuint index, const GLushort * v), (index, v))
GEN_THUNKS(glVertexAttribIFormat, (GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset), (attribindex, size, type, relativeoffset))
GEN_THUNKS(glVertexAttribIFormatNV, (GLuint index, GLint size, GLenum type, GLsizei stride), (index, size, type, stride))
GEN_THUNKS(glVertexAttribIPointer, (GLuint index, GLint size, GLenum type, GLsizei stride, const void * pointer), (index, size, type, stride, pointer))
GEN_THUNKS(glVertexAttribIPointerEXT, (GLuint index, GLint size, GLenum type, GLsizei stride, const void * pointer), (index, size, type, stride, pointer))
GEN_THUNKS(glVertexAttribL1d, (GLuint index, GLdouble x), (index, x))
GEN_THUNKS(glVertexAttribL1dEXT, (GLuint index, GLdouble x), (index, x))
GEN_THUNKS(glVertexAttribL1dv, (GLuint index, const GLdouble * v), (index, v))
GEN_THUNKS(glVertexAttribL1dvEXT, (GLuint index, const GLdouble * v), (index, v))
GEN_THUNKS(glVertexAttribL1i64NV, (GLuint index, GLint64EXT x), (index, x))
GEN_THUNKS(glVertexAttribL1i64vNV, (GLuint index, const GLint64EXT * v), (index, v))
GEN_THUNKS(glVertexAttribL1ui64ARB, (GLuint index, GLuint64EXT x), (index, x))
GEN_THUNKS(glVertexAttribL1ui64NV, (GLuint index, GLuint64EXT x), (index, x))
GEN_THUNKS(glVertexAttribL1ui64vARB, (GLuint index, const GLuint64EXT * v), (index, v))
GEN_THUNKS(glVertexAttribL1ui64vNV, (GLuint index, const GLuint64EXT * v), (index, v))
GEN_THUNKS(glVertexAttribL2d, (GLuint index, GLdouble x, GLdouble y), (index, x, y))
GEN_THUNKS(glVertexAttribL2dEXT, (GLuint index, GLdouble x, GLdouble y), (index, x, y))
GEN_THUNKS(glVertexAttribL2dv, (GLuint index, const GLdouble * v), (index, v))
GEN_THUNKS(glVertexAttribL2dvEXT, (GLuint index, const GLdouble * v), (index, v))
GEN_THUNKS(glVertexAttribL2i64NV, (GLuint index, GLint64EXT x, GLint64EXT y), (index, x, y))
GEN_THUNKS(glVertexAttribL2i64vNV, (GLuint index, const GLint64EXT * v), (index, v))
GEN_THUNKS(glVertexAttribL2ui64NV, (GLuint index, GLuint64EXT x, GLuint64EXT y), (index, x, y))
GEN_THUNKS(glVertexAttribL2ui64vNV, (GLuint index, const GLuint64EXT * v), (index, v))
GEN_THUNKS(glVertexAttribL3d, (GLuint index, GLdouble x, GLdouble y, GLdouble z), (index, x, y, z))
GEN_THUNKS(glVertexAttribL3dEXT, (GLuint index, GLdouble x, GLdouble y, GLdouble z), (index, x, y, z))
GEN_THUNKS(glVertexAttribL3dv, (GLuint index, const GLdouble * v), (index, v))
GEN_THUNKS(glVertexAttribL3dvEXT, (GLuint index, const GLdouble * v), (index, v))
GEN_THUNKS(glVertexAttribL3i64NV, (GLuint index, GLint64EXT x, GLint64EXT y, GLint64EXT z), (index, x, y, z))
GEN_THUNKS(glVertexAttribL3i64vNV, (GLuint index, const GLint64EXT * v), (index, v))
GEN_THUNKS(glVertexAttribL3ui64NV, (GLuint index, GLuint64EXT x, GLuint64EXT y, GLuint64EXT z), (index, x, y, z))
GEN_THUNKS(glVertexAttribL3ui64vNV, (GLuint index, const GLuint64EXT * v), (index, v))
GEN_THUNKS(glVertexAttribL4d, (GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w), (index, x, y, z, w))
GEN_THUNKS(glVertexAttribL4dEXT, (GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w), (index, x, y, z, w))
GEN_THUNKS(glVertexAttribL4dv, (GLuint index, const GLdouble * v), (index, v))
GEN_THUNKS(glVertexAttribL4dvEXT, (GLuint index, const GLdouble * v), (index, v))
GEN_THUNKS(glVertexAttribL4i64NV, (GLuint index, GLint64EXT x, GLint64EXT y, GLint64EXT z, GLint64EXT w), (index, x, y, z, w))
GEN_THUNKS(glVertexAttribL4i64vNV, (GLuint index, const GLint64EXT * v), (index, v))
GEN_THUNKS(glVertexAttribL4ui64NV, (GLuint index, GLuint64EXT x, GLuint64EXT y, GLuint64EXT z, GLuint64EXT w), (index, x, y, z, w))
GEN_THUNKS(glVertexAttribL4ui64vNV, (GLuint index, const GLuint64EXT * v), (index, v))
GEN_THUNKS(glVertexAttribLFormat, (GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset), (attribindex, size, type, relativeoffset))
GEN_THUNKS(glVertexAttribLFormatNV, (GLuint index, GLint size, GLenum type, GLsizei stride), (index, size, type, stride))
GEN_THUNKS(glVertexAttribLPointer, (GLuint index, GLint size, GLenum type, GLsizei stride, const void * pointer), (index, size, type, stride, pointer))
GEN_THUNKS(glVertexAttribLPointerEXT, (GLuint index, GLint size, GLenum type, GLsizei stride, const void * pointer), (index, size, type, stride, pointer))
GEN_THUNKS(glVertexAttribP1ui, (GLuint index, GLenum type, GLboolean normalized, GLuint value), (index, type, normalized, value))
GEN_THUNKS(glVertexAttribP1uiv, (GLuint index, GLenum type, GLboolean normalized, const GLuint * value), (index, type, normalized, value))
GEN_THUNKS(glVertexAttribP2ui, (GLuint index, GLenum type, GLboolean normalized, GLuint value), (index, type, normalized, value))
GEN_THUNKS(glVertexAttribP2uiv, (GLuint index, GLenum type, GLboolean normalized, const GLuint * value), (index, type, normalized, value))
GEN_THUNKS(glVertexAttribP3ui, (GLuint index, GLenum type, GLboolean normalized, GLuint value), (index, type, normalized, value))
GEN_THUNKS(glVertexAttribP3uiv, (GLuint index, GLenum type, GLboolean normalized, const GLuint * value), (index, type, normalized, value))
GEN_THUNKS(glVertexAttribP4ui, (GLuint index, GLenum type, GLboolean normalized, GLuint value), (index, type, normalized, value))
GEN_THUNKS(glVertexAttribP4uiv, (GLuint index, GLenum type, GLboolean normalized, const GLuint * value), (index, type, normalized, value))
GEN_THUNKS(glVertexAttribParameteriAMD, (GLuint index, GLenum pname, GLint param), (index, pname, param))
GEN_THUNKS(glVertexAttribPointer, (GLuint index, GLint size, GLenum type, GLboolean normalized, GLsizei stride, const void * pointer), (index, size, type, normalized, stride, pointer))
GEN_THUNKS(glVertexAttribPointerARB, (GLuint index, GLint size, GLenum type, GLboolean normalized, GLsizei stride, const void * pointer), (index, size, type, normalized, stride, pointer))
GEN_THUNKS(glVertexAttribPointerNV, (GLuint index, GLint fsize, GLenum type, GLsizei stride, const void * pointer), (index, fsize, type, stride, pointer))
GEN_THUNKS(glVertexAttribs1dvNV, (GLuint index, GLsizei count, const GLdouble * v), (index, count, v))
GEN_THUNKS(glVertexAttribs1fvNV, (GLuint index, GLsizei count, const GLfloat * v), (index, count, v))
GEN_THUNKS(glVertexAttribs1hvNV, (GLuint index, GLsizei n, const GLhalfNV * v), (index, n, v))
GEN_THUNKS(glVertexAttribs1svNV, (GLuint index, GLsizei count, const GLshort * v), (index, count, v))
GEN_THUNKS(glVertexAttribs2dvNV, (GLuint index, GLsizei count, const GLdouble * v), (index, count, v))
GEN_THUNKS(glVertexAttribs2fvNV, (GLuint index, GLsizei count, const GLfloat * v), (index, count, v))
GEN_THUNKS(glVertexAttribs2hvNV, (GLuint index, GLsizei n, const GLhalfNV * v), (index, n, v))
GEN_THUNKS(glVertexAttribs2svNV, (GLuint index, GLsizei count, const GLshort * v), (index, count, v))
GEN_THUNKS(glVertexAttribs3dvNV, (GLuint index, GLsizei count, const GLdouble * v), (index, count, v))
GEN_THUNKS(glVertexAttribs3fvNV, (GLuint index, GLsizei count, const GLfloat * v), (index, count, v))
GEN_THUNKS(glVertexAttribs3hvNV, (GLuint index, GLsizei n, const GLhalfNV * v), (index, n, v))
GEN_THUNKS(glVertexAttribs3svNV, (GLuint index, GLsizei count, const GLshort * v), (index, count, v))
GEN_THUNKS(glVertexAttribs4dvNV, (GLuint index, GLsizei count, const GLdouble * v), (index, count, v))
GEN_THUNKS(glVertexAttribs4fvNV, (GLuint index, GLsizei count, const GLfloat * v), (index, count, v))
GEN_THUNKS(glVertexAttribs4hvNV, (GLuint index, GLsizei n, const GLhalfNV * v), (index, n, v))
GEN_THUNKS(glVertexAttribs4svNV, (GLuint index, GLsizei count, const GLshort * v), (index, count, v))
GEN_THUNKS(glVertexAttribs4ubvNV, (GLuint index, GLsizei count, const GLubyte * v), (index, count, v))
GEN_THUNKS(glVertexBindingDivisor, (GLuint bindingindex, GLuint divisor), (bindingindex, divisor))
GEN_THUNKS(glVertexBlendARB, (GLint count), (count))
GEN_THUNKS(glVertexBlendEnvfATI, (GLenum pname, GLfloat param), (pname, param))
GEN_THUNKS(glVertexBlendEnviATI, (GLenum pname, GLint param), (pname, param))
GEN_THUNKS(glVertexFormatNV, (GLint size, GLenum type, GLsizei stride), (size, type, stride))
GEN_THUNKS(glVertexP2ui, (GLenum type, GLuint value), (type, value))
GEN_THUNKS(glVertexP2uiv, (GLenum type, const GLuint * value), (type, value))
GEN_THUNKS(glVertexP3ui, (GLenum type, GLuint value), (type, value))
GEN_THUNKS(glVertexP3uiv, (GLenum type, const GLuint * value), (type, value))
GEN_THUNKS(glVertexP4ui, (GLenum type, GLuint value), (type, value))
GEN_THUNKS(glVertexP4uiv, (GLenum type, const GLuint * value), (type, value))
GEN_THUNKS(glVertexPointer, (GLint size, GLenum type, GLsizei stride, const void * pointer), (size, type, stride, pointer))
GEN_THUNKS(glVertexPointerEXT, (GLint size, GLenum type, GLsizei stride, GLsizei count, const void * pointer), (size, type, stride, count, pointer))
GEN_THUNKS(glVertexPointerListIBM, (GLint size, GLenum type, GLint stride, const void ** pointer, GLint ptrstride), (size, type, stride, pointer, ptrstride))
GEN_THUNKS(glVertexPointervINTEL, (GLint size, GLenum type, const void ** pointer), (size, type, pointer))
GEN_THUNKS(glVertexStream1dATI, (GLenum stream, GLdouble x), (stream, x))
GEN_THUNKS(glVertexStream1dvATI, (GLenum stream, const GLdouble * coords), (stream, coords))
GEN_THUNKS(glVertexStream1fATI, (GLenum stream, GLfloat x), (stream, x))
GEN_THUNKS(glVertexStream1fvATI, (GLenum stream, const GLfloat * coords), (stream, coords))
GEN_THUNKS(glVertexStream1iATI, (GLenum stream, GLint x), (stream, x))
GEN_THUNKS(glVertexStream1ivATI, (GLenum stream, const GLint * coords), (stream, coords))
GEN_THUNKS(glVertexStream1sATI, (GLenum stream, GLshort x), (stream, x))
GEN_THUNKS(glVertexStream1svATI, (GLenum stream, const GLshort * coords), (stream, coords))
GEN_THUNKS(glVertexStream2dATI, (GLenum stream, GLdouble x, GLdouble y), (stream, x, y))
GEN_THUNKS(glVertexStream2dvATI, (GLenum stream, const GLdouble * coords), (stream, coords))
GEN_THUNKS(glVertexStream2fATI, (GLenum stream, GLfloat x, GLfloat y), (stream, x, y))
GEN_THUNKS(glVertexStream2fvATI, (GLenum stream, const GLfloat * coords), (stream, coords))
GEN_THUNKS(glVertexStream2iATI, (GLenum stream, GLint x, GLint y), (stream, x, y))
GEN_THUNKS(glVertexStream2ivATI, (GLenum stream, const GLint * coords), (stream, coords))
GEN_THUNKS(glVertexStream2sATI, (GLenum stream, GLshort x, GLshort y), (stream, x, y))
GEN_THUNKS(glVertexStream2svATI, (GLenum stream, const GLshort * coords), (stream, coords))
GEN_THUNKS(glVertexStream3dATI, (GLenum stream, GLdouble x, GLdouble y, GLdouble z), (stream, x, y, z))
GEN_THUNKS(glVertexStream3dvATI, (GLenum stream, const GLdouble * coords), (stream, coords))
GEN_THUNKS(glVertexStream3fATI, (GLenum stream, GLfloat x, GLfloat y, GLfloat z), (stream, x, y, z))
GEN_THUNKS(glVertexStream3fvATI, (GLenum stream, const GLfloat * coords), (stream, coords))
GEN_THUNKS(glVertexStream3iATI, (GLenum stream, GLint x, GLint y, GLint z), (stream, x, y, z))
GEN_THUNKS(glVertexStream3ivATI, (GLenum stream, const GLint * coords), (stream, coords))
GEN_THUNKS(glVertexStream3sATI, (GLenum stream, GLshort x, GLshort y, GLshort z), (stream, x, y, z))
GEN_THUNKS(glVertexStream3svATI, (GLenum stream, const GLshort * coords), (stream, coords))
GEN_THUNKS(glVertexStream4dATI, (GLenum stream, GLdouble x, GLdouble y, GLdouble z, GLdouble w), (stream, x, y, z, w))
GEN_THUNKS(glVertexStream4dvATI, (GLenum stream, const GLdouble * coords), (stream, coords))
GEN_THUNKS(glVertexStream4fATI, (GLenum stream, GLfloat x, GLfloat y, GLfloat z, GLfloat w), (stream, x, y, z, w))
GEN_THUNKS(glVertexStream4fvATI, (GLenum stream, const GLfloat * coords), (stream, coords))
GEN_THUNKS(glVertexStream4iATI, (GLenum stream, GLint x, GLint y, GLint z, GLint w), (stream, x, y, z, w))
GEN_THUNKS(glVertexStream4ivATI, (GLenum stream, const GLint * coords), (stream, coords))
GEN_THUNKS(glVertexStream4sATI, (GLenum stream, GLshort x, GLshort y, GLshort z, GLshort w), (stream, x, y, z, w))
GEN_THUNKS(glVertexStream4svATI, (GLenum stream, const GLshort * coords), (stream, coords))
GEN_THUNKS(glVertexWeightPointerEXT, (GLint size, GLenum type, GLsizei stride, const void * pointer), (size, type, stride, pointer))
GEN_THUNKS(glVertexWeightfEXT, (GLfloat weight), (weight))
GEN_THUNKS(glVertexWeightfvEXT, (const GLfloat * weight), (weight))
GEN_THUNKS(glVertexWeighthNV, (GLhalfNV weight), (weight))
GEN_THUNKS(glVertexWeighthvNV, (const GLhalfNV * weight), (weight))
GEN_THUNKS_RET(GLenum, glVideoCaptureNV, (GLuint video_capture_slot, GLuint * sequence_num, GLuint64EXT * capture_time), (video_capture_slot, sequence_num, capture_time))
GEN_THUNKS(glVideoCaptureStreamParameterdvNV, (GLuint video_capture_slot, GLuint stream, GLenum pname, const GLdouble * params), (video_capture_slot, stream, pname, params))
GEN_THUNKS(glVideoCaptureStreamParameterfvNV, (GLuint video_capture_slot, GLuint stream, GLenum pname, const GLfloat * params), (video_capture_slot, stream, pname, params))
GEN_THUNKS(glVideoCaptureStreamParameterivNV, (GLuint video_capture_slot, GLuint stream, GLenum pname, const GLint * params), (video_capture_slot, stream, pname, params))
GEN_THUNKS(glViewport, (GLint x, GLint y, GLsizei width, GLsizei height), (x, y, width, height))
GEN_THUNKS(glViewportArrayv, (GLuint first, GLsizei count, const GLfloat * v), (first, count, v))
GEN_THUNKS(glViewportArrayvNV, (GLuint first, GLsizei count, const GLfloat * v), (first, count, v))
GEN_THUNKS(glViewportArrayvOES, (GLuint first, GLsizei count, const GLfloat * v), (first, count, v))
GEN_THUNKS(glViewportIndexedf, (GLuint index, GLfloat x, GLfloat y, GLfloat w, GLfloat h), (index, x, y, w, h))
GEN_THUNKS(glViewportIndexedfNV, (GLuint index, GLfloat x, GLfloat y, GLfloat w, GLfloat h), (index, x, y, w, h))
GEN_THUNKS(glViewportIndexedfOES, (GLuint index, GLfloat x, GLfloat y, GLfloat w, GLfloat h), (index, x, y, w, h))
GEN_THUNKS(glViewportIndexedfv, (GLuint index, const GLfloat * v), (index, v))
GEN_THUNKS(glViewportIndexedfvNV, (GLuint index, const GLfloat * v), (index, v))
GEN_THUNKS(glViewportIndexedfvOES, (GLuint index, const GLfloat * v), (index, v))
GEN_THUNKS(glViewportPositionWScaleNV, (GLuint index, GLfloat xcoeff, GLfloat ycoeff), (index, xcoeff, ycoeff))
GEN_THUNKS(glViewportSwizzleNV, (GLuint index, GLenum swizzlex, GLenum swizzley, GLenum swizzlez, GLenum swizzlew), (index, swizzlex, swizzley, swizzlez, swizzlew))
GEN_THUNKS(glWaitSemaphoreEXT, (GLuint semaphore, GLuint numBufferBarriers, const GLuint * buffers, GLuint numTextureBarriers, const GLuint * textures, const GLenum * srcLayouts), (semaphore, numBufferBarriers, buffers, numTextureBarriers, textures, srcLayouts))
GEN_THUNKS(glWaitSemaphoreui64NVX, (GLuint waitGpu, GLsizei fenceObjectCount, const GLuint * semaphoreArray, const GLuint64 * fenceValueArray), (waitGpu, fenceObjectCount, semaphoreArray, fenceValueArray))
GEN_THUNKS(glWaitSync, (GLsync sync, GLbitfield flags, GLuint64 timeout), (sync, flags, timeout))
GEN_THUNKS(glWaitSyncAPPLE, (GLsync sync, GLbitfield flags, GLuint64 timeout), (sync, flags, timeout))
GEN_THUNKS(glWaitVkSemaphoreNV, (GLuint64 vkSemaphore), (vkSemaphore))
GEN_THUNKS(glWeightPathsNV, (GLuint resultPath, GLsizei numPaths, const GLuint * paths, const GLfloat * weights), (resultPath, numPaths, paths, weights))
GEN_THUNKS(glWeightPointerARB, (GLint size, GLenum type, GLsizei stride, const void * pointer), (size, type, stride, pointer))
GEN_THUNKS(glWeightPointerOES, (GLint size, GLenum type, GLsizei stride, const void * pointer), (size, type, stride, pointer))
GEN_THUNKS(glWeightbvARB, (GLint size, const GLbyte * weights), (size, weights))
GEN_THUNKS(glWeightdvARB, (GLint size, const GLdouble * weights), (size, weights))
GEN_THUNKS(glWeightfvARB, (GLint size, const GLfloat * weights), (size, weights))
GEN_THUNKS(glWeightivARB, (GLint size, const GLint * weights), (size, weights))
GEN_THUNKS(glWeightsvARB, (GLint size, const GLshort * weights), (size, weights))
GEN_THUNKS(glWeightubvARB, (GLint size, const GLubyte * weights), (size, weights))
GEN_THUNKS(glWeightuivARB, (GLint size, const GLuint * weights), (size, weights))
GEN_THUNKS(glWeightusvARB, (GLint size, const GLushort * weights), (size, weights))
GEN_THUNKS(glWindowPos2d, (GLdouble x, GLdouble y), (x, y))
GEN_THUNKS(glWindowPos2dARB, (GLdouble x, GLdouble y), (x, y))
GEN_THUNKS(glWindowPos2dMESA, (GLdouble x, GLdouble y), (x, y))
GEN_THUNKS(glWindowPos2dv, (const GLdouble * v), (v))
GEN_THUNKS(glWindowPos2dvARB, (const GLdouble * v), (v))
GEN_THUNKS(glWindowPos2dvMESA, (const GLdouble * v), (v))
GEN_THUNKS(glWindowPos2f, (GLfloat x, GLfloat y), (x, y))
GEN_THUNKS(glWindowPos2fARB, (GLfloat x, GLfloat y), (x, y))
GEN_THUNKS(glWindowPos2fMESA, (GLfloat x, GLfloat y), (x, y))
GEN_THUNKS(glWindowPos2fv, (const GLfloat * v), (v))
GEN_THUNKS(glWindowPos2fvARB, (const GLfloat * v), (v))
GEN_THUNKS(glWindowPos2fvMESA, (const GLfloat * v), (v))
GEN_THUNKS(glWindowPos2i, (GLint x, GLint y), (x, y))
GEN_THUNKS(glWindowPos2iARB, (GLint x, GLint y), (x, y))
GEN_THUNKS(glWindowPos2iMESA, (GLint x, GLint y), (x, y))
GEN_THUNKS(glWindowPos2iv, (const GLint * v), (v))
GEN_THUNKS(glWindowPos2ivARB, (const GLint * v), (v))
GEN_THUNKS(glWindowPos2ivMESA, (const GLint * v), (v))
GEN_THUNKS(glWindowPos2s, (GLshort x, GLshort y), (x, y))
GEN_THUNKS(glWindowPos2sARB, (GLshort x, GLshort y), (x, y))
GEN_THUNKS(glWindowPos2sMESA, (GLshort x, GLshort y), (x, y))
GEN_THUNKS(glWindowPos2sv, (const GLshort * v), (v))
GEN_THUNKS(glWindowPos2svARB, (const GLshort * v), (v))
GEN_THUNKS(glWindowPos2svMESA, (const GLshort * v), (v))
GEN_THUNKS(glWindowPos3d, (GLdouble x, GLdouble y, GLdouble z), (x, y, z))
GEN_THUNKS(glWindowPos3dARB, (GLdouble x, GLdouble y, GLdouble z), (x, y, z))
GEN_THUNKS(glWindowPos3dMESA, (GLdouble x, GLdouble y, GLdouble z), (x, y, z))
GEN_THUNKS(glWindowPos3dv, (const GLdouble * v), (v))
GEN_THUNKS(glWindowPos3dvARB, (const GLdouble * v), (v))
GEN_THUNKS(glWindowPos3dvMESA, (const GLdouble * v), (v))
GEN_THUNKS(glWindowPos3f, (GLfloat x, GLfloat y, GLfloat z), (x, y, z))
GEN_THUNKS(glWindowPos3fARB, (GLfloat x, GLfloat y, GLfloat z), (x, y, z))
GEN_THUNKS(glWindowPos3fMESA, (GLfloat x, GLfloat y, GLfloat z), (x, y, z))
GEN_THUNKS(glWindowPos3fv, (const GLfloat * v), (v))
GEN_THUNKS(glWindowPos3fvARB, (const GLfloat * v), (v))
GEN_THUNKS(glWindowPos3fvMESA, (const GLfloat * v), (v))
GEN_THUNKS(glWindowPos3i, (GLint x, GLint y, GLint z), (x, y, z))
GEN_THUNKS(glWindowPos3iARB, (GLint x, GLint y, GLint z), (x, y, z))
GEN_THUNKS(glWindowPos3iMESA, (GLint x, GLint y, GLint z), (x, y, z))
GEN_THUNKS(glWindowPos3iv, (const GLint * v), (v))
GEN_THUNKS(glWindowPos3ivARB, (const GLint * v), (v))
GEN_THUNKS(glWindowPos3ivMESA, (const GLint * v), (v))
GEN_THUNKS(glWindowPos3s, (GLshort x, GLshort y, GLshort z), (x, y, z))
GEN_THUNKS(glWindowPos3sARB, (GLshort x, GLshort y, GLshort z), (x, y, z))
GEN_THUNKS(glWindowPos3sMESA, (GLshort x, GLshort y, GLshort z), (x, y, z))
GEN_THUNKS(glWindowPos3sv, (const GLshort * v), (v))
GEN_THUNKS(glWindowPos3svARB, (const GLshort * v), (v))
GEN_THUNKS(glWindowPos3svMESA, (const GLshort * v), (v))
GEN_THUNKS(glWindowPos4dMESA, (GLdouble x, GLdouble y, GLdouble z, GLdouble w), (x, y, z, w))
GEN_THUNKS(glWindowPos4dvMESA, (const GLdouble * v), (v))
GEN_THUNKS(glWindowPos4fMESA, (GLfloat x, GLfloat y, GLfloat z, GLfloat w), (x, y, z, w))
GEN_THUNKS(glWindowPos4fvMESA, (const GLfloat * v), (v))
GEN_THUNKS(glWindowPos4iMESA, (GLint x, GLint y, GLint z, GLint w), (x, y, z, w))
GEN_THUNKS(glWindowPos4ivMESA, (const GLint * v), (v))
GEN_THUNKS(glWindowPos4sMESA, (GLshort x, GLshort y, GLshort z, GLshort w), (x, y, z, w))
GEN_THUNKS(glWindowPos4svMESA, (const GLshort * v), (v))
GEN_THUNKS(glWindowRectanglesEXT, (GLenum mode, GLsizei count, const GLint * box), (mode, count, box))
GEN_THUNKS(glWriteMaskEXT, (GLuint res, GLuint in, GLenum outX, GLenum outY, GLenum outZ, GLenum outW), (res, in, outX, outY, outZ, outW))

#if USING_DISPATCH_TABLE
static struct dispatch_table resolver_table = {
    epoxy_glAccum_dispatch_table_rewrite_ptr, /* glAccum */
    epoxy_glAccumxOES_dispatch_table_rewrite_ptr, /* glAccumxOES */
    epoxy_glAcquireKeyedMutexWin32EXT_dispatch_table_rewrite_ptr, /* glAcquireKeyedMutexWin32EXT */
    epoxy_glActiveProgramEXT_dispatch_table_rewrite_ptr, /* glActiveProgramEXT */
    epoxy_glActiveShaderProgram_dispatch_table_rewrite_ptr, /* glActiveShaderProgram */
    epoxy_glActiveShaderProgramEXT_dispatch_table_rewrite_ptr, /* glActiveShaderProgramEXT */
    epoxy_glActiveStencilFaceEXT_dispatch_table_rewrite_ptr, /* glActiveStencilFaceEXT */
    epoxy_glActiveTexture_dispatch_table_rewrite_ptr, /* glActiveTexture */
    epoxy_glActiveTextureARB_dispatch_table_rewrite_ptr, /* glActiveTextureARB */
    epoxy_glActiveVaryingNV_dispatch_table_rewrite_ptr, /* glActiveVaryingNV */
    epoxy_glAlphaFragmentOp1ATI_dispatch_table_rewrite_ptr, /* glAlphaFragmentOp1ATI */
    epoxy_glAlphaFragmentOp2ATI_dispatch_table_rewrite_ptr, /* glAlphaFragmentOp2ATI */
    epoxy_glAlphaFragmentOp3ATI_dispatch_table_rewrite_ptr, /* glAlphaFragmentOp3ATI */
    epoxy_glAlphaFunc_dispatch_table_rewrite_ptr, /* glAlphaFunc */
    epoxy_glAlphaFuncQCOM_dispatch_table_rewrite_ptr, /* glAlphaFuncQCOM */
    epoxy_glAlphaFuncx_dispatch_table_rewrite_ptr, /* glAlphaFuncx */
    epoxy_glAlphaFuncxOES_dispatch_table_rewrite_ptr, /* glAlphaFuncxOES */
    epoxy_glAlphaToCoverageDitherControlNV_dispatch_table_rewrite_ptr, /* glAlphaToCoverageDitherControlNV */
    epoxy_glApplyFramebufferAttachmentCMAAINTEL_dispatch_table_rewrite_ptr, /* glApplyFramebufferAttachmentCMAAINTEL */
    epoxy_glApplyTextureEXT_dispatch_table_rewrite_ptr, /* glApplyTextureEXT */
    epoxy_glAreProgramsResidentNV_dispatch_table_rewrite_ptr, /* glAreProgramsResidentNV */
    epoxy_glAreTexturesResident_dispatch_table_rewrite_ptr, /* glAreTexturesResident */
    epoxy_glAreTexturesResidentEXT_dispatch_table_rewrite_ptr, /* glAreTexturesResidentEXT */
    epoxy_glArrayElement_dispatch_table_rewrite_ptr, /* glArrayElement */
    epoxy_glArrayElementEXT_dispatch_table_rewrite_ptr, /* glArrayElementEXT */
    epoxy_glArrayObjectATI_dispatch_table_rewrite_ptr, /* glArrayObjectATI */
    epoxy_glAsyncCopyBufferSubDataNVX_dispatch_table_rewrite_ptr, /* glAsyncCopyBufferSubDataNVX */
    epoxy_glAsyncCopyImageSubDataNVX_dispatch_table_rewrite_ptr, /* glAsyncCopyImageSubDataNVX */
    epoxy_glAsyncMarkerSGIX_dispatch_table_rewrite_ptr, /* glAsyncMarkerSGIX */
    epoxy_glAttachObjectARB_dispatch_table_rewrite_ptr, /* glAttachObjectARB */
    epoxy_glAttachShader_dispatch_table_rewrite_ptr, /* glAttachShader */
    epoxy_glBegin_unwrapped_dispatch_table_rewrite_ptr, /* glBegin_unwrapped */
    epoxy_glBeginConditionalRender_dispatch_table_rewrite_ptr, /* glBeginConditionalRender */
    epoxy_glBeginConditionalRenderNV_dispatch_table_rewrite_ptr, /* glBeginConditionalRenderNV */
    epoxy_glBeginConditionalRenderNVX_dispatch_table_rewrite_ptr, /* glBeginConditionalRenderNVX */
    epoxy_glBeginFragmentShaderATI_dispatch_table_rewrite_ptr, /* glBeginFragmentShaderATI */
    epoxy_glBeginOcclusionQueryNV_dispatch_table_rewrite_ptr, /* glBeginOcclusionQueryNV */
    epoxy_glBeginPerfMonitorAMD_dispatch_table_rewrite_ptr, /* glBeginPerfMonitorAMD */
    epoxy_glBeginPerfQueryINTEL_dispatch_table_rewrite_ptr, /* glBeginPerfQueryINTEL */
    epoxy_glBeginQuery_dispatch_table_rewrite_ptr, /* glBeginQuery */
    epoxy_glBeginQueryARB_dispatch_table_rewrite_ptr, /* glBeginQueryARB */
    epoxy_glBeginQueryEXT_dispatch_table_rewrite_ptr, /* glBeginQueryEXT */
    epoxy_glBeginQueryIndexed_dispatch_table_rewrite_ptr, /* glBeginQueryIndexed */
    epoxy_glBeginTransformFeedback_dispatch_table_rewrite_ptr, /* glBeginTransformFeedback */
    epoxy_glBeginTransformFeedbackEXT_dispatch_table_rewrite_ptr, /* glBeginTransformFeedbackEXT */
    epoxy_glBeginTransformFeedbackNV_dispatch_table_rewrite_ptr, /* glBeginTransformFeedbackNV */
    epoxy_glBeginVertexShaderEXT_dispatch_table_rewrite_ptr, /* glBeginVertexShaderEXT */
    epoxy_glBeginVideoCaptureNV_dispatch_table_rewrite_ptr, /* glBeginVideoCaptureNV */
    epoxy_glBindAttribLocation_dispatch_table_rewrite_ptr, /* glBindAttribLocation */
    epoxy_glBindAttribLocationARB_dispatch_table_rewrite_ptr, /* glBindAttribLocationARB */
    epoxy_glBindBuffer_dispatch_table_rewrite_ptr, /* glBindBuffer */
    epoxy_glBindBufferARB_dispatch_table_rewrite_ptr, /* glBindBufferARB */
    epoxy_glBindBufferBase_dispatch_table_rewrite_ptr, /* glBindBufferBase */
    epoxy_glBindBufferBaseEXT_dispatch_table_rewrite_ptr, /* glBindBufferBaseEXT */
    epoxy_glBindBufferBaseNV_dispatch_table_rewrite_ptr, /* glBindBufferBaseNV */
    epoxy_glBindBufferOffsetEXT_dispatch_table_rewrite_ptr, /* glBindBufferOffsetEXT */
    epoxy_glBindBufferOffsetNV_dispatch_table_rewrite_ptr, /* glBindBufferOffsetNV */
    epoxy_glBindBufferRange_dispatch_table_rewrite_ptr, /* glBindBufferRange */
    epoxy_glBindBufferRangeEXT_dispatch_table_rewrite_ptr, /* glBindBufferRangeEXT */
    epoxy_glBindBufferRangeNV_dispatch_table_rewrite_ptr, /* glBindBufferRangeNV */
    epoxy_glBindBuffersBase_dispatch_table_rewrite_ptr, /* glBindBuffersBase */
    epoxy_glBindBuffersRange_dispatch_table_rewrite_ptr, /* glBindBuffersRange */
    epoxy_glBindFragDataLocation_dispatch_table_rewrite_ptr, /* glBindFragDataLocation */
    epoxy_glBindFragDataLocationEXT_dispatch_table_rewrite_ptr, /* glBindFragDataLocationEXT */
    epoxy_glBindFragDataLocationIndexed_dispatch_table_rewrite_ptr, /* glBindFragDataLocationIndexed */
    epoxy_glBindFragDataLocationIndexedEXT_dispatch_table_rewrite_ptr, /* glBindFragDataLocationIndexedEXT */
    epoxy_glBindFragmentShaderATI_dispatch_table_rewrite_ptr, /* glBindFragmentShaderATI */
    epoxy_glBindFramebuffer_dispatch_table_rewrite_ptr, /* glBindFramebuffer */
    epoxy_glBindFramebufferEXT_dispatch_table_rewrite_ptr, /* glBindFramebufferEXT */
    epoxy_glBindFramebufferOES_dispatch_table_rewrite_ptr, /* glBindFramebufferOES */
    epoxy_glBindImageTexture_dispatch_table_rewrite_ptr, /* glBindImageTexture */
    epoxy_glBindImageTextureEXT_dispatch_table_rewrite_ptr, /* glBindImageTextureEXT */
    epoxy_glBindImageTextures_dispatch_table_rewrite_ptr, /* glBindImageTextures */
    epoxy_glBindLightParameterEXT_dispatch_table_rewrite_ptr, /* glBindLightParameterEXT */
    epoxy_glBindMaterialParameterEXT_dispatch_table_rewrite_ptr, /* glBindMaterialParameterEXT */
    epoxy_glBindMultiTextureEXT_dispatch_table_rewrite_ptr, /* glBindMultiTextureEXT */
    epoxy_glBindParameterEXT_dispatch_table_rewrite_ptr, /* glBindParameterEXT */
    epoxy_glBindProgramARB_dispatch_table_rewrite_ptr, /* glBindProgramARB */
    epoxy_glBindProgramNV_dispatch_table_rewrite_ptr, /* glBindProgramNV */
    epoxy_glBindProgramPipeline_dispatch_table_rewrite_ptr, /* glBindProgramPipeline */
    epoxy_glBindProgramPipelineEXT_dispatch_table_rewrite_ptr, /* glBindProgramPipelineEXT */
    epoxy_glBindRenderbuffer_dispatch_table_rewrite_ptr, /* glBindRenderbuffer */
    epoxy_glBindRenderbufferEXT_dispatch_table_rewrite_ptr, /* glBindRenderbufferEXT */
    epoxy_glBindRenderbufferOES_dispatch_table_rewrite_ptr, /* glBindRenderbufferOES */
    epoxy_glBindSampler_dispatch_table_rewrite_ptr, /* glBindSampler */
    epoxy_glBindSamplers_dispatch_table_rewrite_ptr, /* glBindSamplers */
    epoxy_glBindShadingRateImageNV_dispatch_table_rewrite_ptr, /* glBindShadingRateImageNV */
    epoxy_glBindTexGenParameterEXT_dispatch_table_rewrite_ptr, /* glBindTexGenParameterEXT */
    epoxy_glBindTexture_dispatch_table_rewrite_ptr, /* glBindTexture */
    epoxy_glBindTextureEXT_dispatch_table_rewrite_ptr, /* glBindTextureEXT */
    epoxy_glBindTextureUnit_dispatch_table_rewrite_ptr, /* glBindTextureUnit */
    epoxy_glBindTextureUnitParameterEXT_dispatch_table_rewrite_ptr, /* glBindTextureUnitParameterEXT */
    epoxy_glBindTextures_dispatch_table_rewrite_ptr, /* glBindTextures */
    epoxy_glBindTransformFeedback_dispatch_table_rewrite_ptr, /* glBindTransformFeedback */
    epoxy_glBindTransformFeedbackNV_dispatch_table_rewrite_ptr, /* glBindTransformFeedbackNV */
    epoxy_glBindVertexArray_dispatch_table_rewrite_ptr, /* glBindVertexArray */
    epoxy_glBindVertexArrayAPPLE_dispatch_table_rewrite_ptr, /* glBindVertexArrayAPPLE */
    epoxy_glBindVertexArrayOES_dispatch_table_rewrite_ptr, /* glBindVertexArrayOES */
    epoxy_glBindVertexBuffer_dispatch_table_rewrite_ptr, /* glBindVertexBuffer */
    epoxy_glBindVertexBuffers_dispatch_table_rewrite_ptr, /* glBindVertexBuffers */
    epoxy_glBindVertexShaderEXT_dispatch_table_rewrite_ptr, /* glBindVertexShaderEXT */
    epoxy_glBindVideoCaptureStreamBufferNV_dispatch_table_rewrite_ptr, /* glBindVideoCaptureStreamBufferNV */
    epoxy_glBindVideoCaptureStreamTextureNV_dispatch_table_rewrite_ptr, /* glBindVideoCaptureStreamTextureNV */
    epoxy_glBinormal3bEXT_dispatch_table_rewrite_ptr, /* glBinormal3bEXT */
    epoxy_glBinormal3bvEXT_dispatch_table_rewrite_ptr, /* glBinormal3bvEXT */
    epoxy_glBinormal3dEXT_dispatch_table_rewrite_ptr, /* glBinormal3dEXT */
    epoxy_glBinormal3dvEXT_dispatch_table_rewrite_ptr, /* glBinormal3dvEXT */
    epoxy_glBinormal3fEXT_dispatch_table_rewrite_ptr, /* glBinormal3fEXT */
    epoxy_glBinormal3fvEXT_dispatch_table_rewrite_ptr, /* glBinormal3fvEXT */
    epoxy_glBinormal3iEXT_dispatch_table_rewrite_ptr, /* glBinormal3iEXT */
    epoxy_glBinormal3ivEXT_dispatch_table_rewrite_ptr, /* glBinormal3ivEXT */
    epoxy_glBinormal3sEXT_dispatch_table_rewrite_ptr, /* glBinormal3sEXT */
    epoxy_glBinormal3svEXT_dispatch_table_rewrite_ptr, /* glBinormal3svEXT */
    epoxy_glBinormalPointerEXT_dispatch_table_rewrite_ptr, /* glBinormalPointerEXT */
    epoxy_glBitmap_dispatch_table_rewrite_ptr, /* glBitmap */
    epoxy_glBitmapxOES_dispatch_table_rewrite_ptr, /* glBitmapxOES */
    epoxy_glBlendBarrier_dispatch_table_rewrite_ptr, /* glBlendBarrier */
    epoxy_glBlendBarrierKHR_dispatch_table_rewrite_ptr, /* glBlendBarrierKHR */
    epoxy_glBlendBarrierNV_dispatch_table_rewrite_ptr, /* glBlendBarrierNV */
    epoxy_glBlendColor_dispatch_table_rewrite_ptr, /* glBlendColor */
    epoxy_glBlendColorEXT_dispatch_table_rewrite_ptr, /* glBlendColorEXT */
    epoxy_glBlendColorxOES_dispatch_table_rewrite_ptr, /* glBlendColorxOES */
    epoxy_glBlendEquation_dispatch_table_rewrite_ptr, /* glBlendEquation */
    epoxy_glBlendEquationEXT_dispatch_table_rewrite_ptr, /* glBlendEquationEXT */
    epoxy_glBlendEquationIndexedAMD_dispatch_table_rewrite_ptr, /* glBlendEquationIndexedAMD */
    epoxy_glBlendEquationOES_dispatch_table_rewrite_ptr, /* glBlendEquationOES */
    epoxy_glBlendEquationSeparate_dispatch_table_rewrite_ptr, /* glBlendEquationSeparate */
    epoxy_glBlendEquationSeparateEXT_dispatch_table_rewrite_ptr, /* glBlendEquationSeparateEXT */
    epoxy_glBlendEquationSeparateIndexedAMD_dispatch_table_rewrite_ptr, /* glBlendEquationSeparateIndexedAMD */
    epoxy_glBlendEquationSeparateOES_dispatch_table_rewrite_ptr, /* glBlendEquationSeparateOES */
    epoxy_glBlendEquationSeparatei_dispatch_table_rewrite_ptr, /* glBlendEquationSeparatei */
    epoxy_glBlendEquationSeparateiARB_dispatch_table_rewrite_ptr, /* glBlendEquationSeparateiARB */
    epoxy_glBlendEquationSeparateiEXT_dispatch_table_rewrite_ptr, /* glBlendEquationSeparateiEXT */
    epoxy_glBlendEquationSeparateiOES_dispatch_table_rewrite_ptr, /* glBlendEquationSeparateiOES */
    epoxy_glBlendEquationi_dispatch_table_rewrite_ptr, /* glBlendEquationi */
    epoxy_glBlendEquationiARB_dispatch_table_rewrite_ptr, /* glBlendEquationiARB */
    epoxy_glBlendEquationiEXT_dispatch_table_rewrite_ptr, /* glBlendEquationiEXT */
    epoxy_glBlendEquationiOES_dispatch_table_rewrite_ptr, /* glBlendEquationiOES */
    epoxy_glBlendFunc_dispatch_table_rewrite_ptr, /* glBlendFunc */
    epoxy_glBlendFuncIndexedAMD_dispatch_table_rewrite_ptr, /* glBlendFuncIndexedAMD */
    epoxy_glBlendFuncSeparate_dispatch_table_rewrite_ptr, /* glBlendFuncSeparate */
    epoxy_glBlendFuncSeparateEXT_dispatch_table_rewrite_ptr, /* glBlendFuncSeparateEXT */
    epoxy_glBlendFuncSeparateINGR_dispatch_table_rewrite_ptr, /* glBlendFuncSeparateINGR */
    epoxy_glBlendFuncSeparateIndexedAMD_dispatch_table_rewrite_ptr, /* glBlendFuncSeparateIndexedAMD */
    epoxy_glBlendFuncSeparateOES_dispatch_table_rewrite_ptr, /* glBlendFuncSeparateOES */
    epoxy_glBlendFuncSeparatei_dispatch_table_rewrite_ptr, /* glBlendFuncSeparatei */
    epoxy_glBlendFuncSeparateiARB_dispatch_table_rewrite_ptr, /* glBlendFuncSeparateiARB */
    epoxy_glBlendFuncSeparateiEXT_dispatch_table_rewrite_ptr, /* glBlendFuncSeparateiEXT */
    epoxy_glBlendFuncSeparateiOES_dispatch_table_rewrite_ptr, /* glBlendFuncSeparateiOES */
    epoxy_glBlendFunci_dispatch_table_rewrite_ptr, /* glBlendFunci */
    epoxy_glBlendFunciARB_dispatch_table_rewrite_ptr, /* glBlendFunciARB */
    epoxy_glBlendFunciEXT_dispatch_table_rewrite_ptr, /* glBlendFunciEXT */
    epoxy_glBlendFunciOES_dispatch_table_rewrite_ptr, /* glBlendFunciOES */
    epoxy_glBlendParameteriNV_dispatch_table_rewrite_ptr, /* glBlendParameteriNV */
    epoxy_glBlitFramebuffer_dispatch_table_rewrite_ptr, /* glBlitFramebuffer */
    epoxy_glBlitFramebufferANGLE_dispatch_table_rewrite_ptr, /* glBlitFramebufferANGLE */
    epoxy_glBlitFramebufferEXT_dispatch_table_rewrite_ptr, /* glBlitFramebufferEXT */
    epoxy_glBlitFramebufferNV_dispatch_table_rewrite_ptr, /* glBlitFramebufferNV */
    epoxy_glBlitNamedFramebuffer_dispatch_table_rewrite_ptr, /* glBlitNamedFramebuffer */
    epoxy_glBufferAddressRangeNV_dispatch_table_rewrite_ptr, /* glBufferAddressRangeNV */
    epoxy_glBufferAttachMemoryNV_dispatch_table_rewrite_ptr, /* glBufferAttachMemoryNV */
    epoxy_glBufferData_dispatch_table_rewrite_ptr, /* glBufferData */
    epoxy_glBufferDataARB_dispatch_table_rewrite_ptr, /* glBufferDataARB */
    epoxy_glBufferPageCommitmentARB_dispatch_table_rewrite_ptr, /* glBufferPageCommitmentARB */
    epoxy_glBufferParameteriAPPLE_dispatch_table_rewrite_ptr, /* glBufferParameteriAPPLE */
    epoxy_glBufferStorage_dispatch_table_rewrite_ptr, /* glBufferStorage */
    epoxy_glBufferStorageEXT_dispatch_table_rewrite_ptr, /* glBufferStorageEXT */
    epoxy_glBufferStorageExternalEXT_dispatch_table_rewrite_ptr, /* glBufferStorageExternalEXT */
    epoxy_glBufferStorageMemEXT_dispatch_table_rewrite_ptr, /* glBufferStorageMemEXT */
    epoxy_glBufferSubData_dispatch_table_rewrite_ptr, /* glBufferSubData */
    epoxy_glBufferSubDataARB_dispatch_table_rewrite_ptr, /* glBufferSubDataARB */
    epoxy_glCallCommandListNV_dispatch_table_rewrite_ptr, /* glCallCommandListNV */
    epoxy_glCallList_dispatch_table_rewrite_ptr, /* glCallList */
    epoxy_glCallLists_dispatch_table_rewrite_ptr, /* glCallLists */
    epoxy_glCheckFramebufferStatus_dispatch_table_rewrite_ptr, /* glCheckFramebufferStatus */
    epoxy_glCheckFramebufferStatusEXT_dispatch_table_rewrite_ptr, /* glCheckFramebufferStatusEXT */
    epoxy_glCheckFramebufferStatusOES_dispatch_table_rewrite_ptr, /* glCheckFramebufferStatusOES */
    epoxy_glCheckNamedFramebufferStatus_dispatch_table_rewrite_ptr, /* glCheckNamedFramebufferStatus */
    epoxy_glCheckNamedFramebufferStatusEXT_dispatch_table_rewrite_ptr, /* glCheckNamedFramebufferStatusEXT */
    epoxy_glClampColor_dispatch_table_rewrite_ptr, /* glClampColor */
    epoxy_glClampColorARB_dispatch_table_rewrite_ptr, /* glClampColorARB */
    epoxy_glClear_dispatch_table_rewrite_ptr, /* glClear */
    epoxy_glClearAccum_dispatch_table_rewrite_ptr, /* glClearAccum */
    epoxy_glClearAccumxOES_dispatch_table_rewrite_ptr, /* glClearAccumxOES */
    epoxy_glClearBufferData_dispatch_table_rewrite_ptr, /* glClearBufferData */
    epoxy_glClearBufferSubData_dispatch_table_rewrite_ptr, /* glClearBufferSubData */
    epoxy_glClearBufferfi_dispatch_table_rewrite_ptr, /* glClearBufferfi */
    epoxy_glClearBufferfv_dispatch_table_rewrite_ptr, /* glClearBufferfv */
    epoxy_glClearBufferiv_dispatch_table_rewrite_ptr, /* glClearBufferiv */
    epoxy_glClearBufferuiv_dispatch_table_rewrite_ptr, /* glClearBufferuiv */
    epoxy_glClearColor_dispatch_table_rewrite_ptr, /* glClearColor */
    epoxy_glClearColorIiEXT_dispatch_table_rewrite_ptr, /* glClearColorIiEXT */
    epoxy_glClearColorIuiEXT_dispatch_table_rewrite_ptr, /* glClearColorIuiEXT */
    epoxy_glClearColorx_dispatch_table_rewrite_ptr, /* glClearColorx */
    epoxy_glClearColorxOES_dispatch_table_rewrite_ptr, /* glClearColorxOES */
    epoxy_glClearDepth_dispatch_table_rewrite_ptr, /* glClearDepth */
    epoxy_glClearDepthdNV_dispatch_table_rewrite_ptr, /* glClearDepthdNV */
    epoxy_glClearDepthf_dispatch_table_rewrite_ptr, /* glClearDepthf */
    epoxy_glClearDepthfOES_dispatch_table_rewrite_ptr, /* glClearDepthfOES */
    epoxy_glClearDepthx_dispatch_table_rewrite_ptr, /* glClearDepthx */
    epoxy_glClearDepthxOES_dispatch_table_rewrite_ptr, /* glClearDepthxOES */
    epoxy_glClearIndex_dispatch_table_rewrite_ptr, /* glClearIndex */
    epoxy_glClearNamedBufferData_dispatch_table_rewrite_ptr, /* glClearNamedBufferData */
    epoxy_glClearNamedBufferDataEXT_dispatch_table_rewrite_ptr, /* glClearNamedBufferDataEXT */
    epoxy_glClearNamedBufferSubData_dispatch_table_rewrite_ptr, /* glClearNamedBufferSubData */
    epoxy_glClearNamedBufferSubDataEXT_dispatch_table_rewrite_ptr, /* glClearNamedBufferSubDataEXT */
    epoxy_glClearNamedFramebufferfi_dispatch_table_rewrite_ptr, /* glClearNamedFramebufferfi */
    epoxy_glClearNamedFramebufferfv_dispatch_table_rewrite_ptr, /* glClearNamedFramebufferfv */
    epoxy_glClearNamedFramebufferiv_dispatch_table_rewrite_ptr, /* glClearNamedFramebufferiv */
    epoxy_glClearNamedFramebufferuiv_dispatch_table_rewrite_ptr, /* glClearNamedFramebufferuiv */
    epoxy_glClearPixelLocalStorageuiEXT_dispatch_table_rewrite_ptr, /* glClearPixelLocalStorageuiEXT */
    epoxy_glClearStencil_dispatch_table_rewrite_ptr, /* glClearStencil */
    epoxy_glClearTexImage_dispatch_table_rewrite_ptr, /* glClearTexImage */
    epoxy_glClearTexImageEXT_dispatch_table_rewrite_ptr, /* glClearTexImageEXT */
    epoxy_glClearTexSubImage_dispatch_table_rewrite_ptr, /* glClearTexSubImage */
    epoxy_glClearTexSubImageEXT_dispatch_table_rewrite_ptr, /* glClearTexSubImageEXT */
    epoxy_glClientActiveTexture_dispatch_table_rewrite_ptr, /* glClientActiveTexture */
    epoxy_glClientActiveTextureARB_dispatch_table_rewrite_ptr, /* glClientActiveTextureARB */
    epoxy_glClientActiveVertexStreamATI_dispatch_table_rewrite_ptr, /* glClientActiveVertexStreamATI */
    epoxy_glClientAttribDefaultEXT_dispatch_table_rewrite_ptr, /* glClientAttribDefaultEXT */
    epoxy_glClientWaitSemaphoreui64NVX_dispatch_table_rewrite_ptr, /* glClientWaitSemaphoreui64NVX */
    epoxy_glClientWaitSync_dispatch_table_rewrite_ptr, /* glClientWaitSync */
    epoxy_glClientWaitSyncAPPLE_dispatch_table_rewrite_ptr, /* glClientWaitSyncAPPLE */
    epoxy_glClipControl_dispatch_table_rewrite_ptr, /* glClipControl */
    epoxy_glClipControlEXT_dispatch_table_rewrite_ptr, /* glClipControlEXT */
    epoxy_glClipPlane_dispatch_table_rewrite_ptr, /* glClipPlane */
    epoxy_glClipPlanef_dispatch_table_rewrite_ptr, /* glClipPlanef */
    epoxy_glClipPlanefIMG_dispatch_table_rewrite_ptr, /* glClipPlanefIMG */
    epoxy_glClipPlanefOES_dispatch_table_rewrite_ptr, /* glClipPlanefOES */
    epoxy_glClipPlanex_dispatch_table_rewrite_ptr, /* glClipPlanex */
    epoxy_glClipPlanexIMG_dispatch_table_rewrite_ptr, /* glClipPlanexIMG */
    epoxy_glClipPlanexOES_dispatch_table_rewrite_ptr, /* glClipPlanexOES */
    epoxy_glColor3b_dispatch_table_rewrite_ptr, /* glColor3b */
    epoxy_glColor3bv_dispatch_table_rewrite_ptr, /* glColor3bv */
    epoxy_glColor3d_dispatch_table_rewrite_ptr, /* glColor3d */
    epoxy_glColor3dv_dispatch_table_rewrite_ptr, /* glColor3dv */
    epoxy_glColor3f_dispatch_table_rewrite_ptr, /* glColor3f */
    epoxy_glColor3fVertex3fSUN_dispatch_table_rewrite_ptr, /* glColor3fVertex3fSUN */
    epoxy_glColor3fVertex3fvSUN_dispatch_table_rewrite_ptr, /* glColor3fVertex3fvSUN */
    epoxy_glColor3fv_dispatch_table_rewrite_ptr, /* glColor3fv */
    epoxy_glColor3hNV_dispatch_table_rewrite_ptr, /* glColor3hNV */
    epoxy_glColor3hvNV_dispatch_table_rewrite_ptr, /* glColor3hvNV */
    epoxy_glColor3i_dispatch_table_rewrite_ptr, /* glColor3i */
    epoxy_glColor3iv_dispatch_table_rewrite_ptr, /* glColor3iv */
    epoxy_glColor3s_dispatch_table_rewrite_ptr, /* glColor3s */
    epoxy_glColor3sv_dispatch_table_rewrite_ptr, /* glColor3sv */
    epoxy_glColor3ub_dispatch_table_rewrite_ptr, /* glColor3ub */
    epoxy_glColor3ubv_dispatch_table_rewrite_ptr, /* glColor3ubv */
    epoxy_glColor3ui_dispatch_table_rewrite_ptr, /* glColor3ui */
    epoxy_glColor3uiv_dispatch_table_rewrite_ptr, /* glColor3uiv */
    epoxy_glColor3us_dispatch_table_rewrite_ptr, /* glColor3us */
    epoxy_glColor3usv_dispatch_table_rewrite_ptr, /* glColor3usv */
    epoxy_glColor3xOES_dispatch_table_rewrite_ptr, /* glColor3xOES */
    epoxy_glColor3xvOES_dispatch_table_rewrite_ptr, /* glColor3xvOES */
    epoxy_glColor4b_dispatch_table_rewrite_ptr, /* glColor4b */
    epoxy_glColor4bv_dispatch_table_rewrite_ptr, /* glColor4bv */
    epoxy_glColor4d_dispatch_table_rewrite_ptr, /* glColor4d */
    epoxy_glColor4dv_dispatch_table_rewrite_ptr, /* glColor4dv */
    epoxy_glColor4f_dispatch_table_rewrite_ptr, /* glColor4f */
    epoxy_glColor4fNormal3fVertex3fSUN_dispatch_table_rewrite_ptr, /* glColor4fNormal3fVertex3fSUN */
    epoxy_glColor4fNormal3fVertex3fvSUN_dispatch_table_rewrite_ptr, /* glColor4fNormal3fVertex3fvSUN */
    epoxy_glColor4fv_dispatch_table_rewrite_ptr, /* glColor4fv */
    epoxy_glColor4hNV_dispatch_table_rewrite_ptr, /* glColor4hNV */
    epoxy_glColor4hvNV_dispatch_table_rewrite_ptr, /* glColor4hvNV */
    epoxy_glColor4i_dispatch_table_rewrite_ptr, /* glColor4i */
    epoxy_glColor4iv_dispatch_table_rewrite_ptr, /* glColor4iv */
    epoxy_glColor4s_dispatch_table_rewrite_ptr, /* glColor4s */
    epoxy_glColor4sv_dispatch_table_rewrite_ptr, /* glColor4sv */
    epoxy_glColor4ub_dispatch_table_rewrite_ptr, /* glColor4ub */
    epoxy_glColor4ubVertex2fSUN_dispatch_table_rewrite_ptr, /* glColor4ubVertex2fSUN */
    epoxy_glColor4ubVertex2fvSUN_dispatch_table_rewrite_ptr, /* glColor4ubVertex2fvSUN */
    epoxy_glColor4ubVertex3fSUN_dispatch_table_rewrite_ptr, /* glColor4ubVertex3fSUN */
    epoxy_glColor4ubVertex3fvSUN_dispatch_table_rewrite_ptr, /* glColor4ubVertex3fvSUN */
    epoxy_glColor4ubv_dispatch_table_rewrite_ptr, /* glColor4ubv */
    epoxy_glColor4ui_dispatch_table_rewrite_ptr, /* glColor4ui */
    epoxy_glColor4uiv_dispatch_table_rewrite_ptr, /* glColor4uiv */
    epoxy_glColor4us_dispatch_table_rewrite_ptr, /* glColor4us */
    epoxy_glColor4usv_dispatch_table_rewrite_ptr, /* glColor4usv */
    epoxy_glColor4x_dispatch_table_rewrite_ptr, /* glColor4x */
    epoxy_glColor4xOES_dispatch_table_rewrite_ptr, /* glColor4xOES */
    epoxy_glColor4xvOES_dispatch_table_rewrite_ptr, /* glColor4xvOES */
    epoxy_glColorFormatNV_dispatch_table_rewrite_ptr, /* glColorFormatNV */
    epoxy_glColorFragmentOp1ATI_dispatch_table_rewrite_ptr, /* glColorFragmentOp1ATI */
    epoxy_glColorFragmentOp2ATI_dispatch_table_rewrite_ptr, /* glColorFragmentOp2ATI */
    epoxy_glColorFragmentOp3ATI_dispatch_table_rewrite_ptr, /* glColorFragmentOp3ATI */
    epoxy_glColorMask_dispatch_table_rewrite_ptr, /* glColorMask */
    epoxy_glColorMaskIndexedEXT_dispatch_table_rewrite_ptr, /* glColorMaskIndexedEXT */
    epoxy_glColorMaski_dispatch_table_rewrite_ptr, /* glColorMaski */
    epoxy_glColorMaskiEXT_dispatch_table_rewrite_ptr, /* glColorMaskiEXT */
    epoxy_glColorMaskiOES_dispatch_table_rewrite_ptr, /* glColorMaskiOES */
    epoxy_glColorMaterial_dispatch_table_rewrite_ptr, /* glColorMaterial */
    epoxy_glColorP3ui_dispatch_table_rewrite_ptr, /* glColorP3ui */
    epoxy_glColorP3uiv_dispatch_table_rewrite_ptr, /* glColorP3uiv */
    epoxy_glColorP4ui_dispatch_table_rewrite_ptr, /* glColorP4ui */
    epoxy_glColorP4uiv_dispatch_table_rewrite_ptr, /* glColorP4uiv */
    epoxy_glColorPointer_dispatch_table_rewrite_ptr, /* glColorPointer */
    epoxy_glColorPointerEXT_dispatch_table_rewrite_ptr, /* glColorPointerEXT */
    epoxy_glColorPointerListIBM_dispatch_table_rewrite_ptr, /* glColorPointerListIBM */
    epoxy_glColorPointervINTEL_dispatch_table_rewrite_ptr, /* glColorPointervINTEL */
    epoxy_glColorSubTable_dispatch_table_rewrite_ptr, /* glColorSubTable */
    epoxy_glColorSubTableEXT_dispatch_table_rewrite_ptr, /* glColorSubTableEXT */
    epoxy_glColorTable_dispatch_table_rewrite_ptr, /* glColorTable */
    epoxy_glColorTableEXT_dispatch_table_rewrite_ptr, /* glColorTableEXT */
    epoxy_glColorTableParameterfv_dispatch_table_rewrite_ptr, /* glColorTableParameterfv */
    epoxy_glColorTableParameterfvSGI_dispatch_table_rewrite_ptr, /* glColorTableParameterfvSGI */
    epoxy_glColorTableParameteriv_dispatch_table_rewrite_ptr, /* glColorTableParameteriv */
    epoxy_glColorTableParameterivSGI_dispatch_table_rewrite_ptr, /* glColorTableParameterivSGI */
    epoxy_glColorTableSGI_dispatch_table_rewrite_ptr, /* glColorTableSGI */
    epoxy_glCombinerInputNV_dispatch_table_rewrite_ptr, /* glCombinerInputNV */
    epoxy_glCombinerOutputNV_dispatch_table_rewrite_ptr, /* glCombinerOutputNV */
    epoxy_glCombinerParameterfNV_dispatch_table_rewrite_ptr, /* glCombinerParameterfNV */
    epoxy_glCombinerParameterfvNV_dispatch_table_rewrite_ptr, /* glCombinerParameterfvNV */
    epoxy_glCombinerParameteriNV_dispatch_table_rewrite_ptr, /* glCombinerParameteriNV */
    epoxy_glCombinerParameterivNV_dispatch_table_rewrite_ptr, /* glCombinerParameterivNV */
    epoxy_glCombinerStageParameterfvNV_dispatch_table_rewrite_ptr, /* glCombinerStageParameterfvNV */
    epoxy_glCommandListSegmentsNV_dispatch_table_rewrite_ptr, /* glCommandListSegmentsNV */
    epoxy_glCompileCommandListNV_dispatch_table_rewrite_ptr, /* glCompileCommandListNV */
    epoxy_glCompileShader_dispatch_table_rewrite_ptr, /* glCompileShader */
    epoxy_glCompileShaderARB_dispatch_table_rewrite_ptr, /* glCompileShaderARB */
    epoxy_glCompileShaderIncludeARB_dispatch_table_rewrite_ptr, /* glCompileShaderIncludeARB */
    epoxy_glCompressedMultiTexImage1DEXT_dispatch_table_rewrite_ptr, /* glCompressedMultiTexImage1DEXT */
    epoxy_glCompressedMultiTexImage2DEXT_dispatch_table_rewrite_ptr, /* glCompressedMultiTexImage2DEXT */
    epoxy_glCompressedMultiTexImage3DEXT_dispatch_table_rewrite_ptr, /* glCompressedMultiTexImage3DEXT */
    epoxy_glCompressedMultiTexSubImage1DEXT_dispatch_table_rewrite_ptr, /* glCompressedMultiTexSubImage1DEXT */
    epoxy_glCompressedMultiTexSubImage2DEXT_dispatch_table_rewrite_ptr, /* glCompressedMultiTexSubImage2DEXT */
    epoxy_glCompressedMultiTexSubImage3DEXT_dispatch_table_rewrite_ptr, /* glCompressedMultiTexSubImage3DEXT */
    epoxy_glCompressedTexImage1D_dispatch_table_rewrite_ptr, /* glCompressedTexImage1D */
    epoxy_glCompressedTexImage1DARB_dispatch_table_rewrite_ptr, /* glCompressedTexImage1DARB */
    epoxy_glCompressedTexImage2D_dispatch_table_rewrite_ptr, /* glCompressedTexImage2D */
    epoxy_glCompressedTexImage2DARB_dispatch_table_rewrite_ptr, /* glCompressedTexImage2DARB */
    epoxy_glCompressedTexImage3D_dispatch_table_rewrite_ptr, /* glCompressedTexImage3D */
    epoxy_glCompressedTexImage3DARB_dispatch_table_rewrite_ptr, /* glCompressedTexImage3DARB */
    epoxy_glCompressedTexImage3DOES_dispatch_table_rewrite_ptr, /* glCompressedTexImage3DOES */
    epoxy_glCompressedTexSubImage1D_dispatch_table_rewrite_ptr, /* glCompressedTexSubImage1D */
    epoxy_glCompressedTexSubImage1DARB_dispatch_table_rewrite_ptr, /* glCompressedTexSubImage1DARB */
    epoxy_glCompressedTexSubImage2D_dispatch_table_rewrite_ptr, /* glCompressedTexSubImage2D */
    epoxy_glCompressedTexSubImage2DARB_dispatch_table_rewrite_ptr, /* glCompressedTexSubImage2DARB */
    epoxy_glCompressedTexSubImage3D_dispatch_table_rewrite_ptr, /* glCompressedTexSubImage3D */
    epoxy_glCompressedTexSubImage3DARB_dispatch_table_rewrite_ptr, /* glCompressedTexSubImage3DARB */
    epoxy_glCompressedTexSubImage3DOES_dispatch_table_rewrite_ptr, /* glCompressedTexSubImage3DOES */
    epoxy_glCompressedTextureImage1DEXT_dispatch_table_rewrite_ptr, /* glCompressedTextureImage1DEXT */
    epoxy_glCompressedTextureImage2DEXT_dispatch_table_rewrite_ptr, /* glCompressedTextureImage2DEXT */
    epoxy_glCompressedTextureImage3DEXT_dispatch_table_rewrite_ptr, /* glCompressedTextureImage3DEXT */
    epoxy_glCompressedTextureSubImage1D_dispatch_table_rewrite_ptr, /* glCompressedTextureSubImage1D */
    epoxy_glCompressedTextureSubImage1DEXT_dispatch_table_rewrite_ptr, /* glCompressedTextureSubImage1DEXT */
    epoxy_glCompressedTextureSubImage2D_dispatch_table_rewrite_ptr, /* glCompressedTextureSubImage2D */
    epoxy_glCompressedTextureSubImage2DEXT_dispatch_table_rewrite_ptr, /* glCompressedTextureSubImage2DEXT */
    epoxy_glCompressedTextureSubImage3D_dispatch_table_rewrite_ptr, /* glCompressedTextureSubImage3D */
    epoxy_glCompressedTextureSubImage3DEXT_dispatch_table_rewrite_ptr, /* glCompressedTextureSubImage3DEXT */
    epoxy_glConservativeRasterParameterfNV_dispatch_table_rewrite_ptr, /* glConservativeRasterParameterfNV */
    epoxy_glConservativeRasterParameteriNV_dispatch_table_rewrite_ptr, /* glConservativeRasterParameteriNV */
    epoxy_glConvolutionFilter1D_dispatch_table_rewrite_ptr, /* glConvolutionFilter1D */
    epoxy_glConvolutionFilter1DEXT_dispatch_table_rewrite_ptr, /* glConvolutionFilter1DEXT */
    epoxy_glConvolutionFilter2D_dispatch_table_rewrite_ptr, /* glConvolutionFilter2D */
    epoxy_glConvolutionFilter2DEXT_dispatch_table_rewrite_ptr, /* glConvolutionFilter2DEXT */
    epoxy_glConvolutionParameterf_dispatch_table_rewrite_ptr, /* glConvolutionParameterf */
    epoxy_glConvolutionParameterfEXT_dispatch_table_rewrite_ptr, /* glConvolutionParameterfEXT */
    epoxy_glConvolutionParameterfv_dispatch_table_rewrite_ptr, /* glConvolutionParameterfv */
    epoxy_glConvolutionParameterfvEXT_dispatch_table_rewrite_ptr, /* glConvolutionParameterfvEXT */
    epoxy_glConvolutionParameteri_dispatch_table_rewrite_ptr, /* glConvolutionParameteri */
    epoxy_glConvolutionParameteriEXT_dispatch_table_rewrite_ptr, /* glConvolutionParameteriEXT */
    epoxy_glConvolutionParameteriv_dispatch_table_rewrite_ptr, /* glConvolutionParameteriv */
    epoxy_glConvolutionParameterivEXT_dispatch_table_rewrite_ptr, /* glConvolutionParameterivEXT */
    epoxy_glConvolutionParameterxOES_dispatch_table_rewrite_ptr, /* glConvolutionParameterxOES */
    epoxy_glConvolutionParameterxvOES_dispatch_table_rewrite_ptr, /* glConvolutionParameterxvOES */
    epoxy_glCopyBufferSubData_dispatch_table_rewrite_ptr, /* glCopyBufferSubData */
    epoxy_glCopyBufferSubDataNV_dispatch_table_rewrite_ptr, /* glCopyBufferSubDataNV */
    epoxy_glCopyColorSubTable_dispatch_table_rewrite_ptr, /* glCopyColorSubTable */
    epoxy_glCopyColorSubTableEXT_dispatch_table_rewrite_ptr, /* glCopyColorSubTableEXT */
    epoxy_glCopyColorTable_dispatch_table_rewrite_ptr, /* glCopyColorTable */
    epoxy_glCopyColorTableSGI_dispatch_table_rewrite_ptr, /* glCopyColorTableSGI */
    epoxy_glCopyConvolutionFilter1D_dispatch_table_rewrite_ptr, /* glCopyConvolutionFilter1D */
    epoxy_glCopyConvolutionFilter1DEXT_dispatch_table_rewrite_ptr, /* glCopyConvolutionFilter1DEXT */
    epoxy_glCopyConvolutionFilter2D_dispatch_table_rewrite_ptr, /* glCopyConvolutionFilter2D */
    epoxy_glCopyConvolutionFilter2DEXT_dispatch_table_rewrite_ptr, /* glCopyConvolutionFilter2DEXT */
    epoxy_glCopyImageSubData_dispatch_table_rewrite_ptr, /* glCopyImageSubData */
    epoxy_glCopyImageSubDataEXT_dispatch_table_rewrite_ptr, /* glCopyImageSubDataEXT */
    epoxy_glCopyImageSubDataNV_dispatch_table_rewrite_ptr, /* glCopyImageSubDataNV */
    epoxy_glCopyImageSubDataOES_dispatch_table_rewrite_ptr, /* glCopyImageSubDataOES */
    epoxy_glCopyMultiTexImage1DEXT_dispatch_table_rewrite_ptr, /* glCopyMultiTexImage1DEXT */
    epoxy_glCopyMultiTexImage2DEXT_dispatch_table_rewrite_ptr, /* glCopyMultiTexImage2DEXT */
    epoxy_glCopyMultiTexSubImage1DEXT_dispatch_table_rewrite_ptr, /* glCopyMultiTexSubImage1DEXT */
    epoxy_glCopyMultiTexSubImage2DEXT_dispatch_table_rewrite_ptr, /* glCopyMultiTexSubImage2DEXT */
    epoxy_glCopyMultiTexSubImage3DEXT_dispatch_table_rewrite_ptr, /* glCopyMultiTexSubImage3DEXT */
    epoxy_glCopyNamedBufferSubData_dispatch_table_rewrite_ptr, /* glCopyNamedBufferSubData */
    epoxy_glCopyPathNV_dispatch_table_rewrite_ptr, /* glCopyPathNV */
    epoxy_glCopyPixels_dispatch_table_rewrite_ptr, /* glCopyPixels */
    epoxy_glCopyTexImage1D_dispatch_table_rewrite_ptr, /* glCopyTexImage1D */
    epoxy_glCopyTexImage1DEXT_dispatch_table_rewrite_ptr, /* glCopyTexImage1DEXT */
    epoxy_glCopyTexImage2D_dispatch_table_rewrite_ptr, /* glCopyTexImage2D */
    epoxy_glCopyTexImage2DEXT_dispatch_table_rewrite_ptr, /* glCopyTexImage2DEXT */
    epoxy_glCopyTexSubImage1D_dispatch_table_rewrite_ptr, /* glCopyTexSubImage1D */
    epoxy_glCopyTexSubImage1DEXT_dispatch_table_rewrite_ptr, /* glCopyTexSubImage1DEXT */
    epoxy_glCopyTexSubImage2D_dispatch_table_rewrite_ptr, /* glCopyTexSubImage2D */
    epoxy_glCopyTexSubImage2DEXT_dispatch_table_rewrite_ptr, /* glCopyTexSubImage2DEXT */
    epoxy_glCopyTexSubImage3D_dispatch_table_rewrite_ptr, /* glCopyTexSubImage3D */
    epoxy_glCopyTexSubImage3DEXT_dispatch_table_rewrite_ptr, /* glCopyTexSubImage3DEXT */
    epoxy_glCopyTexSubImage3DOES_dispatch_table_rewrite_ptr, /* glCopyTexSubImage3DOES */
    epoxy_glCopyTextureImage1DEXT_dispatch_table_rewrite_ptr, /* glCopyTextureImage1DEXT */
    epoxy_glCopyTextureImage2DEXT_dispatch_table_rewrite_ptr, /* glCopyTextureImage2DEXT */
    epoxy_glCopyTextureLevelsAPPLE_dispatch_table_rewrite_ptr, /* glCopyTextureLevelsAPPLE */
    epoxy_glCopyTextureSubImage1D_dispatch_table_rewrite_ptr, /* glCopyTextureSubImage1D */
    epoxy_glCopyTextureSubImage1DEXT_dispatch_table_rewrite_ptr, /* glCopyTextureSubImage1DEXT */
    epoxy_glCopyTextureSubImage2D_dispatch_table_rewrite_ptr, /* glCopyTextureSubImage2D */
    epoxy_glCopyTextureSubImage2DEXT_dispatch_table_rewrite_ptr, /* glCopyTextureSubImage2DEXT */
    epoxy_glCopyTextureSubImage3D_dispatch_table_rewrite_ptr, /* glCopyTextureSubImage3D */
    epoxy_glCopyTextureSubImage3DEXT_dispatch_table_rewrite_ptr, /* glCopyTextureSubImage3DEXT */
    epoxy_glCoverFillPathInstancedNV_dispatch_table_rewrite_ptr, /* glCoverFillPathInstancedNV */
    epoxy_glCoverFillPathNV_dispatch_table_rewrite_ptr, /* glCoverFillPathNV */
    epoxy_glCoverStrokePathInstancedNV_dispatch_table_rewrite_ptr, /* glCoverStrokePathInstancedNV */
    epoxy_glCoverStrokePathNV_dispatch_table_rewrite_ptr, /* glCoverStrokePathNV */
    epoxy_glCoverageMaskNV_dispatch_table_rewrite_ptr, /* glCoverageMaskNV */
    epoxy_glCoverageModulationNV_dispatch_table_rewrite_ptr, /* glCoverageModulationNV */
    epoxy_glCoverageModulationTableNV_dispatch_table_rewrite_ptr, /* glCoverageModulationTableNV */
    epoxy_glCoverageOperationNV_dispatch_table_rewrite_ptr, /* glCoverageOperationNV */
    epoxy_glCreateBuffers_dispatch_table_rewrite_ptr, /* glCreateBuffers */
    epoxy_glCreateCommandListsNV_dispatch_table_rewrite_ptr, /* glCreateCommandListsNV */
    epoxy_glCreateFramebuffers_dispatch_table_rewrite_ptr, /* glCreateFramebuffers */
    epoxy_glCreateMemoryObjectsEXT_dispatch_table_rewrite_ptr, /* glCreateMemoryObjectsEXT */
    epoxy_glCreatePerfQueryINTEL_dispatch_table_rewrite_ptr, /* glCreatePerfQueryINTEL */
    epoxy_glCreateProgram_dispatch_table_rewrite_ptr, /* glCreateProgram */
    epoxy_glCreateProgramObjectARB_dispatch_table_rewrite_ptr, /* glCreateProgramObjectARB */
    epoxy_glCreateProgramPipelines_dispatch_table_rewrite_ptr, /* glCreateProgramPipelines */
    epoxy_glCreateProgressFenceNVX_dispatch_table_rewrite_ptr, /* glCreateProgressFenceNVX */
    epoxy_glCreateQueries_dispatch_table_rewrite_ptr, /* glCreateQueries */
    epoxy_glCreateRenderbuffers_dispatch_table_rewrite_ptr, /* glCreateRenderbuffers */
    epoxy_glCreateSamplers_dispatch_table_rewrite_ptr, /* glCreateSamplers */
    epoxy_glCreateShader_dispatch_table_rewrite_ptr, /* glCreateShader */
    epoxy_glCreateShaderObjectARB_dispatch_table_rewrite_ptr, /* glCreateShaderObjectARB */
    epoxy_glCreateShaderProgramEXT_dispatch_table_rewrite_ptr, /* glCreateShaderProgramEXT */
    epoxy_glCreateShaderProgramv_dispatch_table_rewrite_ptr, /* glCreateShaderProgramv */
    epoxy_glCreateShaderProgramvEXT_dispatch_table_rewrite_ptr, /* glCreateShaderProgramvEXT */
    epoxy_glCreateStatesNV_dispatch_table_rewrite_ptr, /* glCreateStatesNV */
    epoxy_glCreateSyncFromCLeventARB_dispatch_table_rewrite_ptr, /* glCreateSyncFromCLeventARB */
    epoxy_glCreateTextures_dispatch_table_rewrite_ptr, /* glCreateTextures */
    epoxy_glCreateTransformFeedbacks_dispatch_table_rewrite_ptr, /* glCreateTransformFeedbacks */
    epoxy_glCreateVertexArrays_dispatch_table_rewrite_ptr, /* glCreateVertexArrays */
    epoxy_glCullFace_dispatch_table_rewrite_ptr, /* glCullFace */
    epoxy_glCullParameterdvEXT_dispatch_table_rewrite_ptr, /* glCullParameterdvEXT */
    epoxy_glCullParameterfvEXT_dispatch_table_rewrite_ptr, /* glCullParameterfvEXT */
    epoxy_glCurrentPaletteMatrixARB_dispatch_table_rewrite_ptr, /* glCurrentPaletteMatrixARB */
    epoxy_glCurrentPaletteMatrixOES_dispatch_table_rewrite_ptr, /* glCurrentPaletteMatrixOES */
    epoxy_glDebugMessageCallback_dispatch_table_rewrite_ptr, /* glDebugMessageCallback */
    epoxy_glDebugMessageCallbackAMD_dispatch_table_rewrite_ptr, /* glDebugMessageCallbackAMD */
    epoxy_glDebugMessageCallbackARB_dispatch_table_rewrite_ptr, /* glDebugMessageCallbackARB */
    epoxy_glDebugMessageCallbackKHR_dispatch_table_rewrite_ptr, /* glDebugMessageCallbackKHR */
    epoxy_glDebugMessageControl_dispatch_table_rewrite_ptr, /* glDebugMessageControl */
    epoxy_glDebugMessageControlARB_dispatch_table_rewrite_ptr, /* glDebugMessageControlARB */
    epoxy_glDebugMessageControlKHR_dispatch_table_rewrite_ptr, /* glDebugMessageControlKHR */
    epoxy_glDebugMessageEnableAMD_dispatch_table_rewrite_ptr, /* glDebugMessageEnableAMD */
    epoxy_glDebugMessageInsert_dispatch_table_rewrite_ptr, /* glDebugMessageInsert */
    epoxy_glDebugMessageInsertAMD_dispatch_table_rewrite_ptr, /* glDebugMessageInsertAMD */
    epoxy_glDebugMessageInsertARB_dispatch_table_rewrite_ptr, /* glDebugMessageInsertARB */
    epoxy_glDebugMessageInsertKHR_dispatch_table_rewrite_ptr, /* glDebugMessageInsertKHR */
    epoxy_glDeformSGIX_dispatch_table_rewrite_ptr, /* glDeformSGIX */
    epoxy_glDeformationMap3dSGIX_dispatch_table_rewrite_ptr, /* glDeformationMap3dSGIX */
    epoxy_glDeformationMap3fSGIX_dispatch_table_rewrite_ptr, /* glDeformationMap3fSGIX */
    epoxy_glDeleteAsyncMarkersSGIX_dispatch_table_rewrite_ptr, /* glDeleteAsyncMarkersSGIX */
    epoxy_glDeleteBuffers_dispatch_table_rewrite_ptr, /* glDeleteBuffers */
    epoxy_glDeleteBuffersARB_dispatch_table_rewrite_ptr, /* glDeleteBuffersARB */
    epoxy_glDeleteCommandListsNV_dispatch_table_rewrite_ptr, /* glDeleteCommandListsNV */
    epoxy_glDeleteFencesAPPLE_dispatch_table_rewrite_ptr, /* glDeleteFencesAPPLE */
    epoxy_glDeleteFencesNV_dispatch_table_rewrite_ptr, /* glDeleteFencesNV */
    epoxy_glDeleteFragmentShaderATI_dispatch_table_rewrite_ptr, /* glDeleteFragmentShaderATI */
    epoxy_glDeleteFramebuffers_dispatch_table_rewrite_ptr, /* glDeleteFramebuffers */
    epoxy_glDeleteFramebuffersEXT_dispatch_table_rewrite_ptr, /* glDeleteFramebuffersEXT */
    epoxy_glDeleteFramebuffersOES_dispatch_table_rewrite_ptr, /* glDeleteFramebuffersOES */
    epoxy_glDeleteLists_dispatch_table_rewrite_ptr, /* glDeleteLists */
    epoxy_glDeleteMemoryObjectsEXT_dispatch_table_rewrite_ptr, /* glDeleteMemoryObjectsEXT */
    epoxy_glDeleteNamedStringARB_dispatch_table_rewrite_ptr, /* glDeleteNamedStringARB */
    epoxy_glDeleteNamesAMD_dispatch_table_rewrite_ptr, /* glDeleteNamesAMD */
    epoxy_glDeleteObjectARB_dispatch_table_rewrite_ptr, /* glDeleteObjectARB */
    epoxy_glDeleteOcclusionQueriesNV_dispatch_table_rewrite_ptr, /* glDeleteOcclusionQueriesNV */
    epoxy_glDeletePathsNV_dispatch_table_rewrite_ptr, /* glDeletePathsNV */
    epoxy_glDeletePerfMonitorsAMD_dispatch_table_rewrite_ptr, /* glDeletePerfMonitorsAMD */
    epoxy_glDeletePerfQueryINTEL_dispatch_table_rewrite_ptr, /* glDeletePerfQueryINTEL */
    epoxy_glDeleteProgram_dispatch_table_rewrite_ptr, /* glDeleteProgram */
    epoxy_glDeleteProgramPipelines_dispatch_table_rewrite_ptr, /* glDeleteProgramPipelines */
    epoxy_glDeleteProgramPipelinesEXT_dispatch_table_rewrite_ptr, /* glDeleteProgramPipelinesEXT */
    epoxy_glDeleteProgramsARB_dispatch_table_rewrite_ptr, /* glDeleteProgramsARB */
    epoxy_glDeleteProgramsNV_dispatch_table_rewrite_ptr, /* glDeleteProgramsNV */
    epoxy_glDeleteQueries_dispatch_table_rewrite_ptr, /* glDeleteQueries */
    epoxy_glDeleteQueriesARB_dispatch_table_rewrite_ptr, /* glDeleteQueriesARB */
    epoxy_glDeleteQueriesEXT_dispatch_table_rewrite_ptr, /* glDeleteQueriesEXT */
    epoxy_glDeleteQueryResourceTagNV_dispatch_table_rewrite_ptr, /* glDeleteQueryResourceTagNV */
    epoxy_glDeleteRenderbuffers_dispatch_table_rewrite_ptr, /* glDeleteRenderbuffers */
    epoxy_glDeleteRenderbuffersEXT_dispatch_table_rewrite_ptr, /* glDeleteRenderbuffersEXT */
    epoxy_glDeleteRenderbuffersOES_dispatch_table_rewrite_ptr, /* glDeleteRenderbuffersOES */
    epoxy_glDeleteSamplers_dispatch_table_rewrite_ptr, /* glDeleteSamplers */
    epoxy_glDeleteSemaphoresEXT_dispatch_table_rewrite_ptr, /* glDeleteSemaphoresEXT */
    epoxy_glDeleteShader_dispatch_table_rewrite_ptr, /* glDeleteShader */
    epoxy_glDeleteStatesNV_dispatch_table_rewrite_ptr, /* glDeleteStatesNV */
    epoxy_glDeleteSync_dispatch_table_rewrite_ptr, /* glDeleteSync */
    epoxy_glDeleteSyncAPPLE_dispatch_table_rewrite_ptr, /* glDeleteSyncAPPLE */
    epoxy_glDeleteTextures_dispatch_table_rewrite_ptr, /* glDeleteTextures */
    epoxy_glDeleteTexturesEXT_dispatch_table_rewrite_ptr, /* glDeleteTexturesEXT */
    epoxy_glDeleteTransformFeedbacks_dispatch_table_rewrite_ptr, /* glDeleteTransformFeedbacks */
    epoxy_glDeleteTransformFeedbacksNV_dispatch_table_rewrite_ptr, /* glDeleteTransformFeedbacksNV */
    epoxy_glDeleteVertexArrays_dispatch_table_rewrite_ptr, /* glDeleteVertexArrays */
    epoxy_glDeleteVertexArraysAPPLE_dispatch_table_rewrite_ptr, /* glDeleteVertexArraysAPPLE */
    epoxy_glDeleteVertexArraysOES_dispatch_table_rewrite_ptr, /* glDeleteVertexArraysOES */
    epoxy_glDeleteVertexShaderEXT_dispatch_table_rewrite_ptr, /* glDeleteVertexShaderEXT */
    epoxy_glDepthBoundsEXT_dispatch_table_rewrite_ptr, /* glDepthBoundsEXT */
    epoxy_glDepthBoundsdNV_dispatch_table_rewrite_ptr, /* glDepthBoundsdNV */
    epoxy_glDepthFunc_dispatch_table_rewrite_ptr, /* glDepthFunc */
    epoxy_glDepthMask_dispatch_table_rewrite_ptr, /* glDepthMask */
    epoxy_glDepthRange_dispatch_table_rewrite_ptr, /* glDepthRange */
    epoxy_glDepthRangeArrayfvNV_dispatch_table_rewrite_ptr, /* glDepthRangeArrayfvNV */
    epoxy_glDepthRangeArrayfvOES_dispatch_table_rewrite_ptr, /* glDepthRangeArrayfvOES */
    epoxy_glDepthRangeArrayv_dispatch_table_rewrite_ptr, /* glDepthRangeArrayv */
    epoxy_glDepthRangeIndexed_dispatch_table_rewrite_ptr, /* glDepthRangeIndexed */
    epoxy_glDepthRangeIndexedfNV_dispatch_table_rewrite_ptr, /* glDepthRangeIndexedfNV */
    epoxy_glDepthRangeIndexedfOES_dispatch_table_rewrite_ptr, /* glDepthRangeIndexedfOES */
    epoxy_glDepthRangedNV_dispatch_table_rewrite_ptr, /* glDepthRangedNV */
    epoxy_glDepthRangef_dispatch_table_rewrite_ptr, /* glDepthRangef */
    epoxy_glDepthRangefOES_dispatch_table_rewrite_ptr, /* glDepthRangefOES */
    epoxy_glDepthRangex_dispatch_table_rewrite_ptr, /* glDepthRangex */
    epoxy_glDepthRangexOES_dispatch_table_rewrite_ptr, /* glDepthRangexOES */
    epoxy_glDetachObjectARB_dispatch_table_rewrite_ptr, /* glDetachObjectARB */
    epoxy_glDetachShader_dispatch_table_rewrite_ptr, /* glDetachShader */
    epoxy_glDetailTexFuncSGIS_dispatch_table_rewrite_ptr, /* glDetailTexFuncSGIS */
    epoxy_glDisable_dispatch_table_rewrite_ptr, /* glDisable */
    epoxy_glDisableClientState_dispatch_table_rewrite_ptr, /* glDisableClientState */
    epoxy_glDisableClientStateIndexedEXT_dispatch_table_rewrite_ptr, /* glDisableClientStateIndexedEXT */
    epoxy_glDisableClientStateiEXT_dispatch_table_rewrite_ptr, /* glDisableClientStateiEXT */
    epoxy_glDisableDriverControlQCOM_dispatch_table_rewrite_ptr, /* glDisableDriverControlQCOM */
    epoxy_glDisableIndexedEXT_dispatch_table_rewrite_ptr, /* glDisableIndexedEXT */
    epoxy_glDisableVariantClientStateEXT_dispatch_table_rewrite_ptr, /* glDisableVariantClientStateEXT */
    epoxy_glDisableVertexArrayAttrib_dispatch_table_rewrite_ptr, /* glDisableVertexArrayAttrib */
    epoxy_glDisableVertexArrayAttribEXT_dispatch_table_rewrite_ptr, /* glDisableVertexArrayAttribEXT */
    epoxy_glDisableVertexArrayEXT_dispatch_table_rewrite_ptr, /* glDisableVertexArrayEXT */
    epoxy_glDisableVertexAttribAPPLE_dispatch_table_rewrite_ptr, /* glDisableVertexAttribAPPLE */
    epoxy_glDisableVertexAttribArray_dispatch_table_rewrite_ptr, /* glDisableVertexAttribArray */
    epoxy_glDisableVertexAttribArrayARB_dispatch_table_rewrite_ptr, /* glDisableVertexAttribArrayARB */
    epoxy_glDisablei_dispatch_table_rewrite_ptr, /* glDisablei */
    epoxy_glDisableiEXT_dispatch_table_rewrite_ptr, /* glDisableiEXT */
    epoxy_glDisableiNV_dispatch_table_rewrite_ptr, /* glDisableiNV */
    epoxy_glDisableiOES_dispatch_table_rewrite_ptr, /* glDisableiOES */
    epoxy_glDiscardFramebufferEXT_dispatch_table_rewrite_ptr, /* glDiscardFramebufferEXT */
    epoxy_glDispatchCompute_dispatch_table_rewrite_ptr, /* glDispatchCompute */
    epoxy_glDispatchComputeGroupSizeARB_dispatch_table_rewrite_ptr, /* glDispatchComputeGroupSizeARB */
    epoxy_glDispatchComputeIndirect_dispatch_table_rewrite_ptr, /* glDispatchComputeIndirect */
    epoxy_glDrawArrays_dispatch_table_rewrite_ptr, /* glDrawArrays */
    epoxy_glDrawArraysEXT_dispatch_table_rewrite_ptr, /* glDrawArraysEXT */
    epoxy_glDrawArraysIndirect_dispatch_table_rewrite_ptr, /* glDrawArraysIndirect */
    epoxy_glDrawArraysInstanced_dispatch_table_rewrite_ptr, /* glDrawArraysInstanced */
    epoxy_glDrawArraysInstancedANGLE_dispatch_table_rewrite_ptr, /* glDrawArraysInstancedANGLE */
    epoxy_glDrawArraysInstancedARB_dispatch_table_rewrite_ptr, /* glDrawArraysInstancedARB */
    epoxy_glDrawArraysInstancedBaseInstance_dispatch_table_rewrite_ptr, /* glDrawArraysInstancedBaseInstance */
    epoxy_glDrawArraysInstancedBaseInstanceEXT_dispatch_table_rewrite_ptr, /* glDrawArraysInstancedBaseInstanceEXT */
    epoxy_glDrawArraysInstancedEXT_dispatch_table_rewrite_ptr, /* glDrawArraysInstancedEXT */
    epoxy_glDrawArraysInstancedNV_dispatch_table_rewrite_ptr, /* glDrawArraysInstancedNV */
    epoxy_glDrawBuffer_dispatch_table_rewrite_ptr, /* glDrawBuffer */
    epoxy_glDrawBuffers_dispatch_table_rewrite_ptr, /* glDrawBuffers */
    epoxy_glDrawBuffersARB_dispatch_table_rewrite_ptr, /* glDrawBuffersARB */
    epoxy_glDrawBuffersATI_dispatch_table_rewrite_ptr, /* glDrawBuffersATI */
    epoxy_glDrawBuffersEXT_dispatch_table_rewrite_ptr, /* glDrawBuffersEXT */
    epoxy_glDrawBuffersIndexedEXT_dispatch_table_rewrite_ptr, /* glDrawBuffersIndexedEXT */
    epoxy_glDrawBuffersNV_dispatch_table_rewrite_ptr, /* glDrawBuffersNV */
    epoxy_glDrawCommandsAddressNV_dispatch_table_rewrite_ptr, /* glDrawCommandsAddressNV */
    epoxy_glDrawCommandsNV_dispatch_table_rewrite_ptr, /* glDrawCommandsNV */
    epoxy_glDrawCommandsStatesAddressNV_dispatch_table_rewrite_ptr, /* glDrawCommandsStatesAddressNV */
    epoxy_glDrawCommandsStatesNV_dispatch_table_rewrite_ptr, /* glDrawCommandsStatesNV */
    epoxy_glDrawElementArrayAPPLE_dispatch_table_rewrite_ptr, /* glDrawElementArrayAPPLE */
    epoxy_glDrawElementArrayATI_dispatch_table_rewrite_ptr, /* glDrawElementArrayATI */
    epoxy_glDrawElements_dispatch_table_rewrite_ptr, /* glDrawElements */
    epoxy_glDrawElementsBaseVertex_dispatch_table_rewrite_ptr, /* glDrawElementsBaseVertex */
    epoxy_glDrawElementsBaseVertexEXT_dispatch_table_rewrite_ptr, /* glDrawElementsBaseVertexEXT */
    epoxy_glDrawElementsBaseVertexOES_dispatch_table_rewrite_ptr, /* glDrawElementsBaseVertexOES */
    epoxy_glDrawElementsIndirect_dispatch_table_rewrite_ptr, /* glDrawElementsIndirect */
    epoxy_glDrawElementsInstanced_dispatch_table_rewrite_ptr, /* glDrawElementsInstanced */
    epoxy_glDrawElementsInstancedANGLE_dispatch_table_rewrite_ptr, /* glDrawElementsInstancedANGLE */
    epoxy_glDrawElementsInstancedARB_dispatch_table_rewrite_ptr, /* glDrawElementsInstancedARB */
    epoxy_glDrawElementsInstancedBaseInstance_dispatch_table_rewrite_ptr, /* glDrawElementsInstancedBaseInstance */
    epoxy_glDrawElementsInstancedBaseInstanceEXT_dispatch_table_rewrite_ptr, /* glDrawElementsInstancedBaseInstanceEXT */
    epoxy_glDrawElementsInstancedBaseVertex_dispatch_table_rewrite_ptr, /* glDrawElementsInstancedBaseVertex */
    epoxy_glDrawElementsInstancedBaseVertexBaseInstance_dispatch_table_rewrite_ptr, /* glDrawElementsInstancedBaseVertexBaseInstance */
    epoxy_glDrawElementsInstancedBaseVertexBaseInstanceEXT_dispatch_table_rewrite_ptr, /* glDrawElementsInstancedBaseVertexBaseInstanceEXT */
    epoxy_glDrawElementsInstancedBaseVertexEXT_dispatch_table_rewrite_ptr, /* glDrawElementsInstancedBaseVertexEXT */
    epoxy_glDrawElementsInstancedBaseVertexOES_dispatch_table_rewrite_ptr, /* glDrawElementsInstancedBaseVertexOES */
    epoxy_glDrawElementsInstancedEXT_dispatch_table_rewrite_ptr, /* glDrawElementsInstancedEXT */
    epoxy_glDrawElementsInstancedNV_dispatch_table_rewrite_ptr, /* glDrawElementsInstancedNV */
    epoxy_glDrawMeshArraysSUN_dispatch_table_rewrite_ptr, /* glDrawMeshArraysSUN */
    epoxy_glDrawMeshTasksIndirectNV_dispatch_table_rewrite_ptr, /* glDrawMeshTasksIndirectNV */
    epoxy_glDrawMeshTasksNV_dispatch_table_rewrite_ptr, /* glDrawMeshTasksNV */
    epoxy_glDrawPixels_dispatch_table_rewrite_ptr, /* glDrawPixels */
    epoxy_glDrawRangeElementArrayAPPLE_dispatch_table_rewrite_ptr, /* glDrawRangeElementArrayAPPLE */
    epoxy_glDrawRangeElementArrayATI_dispatch_table_rewrite_ptr, /* glDrawRangeElementArrayATI */
    epoxy_glDrawRangeElements_dispatch_table_rewrite_ptr, /* glDrawRangeElements */
    epoxy_glDrawRangeElementsBaseVertex_dispatch_table_rewrite_ptr, /* glDrawRangeElementsBaseVertex */
    epoxy_glDrawRangeElementsBaseVertexEXT_dispatch_table_rewrite_ptr, /* glDrawRangeElementsBaseVertexEXT */
    epoxy_glDrawRangeElementsBaseVertexOES_dispatch_table_rewrite_ptr, /* glDrawRangeElementsBaseVertexOES */
    epoxy_glDrawRangeElementsEXT_dispatch_table_rewrite_ptr, /* glDrawRangeElementsEXT */
    epoxy_glDrawTexfOES_dispatch_table_rewrite_ptr, /* glDrawTexfOES */
    epoxy_glDrawTexfvOES_dispatch_table_rewrite_ptr, /* glDrawTexfvOES */
    epoxy_glDrawTexiOES_dispatch_table_rewrite_ptr, /* glDrawTexiOES */
    epoxy_glDrawTexivOES_dispatch_table_rewrite_ptr, /* glDrawTexivOES */
    epoxy_glDrawTexsOES_dispatch_table_rewrite_ptr, /* glDrawTexsOES */
    epoxy_glDrawTexsvOES_dispatch_table_rewrite_ptr, /* glDrawTexsvOES */
    epoxy_glDrawTextureNV_dispatch_table_rewrite_ptr, /* glDrawTextureNV */
    epoxy_glDrawTexxOES_dispatch_table_rewrite_ptr, /* glDrawTexxOES */
    epoxy_glDrawTexxvOES_dispatch_table_rewrite_ptr, /* glDrawTexxvOES */
    epoxy_glDrawTransformFeedback_dispatch_table_rewrite_ptr, /* glDrawTransformFeedback */
    epoxy_glDrawTransformFeedbackEXT_dispatch_table_rewrite_ptr, /* glDrawTransformFeedbackEXT */
    epoxy_glDrawTransformFeedbackInstanced_dispatch_table_rewrite_ptr, /* glDrawTransformFeedbackInstanced */
    epoxy_glDrawTransformFeedbackInstancedEXT_dispatch_table_rewrite_ptr, /* glDrawTransformFeedbackInstancedEXT */
    epoxy_glDrawTransformFeedbackNV_dispatch_table_rewrite_ptr, /* glDrawTransformFeedbackNV */
    epoxy_glDrawTransformFeedbackStream_dispatch_table_rewrite_ptr, /* glDrawTransformFeedbackStream */
    epoxy_glDrawTransformFeedbackStreamInstanced_dispatch_table_rewrite_ptr, /* glDrawTransformFeedbackStreamInstanced */
    epoxy_glDrawVkImageNV_dispatch_table_rewrite_ptr, /* glDrawVkImageNV */
    epoxy_glEGLImageTargetRenderbufferStorageOES_dispatch_table_rewrite_ptr, /* glEGLImageTargetRenderbufferStorageOES */
    epoxy_glEGLImageTargetTexStorageEXT_dispatch_table_rewrite_ptr, /* glEGLImageTargetTexStorageEXT */
    epoxy_glEGLImageTargetTexture2DOES_dispatch_table_rewrite_ptr, /* glEGLImageTargetTexture2DOES */
    epoxy_glEGLImageTargetTextureStorageEXT_dispatch_table_rewrite_ptr, /* glEGLImageTargetTextureStorageEXT */
    epoxy_glEdgeFlag_dispatch_table_rewrite_ptr, /* glEdgeFlag */
    epoxy_glEdgeFlagFormatNV_dispatch_table_rewrite_ptr, /* glEdgeFlagFormatNV */
    epoxy_glEdgeFlagPointer_dispatch_table_rewrite_ptr, /* glEdgeFlagPointer */
    epoxy_glEdgeFlagPointerEXT_dispatch_table_rewrite_ptr, /* glEdgeFlagPointerEXT */
    epoxy_glEdgeFlagPointerListIBM_dispatch_table_rewrite_ptr, /* glEdgeFlagPointerListIBM */
    epoxy_glEdgeFlagv_dispatch_table_rewrite_ptr, /* glEdgeFlagv */
    epoxy_glElementPointerAPPLE_dispatch_table_rewrite_ptr, /* glElementPointerAPPLE */
    epoxy_glElementPointerATI_dispatch_table_rewrite_ptr, /* glElementPointerATI */
    epoxy_glEnable_dispatch_table_rewrite_ptr, /* glEnable */
    epoxy_glEnableClientState_dispatch_table_rewrite_ptr, /* glEnableClientState */
    epoxy_glEnableClientStateIndexedEXT_dispatch_table_rewrite_ptr, /* glEnableClientStateIndexedEXT */
    epoxy_glEnableClientStateiEXT_dispatch_table_rewrite_ptr, /* glEnableClientStateiEXT */
    epoxy_glEnableDriverControlQCOM_dispatch_table_rewrite_ptr, /* glEnableDriverControlQCOM */
    epoxy_glEnableIndexedEXT_dispatch_table_rewrite_ptr, /* glEnableIndexedEXT */
    epoxy_glEnableVariantClientStateEXT_dispatch_table_rewrite_ptr, /* glEnableVariantClientStateEXT */
    epoxy_glEnableVertexArrayAttrib_dispatch_table_rewrite_ptr, /* glEnableVertexArrayAttrib */
    epoxy_glEnableVertexArrayAttribEXT_dispatch_table_rewrite_ptr, /* glEnableVertexArrayAttribEXT */
    epoxy_glEnableVertexArrayEXT_dispatch_table_rewrite_ptr, /* glEnableVertexArrayEXT */
    epoxy_glEnableVertexAttribAPPLE_dispatch_table_rewrite_ptr, /* glEnableVertexAttribAPPLE */
    epoxy_glEnableVertexAttribArray_dispatch_table_rewrite_ptr, /* glEnableVertexAttribArray */
    epoxy_glEnableVertexAttribArrayARB_dispatch_table_rewrite_ptr, /* glEnableVertexAttribArrayARB */
    epoxy_glEnablei_dispatch_table_rewrite_ptr, /* glEnablei */
    epoxy_glEnableiEXT_dispatch_table_rewrite_ptr, /* glEnableiEXT */
    epoxy_glEnableiNV_dispatch_table_rewrite_ptr, /* glEnableiNV */
    epoxy_glEnableiOES_dispatch_table_rewrite_ptr, /* glEnableiOES */
    epoxy_glEnd_unwrapped_dispatch_table_rewrite_ptr, /* glEnd_unwrapped */
    epoxy_glEndConditionalRender_dispatch_table_rewrite_ptr, /* glEndConditionalRender */
    epoxy_glEndConditionalRenderNV_dispatch_table_rewrite_ptr, /* glEndConditionalRenderNV */
    epoxy_glEndConditionalRenderNVX_dispatch_table_rewrite_ptr, /* glEndConditionalRenderNVX */
    epoxy_glEndFragmentShaderATI_dispatch_table_rewrite_ptr, /* glEndFragmentShaderATI */
    epoxy_glEndList_dispatch_table_rewrite_ptr, /* glEndList */
    epoxy_glEndOcclusionQueryNV_dispatch_table_rewrite_ptr, /* glEndOcclusionQueryNV */
    epoxy_glEndPerfMonitorAMD_dispatch_table_rewrite_ptr, /* glEndPerfMonitorAMD */
    epoxy_glEndPerfQueryINTEL_dispatch_table_rewrite_ptr, /* glEndPerfQueryINTEL */
    epoxy_glEndQuery_dispatch_table_rewrite_ptr, /* glEndQuery */
    epoxy_glEndQueryARB_dispatch_table_rewrite_ptr, /* glEndQueryARB */
    epoxy_glEndQueryEXT_dispatch_table_rewrite_ptr, /* glEndQueryEXT */
    epoxy_glEndQueryIndexed_dispatch_table_rewrite_ptr, /* glEndQueryIndexed */
    epoxy_glEndTilingQCOM_dispatch_table_rewrite_ptr, /* glEndTilingQCOM */
    epoxy_glEndTransformFeedback_dispatch_table_rewrite_ptr, /* glEndTransformFeedback */
    epoxy_glEndTransformFeedbackEXT_dispatch_table_rewrite_ptr, /* glEndTransformFeedbackEXT */
    epoxy_glEndTransformFeedbackNV_dispatch_table_rewrite_ptr, /* glEndTransformFeedbackNV */
    epoxy_glEndVertexShaderEXT_dispatch_table_rewrite_ptr, /* glEndVertexShaderEXT */
    epoxy_glEndVideoCaptureNV_dispatch_table_rewrite_ptr, /* glEndVideoCaptureNV */
    epoxy_glEvalCoord1d_dispatch_table_rewrite_ptr, /* glEvalCoord1d */
    epoxy_glEvalCoord1dv_dispatch_table_rewrite_ptr, /* glEvalCoord1dv */
    epoxy_glEvalCoord1f_dispatch_table_rewrite_ptr, /* glEvalCoord1f */
    epoxy_glEvalCoord1fv_dispatch_table_rewrite_ptr, /* glEvalCoord1fv */
    epoxy_glEvalCoord1xOES_dispatch_table_rewrite_ptr, /* glEvalCoord1xOES */
    epoxy_glEvalCoord1xvOES_dispatch_table_rewrite_ptr, /* glEvalCoord1xvOES */
    epoxy_glEvalCoord2d_dispatch_table_rewrite_ptr, /* glEvalCoord2d */
    epoxy_glEvalCoord2dv_dispatch_table_rewrite_ptr, /* glEvalCoord2dv */
    epoxy_glEvalCoord2f_dispatch_table_rewrite_ptr, /* glEvalCoord2f */
    epoxy_glEvalCoord2fv_dispatch_table_rewrite_ptr, /* glEvalCoord2fv */
    epoxy_glEvalCoord2xOES_dispatch_table_rewrite_ptr, /* glEvalCoord2xOES */
    epoxy_glEvalCoord2xvOES_dispatch_table_rewrite_ptr, /* glEvalCoord2xvOES */
    epoxy_glEvalMapsNV_dispatch_table_rewrite_ptr, /* glEvalMapsNV */
    epoxy_glEvalMesh1_dispatch_table_rewrite_ptr, /* glEvalMesh1 */
    epoxy_glEvalMesh2_dispatch_table_rewrite_ptr, /* glEvalMesh2 */
    epoxy_glEvalPoint1_dispatch_table_rewrite_ptr, /* glEvalPoint1 */
    epoxy_glEvalPoint2_dispatch_table_rewrite_ptr, /* glEvalPoint2 */
    epoxy_glEvaluateDepthValuesARB_dispatch_table_rewrite_ptr, /* glEvaluateDepthValuesARB */
    epoxy_glExecuteProgramNV_dispatch_table_rewrite_ptr, /* glExecuteProgramNV */
    epoxy_glExtGetBufferPointervQCOM_dispatch_table_rewrite_ptr, /* glExtGetBufferPointervQCOM */
    epoxy_glExtGetBuffersQCOM_dispatch_table_rewrite_ptr, /* glExtGetBuffersQCOM */
    epoxy_glExtGetFramebuffersQCOM_dispatch_table_rewrite_ptr, /* glExtGetFramebuffersQCOM */
    epoxy_glExtGetProgramBinarySourceQCOM_dispatch_table_rewrite_ptr, /* glExtGetProgramBinarySourceQCOM */
    epoxy_glExtGetProgramsQCOM_dispatch_table_rewrite_ptr, /* glExtGetProgramsQCOM */
    epoxy_glExtGetRenderbuffersQCOM_dispatch_table_rewrite_ptr, /* glExtGetRenderbuffersQCOM */
    epoxy_glExtGetShadersQCOM_dispatch_table_rewrite_ptr, /* glExtGetShadersQCOM */
    epoxy_glExtGetTexLevelParameterivQCOM_dispatch_table_rewrite_ptr, /* glExtGetTexLevelParameterivQCOM */
    epoxy_glExtGetTexSubImageQCOM_dispatch_table_rewrite_ptr, /* glExtGetTexSubImageQCOM */
    epoxy_glExtGetTexturesQCOM_dispatch_table_rewrite_ptr, /* glExtGetTexturesQCOM */
    epoxy_glExtIsProgramBinaryQCOM_dispatch_table_rewrite_ptr, /* glExtIsProgramBinaryQCOM */
    epoxy_glExtTexObjectStateOverrideiQCOM_dispatch_table_rewrite_ptr, /* glExtTexObjectStateOverrideiQCOM */
    epoxy_glExtractComponentEXT_dispatch_table_rewrite_ptr, /* glExtractComponentEXT */
    epoxy_glFeedbackBuffer_dispatch_table_rewrite_ptr, /* glFeedbackBuffer */
    epoxy_glFeedbackBufferxOES_dispatch_table_rewrite_ptr, /* glFeedbackBufferxOES */
    epoxy_glFenceSync_dispatch_table_rewrite_ptr, /* glFenceSync */
    epoxy_glFenceSyncAPPLE_dispatch_table_rewrite_ptr, /* glFenceSyncAPPLE */
    epoxy_glFinalCombinerInputNV_dispatch_table_rewrite_ptr, /* glFinalCombinerInputNV */
    epoxy_glFinish_dispatch_table_rewrite_ptr, /* glFinish */
    epoxy_glFinishAsyncSGIX_dispatch_table_rewrite_ptr, /* glFinishAsyncSGIX */
    epoxy_glFinishFenceAPPLE_dispatch_table_rewrite_ptr, /* glFinishFenceAPPLE */
    epoxy_glFinishFenceNV_dispatch_table_rewrite_ptr, /* glFinishFenceNV */
    epoxy_glFinishObjectAPPLE_dispatch_table_rewrite_ptr, /* glFinishObjectAPPLE */
    epoxy_glFinishTextureSUNX_dispatch_table_rewrite_ptr, /* glFinishTextureSUNX */
    epoxy_glFlush_dispatch_table_rewrite_ptr, /* glFlush */
    epoxy_glFlushMappedBufferRange_dispatch_table_rewrite_ptr, /* glFlushMappedBufferRange */
    epoxy_glFlushMappedBufferRangeAPPLE_dispatch_table_rewrite_ptr, /* glFlushMappedBufferRangeAPPLE */
    epoxy_glFlushMappedBufferRangeEXT_dispatch_table_rewrite_ptr, /* glFlushMappedBufferRangeEXT */
    epoxy_glFlushMappedNamedBufferRange_dispatch_table_rewrite_ptr, /* glFlushMappedNamedBufferRange */
    epoxy_glFlushMappedNamedBufferRangeEXT_dispatch_table_rewrite_ptr, /* glFlushMappedNamedBufferRangeEXT */
    epoxy_glFlushPixelDataRangeNV_dispatch_table_rewrite_ptr, /* glFlushPixelDataRangeNV */
    epoxy_glFlushRasterSGIX_dispatch_table_rewrite_ptr, /* glFlushRasterSGIX */
    epoxy_glFlushStaticDataIBM_dispatch_table_rewrite_ptr, /* glFlushStaticDataIBM */
    epoxy_glFlushVertexArrayRangeAPPLE_dispatch_table_rewrite_ptr, /* glFlushVertexArrayRangeAPPLE */
    epoxy_glFlushVertexArrayRangeNV_dispatch_table_rewrite_ptr, /* glFlushVertexArrayRangeNV */
    epoxy_glFogCoordFormatNV_dispatch_table_rewrite_ptr, /* glFogCoordFormatNV */
    epoxy_glFogCoordPointer_dispatch_table_rewrite_ptr, /* glFogCoordPointer */
    epoxy_glFogCoordPointerEXT_dispatch_table_rewrite_ptr, /* glFogCoordPointerEXT */
    epoxy_glFogCoordPointerListIBM_dispatch_table_rewrite_ptr, /* glFogCoordPointerListIBM */
    epoxy_glFogCoordd_dispatch_table_rewrite_ptr, /* glFogCoordd */
    epoxy_glFogCoorddEXT_dispatch_table_rewrite_ptr, /* glFogCoorddEXT */
    epoxy_glFogCoorddv_dispatch_table_rewrite_ptr, /* glFogCoorddv */
    epoxy_glFogCoorddvEXT_dispatch_table_rewrite_ptr, /* glFogCoorddvEXT */
    epoxy_glFogCoordf_dispatch_table_rewrite_ptr, /* glFogCoordf */
    epoxy_glFogCoordfEXT_dispatch_table_rewrite_ptr, /* glFogCoordfEXT */
    epoxy_glFogCoordfv_dispatch_table_rewrite_ptr, /* glFogCoordfv */
    epoxy_glFogCoordfvEXT_dispatch_table_rewrite_ptr, /* glFogCoordfvEXT */
    epoxy_glFogCoordhNV_dispatch_table_rewrite_ptr, /* glFogCoordhNV */
    epoxy_glFogCoordhvNV_dispatch_table_rewrite_ptr, /* glFogCoordhvNV */
    epoxy_glFogFuncSGIS_dispatch_table_rewrite_ptr, /* glFogFuncSGIS */
    epoxy_glFogf_dispatch_table_rewrite_ptr, /* glFogf */
    epoxy_glFogfv_dispatch_table_rewrite_ptr, /* glFogfv */
    epoxy_glFogi_dispatch_table_rewrite_ptr, /* glFogi */
    epoxy_glFogiv_dispatch_table_rewrite_ptr, /* glFogiv */
    epoxy_glFogx_dispatch_table_rewrite_ptr, /* glFogx */
    epoxy_glFogxOES_dispatch_table_rewrite_ptr, /* glFogxOES */
    epoxy_glFogxv_dispatch_table_rewrite_ptr, /* glFogxv */
    epoxy_glFogxvOES_dispatch_table_rewrite_ptr, /* glFogxvOES */
    epoxy_glFragmentColorMaterialSGIX_dispatch_table_rewrite_ptr, /* glFragmentColorMaterialSGIX */
    epoxy_glFragmentCoverageColorNV_dispatch_table_rewrite_ptr, /* glFragmentCoverageColorNV */
    epoxy_glFragmentLightModelfSGIX_dispatch_table_rewrite_ptr, /* glFragmentLightModelfSGIX */
    epoxy_glFragmentLightModelfvSGIX_dispatch_table_rewrite_ptr, /* glFragmentLightModelfvSGIX */
    epoxy_glFragmentLightModeliSGIX_dispatch_table_rewrite_ptr, /* glFragmentLightModeliSGIX */
    epoxy_glFragmentLightModelivSGIX_dispatch_table_rewrite_ptr, /* glFragmentLightModelivSGIX */
    epoxy_glFragmentLightfSGIX_dispatch_table_rewrite_ptr, /* glFragmentLightfSGIX */
    epoxy_glFragmentLightfvSGIX_dispatch_table_rewrite_ptr, /* glFragmentLightfvSGIX */
    epoxy_glFragmentLightiSGIX_dispatch_table_rewrite_ptr, /* glFragmentLightiSGIX */
    epoxy_glFragmentLightivSGIX_dispatch_table_rewrite_ptr, /* glFragmentLightivSGIX */
    epoxy_glFragmentMaterialfSGIX_dispatch_table_rewrite_ptr, /* glFragmentMaterialfSGIX */
    epoxy_glFragmentMaterialfvSGIX_dispatch_table_rewrite_ptr, /* glFragmentMaterialfvSGIX */
    epoxy_glFragmentMaterialiSGIX_dispatch_table_rewrite_ptr, /* glFragmentMaterialiSGIX */
    epoxy_glFragmentMaterialivSGIX_dispatch_table_rewrite_ptr, /* glFragmentMaterialivSGIX */
    epoxy_glFrameTerminatorGREMEDY_dispatch_table_rewrite_ptr, /* glFrameTerminatorGREMEDY */
    epoxy_glFrameZoomSGIX_dispatch_table_rewrite_ptr, /* glFrameZoomSGIX */
    epoxy_glFramebufferDrawBufferEXT_dispatch_table_rewrite_ptr, /* glFramebufferDrawBufferEXT */
    epoxy_glFramebufferDrawBuffersEXT_dispatch_table_rewrite_ptr, /* glFramebufferDrawBuffersEXT */
    epoxy_glFramebufferFetchBarrierEXT_dispatch_table_rewrite_ptr, /* glFramebufferFetchBarrierEXT */
    epoxy_glFramebufferFetchBarrierQCOM_dispatch_table_rewrite_ptr, /* glFramebufferFetchBarrierQCOM */
    epoxy_glFramebufferFoveationConfigQCOM_dispatch_table_rewrite_ptr, /* glFramebufferFoveationConfigQCOM */
    epoxy_glFramebufferFoveationParametersQCOM_dispatch_table_rewrite_ptr, /* glFramebufferFoveationParametersQCOM */
    epoxy_glFramebufferParameteri_dispatch_table_rewrite_ptr, /* glFramebufferParameteri */
    epoxy_glFramebufferParameteriMESA_dispatch_table_rewrite_ptr, /* glFramebufferParameteriMESA */
    epoxy_glFramebufferPixelLocalStorageSizeEXT_dispatch_table_rewrite_ptr, /* glFramebufferPixelLocalStorageSizeEXT */
    epoxy_glFramebufferReadBufferEXT_dispatch_table_rewrite_ptr, /* glFramebufferReadBufferEXT */
    epoxy_glFramebufferRenderbuffer_dispatch_table_rewrite_ptr, /* glFramebufferRenderbuffer */
    epoxy_glFramebufferRenderbufferEXT_dispatch_table_rewrite_ptr, /* glFramebufferRenderbufferEXT */
    epoxy_glFramebufferRenderbufferOES_dispatch_table_rewrite_ptr, /* glFramebufferRenderbufferOES */
    epoxy_glFramebufferSampleLocationsfvARB_dispatch_table_rewrite_ptr, /* glFramebufferSampleLocationsfvARB */
    epoxy_glFramebufferSampleLocationsfvNV_dispatch_table_rewrite_ptr, /* glFramebufferSampleLocationsfvNV */
    epoxy_glFramebufferSamplePositionsfvAMD_dispatch_table_rewrite_ptr, /* glFramebufferSamplePositionsfvAMD */
    epoxy_glFramebufferTexture_dispatch_table_rewrite_ptr, /* glFramebufferTexture */
    epoxy_glFramebufferTexture1D_dispatch_table_rewrite_ptr, /* glFramebufferTexture1D */
    epoxy_glFramebufferTexture1DEXT_dispatch_table_rewrite_ptr, /* glFramebufferTexture1DEXT */
    epoxy_glFramebufferTexture2D_dispatch_table_rewrite_ptr, /* glFramebufferTexture2D */
    epoxy_glFramebufferTexture2DDownsampleIMG_dispatch_table_rewrite_ptr, /* glFramebufferTexture2DDownsampleIMG */
    epoxy_glFramebufferTexture2DEXT_dispatch_table_rewrite_ptr, /* glFramebufferTexture2DEXT */
    epoxy_glFramebufferTexture2DMultisampleEXT_dispatch_table_rewrite_ptr, /* glFramebufferTexture2DMultisampleEXT */
    epoxy_glFramebufferTexture2DMultisampleIMG_dispatch_table_rewrite_ptr, /* glFramebufferTexture2DMultisampleIMG */
    epoxy_glFramebufferTexture2DOES_dispatch_table_rewrite_ptr, /* glFramebufferTexture2DOES */
    epoxy_glFramebufferTexture3D_dispatch_table_rewrite_ptr, /* glFramebufferTexture3D */
    epoxy_glFramebufferTexture3DEXT_dispatch_table_rewrite_ptr, /* glFramebufferTexture3DEXT */
    epoxy_glFramebufferTexture3DOES_dispatch_table_rewrite_ptr, /* glFramebufferTexture3DOES */
    epoxy_glFramebufferTextureARB_dispatch_table_rewrite_ptr, /* glFramebufferTextureARB */
    epoxy_glFramebufferTextureEXT_dispatch_table_rewrite_ptr, /* glFramebufferTextureEXT */
    epoxy_glFramebufferTextureFaceARB_dispatch_table_rewrite_ptr, /* glFramebufferTextureFaceARB */
    epoxy_glFramebufferTextureFaceEXT_dispatch_table_rewrite_ptr, /* glFramebufferTextureFaceEXT */
    epoxy_glFramebufferTextureLayer_dispatch_table_rewrite_ptr, /* glFramebufferTextureLayer */
    epoxy_glFramebufferTextureLayerARB_dispatch_table_rewrite_ptr, /* glFramebufferTextureLayerARB */
    epoxy_glFramebufferTextureLayerDownsampleIMG_dispatch_table_rewrite_ptr, /* glFramebufferTextureLayerDownsampleIMG */
    epoxy_glFramebufferTextureLayerEXT_dispatch_table_rewrite_ptr, /* glFramebufferTextureLayerEXT */
    epoxy_glFramebufferTextureMultisampleMultiviewOVR_dispatch_table_rewrite_ptr, /* glFramebufferTextureMultisampleMultiviewOVR */
    epoxy_glFramebufferTextureMultiviewOVR_dispatch_table_rewrite_ptr, /* glFramebufferTextureMultiviewOVR */
    epoxy_glFramebufferTextureOES_dispatch_table_rewrite_ptr, /* glFramebufferTextureOES */
    epoxy_glFreeObjectBufferATI_dispatch_table_rewrite_ptr, /* glFreeObjectBufferATI */
    epoxy_glFrontFace_dispatch_table_rewrite_ptr, /* glFrontFace */
    epoxy_glFrustum_dispatch_table_rewrite_ptr, /* glFrustum */
    epoxy_glFrustumf_dispatch_table_rewrite_ptr, /* glFrustumf */
    epoxy_glFrustumfOES_dispatch_table_rewrite_ptr, /* glFrustumfOES */
    epoxy_glFrustumx_dispatch_table_rewrite_ptr, /* glFrustumx */
    epoxy_glFrustumxOES_dispatch_table_rewrite_ptr, /* glFrustumxOES */
    epoxy_glGenAsyncMarkersSGIX_dispatch_table_rewrite_ptr, /* glGenAsyncMarkersSGIX */
    epoxy_glGenBuffers_dispatch_table_rewrite_ptr, /* glGenBuffers */
    epoxy_glGenBuffersARB_dispatch_table_rewrite_ptr, /* glGenBuffersARB */
    epoxy_glGenFencesAPPLE_dispatch_table_rewrite_ptr, /* glGenFencesAPPLE */
    epoxy_glGenFencesNV_dispatch_table_rewrite_ptr, /* glGenFencesNV */
    epoxy_glGenFragmentShadersATI_dispatch_table_rewrite_ptr, /* glGenFragmentShadersATI */
    epoxy_glGenFramebuffers_dispatch_table_rewrite_ptr, /* glGenFramebuffers */
    epoxy_glGenFramebuffersEXT_dispatch_table_rewrite_ptr, /* glGenFramebuffersEXT */
    epoxy_glGenFramebuffersOES_dispatch_table_rewrite_ptr, /* glGenFramebuffersOES */
    epoxy_glGenLists_dispatch_table_rewrite_ptr, /* glGenLists */
    epoxy_glGenNamesAMD_dispatch_table_rewrite_ptr, /* glGenNamesAMD */
    epoxy_glGenOcclusionQueriesNV_dispatch_table_rewrite_ptr, /* glGenOcclusionQueriesNV */
    epoxy_glGenPathsNV_dispatch_table_rewrite_ptr, /* glGenPathsNV */
    epoxy_glGenPerfMonitorsAMD_dispatch_table_rewrite_ptr, /* glGenPerfMonitorsAMD */
    epoxy_glGenProgramPipelines_dispatch_table_rewrite_ptr, /* glGenProgramPipelines */
    epoxy_glGenProgramPipelinesEXT_dispatch_table_rewrite_ptr, /* glGenProgramPipelinesEXT */
    epoxy_glGenProgramsARB_dispatch_table_rewrite_ptr, /* glGenProgramsARB */
    epoxy_glGenProgramsNV_dispatch_table_rewrite_ptr, /* glGenProgramsNV */
    epoxy_glGenQueries_dispatch_table_rewrite_ptr, /* glGenQueries */
    epoxy_glGenQueriesARB_dispatch_table_rewrite_ptr, /* glGenQueriesARB */
    epoxy_glGenQueriesEXT_dispatch_table_rewrite_ptr, /* glGenQueriesEXT */
    epoxy_glGenQueryResourceTagNV_dispatch_table_rewrite_ptr, /* glGenQueryResourceTagNV */
    epoxy_glGenRenderbuffers_dispatch_table_rewrite_ptr, /* glGenRenderbuffers */
    epoxy_glGenRenderbuffersEXT_dispatch_table_rewrite_ptr, /* glGenRenderbuffersEXT */
    epoxy_glGenRenderbuffersOES_dispatch_table_rewrite_ptr, /* glGenRenderbuffersOES */
    epoxy_glGenSamplers_dispatch_table_rewrite_ptr, /* glGenSamplers */
    epoxy_glGenSemaphoresEXT_dispatch_table_rewrite_ptr, /* glGenSemaphoresEXT */
    epoxy_glGenSymbolsEXT_dispatch_table_rewrite_ptr, /* glGenSymbolsEXT */
    epoxy_glGenTextures_dispatch_table_rewrite_ptr, /* glGenTextures */
    epoxy_glGenTexturesEXT_dispatch_table_rewrite_ptr, /* glGenTexturesEXT */
    epoxy_glGenTransformFeedbacks_dispatch_table_rewrite_ptr, /* glGenTransformFeedbacks */
    epoxy_glGenTransformFeedbacksNV_dispatch_table_rewrite_ptr, /* glGenTransformFeedbacksNV */
    epoxy_glGenVertexArrays_dispatch_table_rewrite_ptr, /* glGenVertexArrays */
    epoxy_glGenVertexArraysAPPLE_dispatch_table_rewrite_ptr, /* glGenVertexArraysAPPLE */
    epoxy_glGenVertexArraysOES_dispatch_table_rewrite_ptr, /* glGenVertexArraysOES */
    epoxy_glGenVertexShadersEXT_dispatch_table_rewrite_ptr, /* glGenVertexShadersEXT */
    epoxy_glGenerateMipmap_dispatch_table_rewrite_ptr, /* glGenerateMipmap */
    epoxy_glGenerateMipmapEXT_dispatch_table_rewrite_ptr, /* glGenerateMipmapEXT */
    epoxy_glGenerateMipmapOES_dispatch_table_rewrite_ptr, /* glGenerateMipmapOES */
    epoxy_glGenerateMultiTexMipmapEXT_dispatch_table_rewrite_ptr, /* glGenerateMultiTexMipmapEXT */
    epoxy_glGenerateTextureMipmap_dispatch_table_rewrite_ptr, /* glGenerateTextureMipmap */
    epoxy_glGenerateTextureMipmapEXT_dispatch_table_rewrite_ptr, /* glGenerateTextureMipmapEXT */
    epoxy_glGetActiveAtomicCounterBufferiv_dispatch_table_rewrite_ptr, /* glGetActiveAtomicCounterBufferiv */
    epoxy_glGetActiveAttrib_dispatch_table_rewrite_ptr, /* glGetActiveAttrib */
    epoxy_glGetActiveAttribARB_dispatch_table_rewrite_ptr, /* glGetActiveAttribARB */
    epoxy_glGetActiveSubroutineName_dispatch_table_rewrite_ptr, /* glGetActiveSubroutineName */
    epoxy_glGetActiveSubroutineUniformName_dispatch_table_rewrite_ptr, /* glGetActiveSubroutineUniformName */
    epoxy_glGetActiveSubroutineUniformiv_dispatch_table_rewrite_ptr, /* glGetActiveSubroutineUniformiv */
    epoxy_glGetActiveUniform_dispatch_table_rewrite_ptr, /* glGetActiveUniform */
    epoxy_glGetActiveUniformARB_dispatch_table_rewrite_ptr, /* glGetActiveUniformARB */
    epoxy_glGetActiveUniformBlockName_dispatch_table_rewrite_ptr, /* glGetActiveUniformBlockName */
    epoxy_glGetActiveUniformBlockiv_dispatch_table_rewrite_ptr, /* glGetActiveUniformBlockiv */
    epoxy_glGetActiveUniformName_dispatch_table_rewrite_ptr, /* glGetActiveUniformName */
    epoxy_glGetActiveUniformsiv_dispatch_table_rewrite_ptr, /* glGetActiveUniformsiv */
    epoxy_glGetActiveVaryingNV_dispatch_table_rewrite_ptr, /* glGetActiveVaryingNV */
    epoxy_glGetArrayObjectfvATI_dispatch_table_rewrite_ptr, /* glGetArrayObjectfvATI */
    epoxy_glGetArrayObjectivATI_dispatch_table_rewrite_ptr, /* glGetArrayObjectivATI */
    epoxy_glGetAttachedObjectsARB_dispatch_table_rewrite_ptr, /* glGetAttachedObjectsARB */
    epoxy_glGetAttachedShaders_dispatch_table_rewrite_ptr, /* glGetAttachedShaders */
    epoxy_glGetAttribLocation_dispatch_table_rewrite_ptr, /* glGetAttribLocation */
    epoxy_glGetAttribLocationARB_dispatch_table_rewrite_ptr, /* glGetAttribLocationARB */
    epoxy_glGetBooleanIndexedvEXT_dispatch_table_rewrite_ptr, /* glGetBooleanIndexedvEXT */
    epoxy_glGetBooleani_v_dispatch_table_rewrite_ptr, /* glGetBooleani_v */
    epoxy_glGetBooleanv_dispatch_table_rewrite_ptr, /* glGetBooleanv */
    epoxy_glGetBufferParameteri64v_dispatch_table_rewrite_ptr, /* glGetBufferParameteri64v */
    epoxy_glGetBufferParameteriv_dispatch_table_rewrite_ptr, /* glGetBufferParameteriv */
    epoxy_glGetBufferParameterivARB_dispatch_table_rewrite_ptr, /* glGetBufferParameterivARB */
    epoxy_glGetBufferParameterui64vNV_dispatch_table_rewrite_ptr, /* glGetBufferParameterui64vNV */
    epoxy_glGetBufferPointerv_dispatch_table_rewrite_ptr, /* glGetBufferPointerv */
    epoxy_glGetBufferPointervARB_dispatch_table_rewrite_ptr, /* glGetBufferPointervARB */
    epoxy_glGetBufferPointervOES_dispatch_table_rewrite_ptr, /* glGetBufferPointervOES */
    epoxy_glGetBufferSubData_dispatch_table_rewrite_ptr, /* glGetBufferSubData */
    epoxy_glGetBufferSubDataARB_dispatch_table_rewrite_ptr, /* glGetBufferSubDataARB */
    epoxy_glGetClipPlane_dispatch_table_rewrite_ptr, /* glGetClipPlane */
    epoxy_glGetClipPlanef_dispatch_table_rewrite_ptr, /* glGetClipPlanef */
    epoxy_glGetClipPlanefOES_dispatch_table_rewrite_ptr, /* glGetClipPlanefOES */
    epoxy_glGetClipPlanex_dispatch_table_rewrite_ptr, /* glGetClipPlanex */
    epoxy_glGetClipPlanexOES_dispatch_table_rewrite_ptr, /* glGetClipPlanexOES */
    epoxy_glGetColorTable_dispatch_table_rewrite_ptr, /* glGetColorTable */
    epoxy_glGetColorTableEXT_dispatch_table_rewrite_ptr, /* glGetColorTableEXT */
    epoxy_glGetColorTableParameterfv_dispatch_table_rewrite_ptr, /* glGetColorTableParameterfv */
    epoxy_glGetColorTableParameterfvEXT_dispatch_table_rewrite_ptr, /* glGetColorTableParameterfvEXT */
    epoxy_glGetColorTableParameterfvSGI_dispatch_table_rewrite_ptr, /* glGetColorTableParameterfvSGI */
    epoxy_glGetColorTableParameteriv_dispatch_table_rewrite_ptr, /* glGetColorTableParameteriv */
    epoxy_glGetColorTableParameterivEXT_dispatch_table_rewrite_ptr, /* glGetColorTableParameterivEXT */
    epoxy_glGetColorTableParameterivSGI_dispatch_table_rewrite_ptr, /* glGetColorTableParameterivSGI */
    epoxy_glGetColorTableSGI_dispatch_table_rewrite_ptr, /* glGetColorTableSGI */
    epoxy_glGetCombinerInputParameterfvNV_dispatch_table_rewrite_ptr, /* glGetCombinerInputParameterfvNV */
    epoxy_glGetCombinerInputParameterivNV_dispatch_table_rewrite_ptr, /* glGetCombinerInputParameterivNV */
    epoxy_glGetCombinerOutputParameterfvNV_dispatch_table_rewrite_ptr, /* glGetCombinerOutputParameterfvNV */
    epoxy_glGetCombinerOutputParameterivNV_dispatch_table_rewrite_ptr, /* glGetCombinerOutputParameterivNV */
    epoxy_glGetCombinerStageParameterfvNV_dispatch_table_rewrite_ptr, /* glGetCombinerStageParameterfvNV */
    epoxy_glGetCommandHeaderNV_dispatch_table_rewrite_ptr, /* glGetCommandHeaderNV */
    epoxy_glGetCompressedMultiTexImageEXT_dispatch_table_rewrite_ptr, /* glGetCompressedMultiTexImageEXT */
    epoxy_glGetCompressedTexImage_dispatch_table_rewrite_ptr, /* glGetCompressedTexImage */
    epoxy_glGetCompressedTexImageARB_dispatch_table_rewrite_ptr, /* glGetCompressedTexImageARB */
    epoxy_glGetCompressedTextureImage_dispatch_table_rewrite_ptr, /* glGetCompressedTextureImage */
    epoxy_glGetCompressedTextureImageEXT_dispatch_table_rewrite_ptr, /* glGetCompressedTextureImageEXT */
    epoxy_glGetCompressedTextureSubImage_dispatch_table_rewrite_ptr, /* glGetCompressedTextureSubImage */
    epoxy_glGetConvolutionFilter_dispatch_table_rewrite_ptr, /* glGetConvolutionFilter */
    epoxy_glGetConvolutionFilterEXT_dispatch_table_rewrite_ptr, /* glGetConvolutionFilterEXT */
    epoxy_glGetConvolutionParameterfv_dispatch_table_rewrite_ptr, /* glGetConvolutionParameterfv */
    epoxy_glGetConvolutionParameterfvEXT_dispatch_table_rewrite_ptr, /* glGetConvolutionParameterfvEXT */
    epoxy_glGetConvolutionParameteriv_dispatch_table_rewrite_ptr, /* glGetConvolutionParameteriv */
    epoxy_glGetConvolutionParameterivEXT_dispatch_table_rewrite_ptr, /* glGetConvolutionParameterivEXT */
    epoxy_glGetConvolutionParameterxvOES_dispatch_table_rewrite_ptr, /* glGetConvolutionParameterxvOES */
    epoxy_glGetCoverageModulationTableNV_dispatch_table_rewrite_ptr, /* glGetCoverageModulationTableNV */
    epoxy_glGetDebugMessageLog_dispatch_table_rewrite_ptr, /* glGetDebugMessageLog */
    epoxy_glGetDebugMessageLogAMD_dispatch_table_rewrite_ptr, /* glGetDebugMessageLogAMD */
    epoxy_glGetDebugMessageLogARB_dispatch_table_rewrite_ptr, /* glGetDebugMessageLogARB */
    epoxy_glGetDebugMessageLogKHR_dispatch_table_rewrite_ptr, /* glGetDebugMessageLogKHR */
    epoxy_glGetDetailTexFuncSGIS_dispatch_table_rewrite_ptr, /* glGetDetailTexFuncSGIS */
    epoxy_glGetDoubleIndexedvEXT_dispatch_table_rewrite_ptr, /* glGetDoubleIndexedvEXT */
    epoxy_glGetDoublei_v_dispatch_table_rewrite_ptr, /* glGetDoublei_v */
    epoxy_glGetDoublei_vEXT_dispatch_table_rewrite_ptr, /* glGetDoublei_vEXT */
    epoxy_glGetDoublev_dispatch_table_rewrite_ptr, /* glGetDoublev */
    epoxy_glGetDriverControlStringQCOM_dispatch_table_rewrite_ptr, /* glGetDriverControlStringQCOM */
    epoxy_glGetDriverControlsQCOM_dispatch_table_rewrite_ptr, /* glGetDriverControlsQCOM */
    epoxy_glGetError_dispatch_table_rewrite_ptr, /* glGetError */
    epoxy_glGetFenceivNV_dispatch_table_rewrite_ptr, /* glGetFenceivNV */
    epoxy_glGetFinalCombinerInputParameterfvNV_dispatch_table_rewrite_ptr, /* glGetFinalCombinerInputParameterfvNV */
    epoxy_glGetFinalCombinerInputParameterivNV_dispatch_table_rewrite_ptr, /* glGetFinalCombinerInputParameterivNV */
    epoxy_glGetFirstPerfQueryIdINTEL_dispatch_table_rewrite_ptr, /* glGetFirstPerfQueryIdINTEL */
    epoxy_glGetFixedv_dispatch_table_rewrite_ptr, /* glGetFixedv */
    epoxy_glGetFixedvOES_dispatch_table_rewrite_ptr, /* glGetFixedvOES */
    epoxy_glGetFloatIndexedvEXT_dispatch_table_rewrite_ptr, /* glGetFloatIndexedvEXT */
    epoxy_glGetFloati_v_dispatch_table_rewrite_ptr, /* glGetFloati_v */
    epoxy_glGetFloati_vEXT_dispatch_table_rewrite_ptr, /* glGetFloati_vEXT */
    epoxy_glGetFloati_vNV_dispatch_table_rewrite_ptr, /* glGetFloati_vNV */
    epoxy_glGetFloati_vOES_dispatch_table_rewrite_ptr, /* glGetFloati_vOES */
    epoxy_glGetFloatv_dispatch_table_rewrite_ptr, /* glGetFloatv */
    epoxy_glGetFogFuncSGIS_dispatch_table_rewrite_ptr, /* glGetFogFuncSGIS */
    epoxy_glGetFragDataIndex_dispatch_table_rewrite_ptr, /* glGetFragDataIndex */
    epoxy_glGetFragDataIndexEXT_dispatch_table_rewrite_ptr, /* glGetFragDataIndexEXT */
    epoxy_glGetFragDataLocation_dispatch_table_rewrite_ptr, /* glGetFragDataLocation */
    epoxy_glGetFragDataLocationEXT_dispatch_table_rewrite_ptr, /* glGetFragDataLocationEXT */
    epoxy_glGetFragmentLightfvSGIX_dispatch_table_rewrite_ptr, /* glGetFragmentLightfvSGIX */
    epoxy_glGetFragmentLightivSGIX_dispatch_table_rewrite_ptr, /* glGetFragmentLightivSGIX */
    epoxy_glGetFragmentMaterialfvSGIX_dispatch_table_rewrite_ptr, /* glGetFragmentMaterialfvSGIX */
    epoxy_glGetFragmentMaterialivSGIX_dispatch_table_rewrite_ptr, /* glGetFragmentMaterialivSGIX */
    epoxy_glGetFramebufferAttachmentParameteriv_dispatch_table_rewrite_ptr, /* glGetFramebufferAttachmentParameteriv */
    epoxy_glGetFramebufferAttachmentParameterivEXT_dispatch_table_rewrite_ptr, /* glGetFramebufferAttachmentParameterivEXT */
    epoxy_glGetFramebufferAttachmentParameterivOES_dispatch_table_rewrite_ptr, /* glGetFramebufferAttachmentParameterivOES */
    epoxy_glGetFramebufferParameterfvAMD_dispatch_table_rewrite_ptr, /* glGetFramebufferParameterfvAMD */
    epoxy_glGetFramebufferParameteriv_dispatch_table_rewrite_ptr, /* glGetFramebufferParameteriv */
    epoxy_glGetFramebufferParameterivEXT_dispatch_table_rewrite_ptr, /* glGetFramebufferParameterivEXT */
    epoxy_glGetFramebufferParameterivMESA_dispatch_table_rewrite_ptr, /* glGetFramebufferParameterivMESA */
    epoxy_glGetFramebufferPixelLocalStorageSizeEXT_dispatch_table_rewrite_ptr, /* glGetFramebufferPixelLocalStorageSizeEXT */
    epoxy_glGetGraphicsResetStatus_dispatch_table_rewrite_ptr, /* glGetGraphicsResetStatus */
    epoxy_glGetGraphicsResetStatusARB_dispatch_table_rewrite_ptr, /* glGetGraphicsResetStatusARB */
    epoxy_glGetGraphicsResetStatusEXT_dispatch_table_rewrite_ptr, /* glGetGraphicsResetStatusEXT */
    epoxy_glGetGraphicsResetStatusKHR_dispatch_table_rewrite_ptr, /* glGetGraphicsResetStatusKHR */
    epoxy_glGetHandleARB_dispatch_table_rewrite_ptr, /* glGetHandleARB */
    epoxy_glGetHistogram_dispatch_table_rewrite_ptr, /* glGetHistogram */
    epoxy_glGetHistogramEXT_dispatch_table_rewrite_ptr, /* glGetHistogramEXT */
    epoxy_glGetHistogramParameterfv_dispatch_table_rewrite_ptr, /* glGetHistogramParameterfv */
    epoxy_glGetHistogramParameterfvEXT_dispatch_table_rewrite_ptr, /* glGetHistogramParameterfvEXT */
    epoxy_glGetHistogramParameteriv_dispatch_table_rewrite_ptr, /* glGetHistogramParameteriv */
    epoxy_glGetHistogramParameterivEXT_dispatch_table_rewrite_ptr, /* glGetHistogramParameterivEXT */
    epoxy_glGetHistogramParameterxvOES_dispatch_table_rewrite_ptr, /* glGetHistogramParameterxvOES */
    epoxy_glGetImageHandleARB_dispatch_table_rewrite_ptr, /* glGetImageHandleARB */
    epoxy_glGetImageHandleNV_dispatch_table_rewrite_ptr, /* glGetImageHandleNV */
    epoxy_glGetImageTransformParameterfvHP_dispatch_table_rewrite_ptr, /* glGetImageTransformParameterfvHP */
    epoxy_glGetImageTransformParameterivHP_dispatch_table_rewrite_ptr, /* glGetImageTransformParameterivHP */
    epoxy_glGetInfoLogARB_dispatch_table_rewrite_ptr, /* glGetInfoLogARB */
    epoxy_glGetInstrumentsSGIX_dispatch_table_rewrite_ptr, /* glGetInstrumentsSGIX */
    epoxy_glGetInteger64i_v_dispatch_table_rewrite_ptr, /* glGetInteger64i_v */
    epoxy_glGetInteger64v_dispatch_table_rewrite_ptr, /* glGetInteger64v */
    epoxy_glGetInteger64vAPPLE_dispatch_table_rewrite_ptr, /* glGetInteger64vAPPLE */
    epoxy_glGetIntegerIndexedvEXT_dispatch_table_rewrite_ptr, /* glGetIntegerIndexedvEXT */
    epoxy_glGetIntegeri_v_dispatch_table_rewrite_ptr, /* glGetIntegeri_v */
    epoxy_glGetIntegeri_vEXT_dispatch_table_rewrite_ptr, /* glGetIntegeri_vEXT */
    epoxy_glGetIntegerui64i_vNV_dispatch_table_rewrite_ptr, /* glGetIntegerui64i_vNV */
    epoxy_glGetIntegerui64vNV_dispatch_table_rewrite_ptr, /* glGetIntegerui64vNV */
    epoxy_glGetIntegerv_dispatch_table_rewrite_ptr, /* glGetIntegerv */
    epoxy_glGetInternalformatSampleivNV_dispatch_table_rewrite_ptr, /* glGetInternalformatSampleivNV */
    epoxy_glGetInternalformati64v_dispatch_table_rewrite_ptr, /* glGetInternalformati64v */
    epoxy_glGetInternalformativ_dispatch_table_rewrite_ptr, /* glGetInternalformativ */
    epoxy_glGetInvariantBooleanvEXT_dispatch_table_rewrite_ptr, /* glGetInvariantBooleanvEXT */
    epoxy_glGetInvariantFloatvEXT_dispatch_table_rewrite_ptr, /* glGetInvariantFloatvEXT */
    epoxy_glGetInvariantIntegervEXT_dispatch_table_rewrite_ptr, /* glGetInvariantIntegervEXT */
    epoxy_glGetLightfv_dispatch_table_rewrite_ptr, /* glGetLightfv */
    epoxy_glGetLightiv_dispatch_table_rewrite_ptr, /* glGetLightiv */
    epoxy_glGetLightxOES_dispatch_table_rewrite_ptr, /* glGetLightxOES */
    epoxy_glGetLightxv_dispatch_table_rewrite_ptr, /* glGetLightxv */
    epoxy_glGetLightxvOES_dispatch_table_rewrite_ptr, /* glGetLightxvOES */
    epoxy_glGetListParameterfvSGIX_dispatch_table_rewrite_ptr, /* glGetListParameterfvSGIX */
    epoxy_glGetListParameterivSGIX_dispatch_table_rewrite_ptr, /* glGetListParameterivSGIX */
    epoxy_glGetLocalConstantBooleanvEXT_dispatch_table_rewrite_ptr, /* glGetLocalConstantBooleanvEXT */
    epoxy_glGetLocalConstantFloatvEXT_dispatch_table_rewrite_ptr, /* glGetLocalConstantFloatvEXT */
    epoxy_glGetLocalConstantIntegervEXT_dispatch_table_rewrite_ptr, /* glGetLocalConstantIntegervEXT */
    epoxy_glGetMapAttribParameterfvNV_dispatch_table_rewrite_ptr, /* glGetMapAttribParameterfvNV */
    epoxy_glGetMapAttribParameterivNV_dispatch_table_rewrite_ptr, /* glGetMapAttribParameterivNV */
    epoxy_glGetMapControlPointsNV_dispatch_table_rewrite_ptr, /* glGetMapControlPointsNV */
    epoxy_glGetMapParameterfvNV_dispatch_table_rewrite_ptr, /* glGetMapParameterfvNV */
    epoxy_glGetMapParameterivNV_dispatch_table_rewrite_ptr, /* glGetMapParameterivNV */
    epoxy_glGetMapdv_dispatch_table_rewrite_ptr, /* glGetMapdv */
    epoxy_glGetMapfv_dispatch_table_rewrite_ptr, /* glGetMapfv */
    epoxy_glGetMapiv_dispatch_table_rewrite_ptr, /* glGetMapiv */
    epoxy_glGetMapxvOES_dispatch_table_rewrite_ptr, /* glGetMapxvOES */
    epoxy_glGetMaterialfv_dispatch_table_rewrite_ptr, /* glGetMaterialfv */
    epoxy_glGetMaterialiv_dispatch_table_rewrite_ptr, /* glGetMaterialiv */
    epoxy_glGetMaterialxOES_dispatch_table_rewrite_ptr, /* glGetMaterialxOES */
    epoxy_glGetMaterialxv_dispatch_table_rewrite_ptr, /* glGetMaterialxv */
    epoxy_glGetMaterialxvOES_dispatch_table_rewrite_ptr, /* glGetMaterialxvOES */
    epoxy_glGetMemoryObjectDetachedResourcesuivNV_dispatch_table_rewrite_ptr, /* glGetMemoryObjectDetachedResourcesuivNV */
    epoxy_glGetMemoryObjectParameterivEXT_dispatch_table_rewrite_ptr, /* glGetMemoryObjectParameterivEXT */
    epoxy_glGetMinmax_dispatch_table_rewrite_ptr, /* glGetMinmax */
    epoxy_glGetMinmaxEXT_dispatch_table_rewrite_ptr, /* glGetMinmaxEXT */
    epoxy_glGetMinmaxParameterfv_dispatch_table_rewrite_ptr, /* glGetMinmaxParameterfv */
    epoxy_glGetMinmaxParameterfvEXT_dispatch_table_rewrite_ptr, /* glGetMinmaxParameterfvEXT */
    epoxy_glGetMinmaxParameteriv_dispatch_table_rewrite_ptr, /* glGetMinmaxParameteriv */
    epoxy_glGetMinmaxParameterivEXT_dispatch_table_rewrite_ptr, /* glGetMinmaxParameterivEXT */
    epoxy_glGetMultiTexEnvfvEXT_dispatch_table_rewrite_ptr, /* glGetMultiTexEnvfvEXT */
    epoxy_glGetMultiTexEnvivEXT_dispatch_table_rewrite_ptr, /* glGetMultiTexEnvivEXT */
    epoxy_glGetMultiTexGendvEXT_dispatch_table_rewrite_ptr, /* glGetMultiTexGendvEXT */
    epoxy_glGetMultiTexGenfvEXT_dispatch_table_rewrite_ptr, /* glGetMultiTexGenfvEXT */
    epoxy_glGetMultiTexGenivEXT_dispatch_table_rewrite_ptr, /* glGetMultiTexGenivEXT */
    epoxy_glGetMultiTexImageEXT_dispatch_table_rewrite_ptr, /* glGetMultiTexImageEXT */
    epoxy_glGetMultiTexLevelParameterfvEXT_dispatch_table_rewrite_ptr, /* glGetMultiTexLevelParameterfvEXT */
    epoxy_glGetMultiTexLevelParameterivEXT_dispatch_table_rewrite_ptr, /* glGetMultiTexLevelParameterivEXT */
    epoxy_glGetMultiTexParameterIivEXT_dispatch_table_rewrite_ptr, /* glGetMultiTexParameterIivEXT */
    epoxy_glGetMultiTexParameterIuivEXT_dispatch_table_rewrite_ptr, /* glGetMultiTexParameterIuivEXT */
    epoxy_glGetMultiTexParameterfvEXT_dispatch_table_rewrite_ptr, /* glGetMultiTexParameterfvEXT */
    epoxy_glGetMultiTexParameterivEXT_dispatch_table_rewrite_ptr, /* glGetMultiTexParameterivEXT */
    epoxy_glGetMultisamplefv_dispatch_table_rewrite_ptr, /* glGetMultisamplefv */
    epoxy_glGetMultisamplefvNV_dispatch_table_rewrite_ptr, /* glGetMultisamplefvNV */
    epoxy_glGetNamedBufferParameteri64v_dispatch_table_rewrite_ptr, /* glGetNamedBufferParameteri64v */
    epoxy_glGetNamedBufferParameteriv_dispatch_table_rewrite_ptr, /* glGetNamedBufferParameteriv */
    epoxy_glGetNamedBufferParameterivEXT_dispatch_table_rewrite_ptr, /* glGetNamedBufferParameterivEXT */
    epoxy_glGetNamedBufferParameterui64vNV_dispatch_table_rewrite_ptr, /* glGetNamedBufferParameterui64vNV */
    epoxy_glGetNamedBufferPointerv_dispatch_table_rewrite_ptr, /* glGetNamedBufferPointerv */
    epoxy_glGetNamedBufferPointervEXT_dispatch_table_rewrite_ptr, /* glGetNamedBufferPointervEXT */
    epoxy_glGetNamedBufferSubData_dispatch_table_rewrite_ptr, /* glGetNamedBufferSubData */
    epoxy_glGetNamedBufferSubDataEXT_dispatch_table_rewrite_ptr, /* glGetNamedBufferSubDataEXT */
    epoxy_glGetNamedFramebufferAttachmentParameteriv_dispatch_table_rewrite_ptr, /* glGetNamedFramebufferAttachmentParameteriv */
    epoxy_glGetNamedFramebufferAttachmentParameterivEXT_dispatch_table_rewrite_ptr, /* glGetNamedFramebufferAttachmentParameterivEXT */
    epoxy_glGetNamedFramebufferParameterfvAMD_dispatch_table_rewrite_ptr, /* glGetNamedFramebufferParameterfvAMD */
    epoxy_glGetNamedFramebufferParameteriv_dispatch_table_rewrite_ptr, /* glGetNamedFramebufferParameteriv */
    epoxy_glGetNamedFramebufferParameterivEXT_dispatch_table_rewrite_ptr, /* glGetNamedFramebufferParameterivEXT */
    epoxy_glGetNamedProgramLocalParameterIivEXT_dispatch_table_rewrite_ptr, /* glGetNamedProgramLocalParameterIivEXT */
    epoxy_glGetNamedProgramLocalParameterIuivEXT_dispatch_table_rewrite_ptr, /* glGetNamedProgramLocalParameterIuivEXT */
    epoxy_glGetNamedProgramLocalParameterdvEXT_dispatch_table_rewrite_ptr, /* glGetNamedProgramLocalParameterdvEXT */
    epoxy_glGetNamedProgramLocalParameterfvEXT_dispatch_table_rewrite_ptr, /* glGetNamedProgramLocalParameterfvEXT */
    epoxy_glGetNamedProgramStringEXT_dispatch_table_rewrite_ptr, /* glGetNamedProgramStringEXT */
    epoxy_glGetNamedProgramivEXT_dispatch_table_rewrite_ptr, /* glGetNamedProgramivEXT */
    epoxy_glGetNamedRenderbufferParameteriv_dispatch_table_rewrite_ptr, /* glGetNamedRenderbufferParameteriv */
    epoxy_glGetNamedRenderbufferParameterivEXT_dispatch_table_rewrite_ptr, /* glGetNamedRenderbufferParameterivEXT */
    epoxy_glGetNamedStringARB_dispatch_table_rewrite_ptr, /* glGetNamedStringARB */
    epoxy_glGetNamedStringivARB_dispatch_table_rewrite_ptr, /* glGetNamedStringivARB */
    epoxy_glGetNextPerfQueryIdINTEL_dispatch_table_rewrite_ptr, /* glGetNextPerfQueryIdINTEL */
    epoxy_glGetObjectBufferfvATI_dispatch_table_rewrite_ptr, /* glGetObjectBufferfvATI */
    epoxy_glGetObjectBufferivATI_dispatch_table_rewrite_ptr, /* glGetObjectBufferivATI */
    epoxy_glGetObjectLabel_dispatch_table_rewrite_ptr, /* glGetObjectLabel */
    epoxy_glGetObjectLabelEXT_dispatch_table_rewrite_ptr, /* glGetObjectLabelEXT */
    epoxy_glGetObjectLabelKHR_dispatch_table_rewrite_ptr, /* glGetObjectLabelKHR */
    epoxy_glGetObjectParameterfvARB_dispatch_table_rewrite_ptr, /* glGetObjectParameterfvARB */
    epoxy_glGetObjectParameterivAPPLE_dispatch_table_rewrite_ptr, /* glGetObjectParameterivAPPLE */
    epoxy_glGetObjectParameterivARB_dispatch_table_rewrite_ptr, /* glGetObjectParameterivARB */
    epoxy_glGetObjectPtrLabel_dispatch_table_rewrite_ptr, /* glGetObjectPtrLabel */
    epoxy_glGetObjectPtrLabelKHR_dispatch_table_rewrite_ptr, /* glGetObjectPtrLabelKHR */
    epoxy_glGetOcclusionQueryivNV_dispatch_table_rewrite_ptr, /* glGetOcclusionQueryivNV */
    epoxy_glGetOcclusionQueryuivNV_dispatch_table_rewrite_ptr, /* glGetOcclusionQueryuivNV */
    epoxy_glGetPathColorGenfvNV_dispatch_table_rewrite_ptr, /* glGetPathColorGenfvNV */
    epoxy_glGetPathColorGenivNV_dispatch_table_rewrite_ptr, /* glGetPathColorGenivNV */
    epoxy_glGetPathCommandsNV_dispatch_table_rewrite_ptr, /* glGetPathCommandsNV */
    epoxy_glGetPathCoordsNV_dispatch_table_rewrite_ptr, /* glGetPathCoordsNV */
    epoxy_glGetPathDashArrayNV_dispatch_table_rewrite_ptr, /* glGetPathDashArrayNV */
    epoxy_glGetPathLengthNV_dispatch_table_rewrite_ptr, /* glGetPathLengthNV */
    epoxy_glGetPathMetricRangeNV_dispatch_table_rewrite_ptr, /* glGetPathMetricRangeNV */
    epoxy_glGetPathMetricsNV_dispatch_table_rewrite_ptr, /* glGetPathMetricsNV */
    epoxy_glGetPathParameterfvNV_dispatch_table_rewrite_ptr, /* glGetPathParameterfvNV */
    epoxy_glGetPathParameterivNV_dispatch_table_rewrite_ptr, /* glGetPathParameterivNV */
    epoxy_glGetPathSpacingNV_dispatch_table_rewrite_ptr, /* glGetPathSpacingNV */
    epoxy_glGetPathTexGenfvNV_dispatch_table_rewrite_ptr, /* glGetPathTexGenfvNV */
    epoxy_glGetPathTexGenivNV_dispatch_table_rewrite_ptr, /* glGetPathTexGenivNV */
    epoxy_glGetPerfCounterInfoINTEL_dispatch_table_rewrite_ptr, /* glGetPerfCounterInfoINTEL */
    epoxy_glGetPerfMonitorCounterDataAMD_dispatch_table_rewrite_ptr, /* glGetPerfMonitorCounterDataAMD */
    epoxy_glGetPerfMonitorCounterInfoAMD_dispatch_table_rewrite_ptr, /* glGetPerfMonitorCounterInfoAMD */
    epoxy_glGetPerfMonitorCounterStringAMD_dispatch_table_rewrite_ptr, /* glGetPerfMonitorCounterStringAMD */
    epoxy_glGetPerfMonitorCountersAMD_dispatch_table_rewrite_ptr, /* glGetPerfMonitorCountersAMD */
    epoxy_glGetPerfMonitorGroupStringAMD_dispatch_table_rewrite_ptr, /* glGetPerfMonitorGroupStringAMD */
    epoxy_glGetPerfMonitorGroupsAMD_dispatch_table_rewrite_ptr, /* glGetPerfMonitorGroupsAMD */
    epoxy_glGetPerfQueryDataINTEL_dispatch_table_rewrite_ptr, /* glGetPerfQueryDataINTEL */
    epoxy_glGetPerfQueryIdByNameINTEL_dispatch_table_rewrite_ptr, /* glGetPerfQueryIdByNameINTEL */
    epoxy_glGetPerfQueryInfoINTEL_dispatch_table_rewrite_ptr, /* glGetPerfQueryInfoINTEL */
    epoxy_glGetPixelMapfv_dispatch_table_rewrite_ptr, /* glGetPixelMapfv */
    epoxy_glGetPixelMapuiv_dispatch_table_rewrite_ptr, /* glGetPixelMapuiv */
    epoxy_glGetPixelMapusv_dispatch_table_rewrite_ptr, /* glGetPixelMapusv */
    epoxy_glGetPixelMapxv_dispatch_table_rewrite_ptr, /* glGetPixelMapxv */
    epoxy_glGetPixelTexGenParameterfvSGIS_dispatch_table_rewrite_ptr, /* glGetPixelTexGenParameterfvSGIS */
    epoxy_glGetPixelTexGenParameterivSGIS_dispatch_table_rewrite_ptr, /* glGetPixelTexGenParameterivSGIS */
    epoxy_glGetPixelTransformParameterfvEXT_dispatch_table_rewrite_ptr, /* glGetPixelTransformParameterfvEXT */
    epoxy_glGetPixelTransformParameterivEXT_dispatch_table_rewrite_ptr, /* glGetPixelTransformParameterivEXT */
    epoxy_glGetPointerIndexedvEXT_dispatch_table_rewrite_ptr, /* glGetPointerIndexedvEXT */
    epoxy_glGetPointeri_vEXT_dispatch_table_rewrite_ptr, /* glGetPointeri_vEXT */
    epoxy_glGetPointerv_dispatch_table_rewrite_ptr, /* glGetPointerv */
    epoxy_glGetPointervEXT_dispatch_table_rewrite_ptr, /* glGetPointervEXT */
    epoxy_glGetPointervKHR_dispatch_table_rewrite_ptr, /* glGetPointervKHR */
    epoxy_glGetPolygonStipple_dispatch_table_rewrite_ptr, /* glGetPolygonStipple */
    epoxy_glGetProgramBinary_dispatch_table_rewrite_ptr, /* glGetProgramBinary */
    epoxy_glGetProgramBinaryOES_dispatch_table_rewrite_ptr, /* glGetProgramBinaryOES */
    epoxy_glGetProgramEnvParameterIivNV_dispatch_table_rewrite_ptr, /* glGetProgramEnvParameterIivNV */
    epoxy_glGetProgramEnvParameterIuivNV_dispatch_table_rewrite_ptr, /* glGetProgramEnvParameterIuivNV */
    epoxy_glGetProgramEnvParameterdvARB_dispatch_table_rewrite_ptr, /* glGetProgramEnvParameterdvARB */
    epoxy_glGetProgramEnvParameterfvARB_dispatch_table_rewrite_ptr, /* glGetProgramEnvParameterfvARB */
    epoxy_glGetProgramInfoLog_dispatch_table_rewrite_ptr, /* glGetProgramInfoLog */
    epoxy_glGetProgramInterfaceiv_dispatch_table_rewrite_ptr, /* glGetProgramInterfaceiv */
    epoxy_glGetProgramLocalParameterIivNV_dispatch_table_rewrite_ptr, /* glGetProgramLocalParameterIivNV */
    epoxy_glGetProgramLocalParameterIuivNV_dispatch_table_rewrite_ptr, /* glGetProgramLocalParameterIuivNV */
    epoxy_glGetProgramLocalParameterdvARB_dispatch_table_rewrite_ptr, /* glGetProgramLocalParameterdvARB */
    epoxy_glGetProgramLocalParameterfvARB_dispatch_table_rewrite_ptr, /* glGetProgramLocalParameterfvARB */
    epoxy_glGetProgramNamedParameterdvNV_dispatch_table_rewrite_ptr, /* glGetProgramNamedParameterdvNV */
    epoxy_glGetProgramNamedParameterfvNV_dispatch_table_rewrite_ptr, /* glGetProgramNamedParameterfvNV */
    epoxy_glGetProgramParameterdvNV_dispatch_table_rewrite_ptr, /* glGetProgramParameterdvNV */
    epoxy_glGetProgramParameterfvNV_dispatch_table_rewrite_ptr, /* glGetProgramParameterfvNV */
    epoxy_glGetProgramPipelineInfoLog_dispatch_table_rewrite_ptr, /* glGetProgramPipelineInfoLog */
    epoxy_glGetProgramPipelineInfoLogEXT_dispatch_table_rewrite_ptr, /* glGetProgramPipelineInfoLogEXT */
    epoxy_glGetProgramPipelineiv_dispatch_table_rewrite_ptr, /* glGetProgramPipelineiv */
    epoxy_glGetProgramPipelineivEXT_dispatch_table_rewrite_ptr, /* glGetProgramPipelineivEXT */
    epoxy_glGetProgramResourceIndex_dispatch_table_rewrite_ptr, /* glGetProgramResourceIndex */
    epoxy_glGetProgramResourceLocation_dispatch_table_rewrite_ptr, /* glGetProgramResourceLocation */
    epoxy_glGetProgramResourceLocationIndex_dispatch_table_rewrite_ptr, /* glGetProgramResourceLocationIndex */
    epoxy_glGetProgramResourceLocationIndexEXT_dispatch_table_rewrite_ptr, /* glGetProgramResourceLocationIndexEXT */
    epoxy_glGetProgramResourceName_dispatch_table_rewrite_ptr, /* glGetProgramResourceName */
    epoxy_glGetProgramResourcefvNV_dispatch_table_rewrite_ptr, /* glGetProgramResourcefvNV */
    epoxy_glGetProgramResourceiv_dispatch_table_rewrite_ptr, /* glGetProgramResourceiv */
    epoxy_glGetProgramStageiv_dispatch_table_rewrite_ptr, /* glGetProgramStageiv */
    epoxy_glGetProgramStringARB_dispatch_table_rewrite_ptr, /* glGetProgramStringARB */
    epoxy_glGetProgramStringNV_dispatch_table_rewrite_ptr, /* glGetProgramStringNV */
    epoxy_glGetProgramSubroutineParameteruivNV_dispatch_table_rewrite_ptr, /* glGetProgramSubroutineParameteruivNV */
    epoxy_glGetProgramiv_dispatch_table_rewrite_ptr, /* glGetProgramiv */
    epoxy_glGetProgramivARB_dispatch_table_rewrite_ptr, /* glGetProgramivARB */
    epoxy_glGetProgramivNV_dispatch_table_rewrite_ptr, /* glGetProgramivNV */
    epoxy_glGetQueryBufferObjecti64v_dispatch_table_rewrite_ptr, /* glGetQueryBufferObjecti64v */
    epoxy_glGetQueryBufferObjectiv_dispatch_table_rewrite_ptr, /* glGetQueryBufferObjectiv */
    epoxy_glGetQueryBufferObjectui64v_dispatch_table_rewrite_ptr, /* glGetQueryBufferObjectui64v */
    epoxy_glGetQueryBufferObjectuiv_dispatch_table_rewrite_ptr, /* glGetQueryBufferObjectuiv */
    epoxy_glGetQueryIndexediv_dispatch_table_rewrite_ptr, /* glGetQueryIndexediv */
    epoxy_glGetQueryObjecti64v_dispatch_table_rewrite_ptr, /* glGetQueryObjecti64v */
    epoxy_glGetQueryObjecti64vEXT_dispatch_table_rewrite_ptr, /* glGetQueryObjecti64vEXT */
    epoxy_glGetQueryObjectiv_dispatch_table_rewrite_ptr, /* glGetQueryObjectiv */
    epoxy_glGetQueryObjectivARB_dispatch_table_rewrite_ptr, /* glGetQueryObjectivARB */
    epoxy_glGetQueryObjectivEXT_dispatch_table_rewrite_ptr, /* glGetQueryObjectivEXT */
    epoxy_glGetQueryObjectui64v_dispatch_table_rewrite_ptr, /* glGetQueryObjectui64v */
    epoxy_glGetQueryObjectui64vEXT_dispatch_table_rewrite_ptr, /* glGetQueryObjectui64vEXT */
    epoxy_glGetQueryObjectuiv_dispatch_table_rewrite_ptr, /* glGetQueryObjectuiv */
    epoxy_glGetQueryObjectuivARB_dispatch_table_rewrite_ptr, /* glGetQueryObjectuivARB */
    epoxy_glGetQueryObjectuivEXT_dispatch_table_rewrite_ptr, /* glGetQueryObjectuivEXT */
    epoxy_glGetQueryiv_dispatch_table_rewrite_ptr, /* glGetQueryiv */
    epoxy_glGetQueryivARB_dispatch_table_rewrite_ptr, /* glGetQueryivARB */
    epoxy_glGetQueryivEXT_dispatch_table_rewrite_ptr, /* glGetQueryivEXT */
    epoxy_glGetRenderbufferParameteriv_dispatch_table_rewrite_ptr, /* glGetRenderbufferParameteriv */
    epoxy_glGetRenderbufferParameterivEXT_dispatch_table_rewrite_ptr, /* glGetRenderbufferParameterivEXT */
    epoxy_glGetRenderbufferParameterivOES_dispatch_table_rewrite_ptr, /* glGetRenderbufferParameterivOES */
    epoxy_glGetSamplerParameterIiv_dispatch_table_rewrite_ptr, /* glGetSamplerParameterIiv */
    epoxy_glGetSamplerParameterIivEXT_dispatch_table_rewrite_ptr, /* glGetSamplerParameterIivEXT */
    epoxy_glGetSamplerParameterIivOES_dispatch_table_rewrite_ptr, /* glGetSamplerParameterIivOES */
    epoxy_glGetSamplerParameterIuiv_dispatch_table_rewrite_ptr, /* glGetSamplerParameterIuiv */
    epoxy_glGetSamplerParameterIuivEXT_dispatch_table_rewrite_ptr, /* glGetSamplerParameterIuivEXT */
    epoxy_glGetSamplerParameterIuivOES_dispatch_table_rewrite_ptr, /* glGetSamplerParameterIuivOES */
    epoxy_glGetSamplerParameterfv_dispatch_table_rewrite_ptr, /* glGetSamplerParameterfv */
    epoxy_glGetSamplerParameteriv_dispatch_table_rewrite_ptr, /* glGetSamplerParameteriv */
    epoxy_glGetSemaphoreParameterui64vEXT_dispatch_table_rewrite_ptr, /* glGetSemaphoreParameterui64vEXT */
    epoxy_glGetSeparableFilter_dispatch_table_rewrite_ptr, /* glGetSeparableFilter */
    epoxy_glGetSeparableFilterEXT_dispatch_table_rewrite_ptr, /* glGetSeparableFilterEXT */
    epoxy_glGetShaderInfoLog_dispatch_table_rewrite_ptr, /* glGetShaderInfoLog */
    epoxy_glGetShaderPrecisionFormat_dispatch_table_rewrite_ptr, /* glGetShaderPrecisionFormat */
    epoxy_glGetShaderSource_dispatch_table_rewrite_ptr, /* glGetShaderSource */
    epoxy_glGetShaderSourceARB_dispatch_table_rewrite_ptr, /* glGetShaderSourceARB */
    epoxy_glGetShaderiv_dispatch_table_rewrite_ptr, /* glGetShaderiv */
    epoxy_glGetShadingRateImagePaletteNV_dispatch_table_rewrite_ptr, /* glGetShadingRateImagePaletteNV */
    epoxy_glGetShadingRateSampleLocationivNV_dispatch_table_rewrite_ptr, /* glGetShadingRateSampleLocationivNV */
    epoxy_glGetSharpenTexFuncSGIS_dispatch_table_rewrite_ptr, /* glGetSharpenTexFuncSGIS */
    epoxy_glGetStageIndexNV_dispatch_table_rewrite_ptr, /* glGetStageIndexNV */
    epoxy_glGetString_dispatch_table_rewrite_ptr, /* glGetString */
    epoxy_glGetStringi_dispatch_table_rewrite_ptr, /* glGetStringi */
    epoxy_glGetSubroutineIndex_dispatch_table_rewrite_ptr, /* glGetSubroutineIndex */
    epoxy_glGetSubroutineUniformLocation_dispatch_table_rewrite_ptr, /* glGetSubroutineUniformLocation */
    epoxy_glGetSynciv_dispatch_table_rewrite_ptr, /* glGetSynciv */
    epoxy_glGetSyncivAPPLE_dispatch_table_rewrite_ptr, /* glGetSyncivAPPLE */
    epoxy_glGetTexBumpParameterfvATI_dispatch_table_rewrite_ptr, /* glGetTexBumpParameterfvATI */
    epoxy_glGetTexBumpParameterivATI_dispatch_table_rewrite_ptr, /* glGetTexBumpParameterivATI */
    epoxy_glGetTexEnvfv_dispatch_table_rewrite_ptr, /* glGetTexEnvfv */
    epoxy_glGetTexEnviv_dispatch_table_rewrite_ptr, /* glGetTexEnviv */
    epoxy_glGetTexEnvxv_dispatch_table_rewrite_ptr, /* glGetTexEnvxv */
    epoxy_glGetTexEnvxvOES_dispatch_table_rewrite_ptr, /* glGetTexEnvxvOES */
    epoxy_glGetTexFilterFuncSGIS_dispatch_table_rewrite_ptr, /* glGetTexFilterFuncSGIS */
    epoxy_glGetTexGendv_dispatch_table_rewrite_ptr, /* glGetTexGendv */
    epoxy_glGetTexGenfv_dispatch_table_rewrite_ptr, /* glGetTexGenfv */
    epoxy_glGetTexGenfvOES_dispatch_table_rewrite_ptr, /* glGetTexGenfvOES */
    epoxy_glGetTexGeniv_dispatch_table_rewrite_ptr, /* glGetTexGeniv */
    epoxy_glGetTexGenivOES_dispatch_table_rewrite_ptr, /* glGetTexGenivOES */
    epoxy_glGetTexGenxvOES_dispatch_table_rewrite_ptr, /* glGetTexGenxvOES */
    epoxy_glGetTexImage_dispatch_table_rewrite_ptr, /* glGetTexImage */
    epoxy_glGetTexLevelParameterfv_dispatch_table_rewrite_ptr, /* glGetTexLevelParameterfv */
    epoxy_glGetTexLevelParameteriv_dispatch_table_rewrite_ptr, /* glGetTexLevelParameteriv */
    epoxy_glGetTexLevelParameterxvOES_dispatch_table_rewrite_ptr, /* glGetTexLevelParameterxvOES */
    epoxy_glGetTexParameterIiv_dispatch_table_rewrite_ptr, /* glGetTexParameterIiv */
    epoxy_glGetTexParameterIivEXT_dispatch_table_rewrite_ptr, /* glGetTexParameterIivEXT */
    epoxy_glGetTexParameterIivOES_dispatch_table_rewrite_ptr, /* glGetTexParameterIivOES */
    epoxy_glGetTexParameterIuiv_dispatch_table_rewrite_ptr, /* glGetTexParameterIuiv */
    epoxy_glGetTexParameterIuivEXT_dispatch_table_rewrite_ptr, /* glGetTexParameterIuivEXT */
    epoxy_glGetTexParameterIuivOES_dispatch_table_rewrite_ptr, /* glGetTexParameterIuivOES */
    epoxy_glGetTexParameterPointervAPPLE_dispatch_table_rewrite_ptr, /* glGetTexParameterPointervAPPLE */
    epoxy_glGetTexParameterfv_dispatch_table_rewrite_ptr, /* glGetTexParameterfv */
    epoxy_glGetTexParameteriv_dispatch_table_rewrite_ptr, /* glGetTexParameteriv */
    epoxy_glGetTexParameterxv_dispatch_table_rewrite_ptr, /* glGetTexParameterxv */
    epoxy_glGetTexParameterxvOES_dispatch_table_rewrite_ptr, /* glGetTexParameterxvOES */
    epoxy_glGetTextureHandleARB_dispatch_table_rewrite_ptr, /* glGetTextureHandleARB */
    epoxy_glGetTextureHandleIMG_dispatch_table_rewrite_ptr, /* glGetTextureHandleIMG */
    epoxy_glGetTextureHandleNV_dispatch_table_rewrite_ptr, /* glGetTextureHandleNV */
    epoxy_glGetTextureImage_dispatch_table_rewrite_ptr, /* glGetTextureImage */
    epoxy_glGetTextureImageEXT_dispatch_table_rewrite_ptr, /* glGetTextureImageEXT */
    epoxy_glGetTextureLevelParameterfv_dispatch_table_rewrite_ptr, /* glGetTextureLevelParameterfv */
    epoxy_glGetTextureLevelParameterfvEXT_dispatch_table_rewrite_ptr, /* glGetTextureLevelParameterfvEXT */
    epoxy_glGetTextureLevelParameteriv_dispatch_table_rewrite_ptr, /* glGetTextureLevelParameteriv */
    epoxy_glGetTextureLevelParameterivEXT_dispatch_table_rewrite_ptr, /* glGetTextureLevelParameterivEXT */
    epoxy_glGetTextureParameterIiv_dispatch_table_rewrite_ptr, /* glGetTextureParameterIiv */
    epoxy_glGetTextureParameterIivEXT_dispatch_table_rewrite_ptr, /* glGetTextureParameterIivEXT */
    epoxy_glGetTextureParameterIuiv_dispatch_table_rewrite_ptr, /* glGetTextureParameterIuiv */
    epoxy_glGetTextureParameterIuivEXT_dispatch_table_rewrite_ptr, /* glGetTextureParameterIuivEXT */
    epoxy_glGetTextureParameterfv_dispatch_table_rewrite_ptr, /* glGetTextureParameterfv */
    epoxy_glGetTextureParameterfvEXT_dispatch_table_rewrite_ptr, /* glGetTextureParameterfvEXT */
    epoxy_glGetTextureParameteriv_dispatch_table_rewrite_ptr, /* glGetTextureParameteriv */
    epoxy_glGetTextureParameterivEXT_dispatch_table_rewrite_ptr, /* glGetTextureParameterivEXT */
    epoxy_glGetTextureSamplerHandleARB_dispatch_table_rewrite_ptr, /* glGetTextureSamplerHandleARB */
    epoxy_glGetTextureSamplerHandleIMG_dispatch_table_rewrite_ptr, /* glGetTextureSamplerHandleIMG */
    epoxy_glGetTextureSamplerHandleNV_dispatch_table_rewrite_ptr, /* glGetTextureSamplerHandleNV */
    epoxy_glGetTextureSubImage_dispatch_table_rewrite_ptr, /* glGetTextureSubImage */
    epoxy_glGetTrackMatrixivNV_dispatch_table_rewrite_ptr, /* glGetTrackMatrixivNV */
    epoxy_glGetTransformFeedbackVarying_dispatch_table_rewrite_ptr, /* glGetTransformFeedbackVarying */
    epoxy_glGetTransformFeedbackVaryingEXT_dispatch_table_rewrite_ptr, /* glGetTransformFeedbackVaryingEXT */
    epoxy_glGetTransformFeedbackVaryingNV_dispatch_table_rewrite_ptr, /* glGetTransformFeedbackVaryingNV */
    epoxy_glGetTransformFeedbacki64_v_dispatch_table_rewrite_ptr, /* glGetTransformFeedbacki64_v */
    epoxy_glGetTransformFeedbacki_v_dispatch_table_rewrite_ptr, /* glGetTransformFeedbacki_v */
    epoxy_glGetTransformFeedbackiv_dispatch_table_rewrite_ptr, /* glGetTransformFeedbackiv */
    epoxy_glGetTranslatedShaderSourceANGLE_dispatch_table_rewrite_ptr, /* glGetTranslatedShaderSourceANGLE */
    epoxy_glGetUniformBlockIndex_dispatch_table_rewrite_ptr, /* glGetUniformBlockIndex */
    epoxy_glGetUniformBufferSizeEXT_dispatch_table_rewrite_ptr, /* glGetUniformBufferSizeEXT */
    epoxy_glGetUniformIndices_dispatch_table_rewrite_ptr, /* glGetUniformIndices */
    epoxy_glGetUniformLocation_dispatch_table_rewrite_ptr, /* glGetUniformLocation */
    epoxy_glGetUniformLocationARB_dispatch_table_rewrite_ptr, /* glGetUniformLocationARB */
    epoxy_glGetUniformOffsetEXT_dispatch_table_rewrite_ptr, /* glGetUniformOffsetEXT */
    epoxy_glGetUniformSubroutineuiv_dispatch_table_rewrite_ptr, /* glGetUniformSubroutineuiv */
    epoxy_glGetUniformdv_dispatch_table_rewrite_ptr, /* glGetUniformdv */
    epoxy_glGetUniformfv_dispatch_table_rewrite_ptr, /* glGetUniformfv */
    epoxy_glGetUniformfvARB_dispatch_table_rewrite_ptr, /* glGetUniformfvARB */
    epoxy_glGetUniformi64vARB_dispatch_table_rewrite_ptr, /* glGetUniformi64vARB */
    epoxy_glGetUniformi64vNV_dispatch_table_rewrite_ptr, /* glGetUniformi64vNV */
    epoxy_glGetUniformiv_dispatch_table_rewrite_ptr, /* glGetUniformiv */
    epoxy_glGetUniformivARB_dispatch_table_rewrite_ptr, /* glGetUniformivARB */
    epoxy_glGetUniformui64vARB_dispatch_table_rewrite_ptr, /* glGetUniformui64vARB */
    epoxy_glGetUniformui64vNV_dispatch_table_rewrite_ptr, /* glGetUniformui64vNV */
    epoxy_glGetUniformuiv_dispatch_table_rewrite_ptr, /* glGetUniformuiv */
    epoxy_glGetUniformuivEXT_dispatch_table_rewrite_ptr, /* glGetUniformuivEXT */
    epoxy_glGetUnsignedBytei_vEXT_dispatch_table_rewrite_ptr, /* glGetUnsignedBytei_vEXT */
    epoxy_glGetUnsignedBytevEXT_dispatch_table_rewrite_ptr, /* glGetUnsignedBytevEXT */
    epoxy_glGetVariantArrayObjectfvATI_dispatch_table_rewrite_ptr, /* glGetVariantArrayObjectfvATI */
    epoxy_glGetVariantArrayObjectivATI_dispatch_table_rewrite_ptr, /* glGetVariantArrayObjectivATI */
    epoxy_glGetVariantBooleanvEXT_dispatch_table_rewrite_ptr, /* glGetVariantBooleanvEXT */
    epoxy_glGetVariantFloatvEXT_dispatch_table_rewrite_ptr, /* glGetVariantFloatvEXT */
    epoxy_glGetVariantIntegervEXT_dispatch_table_rewrite_ptr, /* glGetVariantIntegervEXT */
    epoxy_glGetVariantPointervEXT_dispatch_table_rewrite_ptr, /* glGetVariantPointervEXT */
    epoxy_glGetVaryingLocationNV_dispatch_table_rewrite_ptr, /* glGetVaryingLocationNV */
    epoxy_glGetVertexArrayIndexed64iv_dispatch_table_rewrite_ptr, /* glGetVertexArrayIndexed64iv */
    epoxy_glGetVertexArrayIndexediv_dispatch_table_rewrite_ptr, /* glGetVertexArrayIndexediv */
    epoxy_glGetVertexArrayIntegeri_vEXT_dispatch_table_rewrite_ptr, /* glGetVertexArrayIntegeri_vEXT */
    epoxy_glGetVertexArrayIntegervEXT_dispatch_table_rewrite_ptr, /* glGetVertexArrayIntegervEXT */
    epoxy_glGetVertexArrayPointeri_vEXT_dispatch_table_rewrite_ptr, /* glGetVertexArrayPointeri_vEXT */
    epoxy_glGetVertexArrayPointervEXT_dispatch_table_rewrite_ptr, /* glGetVertexArrayPointervEXT */
    epoxy_glGetVertexArrayiv_dispatch_table_rewrite_ptr, /* glGetVertexArrayiv */
    epoxy_glGetVertexAttribArrayObjectfvATI_dispatch_table_rewrite_ptr, /* glGetVertexAttribArrayObjectfvATI */
    epoxy_glGetVertexAttribArrayObjectivATI_dispatch_table_rewrite_ptr, /* glGetVertexAttribArrayObjectivATI */
    epoxy_glGetVertexAttribIiv_dispatch_table_rewrite_ptr, /* glGetVertexAttribIiv */
    epoxy_glGetVertexAttribIivEXT_dispatch_table_rewrite_ptr, /* glGetVertexAttribIivEXT */
    epoxy_glGetVertexAttribIuiv_dispatch_table_rewrite_ptr, /* glGetVertexAttribIuiv */
    epoxy_glGetVertexAttribIuivEXT_dispatch_table_rewrite_ptr, /* glGetVertexAttribIuivEXT */
    epoxy_glGetVertexAttribLdv_dispatch_table_rewrite_ptr, /* glGetVertexAttribLdv */
    epoxy_glGetVertexAttribLdvEXT_dispatch_table_rewrite_ptr, /* glGetVertexAttribLdvEXT */
    epoxy_glGetVertexAttribLi64vNV_dispatch_table_rewrite_ptr, /* glGetVertexAttribLi64vNV */
    epoxy_glGetVertexAttribLui64vARB_dispatch_table_rewrite_ptr, /* glGetVertexAttribLui64vARB */
    epoxy_glGetVertexAttribLui64vNV_dispatch_table_rewrite_ptr, /* glGetVertexAttribLui64vNV */
    epoxy_glGetVertexAttribPointerv_dispatch_table_rewrite_ptr, /* glGetVertexAttribPointerv */
    epoxy_glGetVertexAttribPointervARB_dispatch_table_rewrite_ptr, /* glGetVertexAttribPointervARB */
    epoxy_glGetVertexAttribPointervNV_dispatch_table_rewrite_ptr, /* glGetVertexAttribPointervNV */
    epoxy_glGetVertexAttribdv_dispatch_table_rewrite_ptr, /* glGetVertexAttribdv */
    epoxy_glGetVertexAttribdvARB_dispatch_table_rewrite_ptr, /* glGetVertexAttribdvARB */
    epoxy_glGetVertexAttribdvNV_dispatch_table_rewrite_ptr, /* glGetVertexAttribdvNV */
    epoxy_glGetVertexAttribfv_dispatch_table_rewrite_ptr, /* glGetVertexAttribfv */
    epoxy_glGetVertexAttribfvARB_dispatch_table_rewrite_ptr, /* glGetVertexAttribfvARB */
    epoxy_glGetVertexAttribfvNV_dispatch_table_rewrite_ptr, /* glGetVertexAttribfvNV */
    epoxy_glGetVertexAttribiv_dispatch_table_rewrite_ptr, /* glGetVertexAttribiv */
    epoxy_glGetVertexAttribivARB_dispatch_table_rewrite_ptr, /* glGetVertexAttribivARB */
    epoxy_glGetVertexAttribivNV_dispatch_table_rewrite_ptr, /* glGetVertexAttribivNV */
    epoxy_glGetVideoCaptureStreamdvNV_dispatch_table_rewrite_ptr, /* glGetVideoCaptureStreamdvNV */
    epoxy_glGetVideoCaptureStreamfvNV_dispatch_table_rewrite_ptr, /* glGetVideoCaptureStreamfvNV */
    epoxy_glGetVideoCaptureStreamivNV_dispatch_table_rewrite_ptr, /* glGetVideoCaptureStreamivNV */
    epoxy_glGetVideoCaptureivNV_dispatch_table_rewrite_ptr, /* glGetVideoCaptureivNV */
    epoxy_glGetVideoi64vNV_dispatch_table_rewrite_ptr, /* glGetVideoi64vNV */
    epoxy_glGetVideoivNV_dispatch_table_rewrite_ptr, /* glGetVideoivNV */
    epoxy_glGetVideoui64vNV_dispatch_table_rewrite_ptr, /* glGetVideoui64vNV */
    epoxy_glGetVideouivNV_dispatch_table_rewrite_ptr, /* glGetVideouivNV */
    epoxy_glGetVkProcAddrNV_dispatch_table_rewrite_ptr, /* glGetVkProcAddrNV */
    epoxy_glGetnColorTable_dispatch_table_rewrite_ptr, /* glGetnColorTable */
    epoxy_glGetnColorTableARB_dispatch_table_rewrite_ptr, /* glGetnColorTableARB */
    epoxy_glGetnCompressedTexImage_dispatch_table_rewrite_ptr, /* glGetnCompressedTexImage */
    epoxy_glGetnCompressedTexImageARB_dispatch_table_rewrite_ptr, /* glGetnCompressedTexImageARB */
    epoxy_glGetnConvolutionFilter_dispatch_table_rewrite_ptr, /* glGetnConvolutionFilter */
    epoxy_glGetnConvolutionFilterARB_dispatch_table_rewrite_ptr, /* glGetnConvolutionFilterARB */
    epoxy_glGetnHistogram_dispatch_table_rewrite_ptr, /* glGetnHistogram */
    epoxy_glGetnHistogramARB_dispatch_table_rewrite_ptr, /* glGetnHistogramARB */
    epoxy_glGetnMapdv_dispatch_table_rewrite_ptr, /* glGetnMapdv */
    epoxy_glGetnMapdvARB_dispatch_table_rewrite_ptr, /* glGetnMapdvARB */
    epoxy_glGetnMapfv_dispatch_table_rewrite_ptr, /* glGetnMapfv */
    epoxy_glGetnMapfvARB_dispatch_table_rewrite_ptr, /* glGetnMapfvARB */
    epoxy_glGetnMapiv_dispatch_table_rewrite_ptr, /* glGetnMapiv */
    epoxy_glGetnMapivARB_dispatch_table_rewrite_ptr, /* glGetnMapivARB */
    epoxy_glGetnMinmax_dispatch_table_rewrite_ptr, /* glGetnMinmax */
    epoxy_glGetnMinmaxARB_dispatch_table_rewrite_ptr, /* glGetnMinmaxARB */
    epoxy_glGetnPixelMapfv_dispatch_table_rewrite_ptr, /* glGetnPixelMapfv */
    epoxy_glGetnPixelMapfvARB_dispatch_table_rewrite_ptr, /* glGetnPixelMapfvARB */
    epoxy_glGetnPixelMapuiv_dispatch_table_rewrite_ptr, /* glGetnPixelMapuiv */
    epoxy_glGetnPixelMapuivARB_dispatch_table_rewrite_ptr, /* glGetnPixelMapuivARB */
    epoxy_glGetnPixelMapusv_dispatch_table_rewrite_ptr, /* glGetnPixelMapusv */
    epoxy_glGetnPixelMapusvARB_dispatch_table_rewrite_ptr, /* glGetnPixelMapusvARB */
    epoxy_glGetnPolygonStipple_dispatch_table_rewrite_ptr, /* glGetnPolygonStipple */
    epoxy_glGetnPolygonStippleARB_dispatch_table_rewrite_ptr, /* glGetnPolygonStippleARB */
    epoxy_glGetnSeparableFilter_dispatch_table_rewrite_ptr, /* glGetnSeparableFilter */
    epoxy_glGetnSeparableFilterARB_dispatch_table_rewrite_ptr, /* glGetnSeparableFilterARB */
    epoxy_glGetnTexImage_dispatch_table_rewrite_ptr, /* glGetnTexImage */
    epoxy_glGetnTexImageARB_dispatch_table_rewrite_ptr, /* glGetnTexImageARB */
    epoxy_glGetnUniformdv_dispatch_table_rewrite_ptr, /* glGetnUniformdv */
    epoxy_glGetnUniformdvARB_dispatch_table_rewrite_ptr, /* glGetnUniformdvARB */
    epoxy_glGetnUniformfv_dispatch_table_rewrite_ptr, /* glGetnUniformfv */
    epoxy_glGetnUniformfvARB_dispatch_table_rewrite_ptr, /* glGetnUniformfvARB */
    epoxy_glGetnUniformfvEXT_dispatch_table_rewrite_ptr, /* glGetnUniformfvEXT */
    epoxy_glGetnUniformfvKHR_dispatch_table_rewrite_ptr, /* glGetnUniformfvKHR */
    epoxy_glGetnUniformi64vARB_dispatch_table_rewrite_ptr, /* glGetnUniformi64vARB */
    epoxy_glGetnUniformiv_dispatch_table_rewrite_ptr, /* glGetnUniformiv */
    epoxy_glGetnUniformivARB_dispatch_table_rewrite_ptr, /* glGetnUniformivARB */
    epoxy_glGetnUniformivEXT_dispatch_table_rewrite_ptr, /* glGetnUniformivEXT */
    epoxy_glGetnUniformivKHR_dispatch_table_rewrite_ptr, /* glGetnUniformivKHR */
    epoxy_glGetnUniformui64vARB_dispatch_table_rewrite_ptr, /* glGetnUniformui64vARB */
    epoxy_glGetnUniformuiv_dispatch_table_rewrite_ptr, /* glGetnUniformuiv */
    epoxy_glGetnUniformuivARB_dispatch_table_rewrite_ptr, /* glGetnUniformuivARB */
    epoxy_glGetnUniformuivKHR_dispatch_table_rewrite_ptr, /* glGetnUniformuivKHR */
    epoxy_glGlobalAlphaFactorbSUN_dispatch_table_rewrite_ptr, /* glGlobalAlphaFactorbSUN */
    epoxy_glGlobalAlphaFactordSUN_dispatch_table_rewrite_ptr, /* glGlobalAlphaFactordSUN */
    epoxy_glGlobalAlphaFactorfSUN_dispatch_table_rewrite_ptr, /* glGlobalAlphaFactorfSUN */
    epoxy_glGlobalAlphaFactoriSUN_dispatch_table_rewrite_ptr, /* glGlobalAlphaFactoriSUN */
    epoxy_glGlobalAlphaFactorsSUN_dispatch_table_rewrite_ptr, /* glGlobalAlphaFactorsSUN */
    epoxy_glGlobalAlphaFactorubSUN_dispatch_table_rewrite_ptr, /* glGlobalAlphaFactorubSUN */
    epoxy_glGlobalAlphaFactoruiSUN_dispatch_table_rewrite_ptr, /* glGlobalAlphaFactoruiSUN */
    epoxy_glGlobalAlphaFactorusSUN_dispatch_table_rewrite_ptr, /* glGlobalAlphaFactorusSUN */
    epoxy_glHint_dispatch_table_rewrite_ptr, /* glHint */
    epoxy_glHintPGI_dispatch_table_rewrite_ptr, /* glHintPGI */
    epoxy_glHistogram_dispatch_table_rewrite_ptr, /* glHistogram */
    epoxy_glHistogramEXT_dispatch_table_rewrite_ptr, /* glHistogramEXT */
    epoxy_glIglooInterfaceSGIX_dispatch_table_rewrite_ptr, /* glIglooInterfaceSGIX */
    epoxy_glImageTransformParameterfHP_dispatch_table_rewrite_ptr, /* glImageTransformParameterfHP */
    epoxy_glImageTransformParameterfvHP_dispatch_table_rewrite_ptr, /* glImageTransformParameterfvHP */
    epoxy_glImageTransformParameteriHP_dispatch_table_rewrite_ptr, /* glImageTransformParameteriHP */
    epoxy_glImageTransformParameterivHP_dispatch_table_rewrite_ptr, /* glImageTransformParameterivHP */
    epoxy_glImportMemoryFdEXT_dispatch_table_rewrite_ptr, /* glImportMemoryFdEXT */
    epoxy_glImportMemoryWin32HandleEXT_dispatch_table_rewrite_ptr, /* glImportMemoryWin32HandleEXT */
    epoxy_glImportMemoryWin32NameEXT_dispatch_table_rewrite_ptr, /* glImportMemoryWin32NameEXT */
    epoxy_glImportSemaphoreFdEXT_dispatch_table_rewrite_ptr, /* glImportSemaphoreFdEXT */
    epoxy_glImportSemaphoreWin32HandleEXT_dispatch_table_rewrite_ptr, /* glImportSemaphoreWin32HandleEXT */
    epoxy_glImportSemaphoreWin32NameEXT_dispatch_table_rewrite_ptr, /* glImportSemaphoreWin32NameEXT */
    epoxy_glImportSyncEXT_dispatch_table_rewrite_ptr, /* glImportSyncEXT */
    epoxy_glIndexFormatNV_dispatch_table_rewrite_ptr, /* glIndexFormatNV */
    epoxy_glIndexFuncEXT_dispatch_table_rewrite_ptr, /* glIndexFuncEXT */
    epoxy_glIndexMask_dispatch_table_rewrite_ptr, /* glIndexMask */
    epoxy_glIndexMaterialEXT_dispatch_table_rewrite_ptr, /* glIndexMaterialEXT */
    epoxy_glIndexPointer_dispatch_table_rewrite_ptr, /* glIndexPointer */
    epoxy_glIndexPointerEXT_dispatch_table_rewrite_ptr, /* glIndexPointerEXT */
    epoxy_glIndexPointerListIBM_dispatch_table_rewrite_ptr, /* glIndexPointerListIBM */
    epoxy_glIndexd_dispatch_table_rewrite_ptr, /* glIndexd */
    epoxy_glIndexdv_dispatch_table_rewrite_ptr, /* glIndexdv */
    epoxy_glIndexf_dispatch_table_rewrite_ptr, /* glIndexf */
    epoxy_glIndexfv_dispatch_table_rewrite_ptr, /* glIndexfv */
    epoxy_glIndexi_dispatch_table_rewrite_ptr, /* glIndexi */
    epoxy_glIndexiv_dispatch_table_rewrite_ptr, /* glIndexiv */
    epoxy_glIndexs_dispatch_table_rewrite_ptr, /* glIndexs */
    epoxy_glIndexsv_dispatch_table_rewrite_ptr, /* glIndexsv */
    epoxy_glIndexub_dispatch_table_rewrite_ptr, /* glIndexub */
    epoxy_glIndexubv_dispatch_table_rewrite_ptr, /* glIndexubv */
    epoxy_glIndexxOES_dispatch_table_rewrite_ptr, /* glIndexxOES */
    epoxy_glIndexxvOES_dispatch_table_rewrite_ptr, /* glIndexxvOES */
    epoxy_glInitNames_dispatch_table_rewrite_ptr, /* glInitNames */
    epoxy_glInsertComponentEXT_dispatch_table_rewrite_ptr, /* glInsertComponentEXT */
    epoxy_glInsertEventMarkerEXT_dispatch_table_rewrite_ptr, /* glInsertEventMarkerEXT */
    epoxy_glInstrumentsBufferSGIX_dispatch_table_rewrite_ptr, /* glInstrumentsBufferSGIX */
    epoxy_glInterleavedArrays_dispatch_table_rewrite_ptr, /* glInterleavedArrays */
    epoxy_glInterpolatePathsNV_dispatch_table_rewrite_ptr, /* glInterpolatePathsNV */
    epoxy_glInvalidateBufferData_dispatch_table_rewrite_ptr, /* glInvalidateBufferData */
    epoxy_glInvalidateBufferSubData_dispatch_table_rewrite_ptr, /* glInvalidateBufferSubData */
    epoxy_glInvalidateFramebuffer_dispatch_table_rewrite_ptr, /* glInvalidateFramebuffer */
    epoxy_glInvalidateNamedFramebufferData_dispatch_table_rewrite_ptr, /* glInvalidateNamedFramebufferData */
    epoxy_glInvalidateNamedFramebufferSubData_dispatch_table_rewrite_ptr, /* glInvalidateNamedFramebufferSubData */
    epoxy_glInvalidateSubFramebuffer_dispatch_table_rewrite_ptr, /* glInvalidateSubFramebuffer */
    epoxy_glInvalidateTexImage_dispatch_table_rewrite_ptr, /* glInvalidateTexImage */
    epoxy_glInvalidateTexSubImage_dispatch_table_rewrite_ptr, /* glInvalidateTexSubImage */
    epoxy_glIsAsyncMarkerSGIX_dispatch_table_rewrite_ptr, /* glIsAsyncMarkerSGIX */
    epoxy_glIsBuffer_dispatch_table_rewrite_ptr, /* glIsBuffer */
    epoxy_glIsBufferARB_dispatch_table_rewrite_ptr, /* glIsBufferARB */
    epoxy_glIsBufferResidentNV_dispatch_table_rewrite_ptr, /* glIsBufferResidentNV */
    epoxy_glIsCommandListNV_dispatch_table_rewrite_ptr, /* glIsCommandListNV */
    epoxy_glIsEnabled_dispatch_table_rewrite_ptr, /* glIsEnabled */
    epoxy_glIsEnabledIndexedEXT_dispatch_table_rewrite_ptr, /* glIsEnabledIndexedEXT */
    epoxy_glIsEnabledi_dispatch_table_rewrite_ptr, /* glIsEnabledi */
    epoxy_glIsEnablediEXT_dispatch_table_rewrite_ptr, /* glIsEnablediEXT */
    epoxy_glIsEnablediNV_dispatch_table_rewrite_ptr, /* glIsEnablediNV */
    epoxy_glIsEnablediOES_dispatch_table_rewrite_ptr, /* glIsEnablediOES */
    epoxy_glIsFenceAPPLE_dispatch_table_rewrite_ptr, /* glIsFenceAPPLE */
    epoxy_glIsFenceNV_dispatch_table_rewrite_ptr, /* glIsFenceNV */
    epoxy_glIsFramebuffer_dispatch_table_rewrite_ptr, /* glIsFramebuffer */
    epoxy_glIsFramebufferEXT_dispatch_table_rewrite_ptr, /* glIsFramebufferEXT */
    epoxy_glIsFramebufferOES_dispatch_table_rewrite_ptr, /* glIsFramebufferOES */
    epoxy_glIsImageHandleResidentARB_dispatch_table_rewrite_ptr, /* glIsImageHandleResidentARB */
    epoxy_glIsImageHandleResidentNV_dispatch_table_rewrite_ptr, /* glIsImageHandleResidentNV */
    epoxy_glIsList_dispatch_table_rewrite_ptr, /* glIsList */
    epoxy_glIsMemoryObjectEXT_dispatch_table_rewrite_ptr, /* glIsMemoryObjectEXT */
    epoxy_glIsNameAMD_dispatch_table_rewrite_ptr, /* glIsNameAMD */
    epoxy_glIsNamedBufferResidentNV_dispatch_table_rewrite_ptr, /* glIsNamedBufferResidentNV */
    epoxy_glIsNamedStringARB_dispatch_table_rewrite_ptr, /* glIsNamedStringARB */
    epoxy_glIsObjectBufferATI_dispatch_table_rewrite_ptr, /* glIsObjectBufferATI */
    epoxy_glIsOcclusionQueryNV_dispatch_table_rewrite_ptr, /* glIsOcclusionQueryNV */
    epoxy_glIsPathNV_dispatch_table_rewrite_ptr, /* glIsPathNV */
    epoxy_glIsPointInFillPathNV_dispatch_table_rewrite_ptr, /* glIsPointInFillPathNV */
    epoxy_glIsPointInStrokePathNV_dispatch_table_rewrite_ptr, /* glIsPointInStrokePathNV */
    epoxy_glIsProgram_dispatch_table_rewrite_ptr, /* glIsProgram */
    epoxy_glIsProgramARB_dispatch_table_rewrite_ptr, /* glIsProgramARB */
    epoxy_glIsProgramNV_dispatch_table_rewrite_ptr, /* glIsProgramNV */
    epoxy_glIsProgramPipeline_dispatch_table_rewrite_ptr, /* glIsProgramPipeline */
    epoxy_glIsProgramPipelineEXT_dispatch_table_rewrite_ptr, /* glIsProgramPipelineEXT */
    epoxy_glIsQuery_dispatch_table_rewrite_ptr, /* glIsQuery */
    epoxy_glIsQueryARB_dispatch_table_rewrite_ptr, /* glIsQueryARB */
    epoxy_glIsQueryEXT_dispatch_table_rewrite_ptr, /* glIsQueryEXT */
    epoxy_glIsRenderbuffer_dispatch_table_rewrite_ptr, /* glIsRenderbuffer */
    epoxy_glIsRenderbufferEXT_dispatch_table_rewrite_ptr, /* glIsRenderbufferEXT */
    epoxy_glIsRenderbufferOES_dispatch_table_rewrite_ptr, /* glIsRenderbufferOES */
    epoxy_glIsSampler_dispatch_table_rewrite_ptr, /* glIsSampler */
    epoxy_glIsSemaphoreEXT_dispatch_table_rewrite_ptr, /* glIsSemaphoreEXT */
    epoxy_glIsShader_dispatch_table_rewrite_ptr, /* glIsShader */
    epoxy_glIsStateNV_dispatch_table_rewrite_ptr, /* glIsStateNV */
    epoxy_glIsSync_dispatch_table_rewrite_ptr, /* glIsSync */
    epoxy_glIsSyncAPPLE_dispatch_table_rewrite_ptr, /* glIsSyncAPPLE */
    epoxy_glIsTexture_dispatch_table_rewrite_ptr, /* glIsTexture */
    epoxy_glIsTextureEXT_dispatch_table_rewrite_ptr, /* glIsTextureEXT */
    epoxy_glIsTextureHandleResidentARB_dispatch_table_rewrite_ptr, /* glIsTextureHandleResidentARB */
    epoxy_glIsTextureHandleResidentNV_dispatch_table_rewrite_ptr, /* glIsTextureHandleResidentNV */
    epoxy_glIsTransformFeedback_dispatch_table_rewrite_ptr, /* glIsTransformFeedback */
    epoxy_glIsTransformFeedbackNV_dispatch_table_rewrite_ptr, /* glIsTransformFeedbackNV */
    epoxy_glIsVariantEnabledEXT_dispatch_table_rewrite_ptr, /* glIsVariantEnabledEXT */
    epoxy_glIsVertexArray_dispatch_table_rewrite_ptr, /* glIsVertexArray */
    epoxy_glIsVertexArrayAPPLE_dispatch_table_rewrite_ptr, /* glIsVertexArrayAPPLE */
    epoxy_glIsVertexArrayOES_dispatch_table_rewrite_ptr, /* glIsVertexArrayOES */
    epoxy_glIsVertexAttribEnabledAPPLE_dispatch_table_rewrite_ptr, /* glIsVertexAttribEnabledAPPLE */
    epoxy_glLGPUCopyImageSubDataNVX_dispatch_table_rewrite_ptr, /* glLGPUCopyImageSubDataNVX */
    epoxy_glLGPUInterlockNVX_dispatch_table_rewrite_ptr, /* glLGPUInterlockNVX */
    epoxy_glLGPUNamedBufferSubDataNVX_dispatch_table_rewrite_ptr, /* glLGPUNamedBufferSubDataNVX */
    epoxy_glLabelObjectEXT_dispatch_table_rewrite_ptr, /* glLabelObjectEXT */
    epoxy_glLightEnviSGIX_dispatch_table_rewrite_ptr, /* glLightEnviSGIX */
    epoxy_glLightModelf_dispatch_table_rewrite_ptr, /* glLightModelf */
    epoxy_glLightModelfv_dispatch_table_rewrite_ptr, /* glLightModelfv */
    epoxy_glLightModeli_dispatch_table_rewrite_ptr, /* glLightModeli */
    epoxy_glLightModeliv_dispatch_table_rewrite_ptr, /* glLightModeliv */
    epoxy_glLightModelx_dispatch_table_rewrite_ptr, /* glLightModelx */
    epoxy_glLightModelxOES_dispatch_table_rewrite_ptr, /* glLightModelxOES */
    epoxy_glLightModelxv_dispatch_table_rewrite_ptr, /* glLightModelxv */
    epoxy_glLightModelxvOES_dispatch_table_rewrite_ptr, /* glLightModelxvOES */
    epoxy_glLightf_dispatch_table_rewrite_ptr, /* glLightf */
    epoxy_glLightfv_dispatch_table_rewrite_ptr, /* glLightfv */
    epoxy_glLighti_dispatch_table_rewrite_ptr, /* glLighti */
    epoxy_glLightiv_dispatch_table_rewrite_ptr, /* glLightiv */
    epoxy_glLightx_dispatch_table_rewrite_ptr, /* glLightx */
    epoxy_glLightxOES_dispatch_table_rewrite_ptr, /* glLightxOES */
    epoxy_glLightxv_dispatch_table_rewrite_ptr, /* glLightxv */
    epoxy_glLightxvOES_dispatch_table_rewrite_ptr, /* glLightxvOES */
    epoxy_glLineStipple_dispatch_table_rewrite_ptr, /* glLineStipple */
    epoxy_glLineWidth_dispatch_table_rewrite_ptr, /* glLineWidth */
    epoxy_glLineWidthx_dispatch_table_rewrite_ptr, /* glLineWidthx */
    epoxy_glLineWidthxOES_dispatch_table_rewrite_ptr, /* glLineWidthxOES */
    epoxy_glLinkProgram_dispatch_table_rewrite_ptr, /* glLinkProgram */
    epoxy_glLinkProgramARB_dispatch_table_rewrite_ptr, /* glLinkProgramARB */
    epoxy_glListBase_dispatch_table_rewrite_ptr, /* glListBase */
    epoxy_glListDrawCommandsStatesClientNV_dispatch_table_rewrite_ptr, /* glListDrawCommandsStatesClientNV */
    epoxy_glListParameterfSGIX_dispatch_table_rewrite_ptr, /* glListParameterfSGIX */
    epoxy_glListParameterfvSGIX_dispatch_table_rewrite_ptr, /* glListParameterfvSGIX */
    epoxy_glListParameteriSGIX_dispatch_table_rewrite_ptr, /* glListParameteriSGIX */
    epoxy_glListParameterivSGIX_dispatch_table_rewrite_ptr, /* glListParameterivSGIX */
    epoxy_glLoadIdentity_dispatch_table_rewrite_ptr, /* glLoadIdentity */
    epoxy_glLoadIdentityDeformationMapSGIX_dispatch_table_rewrite_ptr, /* glLoadIdentityDeformationMapSGIX */
    epoxy_glLoadMatrixd_dispatch_table_rewrite_ptr, /* glLoadMatrixd */
    epoxy_glLoadMatrixf_dispatch_table_rewrite_ptr, /* glLoadMatrixf */
    epoxy_glLoadMatrixx_dispatch_table_rewrite_ptr, /* glLoadMatrixx */
    epoxy_glLoadMatrixxOES_dispatch_table_rewrite_ptr, /* glLoadMatrixxOES */
    epoxy_glLoadName_dispatch_table_rewrite_ptr, /* glLoadName */
    epoxy_glLoadPaletteFromModelViewMatrixOES_dispatch_table_rewrite_ptr, /* glLoadPaletteFromModelViewMatrixOES */
    epoxy_glLoadProgramNV_dispatch_table_rewrite_ptr, /* glLoadProgramNV */
    epoxy_glLoadTransposeMatrixd_dispatch_table_rewrite_ptr, /* glLoadTransposeMatrixd */
    epoxy_glLoadTransposeMatrixdARB_dispatch_table_rewrite_ptr, /* glLoadTransposeMatrixdARB */
    epoxy_glLoadTransposeMatrixf_dispatch_table_rewrite_ptr, /* glLoadTransposeMatrixf */
    epoxy_glLoadTransposeMatrixfARB_dispatch_table_rewrite_ptr, /* glLoadTransposeMatrixfARB */
    epoxy_glLoadTransposeMatrixxOES_dispatch_table_rewrite_ptr, /* glLoadTransposeMatrixxOES */
    epoxy_glLockArraysEXT_dispatch_table_rewrite_ptr, /* glLockArraysEXT */
    epoxy_glLogicOp_dispatch_table_rewrite_ptr, /* glLogicOp */
    epoxy_glMakeBufferNonResidentNV_dispatch_table_rewrite_ptr, /* glMakeBufferNonResidentNV */
    epoxy_glMakeBufferResidentNV_dispatch_table_rewrite_ptr, /* glMakeBufferResidentNV */
    epoxy_glMakeImageHandleNonResidentARB_dispatch_table_rewrite_ptr, /* glMakeImageHandleNonResidentARB */
    epoxy_glMakeImageHandleNonResidentNV_dispatch_table_rewrite_ptr, /* glMakeImageHandleNonResidentNV */
    epoxy_glMakeImageHandleResidentARB_dispatch_table_rewrite_ptr, /* glMakeImageHandleResidentARB */
    epoxy_glMakeImageHandleResidentNV_dispatch_table_rewrite_ptr, /* glMakeImageHandleResidentNV */
    epoxy_glMakeNamedBufferNonResidentNV_dispatch_table_rewrite_ptr, /* glMakeNamedBufferNonResidentNV */
    epoxy_glMakeNamedBufferResidentNV_dispatch_table_rewrite_ptr, /* glMakeNamedBufferResidentNV */
    epoxy_glMakeTextureHandleNonResidentARB_dispatch_table_rewrite_ptr, /* glMakeTextureHandleNonResidentARB */
    epoxy_glMakeTextureHandleNonResidentNV_dispatch_table_rewrite_ptr, /* glMakeTextureHandleNonResidentNV */
    epoxy_glMakeTextureHandleResidentARB_dispatch_table_rewrite_ptr, /* glMakeTextureHandleResidentARB */
    epoxy_glMakeTextureHandleResidentNV_dispatch_table_rewrite_ptr, /* glMakeTextureHandleResidentNV */
    epoxy_glMap1d_dispatch_table_rewrite_ptr, /* glMap1d */
    epoxy_glMap1f_dispatch_table_rewrite_ptr, /* glMap1f */
    epoxy_glMap1xOES_dispatch_table_rewrite_ptr, /* glMap1xOES */
    epoxy_glMap2d_dispatch_table_rewrite_ptr, /* glMap2d */
    epoxy_glMap2f_dispatch_table_rewrite_ptr, /* glMap2f */
    epoxy_glMap2xOES_dispatch_table_rewrite_ptr, /* glMap2xOES */
    epoxy_glMapBuffer_dispatch_table_rewrite_ptr, /* glMapBuffer */
    epoxy_glMapBufferARB_dispatch_table_rewrite_ptr, /* glMapBufferARB */
    epoxy_glMapBufferOES_dispatch_table_rewrite_ptr, /* glMapBufferOES */
    epoxy_glMapBufferRange_dispatch_table_rewrite_ptr, /* glMapBufferRange */
    epoxy_glMapBufferRangeEXT_dispatch_table_rewrite_ptr, /* glMapBufferRangeEXT */
    epoxy_glMapControlPointsNV_dispatch_table_rewrite_ptr, /* glMapControlPointsNV */
    epoxy_glMapGrid1d_dispatch_table_rewrite_ptr, /* glMapGrid1d */
    epoxy_glMapGrid1f_dispatch_table_rewrite_ptr, /* glMapGrid1f */
    epoxy_glMapGrid1xOES_dispatch_table_rewrite_ptr, /* glMapGrid1xOES */
    epoxy_glMapGrid2d_dispatch_table_rewrite_ptr, /* glMapGrid2d */
    epoxy_glMapGrid2f_dispatch_table_rewrite_ptr, /* glMapGrid2f */
    epoxy_glMapGrid2xOES_dispatch_table_rewrite_ptr, /* glMapGrid2xOES */
    epoxy_glMapNamedBuffer_dispatch_table_rewrite_ptr, /* glMapNamedBuffer */
    epoxy_glMapNamedBufferEXT_dispatch_table_rewrite_ptr, /* glMapNamedBufferEXT */
    epoxy_glMapNamedBufferRange_dispatch_table_rewrite_ptr, /* glMapNamedBufferRange */
    epoxy_glMapNamedBufferRangeEXT_dispatch_table_rewrite_ptr, /* glMapNamedBufferRangeEXT */
    epoxy_glMapObjectBufferATI_dispatch_table_rewrite_ptr, /* glMapObjectBufferATI */
    epoxy_glMapParameterfvNV_dispatch_table_rewrite_ptr, /* glMapParameterfvNV */
    epoxy_glMapParameterivNV_dispatch_table_rewrite_ptr, /* glMapParameterivNV */
    epoxy_glMapTexture2DINTEL_dispatch_table_rewrite_ptr, /* glMapTexture2DINTEL */
    epoxy_glMapVertexAttrib1dAPPLE_dispatch_table_rewrite_ptr, /* glMapVertexAttrib1dAPPLE */
    epoxy_glMapVertexAttrib1fAPPLE_dispatch_table_rewrite_ptr, /* glMapVertexAttrib1fAPPLE */
    epoxy_glMapVertexAttrib2dAPPLE_dispatch_table_rewrite_ptr, /* glMapVertexAttrib2dAPPLE */
    epoxy_glMapVertexAttrib2fAPPLE_dispatch_table_rewrite_ptr, /* glMapVertexAttrib2fAPPLE */
    epoxy_glMaterialf_dispatch_table_rewrite_ptr, /* glMaterialf */
    epoxy_glMaterialfv_dispatch_table_rewrite_ptr, /* glMaterialfv */
    epoxy_glMateriali_dispatch_table_rewrite_ptr, /* glMateriali */
    epoxy_glMaterialiv_dispatch_table_rewrite_ptr, /* glMaterialiv */
    epoxy_glMaterialx_dispatch_table_rewrite_ptr, /* glMaterialx */
    epoxy_glMaterialxOES_dispatch_table_rewrite_ptr, /* glMaterialxOES */
    epoxy_glMaterialxv_dispatch_table_rewrite_ptr, /* glMaterialxv */
    epoxy_glMaterialxvOES_dispatch_table_rewrite_ptr, /* glMaterialxvOES */
    epoxy_glMatrixFrustumEXT_dispatch_table_rewrite_ptr, /* glMatrixFrustumEXT */
    epoxy_glMatrixIndexPointerARB_dispatch_table_rewrite_ptr, /* glMatrixIndexPointerARB */
    epoxy_glMatrixIndexPointerOES_dispatch_table_rewrite_ptr, /* glMatrixIndexPointerOES */
    epoxy_glMatrixIndexubvARB_dispatch_table_rewrite_ptr, /* glMatrixIndexubvARB */
    epoxy_glMatrixIndexuivARB_dispatch_table_rewrite_ptr, /* glMatrixIndexuivARB */
    epoxy_glMatrixIndexusvARB_dispatch_table_rewrite_ptr, /* glMatrixIndexusvARB */
    epoxy_glMatrixLoad3x2fNV_dispatch_table_rewrite_ptr, /* glMatrixLoad3x2fNV */
    epoxy_glMatrixLoad3x3fNV_dispatch_table_rewrite_ptr, /* glMatrixLoad3x3fNV */
    epoxy_glMatrixLoadIdentityEXT_dispatch_table_rewrite_ptr, /* glMatrixLoadIdentityEXT */
    epoxy_glMatrixLoadTranspose3x3fNV_dispatch_table_rewrite_ptr, /* glMatrixLoadTranspose3x3fNV */
    epoxy_glMatrixLoadTransposedEXT_dispatch_table_rewrite_ptr, /* glMatrixLoadTransposedEXT */
    epoxy_glMatrixLoadTransposefEXT_dispatch_table_rewrite_ptr, /* glMatrixLoadTransposefEXT */
    epoxy_glMatrixLoaddEXT_dispatch_table_rewrite_ptr, /* glMatrixLoaddEXT */
    epoxy_glMatrixLoadfEXT_dispatch_table_rewrite_ptr, /* glMatrixLoadfEXT */
    epoxy_glMatrixMode_dispatch_table_rewrite_ptr, /* glMatrixMode */
    epoxy_glMatrixMult3x2fNV_dispatch_table_rewrite_ptr, /* glMatrixMult3x2fNV */
    epoxy_glMatrixMult3x3fNV_dispatch_table_rewrite_ptr, /* glMatrixMult3x3fNV */
    epoxy_glMatrixMultTranspose3x3fNV_dispatch_table_rewrite_ptr, /* glMatrixMultTranspose3x3fNV */
    epoxy_glMatrixMultTransposedEXT_dispatch_table_rewrite_ptr, /* glMatrixMultTransposedEXT */
    epoxy_glMatrixMultTransposefEXT_dispatch_table_rewrite_ptr, /* glMatrixMultTransposefEXT */
    epoxy_glMatrixMultdEXT_dispatch_table_rewrite_ptr, /* glMatrixMultdEXT */
    epoxy_glMatrixMultfEXT_dispatch_table_rewrite_ptr, /* glMatrixMultfEXT */
    epoxy_glMatrixOrthoEXT_dispatch_table_rewrite_ptr, /* glMatrixOrthoEXT */
    epoxy_glMatrixPopEXT_dispatch_table_rewrite_ptr, /* glMatrixPopEXT */
    epoxy_glMatrixPushEXT_dispatch_table_rewrite_ptr, /* glMatrixPushEXT */
    epoxy_glMatrixRotatedEXT_dispatch_table_rewrite_ptr, /* glMatrixRotatedEXT */
    epoxy_glMatrixRotatefEXT_dispatch_table_rewrite_ptr, /* glMatrixRotatefEXT */
    epoxy_glMatrixScaledEXT_dispatch_table_rewrite_ptr, /* glMatrixScaledEXT */
    epoxy_glMatrixScalefEXT_dispatch_table_rewrite_ptr, /* glMatrixScalefEXT */
    epoxy_glMatrixTranslatedEXT_dispatch_table_rewrite_ptr, /* glMatrixTranslatedEXT */
    epoxy_glMatrixTranslatefEXT_dispatch_table_rewrite_ptr, /* glMatrixTranslatefEXT */
    epoxy_glMaxShaderCompilerThreadsARB_dispatch_table_rewrite_ptr, /* glMaxShaderCompilerThreadsARB */
    epoxy_glMaxShaderCompilerThreadsKHR_dispatch_table_rewrite_ptr, /* glMaxShaderCompilerThreadsKHR */
    epoxy_glMemoryBarrier_dispatch_table_rewrite_ptr, /* glMemoryBarrier */
    epoxy_glMemoryBarrierByRegion_dispatch_table_rewrite_ptr, /* glMemoryBarrierByRegion */
    epoxy_glMemoryBarrierEXT_dispatch_table_rewrite_ptr, /* glMemoryBarrierEXT */
    epoxy_glMemoryObjectParameterivEXT_dispatch_table_rewrite_ptr, /* glMemoryObjectParameterivEXT */
    epoxy_glMinSampleShading_dispatch_table_rewrite_ptr, /* glMinSampleShading */
    epoxy_glMinSampleShadingARB_dispatch_table_rewrite_ptr, /* glMinSampleShadingARB */
    epoxy_glMinSampleShadingOES_dispatch_table_rewrite_ptr, /* glMinSampleShadingOES */
    epoxy_glMinmax_dispatch_table_rewrite_ptr, /* glMinmax */
    epoxy_glMinmaxEXT_dispatch_table_rewrite_ptr, /* glMinmaxEXT */
    epoxy_glMultMatrixd_dispatch_table_rewrite_ptr, /* glMultMatrixd */
    epoxy_glMultMatrixf_dispatch_table_rewrite_ptr, /* glMultMatrixf */
    epoxy_glMultMatrixx_dispatch_table_rewrite_ptr, /* glMultMatrixx */
    epoxy_glMultMatrixxOES_dispatch_table_rewrite_ptr, /* glMultMatrixxOES */
    epoxy_glMultTransposeMatrixd_dispatch_table_rewrite_ptr, /* glMultTransposeMatrixd */
    epoxy_glMultTransposeMatrixdARB_dispatch_table_rewrite_ptr, /* glMultTransposeMatrixdARB */
    epoxy_glMultTransposeMatrixf_dispatch_table_rewrite_ptr, /* glMultTransposeMatrixf */
    epoxy_glMultTransposeMatrixfARB_dispatch_table_rewrite_ptr, /* glMultTransposeMatrixfARB */
    epoxy_glMultTransposeMatrixxOES_dispatch_table_rewrite_ptr, /* glMultTransposeMatrixxOES */
    epoxy_glMultiDrawArrays_dispatch_table_rewrite_ptr, /* glMultiDrawArrays */
    epoxy_glMultiDrawArraysEXT_dispatch_table_rewrite_ptr, /* glMultiDrawArraysEXT */
    epoxy_glMultiDrawArraysIndirect_dispatch_table_rewrite_ptr, /* glMultiDrawArraysIndirect */
    epoxy_glMultiDrawArraysIndirectAMD_dispatch_table_rewrite_ptr, /* glMultiDrawArraysIndirectAMD */
    epoxy_glMultiDrawArraysIndirectBindlessCountNV_dispatch_table_rewrite_ptr, /* glMultiDrawArraysIndirectBindlessCountNV */
    epoxy_glMultiDrawArraysIndirectBindlessNV_dispatch_table_rewrite_ptr, /* glMultiDrawArraysIndirectBindlessNV */
    epoxy_glMultiDrawArraysIndirectCount_dispatch_table_rewrite_ptr, /* glMultiDrawArraysIndirectCount */
    epoxy_glMultiDrawArraysIndirectCountARB_dispatch_table_rewrite_ptr, /* glMultiDrawArraysIndirectCountARB */
    epoxy_glMultiDrawArraysIndirectEXT_dispatch_table_rewrite_ptr, /* glMultiDrawArraysIndirectEXT */
    epoxy_glMultiDrawElementArrayAPPLE_dispatch_table_rewrite_ptr, /* glMultiDrawElementArrayAPPLE */
    epoxy_glMultiDrawElements_dispatch_table_rewrite_ptr, /* glMultiDrawElements */
    epoxy_glMultiDrawElementsBaseVertex_dispatch_table_rewrite_ptr, /* glMultiDrawElementsBaseVertex */
    epoxy_glMultiDrawElementsBaseVertexEXT_dispatch_table_rewrite_ptr, /* glMultiDrawElementsBaseVertexEXT */
    epoxy_glMultiDrawElementsEXT_dispatch_table_rewrite_ptr, /* glMultiDrawElementsEXT */
    epoxy_glMultiDrawElementsIndirect_dispatch_table_rewrite_ptr, /* glMultiDrawElementsIndirect */
    epoxy_glMultiDrawElementsIndirectAMD_dispatch_table_rewrite_ptr, /* glMultiDrawElementsIndirectAMD */
    epoxy_glMultiDrawElementsIndirectBindlessCountNV_dispatch_table_rewrite_ptr, /* glMultiDrawElementsIndirectBindlessCountNV */
    epoxy_glMultiDrawElementsIndirectBindlessNV_dispatch_table_rewrite_ptr, /* glMultiDrawElementsIndirectBindlessNV */
    epoxy_glMultiDrawElementsIndirectCount_dispatch_table_rewrite_ptr, /* glMultiDrawElementsIndirectCount */
    epoxy_glMultiDrawElementsIndirectCountARB_dispatch_table_rewrite_ptr, /* glMultiDrawElementsIndirectCountARB */
    epoxy_glMultiDrawElementsIndirectEXT_dispatch_table_rewrite_ptr, /* glMultiDrawElementsIndirectEXT */
    epoxy_glMultiDrawMeshTasksIndirectCountNV_dispatch_table_rewrite_ptr, /* glMultiDrawMeshTasksIndirectCountNV */
    epoxy_glMultiDrawMeshTasksIndirectNV_dispatch_table_rewrite_ptr, /* glMultiDrawMeshTasksIndirectNV */
    epoxy_glMultiDrawRangeElementArrayAPPLE_dispatch_table_rewrite_ptr, /* glMultiDrawRangeElementArrayAPPLE */
    epoxy_glMultiModeDrawArraysIBM_dispatch_table_rewrite_ptr, /* glMultiModeDrawArraysIBM */
    epoxy_glMultiModeDrawElementsIBM_dispatch_table_rewrite_ptr, /* glMultiModeDrawElementsIBM */
    epoxy_glMultiTexBufferEXT_dispatch_table_rewrite_ptr, /* glMultiTexBufferEXT */
    epoxy_glMultiTexCoord1bOES_dispatch_table_rewrite_ptr, /* glMultiTexCoord1bOES */
    epoxy_glMultiTexCoord1bvOES_dispatch_table_rewrite_ptr, /* glMultiTexCoord1bvOES */
    epoxy_glMultiTexCoord1d_dispatch_table_rewrite_ptr, /* glMultiTexCoord1d */
    epoxy_glMultiTexCoord1dARB_dispatch_table_rewrite_ptr, /* glMultiTexCoord1dARB */
    epoxy_glMultiTexCoord1dv_dispatch_table_rewrite_ptr, /* glMultiTexCoord1dv */
    epoxy_glMultiTexCoord1dvARB_dispatch_table_rewrite_ptr, /* glMultiTexCoord1dvARB */
    epoxy_glMultiTexCoord1f_dispatch_table_rewrite_ptr, /* glMultiTexCoord1f */
    epoxy_glMultiTexCoord1fARB_dispatch_table_rewrite_ptr, /* glMultiTexCoord1fARB */
    epoxy_glMultiTexCoord1fv_dispatch_table_rewrite_ptr, /* glMultiTexCoord1fv */
    epoxy_glMultiTexCoord1fvARB_dispatch_table_rewrite_ptr, /* glMultiTexCoord1fvARB */
    epoxy_glMultiTexCoord1hNV_dispatch_table_rewrite_ptr, /* glMultiTexCoord1hNV */
    epoxy_glMultiTexCoord1hvNV_dispatch_table_rewrite_ptr, /* glMultiTexCoord1hvNV */
    epoxy_glMultiTexCoord1i_dispatch_table_rewrite_ptr, /* glMultiTexCoord1i */
    epoxy_glMultiTexCoord1iARB_dispatch_table_rewrite_ptr, /* glMultiTexCoord1iARB */
    epoxy_glMultiTexCoord1iv_dispatch_table_rewrite_ptr, /* glMultiTexCoord1iv */
    epoxy_glMultiTexCoord1ivARB_dispatch_table_rewrite_ptr, /* glMultiTexCoord1ivARB */
    epoxy_glMultiTexCoord1s_dispatch_table_rewrite_ptr, /* glMultiTexCoord1s */
    epoxy_glMultiTexCoord1sARB_dispatch_table_rewrite_ptr, /* glMultiTexCoord1sARB */
    epoxy_glMultiTexCoord1sv_dispatch_table_rewrite_ptr, /* glMultiTexCoord1sv */
    epoxy_glMultiTexCoord1svARB_dispatch_table_rewrite_ptr, /* glMultiTexCoord1svARB */
    epoxy_glMultiTexCoord1xOES_dispatch_table_rewrite_ptr, /* glMultiTexCoord1xOES */
    epoxy_glMultiTexCoord1xvOES_dispatch_table_rewrite_ptr, /* glMultiTexCoord1xvOES */
    epoxy_glMultiTexCoord2bOES_dispatch_table_rewrite_ptr, /* glMultiTexCoord2bOES */
    epoxy_glMultiTexCoord2bvOES_dispatch_table_rewrite_ptr, /* glMultiTexCoord2bvOES */
    epoxy_glMultiTexCoord2d_dispatch_table_rewrite_ptr, /* glMultiTexCoord2d */
    epoxy_glMultiTexCoord2dARB_dispatch_table_rewrite_ptr, /* glMultiTexCoord2dARB */
    epoxy_glMultiTexCoord2dv_dispatch_table_rewrite_ptr, /* glMultiTexCoord2dv */
    epoxy_glMultiTexCoord2dvARB_dispatch_table_rewrite_ptr, /* glMultiTexCoord2dvARB */
    epoxy_glMultiTexCoord2f_dispatch_table_rewrite_ptr, /* glMultiTexCoord2f */
    epoxy_glMultiTexCoord2fARB_dispatch_table_rewrite_ptr, /* glMultiTexCoord2fARB */
    epoxy_glMultiTexCoord2fv_dispatch_table_rewrite_ptr, /* glMultiTexCoord2fv */
    epoxy_glMultiTexCoord2fvARB_dispatch_table_rewrite_ptr, /* glMultiTexCoord2fvARB */
    epoxy_glMultiTexCoord2hNV_dispatch_table_rewrite_ptr, /* glMultiTexCoord2hNV */
    epoxy_glMultiTexCoord2hvNV_dispatch_table_rewrite_ptr, /* glMultiTexCoord2hvNV */
    epoxy_glMultiTexCoord2i_dispatch_table_rewrite_ptr, /* glMultiTexCoord2i */
    epoxy_glMultiTexCoord2iARB_dispatch_table_rewrite_ptr, /* glMultiTexCoord2iARB */
    epoxy_glMultiTexCoord2iv_dispatch_table_rewrite_ptr, /* glMultiTexCoord2iv */
    epoxy_glMultiTexCoord2ivARB_dispatch_table_rewrite_ptr, /* glMultiTexCoord2ivARB */
    epoxy_glMultiTexCoord2s_dispatch_table_rewrite_ptr, /* glMultiTexCoord2s */
    epoxy_glMultiTexCoord2sARB_dispatch_table_rewrite_ptr, /* glMultiTexCoord2sARB */
    epoxy_glMultiTexCoord2sv_dispatch_table_rewrite_ptr, /* glMultiTexCoord2sv */
    epoxy_glMultiTexCoord2svARB_dispatch_table_rewrite_ptr, /* glMultiTexCoord2svARB */
    epoxy_glMultiTexCoord2xOES_dispatch_table_rewrite_ptr, /* glMultiTexCoord2xOES */
    epoxy_glMultiTexCoord2xvOES_dispatch_table_rewrite_ptr, /* glMultiTexCoord2xvOES */
    epoxy_glMultiTexCoord3bOES_dispatch_table_rewrite_ptr, /* glMultiTexCoord3bOES */
    epoxy_glMultiTexCoord3bvOES_dispatch_table_rewrite_ptr, /* glMultiTexCoord3bvOES */
    epoxy_glMultiTexCoord3d_dispatch_table_rewrite_ptr, /* glMultiTexCoord3d */
    epoxy_glMultiTexCoord3dARB_dispatch_table_rewrite_ptr, /* glMultiTexCoord3dARB */
    epoxy_glMultiTexCoord3dv_dispatch_table_rewrite_ptr, /* glMultiTexCoord3dv */
    epoxy_glMultiTexCoord3dvARB_dispatch_table_rewrite_ptr, /* glMultiTexCoord3dvARB */
    epoxy_glMultiTexCoord3f_dispatch_table_rewrite_ptr, /* glMultiTexCoord3f */
    epoxy_glMultiTexCoord3fARB_dispatch_table_rewrite_ptr, /* glMultiTexCoord3fARB */
    epoxy_glMultiTexCoord3fv_dispatch_table_rewrite_ptr, /* glMultiTexCoord3fv */
    epoxy_glMultiTexCoord3fvARB_dispatch_table_rewrite_ptr, /* glMultiTexCoord3fvARB */
    epoxy_glMultiTexCoord3hNV_dispatch_table_rewrite_ptr, /* glMultiTexCoord3hNV */
    epoxy_glMultiTexCoord3hvNV_dispatch_table_rewrite_ptr, /* glMultiTexCoord3hvNV */
    epoxy_glMultiTexCoord3i_dispatch_table_rewrite_ptr, /* glMultiTexCoord3i */
    epoxy_glMultiTexCoord3iARB_dispatch_table_rewrite_ptr, /* glMultiTexCoord3iARB */
    epoxy_glMultiTexCoord3iv_dispatch_table_rewrite_ptr, /* glMultiTexCoord3iv */
    epoxy_glMultiTexCoord3ivARB_dispatch_table_rewrite_ptr, /* glMultiTexCoord3ivARB */
    epoxy_glMultiTexCoord3s_dispatch_table_rewrite_ptr, /* glMultiTexCoord3s */
    epoxy_glMultiTexCoord3sARB_dispatch_table_rewrite_ptr, /* glMultiTexCoord3sARB */
    epoxy_glMultiTexCoord3sv_dispatch_table_rewrite_ptr, /* glMultiTexCoord3sv */
    epoxy_glMultiTexCoord3svARB_dispatch_table_rewrite_ptr, /* glMultiTexCoord3svARB */
    epoxy_glMultiTexCoord3xOES_dispatch_table_rewrite_ptr, /* glMultiTexCoord3xOES */
    epoxy_glMultiTexCoord3xvOES_dispatch_table_rewrite_ptr, /* glMultiTexCoord3xvOES */
    epoxy_glMultiTexCoord4bOES_dispatch_table_rewrite_ptr, /* glMultiTexCoord4bOES */
    epoxy_glMultiTexCoord4bvOES_dispatch_table_rewrite_ptr, /* glMultiTexCoord4bvOES */
    epoxy_glMultiTexCoord4d_dispatch_table_rewrite_ptr, /* glMultiTexCoord4d */
    epoxy_glMultiTexCoord4dARB_dispatch_table_rewrite_ptr, /* glMultiTexCoord4dARB */
    epoxy_glMultiTexCoord4dv_dispatch_table_rewrite_ptr, /* glMultiTexCoord4dv */
    epoxy_glMultiTexCoord4dvARB_dispatch_table_rewrite_ptr, /* glMultiTexCoord4dvARB */
    epoxy_glMultiTexCoord4f_dispatch_table_rewrite_ptr, /* glMultiTexCoord4f */
    epoxy_glMultiTexCoord4fARB_dispatch_table_rewrite_ptr, /* glMultiTexCoord4fARB */
    epoxy_glMultiTexCoord4fv_dispatch_table_rewrite_ptr, /* glMultiTexCoord4fv */
    epoxy_glMultiTexCoord4fvARB_dispatch_table_rewrite_ptr, /* glMultiTexCoord4fvARB */
    epoxy_glMultiTexCoord4hNV_dispatch_table_rewrite_ptr, /* glMultiTexCoord4hNV */
    epoxy_glMultiTexCoord4hvNV_dispatch_table_rewrite_ptr, /* glMultiTexCoord4hvNV */
    epoxy_glMultiTexCoord4i_dispatch_table_rewrite_ptr, /* glMultiTexCoord4i */
    epoxy_glMultiTexCoord4iARB_dispatch_table_rewrite_ptr, /* glMultiTexCoord4iARB */
    epoxy_glMultiTexCoord4iv_dispatch_table_rewrite_ptr, /* glMultiTexCoord4iv */
    epoxy_glMultiTexCoord4ivARB_dispatch_table_rewrite_ptr, /* glMultiTexCoord4ivARB */
    epoxy_glMultiTexCoord4s_dispatch_table_rewrite_ptr, /* glMultiTexCoord4s */
    epoxy_glMultiTexCoord4sARB_dispatch_table_rewrite_ptr, /* glMultiTexCoord4sARB */
    epoxy_glMultiTexCoord4sv_dispatch_table_rewrite_ptr, /* glMultiTexCoord4sv */
    epoxy_glMultiTexCoord4svARB_dispatch_table_rewrite_ptr, /* glMultiTexCoord4svARB */
    epoxy_glMultiTexCoord4x_dispatch_table_rewrite_ptr, /* glMultiTexCoord4x */
    epoxy_glMultiTexCoord4xOES_dispatch_table_rewrite_ptr, /* glMultiTexCoord4xOES */
    epoxy_glMultiTexCoord4xvOES_dispatch_table_rewrite_ptr, /* glMultiTexCoord4xvOES */
    epoxy_glMultiTexCoordP1ui_dispatch_table_rewrite_ptr, /* glMultiTexCoordP1ui */
    epoxy_glMultiTexCoordP1uiv_dispatch_table_rewrite_ptr, /* glMultiTexCoordP1uiv */
    epoxy_glMultiTexCoordP2ui_dispatch_table_rewrite_ptr, /* glMultiTexCoordP2ui */
    epoxy_glMultiTexCoordP2uiv_dispatch_table_rewrite_ptr, /* glMultiTexCoordP2uiv */
    epoxy_glMultiTexCoordP3ui_dispatch_table_rewrite_ptr, /* glMultiTexCoordP3ui */
    epoxy_glMultiTexCoordP3uiv_dispatch_table_rewrite_ptr, /* glMultiTexCoordP3uiv */
    epoxy_glMultiTexCoordP4ui_dispatch_table_rewrite_ptr, /* glMultiTexCoordP4ui */
    epoxy_glMultiTexCoordP4uiv_dispatch_table_rewrite_ptr, /* glMultiTexCoordP4uiv */
    epoxy_glMultiTexCoordPointerEXT_dispatch_table_rewrite_ptr, /* glMultiTexCoordPointerEXT */
    epoxy_glMultiTexEnvfEXT_dispatch_table_rewrite_ptr, /* glMultiTexEnvfEXT */
    epoxy_glMultiTexEnvfvEXT_dispatch_table_rewrite_ptr, /* glMultiTexEnvfvEXT */
    epoxy_glMultiTexEnviEXT_dispatch_table_rewrite_ptr, /* glMultiTexEnviEXT */
    epoxy_glMultiTexEnvivEXT_dispatch_table_rewrite_ptr, /* glMultiTexEnvivEXT */
    epoxy_glMultiTexGendEXT_dispatch_table_rewrite_ptr, /* glMultiTexGendEXT */
    epoxy_glMultiTexGendvEXT_dispatch_table_rewrite_ptr, /* glMultiTexGendvEXT */
    epoxy_glMultiTexGenfEXT_dispatch_table_rewrite_ptr, /* glMultiTexGenfEXT */
    epoxy_glMultiTexGenfvEXT_dispatch_table_rewrite_ptr, /* glMultiTexGenfvEXT */
    epoxy_glMultiTexGeniEXT_dispatch_table_rewrite_ptr, /* glMultiTexGeniEXT */
    epoxy_glMultiTexGenivEXT_dispatch_table_rewrite_ptr, /* glMultiTexGenivEXT */
    epoxy_glMultiTexImage1DEXT_dispatch_table_rewrite_ptr, /* glMultiTexImage1DEXT */
    epoxy_glMultiTexImage2DEXT_dispatch_table_rewrite_ptr, /* glMultiTexImage2DEXT */
    epoxy_glMultiTexImage3DEXT_dispatch_table_rewrite_ptr, /* glMultiTexImage3DEXT */
    epoxy_glMultiTexParameterIivEXT_dispatch_table_rewrite_ptr, /* glMultiTexParameterIivEXT */
    epoxy_glMultiTexParameterIuivEXT_dispatch_table_rewrite_ptr, /* glMultiTexParameterIuivEXT */
    epoxy_glMultiTexParameterfEXT_dispatch_table_rewrite_ptr, /* glMultiTexParameterfEXT */
    epoxy_glMultiTexParameterfvEXT_dispatch_table_rewrite_ptr, /* glMultiTexParameterfvEXT */
    epoxy_glMultiTexParameteriEXT_dispatch_table_rewrite_ptr, /* glMultiTexParameteriEXT */
    epoxy_glMultiTexParameterivEXT_dispatch_table_rewrite_ptr, /* glMultiTexParameterivEXT */
    epoxy_glMultiTexRenderbufferEXT_dispatch_table_rewrite_ptr, /* glMultiTexRenderbufferEXT */
    epoxy_glMultiTexSubImage1DEXT_dispatch_table_rewrite_ptr, /* glMultiTexSubImage1DEXT */
    epoxy_glMultiTexSubImage2DEXT_dispatch_table_rewrite_ptr, /* glMultiTexSubImage2DEXT */
    epoxy_glMultiTexSubImage3DEXT_dispatch_table_rewrite_ptr, /* glMultiTexSubImage3DEXT */
    epoxy_glMulticastBarrierNV_dispatch_table_rewrite_ptr, /* glMulticastBarrierNV */
    epoxy_glMulticastBlitFramebufferNV_dispatch_table_rewrite_ptr, /* glMulticastBlitFramebufferNV */
    epoxy_glMulticastBufferSubDataNV_dispatch_table_rewrite_ptr, /* glMulticastBufferSubDataNV */
    epoxy_glMulticastCopyBufferSubDataNV_dispatch_table_rewrite_ptr, /* glMulticastCopyBufferSubDataNV */
    epoxy_glMulticastCopyImageSubDataNV_dispatch_table_rewrite_ptr, /* glMulticastCopyImageSubDataNV */
    epoxy_glMulticastFramebufferSampleLocationsfvNV_dispatch_table_rewrite_ptr, /* glMulticastFramebufferSampleLocationsfvNV */
    epoxy_glMulticastGetQueryObjecti64vNV_dispatch_table_rewrite_ptr, /* glMulticastGetQueryObjecti64vNV */
    epoxy_glMulticastGetQueryObjectivNV_dispatch_table_rewrite_ptr, /* glMulticastGetQueryObjectivNV */
    epoxy_glMulticastGetQueryObjectui64vNV_dispatch_table_rewrite_ptr, /* glMulticastGetQueryObjectui64vNV */
    epoxy_glMulticastGetQueryObjectuivNV_dispatch_table_rewrite_ptr, /* glMulticastGetQueryObjectuivNV */
    epoxy_glMulticastScissorArrayvNVX_dispatch_table_rewrite_ptr, /* glMulticastScissorArrayvNVX */
    epoxy_glMulticastViewportArrayvNVX_dispatch_table_rewrite_ptr, /* glMulticastViewportArrayvNVX */
    epoxy_glMulticastViewportPositionWScaleNVX_dispatch_table_rewrite_ptr, /* glMulticastViewportPositionWScaleNVX */
    epoxy_glMulticastWaitSyncNV_dispatch_table_rewrite_ptr, /* glMulticastWaitSyncNV */
    epoxy_glNamedBufferAttachMemoryNV_dispatch_table_rewrite_ptr, /* glNamedBufferAttachMemoryNV */
    epoxy_glNamedBufferData_dispatch_table_rewrite_ptr, /* glNamedBufferData */
    epoxy_glNamedBufferDataEXT_dispatch_table_rewrite_ptr, /* glNamedBufferDataEXT */
    epoxy_glNamedBufferPageCommitmentARB_dispatch_table_rewrite_ptr, /* glNamedBufferPageCommitmentARB */
    epoxy_glNamedBufferPageCommitmentEXT_dispatch_table_rewrite_ptr, /* glNamedBufferPageCommitmentEXT */
    epoxy_glNamedBufferStorage_dispatch_table_rewrite_ptr, /* glNamedBufferStorage */
    epoxy_glNamedBufferStorageEXT_dispatch_table_rewrite_ptr, /* glNamedBufferStorageEXT */
    epoxy_glNamedBufferStorageExternalEXT_dispatch_table_rewrite_ptr, /* glNamedBufferStorageExternalEXT */
    epoxy_glNamedBufferStorageMemEXT_dispatch_table_rewrite_ptr, /* glNamedBufferStorageMemEXT */
    epoxy_glNamedBufferSubData_dispatch_table_rewrite_ptr, /* glNamedBufferSubData */
    epoxy_glNamedBufferSubDataEXT_dispatch_table_rewrite_ptr, /* glNamedBufferSubDataEXT */
    epoxy_glNamedCopyBufferSubDataEXT_dispatch_table_rewrite_ptr, /* glNamedCopyBufferSubDataEXT */
    epoxy_glNamedFramebufferDrawBuffer_dispatch_table_rewrite_ptr, /* glNamedFramebufferDrawBuffer */
    epoxy_glNamedFramebufferDrawBuffers_dispatch_table_rewrite_ptr, /* glNamedFramebufferDrawBuffers */
    epoxy_glNamedFramebufferParameteri_dispatch_table_rewrite_ptr, /* glNamedFramebufferParameteri */
    epoxy_glNamedFramebufferParameteriEXT_dispatch_table_rewrite_ptr, /* glNamedFramebufferParameteriEXT */
    epoxy_glNamedFramebufferReadBuffer_dispatch_table_rewrite_ptr, /* glNamedFramebufferReadBuffer */
    epoxy_glNamedFramebufferRenderbuffer_dispatch_table_rewrite_ptr, /* glNamedFramebufferRenderbuffer */
    epoxy_glNamedFramebufferRenderbufferEXT_dispatch_table_rewrite_ptr, /* glNamedFramebufferRenderbufferEXT */
    epoxy_glNamedFramebufferSampleLocationsfvARB_dispatch_table_rewrite_ptr, /* glNamedFramebufferSampleLocationsfvARB */
    epoxy_glNamedFramebufferSampleLocationsfvNV_dispatch_table_rewrite_ptr, /* glNamedFramebufferSampleLocationsfvNV */
    epoxy_glNamedFramebufferSamplePositionsfvAMD_dispatch_table_rewrite_ptr, /* glNamedFramebufferSamplePositionsfvAMD */
    epoxy_glNamedFramebufferTexture_dispatch_table_rewrite_ptr, /* glNamedFramebufferTexture */
    epoxy_glNamedFramebufferTexture1DEXT_dispatch_table_rewrite_ptr, /* glNamedFramebufferTexture1DEXT */
    epoxy_glNamedFramebufferTexture2DEXT_dispatch_table_rewrite_ptr, /* glNamedFramebufferTexture2DEXT */
    epoxy_glNamedFramebufferTexture3DEXT_dispatch_table_rewrite_ptr, /* glNamedFramebufferTexture3DEXT */
    epoxy_glNamedFramebufferTextureEXT_dispatch_table_rewrite_ptr, /* glNamedFramebufferTextureEXT */
    epoxy_glNamedFramebufferTextureFaceEXT_dispatch_table_rewrite_ptr, /* glNamedFramebufferTextureFaceEXT */
    epoxy_glNamedFramebufferTextureLayer_dispatch_table_rewrite_ptr, /* glNamedFramebufferTextureLayer */
    epoxy_glNamedFramebufferTextureLayerEXT_dispatch_table_rewrite_ptr, /* glNamedFramebufferTextureLayerEXT */
    epoxy_glNamedProgramLocalParameter4dEXT_dispatch_table_rewrite_ptr, /* glNamedProgramLocalParameter4dEXT */
    epoxy_glNamedProgramLocalParameter4dvEXT_dispatch_table_rewrite_ptr, /* glNamedProgramLocalParameter4dvEXT */
    epoxy_glNamedProgramLocalParameter4fEXT_dispatch_table_rewrite_ptr, /* glNamedProgramLocalParameter4fEXT */
    epoxy_glNamedProgramLocalParameter4fvEXT_dispatch_table_rewrite_ptr, /* glNamedProgramLocalParameter4fvEXT */
    epoxy_glNamedProgramLocalParameterI4iEXT_dispatch_table_rewrite_ptr, /* glNamedProgramLocalParameterI4iEXT */
    epoxy_glNamedProgramLocalParameterI4ivEXT_dispatch_table_rewrite_ptr, /* glNamedProgramLocalParameterI4ivEXT */
    epoxy_glNamedProgramLocalParameterI4uiEXT_dispatch_table_rewrite_ptr, /* glNamedProgramLocalParameterI4uiEXT */
    epoxy_glNamedProgramLocalParameterI4uivEXT_dispatch_table_rewrite_ptr, /* glNamedProgramLocalParameterI4uivEXT */
    epoxy_glNamedProgramLocalParameters4fvEXT_dispatch_table_rewrite_ptr, /* glNamedProgramLocalParameters4fvEXT */
    epoxy_glNamedProgramLocalParametersI4ivEXT_dispatch_table_rewrite_ptr, /* glNamedProgramLocalParametersI4ivEXT */
    epoxy_glNamedProgramLocalParametersI4uivEXT_dispatch_table_rewrite_ptr, /* glNamedProgramLocalParametersI4uivEXT */
    epoxy_glNamedProgramStringEXT_dispatch_table_rewrite_ptr, /* glNamedProgramStringEXT */
    epoxy_glNamedRenderbufferStorage_dispatch_table_rewrite_ptr, /* glNamedRenderbufferStorage */
    epoxy_glNamedRenderbufferStorageEXT_dispatch_table_rewrite_ptr, /* glNamedRenderbufferStorageEXT */
    epoxy_glNamedRenderbufferStorageMultisample_dispatch_table_rewrite_ptr, /* glNamedRenderbufferStorageMultisample */
    epoxy_glNamedRenderbufferStorageMultisampleAdvancedAMD_dispatch_table_rewrite_ptr, /* glNamedRenderbufferStorageMultisampleAdvancedAMD */
    epoxy_glNamedRenderbufferStorageMultisampleCoverageEXT_dispatch_table_rewrite_ptr, /* glNamedRenderbufferStorageMultisampleCoverageEXT */
    epoxy_glNamedRenderbufferStorageMultisampleEXT_dispatch_table_rewrite_ptr, /* glNamedRenderbufferStorageMultisampleEXT */
    epoxy_glNamedStringARB_dispatch_table_rewrite_ptr, /* glNamedStringARB */
    epoxy_glNewList_dispatch_table_rewrite_ptr, /* glNewList */
    epoxy_glNewObjectBufferATI_dispatch_table_rewrite_ptr, /* glNewObjectBufferATI */
    epoxy_glNormal3b_dispatch_table_rewrite_ptr, /* glNormal3b */
    epoxy_glNormal3bv_dispatch_table_rewrite_ptr, /* glNormal3bv */
    epoxy_glNormal3d_dispatch_table_rewrite_ptr, /* glNormal3d */
    epoxy_glNormal3dv_dispatch_table_rewrite_ptr, /* glNormal3dv */
    epoxy_glNormal3f_dispatch_table_rewrite_ptr, /* glNormal3f */
    epoxy_glNormal3fVertex3fSUN_dispatch_table_rewrite_ptr, /* glNormal3fVertex3fSUN */
    epoxy_glNormal3fVertex3fvSUN_dispatch_table_rewrite_ptr, /* glNormal3fVertex3fvSUN */
    epoxy_glNormal3fv_dispatch_table_rewrite_ptr, /* glNormal3fv */
    epoxy_glNormal3hNV_dispatch_table_rewrite_ptr, /* glNormal3hNV */
    epoxy_glNormal3hvNV_dispatch_table_rewrite_ptr, /* glNormal3hvNV */
    epoxy_glNormal3i_dispatch_table_rewrite_ptr, /* glNormal3i */
    epoxy_glNormal3iv_dispatch_table_rewrite_ptr, /* glNormal3iv */
    epoxy_glNormal3s_dispatch_table_rewrite_ptr, /* glNormal3s */
    epoxy_glNormal3sv_dispatch_table_rewrite_ptr, /* glNormal3sv */
    epoxy_glNormal3x_dispatch_table_rewrite_ptr, /* glNormal3x */
    epoxy_glNormal3xOES_dispatch_table_rewrite_ptr, /* glNormal3xOES */
    epoxy_glNormal3xvOES_dispatch_table_rewrite_ptr, /* glNormal3xvOES */
    epoxy_glNormalFormatNV_dispatch_table_rewrite_ptr, /* glNormalFormatNV */
    epoxy_glNormalP3ui_dispatch_table_rewrite_ptr, /* glNormalP3ui */
    epoxy_glNormalP3uiv_dispatch_table_rewrite_ptr, /* glNormalP3uiv */
    epoxy_glNormalPointer_dispatch_table_rewrite_ptr, /* glNormalPointer */
    epoxy_glNormalPointerEXT_dispatch_table_rewrite_ptr, /* glNormalPointerEXT */
    epoxy_glNormalPointerListIBM_dispatch_table_rewrite_ptr, /* glNormalPointerListIBM */
    epoxy_glNormalPointervINTEL_dispatch_table_rewrite_ptr, /* glNormalPointervINTEL */
    epoxy_glNormalStream3bATI_dispatch_table_rewrite_ptr, /* glNormalStream3bATI */
    epoxy_glNormalStream3bvATI_dispatch_table_rewrite_ptr, /* glNormalStream3bvATI */
    epoxy_glNormalStream3dATI_dispatch_table_rewrite_ptr, /* glNormalStream3dATI */
    epoxy_glNormalStream3dvATI_dispatch_table_rewrite_ptr, /* glNormalStream3dvATI */
    epoxy_glNormalStream3fATI_dispatch_table_rewrite_ptr, /* glNormalStream3fATI */
    epoxy_glNormalStream3fvATI_dispatch_table_rewrite_ptr, /* glNormalStream3fvATI */
    epoxy_glNormalStream3iATI_dispatch_table_rewrite_ptr, /* glNormalStream3iATI */
    epoxy_glNormalStream3ivATI_dispatch_table_rewrite_ptr, /* glNormalStream3ivATI */
    epoxy_glNormalStream3sATI_dispatch_table_rewrite_ptr, /* glNormalStream3sATI */
    epoxy_glNormalStream3svATI_dispatch_table_rewrite_ptr, /* glNormalStream3svATI */
    epoxy_glObjectLabel_dispatch_table_rewrite_ptr, /* glObjectLabel */
    epoxy_glObjectLabelKHR_dispatch_table_rewrite_ptr, /* glObjectLabelKHR */
    epoxy_glObjectPtrLabel_dispatch_table_rewrite_ptr, /* glObjectPtrLabel */
    epoxy_glObjectPtrLabelKHR_dispatch_table_rewrite_ptr, /* glObjectPtrLabelKHR */
    epoxy_glObjectPurgeableAPPLE_dispatch_table_rewrite_ptr, /* glObjectPurgeableAPPLE */
    epoxy_glObjectUnpurgeableAPPLE_dispatch_table_rewrite_ptr, /* glObjectUnpurgeableAPPLE */
    epoxy_glOrtho_dispatch_table_rewrite_ptr, /* glOrtho */
    epoxy_glOrthof_dispatch_table_rewrite_ptr, /* glOrthof */
    epoxy_glOrthofOES_dispatch_table_rewrite_ptr, /* glOrthofOES */
    epoxy_glOrthox_dispatch_table_rewrite_ptr, /* glOrthox */
    epoxy_glOrthoxOES_dispatch_table_rewrite_ptr, /* glOrthoxOES */
    epoxy_glPNTrianglesfATI_dispatch_table_rewrite_ptr, /* glPNTrianglesfATI */
    epoxy_glPNTrianglesiATI_dispatch_table_rewrite_ptr, /* glPNTrianglesiATI */
    epoxy_glPassTexCoordATI_dispatch_table_rewrite_ptr, /* glPassTexCoordATI */
    epoxy_glPassThrough_dispatch_table_rewrite_ptr, /* glPassThrough */
    epoxy_glPassThroughxOES_dispatch_table_rewrite_ptr, /* glPassThroughxOES */
    epoxy_glPatchParameterfv_dispatch_table_rewrite_ptr, /* glPatchParameterfv */
    epoxy_glPatchParameteri_dispatch_table_rewrite_ptr, /* glPatchParameteri */
    epoxy_glPatchParameteriEXT_dispatch_table_rewrite_ptr, /* glPatchParameteriEXT */
    epoxy_glPatchParameteriOES_dispatch_table_rewrite_ptr, /* glPatchParameteriOES */
    epoxy_glPathColorGenNV_dispatch_table_rewrite_ptr, /* glPathColorGenNV */
    epoxy_glPathCommandsNV_dispatch_table_rewrite_ptr, /* glPathCommandsNV */
    epoxy_glPathCoordsNV_dispatch_table_rewrite_ptr, /* glPathCoordsNV */
    epoxy_glPathCoverDepthFuncNV_dispatch_table_rewrite_ptr, /* glPathCoverDepthFuncNV */
    epoxy_glPathDashArrayNV_dispatch_table_rewrite_ptr, /* glPathDashArrayNV */
    epoxy_glPathFogGenNV_dispatch_table_rewrite_ptr, /* glPathFogGenNV */
    epoxy_glPathGlyphIndexArrayNV_dispatch_table_rewrite_ptr, /* glPathGlyphIndexArrayNV */
    epoxy_glPathGlyphIndexRangeNV_dispatch_table_rewrite_ptr, /* glPathGlyphIndexRangeNV */
    epoxy_glPathGlyphRangeNV_dispatch_table_rewrite_ptr, /* glPathGlyphRangeNV */
    epoxy_glPathGlyphsNV_dispatch_table_rewrite_ptr, /* glPathGlyphsNV */
    epoxy_glPathMemoryGlyphIndexArrayNV_dispatch_table_rewrite_ptr, /* glPathMemoryGlyphIndexArrayNV */
    epoxy_glPathParameterfNV_dispatch_table_rewrite_ptr, /* glPathParameterfNV */
    epoxy_glPathParameterfvNV_dispatch_table_rewrite_ptr, /* glPathParameterfvNV */
    epoxy_glPathParameteriNV_dispatch_table_rewrite_ptr, /* glPathParameteriNV */
    epoxy_glPathParameterivNV_dispatch_table_rewrite_ptr, /* glPathParameterivNV */
    epoxy_glPathStencilDepthOffsetNV_dispatch_table_rewrite_ptr, /* glPathStencilDepthOffsetNV */
    epoxy_glPathStencilFuncNV_dispatch_table_rewrite_ptr, /* glPathStencilFuncNV */
    epoxy_glPathStringNV_dispatch_table_rewrite_ptr, /* glPathStringNV */
    epoxy_glPathSubCommandsNV_dispatch_table_rewrite_ptr, /* glPathSubCommandsNV */
    epoxy_glPathSubCoordsNV_dispatch_table_rewrite_ptr, /* glPathSubCoordsNV */
    epoxy_glPathTexGenNV_dispatch_table_rewrite_ptr, /* glPathTexGenNV */
    epoxy_glPauseTransformFeedback_dispatch_table_rewrite_ptr, /* glPauseTransformFeedback */
    epoxy_glPauseTransformFeedbackNV_dispatch_table_rewrite_ptr, /* glPauseTransformFeedbackNV */
    epoxy_glPixelDataRangeNV_dispatch_table_rewrite_ptr, /* glPixelDataRangeNV */
    epoxy_glPixelMapfv_dispatch_table_rewrite_ptr, /* glPixelMapfv */
    epoxy_glPixelMapuiv_dispatch_table_rewrite_ptr, /* glPixelMapuiv */
    epoxy_glPixelMapusv_dispatch_table_rewrite_ptr, /* glPixelMapusv */
    epoxy_glPixelMapx_dispatch_table_rewrite_ptr, /* glPixelMapx */
    epoxy_glPixelStoref_dispatch_table_rewrite_ptr, /* glPixelStoref */
    epoxy_glPixelStorei_dispatch_table_rewrite_ptr, /* glPixelStorei */
    epoxy_glPixelStorex_dispatch_table_rewrite_ptr, /* glPixelStorex */
    epoxy_glPixelTexGenParameterfSGIS_dispatch_table_rewrite_ptr, /* glPixelTexGenParameterfSGIS */
    epoxy_glPixelTexGenParameterfvSGIS_dispatch_table_rewrite_ptr, /* glPixelTexGenParameterfvSGIS */
    epoxy_glPixelTexGenParameteriSGIS_dispatch_table_rewrite_ptr, /* glPixelTexGenParameteriSGIS */
    epoxy_glPixelTexGenParameterivSGIS_dispatch_table_rewrite_ptr, /* glPixelTexGenParameterivSGIS */
    epoxy_glPixelTexGenSGIX_dispatch_table_rewrite_ptr, /* glPixelTexGenSGIX */
    epoxy_glPixelTransferf_dispatch_table_rewrite_ptr, /* glPixelTransferf */
    epoxy_glPixelTransferi_dispatch_table_rewrite_ptr, /* glPixelTransferi */
    epoxy_glPixelTransferxOES_dispatch_table_rewrite_ptr, /* glPixelTransferxOES */
    epoxy_glPixelTransformParameterfEXT_dispatch_table_rewrite_ptr, /* glPixelTransformParameterfEXT */
    epoxy_glPixelTransformParameterfvEXT_dispatch_table_rewrite_ptr, /* glPixelTransformParameterfvEXT */
    epoxy_glPixelTransformParameteriEXT_dispatch_table_rewrite_ptr, /* glPixelTransformParameteriEXT */
    epoxy_glPixelTransformParameterivEXT_dispatch_table_rewrite_ptr, /* glPixelTransformParameterivEXT */
    epoxy_glPixelZoom_dispatch_table_rewrite_ptr, /* glPixelZoom */
    epoxy_glPixelZoomxOES_dispatch_table_rewrite_ptr, /* glPixelZoomxOES */
    epoxy_glPointAlongPathNV_dispatch_table_rewrite_ptr, /* glPointAlongPathNV */
    epoxy_glPointParameterf_dispatch_table_rewrite_ptr, /* glPointParameterf */
    epoxy_glPointParameterfARB_dispatch_table_rewrite_ptr, /* glPointParameterfARB */
    epoxy_glPointParameterfEXT_dispatch_table_rewrite_ptr, /* glPointParameterfEXT */
    epoxy_glPointParameterfSGIS_dispatch_table_rewrite_ptr, /* glPointParameterfSGIS */
    epoxy_glPointParameterfv_dispatch_table_rewrite_ptr, /* glPointParameterfv */
    epoxy_glPointParameterfvARB_dispatch_table_rewrite_ptr, /* glPointParameterfvARB */
    epoxy_glPointParameterfvEXT_dispatch_table_rewrite_ptr, /* glPointParameterfvEXT */
    epoxy_glPointParameterfvSGIS_dispatch_table_rewrite_ptr, /* glPointParameterfvSGIS */
    epoxy_glPointParameteri_dispatch_table_rewrite_ptr, /* glPointParameteri */
    epoxy_glPointParameteriNV_dispatch_table_rewrite_ptr, /* glPointParameteriNV */
    epoxy_glPointParameteriv_dispatch_table_rewrite_ptr, /* glPointParameteriv */
    epoxy_glPointParameterivNV_dispatch_table_rewrite_ptr, /* glPointParameterivNV */
    epoxy_glPointParameterx_dispatch_table_rewrite_ptr, /* glPointParameterx */
    epoxy_glPointParameterxOES_dispatch_table_rewrite_ptr, /* glPointParameterxOES */
    epoxy_glPointParameterxv_dispatch_table_rewrite_ptr, /* glPointParameterxv */
    epoxy_glPointParameterxvOES_dispatch_table_rewrite_ptr, /* glPointParameterxvOES */
    epoxy_glPointSize_dispatch_table_rewrite_ptr, /* glPointSize */
    epoxy_glPointSizePointerOES_dispatch_table_rewrite_ptr, /* glPointSizePointerOES */
    epoxy_glPointSizex_dispatch_table_rewrite_ptr, /* glPointSizex */
    epoxy_glPointSizexOES_dispatch_table_rewrite_ptr, /* glPointSizexOES */
    epoxy_glPollAsyncSGIX_dispatch_table_rewrite_ptr, /* glPollAsyncSGIX */
    epoxy_glPollInstrumentsSGIX_dispatch_table_rewrite_ptr, /* glPollInstrumentsSGIX */
    epoxy_glPolygonMode_dispatch_table_rewrite_ptr, /* glPolygonMode */
    epoxy_glPolygonModeNV_dispatch_table_rewrite_ptr, /* glPolygonModeNV */
    epoxy_glPolygonOffset_dispatch_table_rewrite_ptr, /* glPolygonOffset */
    epoxy_glPolygonOffsetClamp_dispatch_table_rewrite_ptr, /* glPolygonOffsetClamp */
    epoxy_glPolygonOffsetClampEXT_dispatch_table_rewrite_ptr, /* glPolygonOffsetClampEXT */
    epoxy_glPolygonOffsetEXT_dispatch_table_rewrite_ptr, /* glPolygonOffsetEXT */
    epoxy_glPolygonOffsetx_dispatch_table_rewrite_ptr, /* glPolygonOffsetx */
    epoxy_glPolygonOffsetxOES_dispatch_table_rewrite_ptr, /* glPolygonOffsetxOES */
    epoxy_glPolygonStipple_dispatch_table_rewrite_ptr, /* glPolygonStipple */
    epoxy_glPopAttrib_dispatch_table_rewrite_ptr, /* glPopAttrib */
    epoxy_glPopClientAttrib_dispatch_table_rewrite_ptr, /* glPopClientAttrib */
    epoxy_glPopDebugGroup_dispatch_table_rewrite_ptr, /* glPopDebugGroup */
    epoxy_glPopDebugGroupKHR_dispatch_table_rewrite_ptr, /* glPopDebugGroupKHR */
    epoxy_glPopGroupMarkerEXT_dispatch_table_rewrite_ptr, /* glPopGroupMarkerEXT */
    epoxy_glPopMatrix_dispatch_table_rewrite_ptr, /* glPopMatrix */
    epoxy_glPopName_dispatch_table_rewrite_ptr, /* glPopName */
    epoxy_glPresentFrameDualFillNV_dispatch_table_rewrite_ptr, /* glPresentFrameDualFillNV */
    epoxy_glPresentFrameKeyedNV_dispatch_table_rewrite_ptr, /* glPresentFrameKeyedNV */
    epoxy_glPrimitiveBoundingBox_dispatch_table_rewrite_ptr, /* glPrimitiveBoundingBox */
    epoxy_glPrimitiveBoundingBoxARB_dispatch_table_rewrite_ptr, /* glPrimitiveBoundingBoxARB */
    epoxy_glPrimitiveBoundingBoxEXT_dispatch_table_rewrite_ptr, /* glPrimitiveBoundingBoxEXT */
    epoxy_glPrimitiveBoundingBoxOES_dispatch_table_rewrite_ptr, /* glPrimitiveBoundingBoxOES */
    epoxy_glPrimitiveRestartIndex_dispatch_table_rewrite_ptr, /* glPrimitiveRestartIndex */
    epoxy_glPrimitiveRestartIndexNV_dispatch_table_rewrite_ptr, /* glPrimitiveRestartIndexNV */
    epoxy_glPrimitiveRestartNV_dispatch_table_rewrite_ptr, /* glPrimitiveRestartNV */
    epoxy_glPrioritizeTextures_dispatch_table_rewrite_ptr, /* glPrioritizeTextures */
    epoxy_glPrioritizeTexturesEXT_dispatch_table_rewrite_ptr, /* glPrioritizeTexturesEXT */
    epoxy_glPrioritizeTexturesxOES_dispatch_table_rewrite_ptr, /* glPrioritizeTexturesxOES */
    epoxy_glProgramBinary_dispatch_table_rewrite_ptr, /* glProgramBinary */
    epoxy_glProgramBinaryOES_dispatch_table_rewrite_ptr, /* glProgramBinaryOES */
    epoxy_glProgramBufferParametersIivNV_dispatch_table_rewrite_ptr, /* glProgramBufferParametersIivNV */
    epoxy_glProgramBufferParametersIuivNV_dispatch_table_rewrite_ptr, /* glProgramBufferParametersIuivNV */
    epoxy_glProgramBufferParametersfvNV_dispatch_table_rewrite_ptr, /* glProgramBufferParametersfvNV */
    epoxy_glProgramEnvParameter4dARB_dispatch_table_rewrite_ptr, /* glProgramEnvParameter4dARB */
    epoxy_glProgramEnvParameter4dvARB_dispatch_table_rewrite_ptr, /* glProgramEnvParameter4dvARB */
    epoxy_glProgramEnvParameter4fARB_dispatch_table_rewrite_ptr, /* glProgramEnvParameter4fARB */
    epoxy_glProgramEnvParameter4fvARB_dispatch_table_rewrite_ptr, /* glProgramEnvParameter4fvARB */
    epoxy_glProgramEnvParameterI4iNV_dispatch_table_rewrite_ptr, /* glProgramEnvParameterI4iNV */
    epoxy_glProgramEnvParameterI4ivNV_dispatch_table_rewrite_ptr, /* glProgramEnvParameterI4ivNV */
    epoxy_glProgramEnvParameterI4uiNV_dispatch_table_rewrite_ptr, /* glProgramEnvParameterI4uiNV */
    epoxy_glProgramEnvParameterI4uivNV_dispatch_table_rewrite_ptr, /* glProgramEnvParameterI4uivNV */
    epoxy_glProgramEnvParameters4fvEXT_dispatch_table_rewrite_ptr, /* glProgramEnvParameters4fvEXT */
    epoxy_glProgramEnvParametersI4ivNV_dispatch_table_rewrite_ptr, /* glProgramEnvParametersI4ivNV */
    epoxy_glProgramEnvParametersI4uivNV_dispatch_table_rewrite_ptr, /* glProgramEnvParametersI4uivNV */
    epoxy_glProgramLocalParameter4dARB_dispatch_table_rewrite_ptr, /* glProgramLocalParameter4dARB */
    epoxy_glProgramLocalParameter4dvARB_dispatch_table_rewrite_ptr, /* glProgramLocalParameter4dvARB */
    epoxy_glProgramLocalParameter4fARB_dispatch_table_rewrite_ptr, /* glProgramLocalParameter4fARB */
    epoxy_glProgramLocalParameter4fvARB_dispatch_table_rewrite_ptr, /* glProgramLocalParameter4fvARB */
    epoxy_glProgramLocalParameterI4iNV_dispatch_table_rewrite_ptr, /* glProgramLocalParameterI4iNV */
    epoxy_glProgramLocalParameterI4ivNV_dispatch_table_rewrite_ptr, /* glProgramLocalParameterI4ivNV */
    epoxy_glProgramLocalParameterI4uiNV_dispatch_table_rewrite_ptr, /* glProgramLocalParameterI4uiNV */
    epoxy_glProgramLocalParameterI4uivNV_dispatch_table_rewrite_ptr, /* glProgramLocalParameterI4uivNV */
    epoxy_glProgramLocalParameters4fvEXT_dispatch_table_rewrite_ptr, /* glProgramLocalParameters4fvEXT */
    epoxy_glProgramLocalParametersI4ivNV_dispatch_table_rewrite_ptr, /* glProgramLocalParametersI4ivNV */
    epoxy_glProgramLocalParametersI4uivNV_dispatch_table_rewrite_ptr, /* glProgramLocalParametersI4uivNV */
    epoxy_glProgramNamedParameter4dNV_dispatch_table_rewrite_ptr, /* glProgramNamedParameter4dNV */
    epoxy_glProgramNamedParameter4dvNV_dispatch_table_rewrite_ptr, /* glProgramNamedParameter4dvNV */
    epoxy_glProgramNamedParameter4fNV_dispatch_table_rewrite_ptr, /* glProgramNamedParameter4fNV */
    epoxy_glProgramNamedParameter4fvNV_dispatch_table_rewrite_ptr, /* glProgramNamedParameter4fvNV */
    epoxy_glProgramParameter4dNV_dispatch_table_rewrite_ptr, /* glProgramParameter4dNV */
    epoxy_glProgramParameter4dvNV_dispatch_table_rewrite_ptr, /* glProgramParameter4dvNV */
    epoxy_glProgramParameter4fNV_dispatch_table_rewrite_ptr, /* glProgramParameter4fNV */
    epoxy_glProgramParameter4fvNV_dispatch_table_rewrite_ptr, /* glProgramParameter4fvNV */
    epoxy_glProgramParameteri_dispatch_table_rewrite_ptr, /* glProgramParameteri */
    epoxy_glProgramParameteriARB_dispatch_table_rewrite_ptr, /* glProgramParameteriARB */
    epoxy_glProgramParameteriEXT_dispatch_table_rewrite_ptr, /* glProgramParameteriEXT */
    epoxy_glProgramParameters4dvNV_dispatch_table_rewrite_ptr, /* glProgramParameters4dvNV */
    epoxy_glProgramParameters4fvNV_dispatch_table_rewrite_ptr, /* glProgramParameters4fvNV */
    epoxy_glProgramPathFragmentInputGenNV_dispatch_table_rewrite_ptr, /* glProgramPathFragmentInputGenNV */
    epoxy_glProgramStringARB_dispatch_table_rewrite_ptr, /* glProgramStringARB */
    epoxy_glProgramSubroutineParametersuivNV_dispatch_table_rewrite_ptr, /* glProgramSubroutineParametersuivNV */
    epoxy_glProgramUniform1d_dispatch_table_rewrite_ptr, /* glProgramUniform1d */
    epoxy_glProgramUniform1dEXT_dispatch_table_rewrite_ptr, /* glProgramUniform1dEXT */
    epoxy_glProgramUniform1dv_dispatch_table_rewrite_ptr, /* glProgramUniform1dv */
    epoxy_glProgramUniform1dvEXT_dispatch_table_rewrite_ptr, /* glProgramUniform1dvEXT */
    epoxy_glProgramUniform1f_dispatch_table_rewrite_ptr, /* glProgramUniform1f */
    epoxy_glProgramUniform1fEXT_dispatch_table_rewrite_ptr, /* glProgramUniform1fEXT */
    epoxy_glProgramUniform1fv_dispatch_table_rewrite_ptr, /* glProgramUniform1fv */
    epoxy_glProgramUniform1fvEXT_dispatch_table_rewrite_ptr, /* glProgramUniform1fvEXT */
    epoxy_glProgramUniform1i_dispatch_table_rewrite_ptr, /* glProgramUniform1i */
    epoxy_glProgramUniform1i64ARB_dispatch_table_rewrite_ptr, /* glProgramUniform1i64ARB */
    epoxy_glProgramUniform1i64NV_dispatch_table_rewrite_ptr, /* glProgramUniform1i64NV */
    epoxy_glProgramUniform1i64vARB_dispatch_table_rewrite_ptr, /* glProgramUniform1i64vARB */
    epoxy_glProgramUniform1i64vNV_dispatch_table_rewrite_ptr, /* glProgramUniform1i64vNV */
    epoxy_glProgramUniform1iEXT_dispatch_table_rewrite_ptr, /* glProgramUniform1iEXT */
    epoxy_glProgramUniform1iv_dispatch_table_rewrite_ptr, /* glProgramUniform1iv */
    epoxy_glProgramUniform1ivEXT_dispatch_table_rewrite_ptr, /* glProgramUniform1ivEXT */
    epoxy_glProgramUniform1ui_dispatch_table_rewrite_ptr, /* glProgramUniform1ui */
    epoxy_glProgramUniform1ui64ARB_dispatch_table_rewrite_ptr, /* glProgramUniform1ui64ARB */
    epoxy_glProgramUniform1ui64NV_dispatch_table_rewrite_ptr, /* glProgramUniform1ui64NV */
    epoxy_glProgramUniform1ui64vARB_dispatch_table_rewrite_ptr, /* glProgramUniform1ui64vARB */
    epoxy_glProgramUniform1ui64vNV_dispatch_table_rewrite_ptr, /* glProgramUniform1ui64vNV */
    epoxy_glProgramUniform1uiEXT_dispatch_table_rewrite_ptr, /* glProgramUniform1uiEXT */
    epoxy_glProgramUniform1uiv_dispatch_table_rewrite_ptr, /* glProgramUniform1uiv */
    epoxy_glProgramUniform1uivEXT_dispatch_table_rewrite_ptr, /* glProgramUniform1uivEXT */
    epoxy_glProgramUniform2d_dispatch_table_rewrite_ptr, /* glProgramUniform2d */
    epoxy_glProgramUniform2dEXT_dispatch_table_rewrite_ptr, /* glProgramUniform2dEXT */
    epoxy_glProgramUniform2dv_dispatch_table_rewrite_ptr, /* glProgramUniform2dv */
    epoxy_glProgramUniform2dvEXT_dispatch_table_rewrite_ptr, /* glProgramUniform2dvEXT */
    epoxy_glProgramUniform2f_dispatch_table_rewrite_ptr, /* glProgramUniform2f */
    epoxy_glProgramUniform2fEXT_dispatch_table_rewrite_ptr, /* glProgramUniform2fEXT */
    epoxy_glProgramUniform2fv_dispatch_table_rewrite_ptr, /* glProgramUniform2fv */
    epoxy_glProgramUniform2fvEXT_dispatch_table_rewrite_ptr, /* glProgramUniform2fvEXT */
    epoxy_glProgramUniform2i_dispatch_table_rewrite_ptr, /* glProgramUniform2i */
    epoxy_glProgramUniform2i64ARB_dispatch_table_rewrite_ptr, /* glProgramUniform2i64ARB */
    epoxy_glProgramUniform2i64NV_dispatch_table_rewrite_ptr, /* glProgramUniform2i64NV */
    epoxy_glProgramUniform2i64vARB_dispatch_table_rewrite_ptr, /* glProgramUniform2i64vARB */
    epoxy_glProgramUniform2i64vNV_dispatch_table_rewrite_ptr, /* glProgramUniform2i64vNV */
    epoxy_glProgramUniform2iEXT_dispatch_table_rewrite_ptr, /* glProgramUniform2iEXT */
    epoxy_glProgramUniform2iv_dispatch_table_rewrite_ptr, /* glProgramUniform2iv */
    epoxy_glProgramUniform2ivEXT_dispatch_table_rewrite_ptr, /* glProgramUniform2ivEXT */
    epoxy_glProgramUniform2ui_dispatch_table_rewrite_ptr, /* glProgramUniform2ui */
    epoxy_glProgramUniform2ui64ARB_dispatch_table_rewrite_ptr, /* glProgramUniform2ui64ARB */
    epoxy_glProgramUniform2ui64NV_dispatch_table_rewrite_ptr, /* glProgramUniform2ui64NV */
    epoxy_glProgramUniform2ui64vARB_dispatch_table_rewrite_ptr, /* glProgramUniform2ui64vARB */
    epoxy_glProgramUniform2ui64vNV_dispatch_table_rewrite_ptr, /* glProgramUniform2ui64vNV */
    epoxy_glProgramUniform2uiEXT_dispatch_table_rewrite_ptr, /* glProgramUniform2uiEXT */
    epoxy_glProgramUniform2uiv_dispatch_table_rewrite_ptr, /* glProgramUniform2uiv */
    epoxy_glProgramUniform2uivEXT_dispatch_table_rewrite_ptr, /* glProgramUniform2uivEXT */
    epoxy_glProgramUniform3d_dispatch_table_rewrite_ptr, /* glProgramUniform3d */
    epoxy_glProgramUniform3dEXT_dispatch_table_rewrite_ptr, /* glProgramUniform3dEXT */
    epoxy_glProgramUniform3dv_dispatch_table_rewrite_ptr, /* glProgramUniform3dv */
    epoxy_glProgramUniform3dvEXT_dispatch_table_rewrite_ptr, /* glProgramUniform3dvEXT */
    epoxy_glProgramUniform3f_dispatch_table_rewrite_ptr, /* glProgramUniform3f */
    epoxy_glProgramUniform3fEXT_dispatch_table_rewrite_ptr, /* glProgramUniform3fEXT */
    epoxy_glProgramUniform3fv_dispatch_table_rewrite_ptr, /* glProgramUniform3fv */
    epoxy_glProgramUniform3fvEXT_dispatch_table_rewrite_ptr, /* glProgramUniform3fvEXT */
    epoxy_glProgramUniform3i_dispatch_table_rewrite_ptr, /* glProgramUniform3i */
    epoxy_glProgramUniform3i64ARB_dispatch_table_rewrite_ptr, /* glProgramUniform3i64ARB */
    epoxy_glProgramUniform3i64NV_dispatch_table_rewrite_ptr, /* glProgramUniform3i64NV */
    epoxy_glProgramUniform3i64vARB_dispatch_table_rewrite_ptr, /* glProgramUniform3i64vARB */
    epoxy_glProgramUniform3i64vNV_dispatch_table_rewrite_ptr, /* glProgramUniform3i64vNV */
    epoxy_glProgramUniform3iEXT_dispatch_table_rewrite_ptr, /* glProgramUniform3iEXT */
    epoxy_glProgramUniform3iv_dispatch_table_rewrite_ptr, /* glProgramUniform3iv */
    epoxy_glProgramUniform3ivEXT_dispatch_table_rewrite_ptr, /* glProgramUniform3ivEXT */
    epoxy_glProgramUniform3ui_dispatch_table_rewrite_ptr, /* glProgramUniform3ui */
    epoxy_glProgramUniform3ui64ARB_dispatch_table_rewrite_ptr, /* glProgramUniform3ui64ARB */
    epoxy_glProgramUniform3ui64NV_dispatch_table_rewrite_ptr, /* glProgramUniform3ui64NV */
    epoxy_glProgramUniform3ui64vARB_dispatch_table_rewrite_ptr, /* glProgramUniform3ui64vARB */
    epoxy_glProgramUniform3ui64vNV_dispatch_table_rewrite_ptr, /* glProgramUniform3ui64vNV */
    epoxy_glProgramUniform3uiEXT_dispatch_table_rewrite_ptr, /* glProgramUniform3uiEXT */
    epoxy_glProgramUniform3uiv_dispatch_table_rewrite_ptr, /* glProgramUniform3uiv */
    epoxy_glProgramUniform3uivEXT_dispatch_table_rewrite_ptr, /* glProgramUniform3uivEXT */
    epoxy_glProgramUniform4d_dispatch_table_rewrite_ptr, /* glProgramUniform4d */
    epoxy_glProgramUniform4dEXT_dispatch_table_rewrite_ptr, /* glProgramUniform4dEXT */
    epoxy_glProgramUniform4dv_dispatch_table_rewrite_ptr, /* glProgramUniform4dv */
    epoxy_glProgramUniform4dvEXT_dispatch_table_rewrite_ptr, /* glProgramUniform4dvEXT */
    epoxy_glProgramUniform4f_dispatch_table_rewrite_ptr, /* glProgramUniform4f */
    epoxy_glProgramUniform4fEXT_dispatch_table_rewrite_ptr, /* glProgramUniform4fEXT */
    epoxy_glProgramUniform4fv_dispatch_table_rewrite_ptr, /* glProgramUniform4fv */
    epoxy_glProgramUniform4fvEXT_dispatch_table_rewrite_ptr, /* glProgramUniform4fvEXT */
    epoxy_glProgramUniform4i_dispatch_table_rewrite_ptr, /* glProgramUniform4i */
    epoxy_glProgramUniform4i64ARB_dispatch_table_rewrite_ptr, /* glProgramUniform4i64ARB */
    epoxy_glProgramUniform4i64NV_dispatch_table_rewrite_ptr, /* glProgramUniform4i64NV */
    epoxy_glProgramUniform4i64vARB_dispatch_table_rewrite_ptr, /* glProgramUniform4i64vARB */
    epoxy_glProgramUniform4i64vNV_dispatch_table_rewrite_ptr, /* glProgramUniform4i64vNV */
    epoxy_glProgramUniform4iEXT_dispatch_table_rewrite_ptr, /* glProgramUniform4iEXT */
    epoxy_glProgramUniform4iv_dispatch_table_rewrite_ptr, /* glProgramUniform4iv */
    epoxy_glProgramUniform4ivEXT_dispatch_table_rewrite_ptr, /* glProgramUniform4ivEXT */
    epoxy_glProgramUniform4ui_dispatch_table_rewrite_ptr, /* glProgramUniform4ui */
    epoxy_glProgramUniform4ui64ARB_dispatch_table_rewrite_ptr, /* glProgramUniform4ui64ARB */
    epoxy_glProgramUniform4ui64NV_dispatch_table_rewrite_ptr, /* glProgramUniform4ui64NV */
    epoxy_glProgramUniform4ui64vARB_dispatch_table_rewrite_ptr, /* glProgramUniform4ui64vARB */
    epoxy_glProgramUniform4ui64vNV_dispatch_table_rewrite_ptr, /* glProgramUniform4ui64vNV */
    epoxy_glProgramUniform4uiEXT_dispatch_table_rewrite_ptr, /* glProgramUniform4uiEXT */
    epoxy_glProgramUniform4uiv_dispatch_table_rewrite_ptr, /* glProgramUniform4uiv */
    epoxy_glProgramUniform4uivEXT_dispatch_table_rewrite_ptr, /* glProgramUniform4uivEXT */
    epoxy_glProgramUniformHandleui64ARB_dispatch_table_rewrite_ptr, /* glProgramUniformHandleui64ARB */
    epoxy_glProgramUniformHandleui64IMG_dispatch_table_rewrite_ptr, /* glProgramUniformHandleui64IMG */
    epoxy_glProgramUniformHandleui64NV_dispatch_table_rewrite_ptr, /* glProgramUniformHandleui64NV */
    epoxy_glProgramUniformHandleui64vARB_dispatch_table_rewrite_ptr, /* glProgramUniformHandleui64vARB */
    epoxy_glProgramUniformHandleui64vIMG_dispatch_table_rewrite_ptr, /* glProgramUniformHandleui64vIMG */
    epoxy_glProgramUniformHandleui64vNV_dispatch_table_rewrite_ptr, /* glProgramUniformHandleui64vNV */
    epoxy_glProgramUniformMatrix2dv_dispatch_table_rewrite_ptr, /* glProgramUniformMatrix2dv */
    epoxy_glProgramUniformMatrix2dvEXT_dispatch_table_rewrite_ptr, /* glProgramUniformMatrix2dvEXT */
    epoxy_glProgramUniformMatrix2fv_dispatch_table_rewrite_ptr, /* glProgramUniformMatrix2fv */
    epoxy_glProgramUniformMatrix2fvEXT_dispatch_table_rewrite_ptr, /* glProgramUniformMatrix2fvEXT */
    epoxy_glProgramUniformMatrix2x3dv_dispatch_table_rewrite_ptr, /* glProgramUniformMatrix2x3dv */
    epoxy_glProgramUniformMatrix2x3dvEXT_dispatch_table_rewrite_ptr, /* glProgramUniformMatrix2x3dvEXT */
    epoxy_glProgramUniformMatrix2x3fv_dispatch_table_rewrite_ptr, /* glProgramUniformMatrix2x3fv */
    epoxy_glProgramUniformMatrix2x3fvEXT_dispatch_table_rewrite_ptr, /* glProgramUniformMatrix2x3fvEXT */
    epoxy_glProgramUniformMatrix2x4dv_dispatch_table_rewrite_ptr, /* glProgramUniformMatrix2x4dv */
    epoxy_glProgramUniformMatrix2x4dvEXT_dispatch_table_rewrite_ptr, /* glProgramUniformMatrix2x4dvEXT */
    epoxy_glProgramUniformMatrix2x4fv_dispatch_table_rewrite_ptr, /* glProgramUniformMatrix2x4fv */
    epoxy_glProgramUniformMatrix2x4fvEXT_dispatch_table_rewrite_ptr, /* glProgramUniformMatrix2x4fvEXT */
    epoxy_glProgramUniformMatrix3dv_dispatch_table_rewrite_ptr, /* glProgramUniformMatrix3dv */
    epoxy_glProgramUniformMatrix3dvEXT_dispatch_table_rewrite_ptr, /* glProgramUniformMatrix3dvEXT */
    epoxy_glProgramUniformMatrix3fv_dispatch_table_rewrite_ptr, /* glProgramUniformMatrix3fv */
    epoxy_glProgramUniformMatrix3fvEXT_dispatch_table_rewrite_ptr, /* glProgramUniformMatrix3fvEXT */
    epoxy_glProgramUniformMatrix3x2dv_dispatch_table_rewrite_ptr, /* glProgramUniformMatrix3x2dv */
    epoxy_glProgramUniformMatrix3x2dvEXT_dispatch_table_rewrite_ptr, /* glProgramUniformMatrix3x2dvEXT */
    epoxy_glProgramUniformMatrix3x2fv_dispatch_table_rewrite_ptr, /* glProgramUniformMatrix3x2fv */
    epoxy_glProgramUniformMatrix3x2fvEXT_dispatch_table_rewrite_ptr, /* glProgramUniformMatrix3x2fvEXT */
    epoxy_glProgramUniformMatrix3x4dv_dispatch_table_rewrite_ptr, /* glProgramUniformMatrix3x4dv */
    epoxy_glProgramUniformMatrix3x4dvEXT_dispatch_table_rewrite_ptr, /* glProgramUniformMatrix3x4dvEXT */
    epoxy_glProgramUniformMatrix3x4fv_dispatch_table_rewrite_ptr, /* glProgramUniformMatrix3x4fv */
    epoxy_glProgramUniformMatrix3x4fvEXT_dispatch_table_rewrite_ptr, /* glProgramUniformMatrix3x4fvEXT */
    epoxy_glProgramUniformMatrix4dv_dispatch_table_rewrite_ptr, /* glProgramUniformMatrix4dv */
    epoxy_glProgramUniformMatrix4dvEXT_dispatch_table_rewrite_ptr, /* glProgramUniformMatrix4dvEXT */
    epoxy_glProgramUniformMatrix4fv_dispatch_table_rewrite_ptr, /* glProgramUniformMatrix4fv */
    epoxy_glProgramUniformMatrix4fvEXT_dispatch_table_rewrite_ptr, /* glProgramUniformMatrix4fvEXT */
    epoxy_glProgramUniformMatrix4x2dv_dispatch_table_rewrite_ptr, /* glProgramUniformMatrix4x2dv */
    epoxy_glProgramUniformMatrix4x2dvEXT_dispatch_table_rewrite_ptr, /* glProgramUniformMatrix4x2dvEXT */
    epoxy_glProgramUniformMatrix4x2fv_dispatch_table_rewrite_ptr, /* glProgramUniformMatrix4x2fv */
    epoxy_glProgramUniformMatrix4x2fvEXT_dispatch_table_rewrite_ptr, /* glProgramUniformMatrix4x2fvEXT */
    epoxy_glProgramUniformMatrix4x3dv_dispatch_table_rewrite_ptr, /* glProgramUniformMatrix4x3dv */
    epoxy_glProgramUniformMatrix4x3dvEXT_dispatch_table_rewrite_ptr, /* glProgramUniformMatrix4x3dvEXT */
    epoxy_glProgramUniformMatrix4x3fv_dispatch_table_rewrite_ptr, /* glProgramUniformMatrix4x3fv */
    epoxy_glProgramUniformMatrix4x3fvEXT_dispatch_table_rewrite_ptr, /* glProgramUniformMatrix4x3fvEXT */
    epoxy_glProgramUniformui64NV_dispatch_table_rewrite_ptr, /* glProgramUniformui64NV */
    epoxy_glProgramUniformui64vNV_dispatch_table_rewrite_ptr, /* glProgramUniformui64vNV */
    epoxy_glProgramVertexLimitNV_dispatch_table_rewrite_ptr, /* glProgramVertexLimitNV */
    epoxy_glProvokingVertex_dispatch_table_rewrite_ptr, /* glProvokingVertex */
    epoxy_glProvokingVertexEXT_dispatch_table_rewrite_ptr, /* glProvokingVertexEXT */
    epoxy_glPushAttrib_dispatch_table_rewrite_ptr, /* glPushAttrib */
    epoxy_glPushClientAttrib_dispatch_table_rewrite_ptr, /* glPushClientAttrib */
    epoxy_glPushClientAttribDefaultEXT_dispatch_table_rewrite_ptr, /* glPushClientAttribDefaultEXT */
    epoxy_glPushDebugGroup_dispatch_table_rewrite_ptr, /* glPushDebugGroup */
    epoxy_glPushDebugGroupKHR_dispatch_table_rewrite_ptr, /* glPushDebugGroupKHR */
    epoxy_glPushGroupMarkerEXT_dispatch_table_rewrite_ptr, /* glPushGroupMarkerEXT */
    epoxy_glPushMatrix_dispatch_table_rewrite_ptr, /* glPushMatrix */
    epoxy_glPushName_dispatch_table_rewrite_ptr, /* glPushName */
    epoxy_glQueryCounter_dispatch_table_rewrite_ptr, /* glQueryCounter */
    epoxy_glQueryCounterEXT_dispatch_table_rewrite_ptr, /* glQueryCounterEXT */
    epoxy_glQueryMatrixxOES_dispatch_table_rewrite_ptr, /* glQueryMatrixxOES */
    epoxy_glQueryObjectParameteruiAMD_dispatch_table_rewrite_ptr, /* glQueryObjectParameteruiAMD */
    epoxy_glQueryResourceNV_dispatch_table_rewrite_ptr, /* glQueryResourceNV */
    epoxy_glQueryResourceTagNV_dispatch_table_rewrite_ptr, /* glQueryResourceTagNV */
    epoxy_glRasterPos2d_dispatch_table_rewrite_ptr, /* glRasterPos2d */
    epoxy_glRasterPos2dv_dispatch_table_rewrite_ptr, /* glRasterPos2dv */
    epoxy_glRasterPos2f_dispatch_table_rewrite_ptr, /* glRasterPos2f */
    epoxy_glRasterPos2fv_dispatch_table_rewrite_ptr, /* glRasterPos2fv */
    epoxy_glRasterPos2i_dispatch_table_rewrite_ptr, /* glRasterPos2i */
    epoxy_glRasterPos2iv_dispatch_table_rewrite_ptr, /* glRasterPos2iv */
    epoxy_glRasterPos2s_dispatch_table_rewrite_ptr, /* glRasterPos2s */
    epoxy_glRasterPos2sv_dispatch_table_rewrite_ptr, /* glRasterPos2sv */
    epoxy_glRasterPos2xOES_dispatch_table_rewrite_ptr, /* glRasterPos2xOES */
    epoxy_glRasterPos2xvOES_dispatch_table_rewrite_ptr, /* glRasterPos2xvOES */
    epoxy_glRasterPos3d_dispatch_table_rewrite_ptr, /* glRasterPos3d */
    epoxy_glRasterPos3dv_dispatch_table_rewrite_ptr, /* glRasterPos3dv */
    epoxy_glRasterPos3f_dispatch_table_rewrite_ptr, /* glRasterPos3f */
    epoxy_glRasterPos3fv_dispatch_table_rewrite_ptr, /* glRasterPos3fv */
    epoxy_glRasterPos3i_dispatch_table_rewrite_ptr, /* glRasterPos3i */
    epoxy_glRasterPos3iv_dispatch_table_rewrite_ptr, /* glRasterPos3iv */
    epoxy_glRasterPos3s_dispatch_table_rewrite_ptr, /* glRasterPos3s */
    epoxy_glRasterPos3sv_dispatch_table_rewrite_ptr, /* glRasterPos3sv */
    epoxy_glRasterPos3xOES_dispatch_table_rewrite_ptr, /* glRasterPos3xOES */
    epoxy_glRasterPos3xvOES_dispatch_table_rewrite_ptr, /* glRasterPos3xvOES */
    epoxy_glRasterPos4d_dispatch_table_rewrite_ptr, /* glRasterPos4d */
    epoxy_glRasterPos4dv_dispatch_table_rewrite_ptr, /* glRasterPos4dv */
    epoxy_glRasterPos4f_dispatch_table_rewrite_ptr, /* glRasterPos4f */
    epoxy_glRasterPos4fv_dispatch_table_rewrite_ptr, /* glRasterPos4fv */
    epoxy_glRasterPos4i_dispatch_table_rewrite_ptr, /* glRasterPos4i */
    epoxy_glRasterPos4iv_dispatch_table_rewrite_ptr, /* glRasterPos4iv */
    epoxy_glRasterPos4s_dispatch_table_rewrite_ptr, /* glRasterPos4s */
    epoxy_glRasterPos4sv_dispatch_table_rewrite_ptr, /* glRasterPos4sv */
    epoxy_glRasterPos4xOES_dispatch_table_rewrite_ptr, /* glRasterPos4xOES */
    epoxy_glRasterPos4xvOES_dispatch_table_rewrite_ptr, /* glRasterPos4xvOES */
    epoxy_glRasterSamplesEXT_dispatch_table_rewrite_ptr, /* glRasterSamplesEXT */
    epoxy_glReadBuffer_dispatch_table_rewrite_ptr, /* glReadBuffer */
    epoxy_glReadBufferIndexedEXT_dispatch_table_rewrite_ptr, /* glReadBufferIndexedEXT */
    epoxy_glReadBufferNV_dispatch_table_rewrite_ptr, /* glReadBufferNV */
    epoxy_glReadInstrumentsSGIX_dispatch_table_rewrite_ptr, /* glReadInstrumentsSGIX */
    epoxy_glReadPixels_dispatch_table_rewrite_ptr, /* glReadPixels */
    epoxy_glReadnPixels_dispatch_table_rewrite_ptr, /* glReadnPixels */
    epoxy_glReadnPixelsARB_dispatch_table_rewrite_ptr, /* glReadnPixelsARB */
    epoxy_glReadnPixelsEXT_dispatch_table_rewrite_ptr, /* glReadnPixelsEXT */
    epoxy_glReadnPixelsKHR_dispatch_table_rewrite_ptr, /* glReadnPixelsKHR */
    epoxy_glRectd_dispatch_table_rewrite_ptr, /* glRectd */
    epoxy_glRectdv_dispatch_table_rewrite_ptr, /* glRectdv */
    epoxy_glRectf_dispatch_table_rewrite_ptr, /* glRectf */
    epoxy_glRectfv_dispatch_table_rewrite_ptr, /* glRectfv */
    epoxy_glRecti_dispatch_table_rewrite_ptr, /* glRecti */
    epoxy_glRectiv_dispatch_table_rewrite_ptr, /* glRectiv */
    epoxy_glRects_dispatch_table_rewrite_ptr, /* glRects */
    epoxy_glRectsv_dispatch_table_rewrite_ptr, /* glRectsv */
    epoxy_glRectxOES_dispatch_table_rewrite_ptr, /* glRectxOES */
    epoxy_glRectxvOES_dispatch_table_rewrite_ptr, /* glRectxvOES */
    epoxy_glReferencePlaneSGIX_dispatch_table_rewrite_ptr, /* glReferencePlaneSGIX */
    epoxy_glReleaseKeyedMutexWin32EXT_dispatch_table_rewrite_ptr, /* glReleaseKeyedMutexWin32EXT */
    epoxy_glReleaseShaderCompiler_dispatch_table_rewrite_ptr, /* glReleaseShaderCompiler */
    epoxy_glRenderGpuMaskNV_dispatch_table_rewrite_ptr, /* glRenderGpuMaskNV */
    epoxy_glRenderMode_dispatch_table_rewrite_ptr, /* glRenderMode */
    epoxy_glRenderbufferStorage_dispatch_table_rewrite_ptr, /* glRenderbufferStorage */
    epoxy_glRenderbufferStorageEXT_dispatch_table_rewrite_ptr, /* glRenderbufferStorageEXT */
    epoxy_glRenderbufferStorageMultisample_dispatch_table_rewrite_ptr, /* glRenderbufferStorageMultisample */
    epoxy_glRenderbufferStorageMultisampleANGLE_dispatch_table_rewrite_ptr, /* glRenderbufferStorageMultisampleANGLE */
    epoxy_glRenderbufferStorageMultisampleAPPLE_dispatch_table_rewrite_ptr, /* glRenderbufferStorageMultisampleAPPLE */
    epoxy_glRenderbufferStorageMultisampleAdvancedAMD_dispatch_table_rewrite_ptr, /* glRenderbufferStorageMultisampleAdvancedAMD */
    epoxy_glRenderbufferStorageMultisampleCoverageNV_dispatch_table_rewrite_ptr, /* glRenderbufferStorageMultisampleCoverageNV */
    epoxy_glRenderbufferStorageMultisampleEXT_dispatch_table_rewrite_ptr, /* glRenderbufferStorageMultisampleEXT */
    epoxy_glRenderbufferStorageMultisampleIMG_dispatch_table_rewrite_ptr, /* glRenderbufferStorageMultisampleIMG */
    epoxy_glRenderbufferStorageMultisampleNV_dispatch_table_rewrite_ptr, /* glRenderbufferStorageMultisampleNV */
    epoxy_glRenderbufferStorageOES_dispatch_table_rewrite_ptr, /* glRenderbufferStorageOES */
    epoxy_glReplacementCodePointerSUN_dispatch_table_rewrite_ptr, /* glReplacementCodePointerSUN */
    epoxy_glReplacementCodeubSUN_dispatch_table_rewrite_ptr, /* glReplacementCodeubSUN */
    epoxy_glReplacementCodeubvSUN_dispatch_table_rewrite_ptr, /* glReplacementCodeubvSUN */
    epoxy_glReplacementCodeuiColor3fVertex3fSUN_dispatch_table_rewrite_ptr, /* glReplacementCodeuiColor3fVertex3fSUN */
    epoxy_glReplacementCodeuiColor3fVertex3fvSUN_dispatch_table_rewrite_ptr, /* glReplacementCodeuiColor3fVertex3fvSUN */
    epoxy_glReplacementCodeuiColor4fNormal3fVertex3fSUN_dispatch_table_rewrite_ptr, /* glReplacementCodeuiColor4fNormal3fVertex3fSUN */
    epoxy_glReplacementCodeuiColor4fNormal3fVertex3fvSUN_dispatch_table_rewrite_ptr, /* glReplacementCodeuiColor4fNormal3fVertex3fvSUN */
    epoxy_glReplacementCodeuiColor4ubVertex3fSUN_dispatch_table_rewrite_ptr, /* glReplacementCodeuiColor4ubVertex3fSUN */
    epoxy_glReplacementCodeuiColor4ubVertex3fvSUN_dispatch_table_rewrite_ptr, /* glReplacementCodeuiColor4ubVertex3fvSUN */
    epoxy_glReplacementCodeuiNormal3fVertex3fSUN_dispatch_table_rewrite_ptr, /* glReplacementCodeuiNormal3fVertex3fSUN */
    epoxy_glReplacementCodeuiNormal3fVertex3fvSUN_dispatch_table_rewrite_ptr, /* glReplacementCodeuiNormal3fVertex3fvSUN */
    epoxy_glReplacementCodeuiSUN_dispatch_table_rewrite_ptr, /* glReplacementCodeuiSUN */
    epoxy_glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fSUN_dispatch_table_rewrite_ptr, /* glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fSUN */
    epoxy_glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fvSUN_dispatch_table_rewrite_ptr, /* glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fvSUN */
    epoxy_glReplacementCodeuiTexCoord2fNormal3fVertex3fSUN_dispatch_table_rewrite_ptr, /* glReplacementCodeuiTexCoord2fNormal3fVertex3fSUN */
    epoxy_glReplacementCodeuiTexCoord2fNormal3fVertex3fvSUN_dispatch_table_rewrite_ptr, /* glReplacementCodeuiTexCoord2fNormal3fVertex3fvSUN */
    epoxy_glReplacementCodeuiTexCoord2fVertex3fSUN_dispatch_table_rewrite_ptr, /* glReplacementCodeuiTexCoord2fVertex3fSUN */
    epoxy_glReplacementCodeuiTexCoord2fVertex3fvSUN_dispatch_table_rewrite_ptr, /* glReplacementCodeuiTexCoord2fVertex3fvSUN */
    epoxy_glReplacementCodeuiVertex3fSUN_dispatch_table_rewrite_ptr, /* glReplacementCodeuiVertex3fSUN */
    epoxy_glReplacementCodeuiVertex3fvSUN_dispatch_table_rewrite_ptr, /* glReplacementCodeuiVertex3fvSUN */
    epoxy_glReplacementCodeuivSUN_dispatch_table_rewrite_ptr, /* glReplacementCodeuivSUN */
    epoxy_glReplacementCodeusSUN_dispatch_table_rewrite_ptr, /* glReplacementCodeusSUN */
    epoxy_glReplacementCodeusvSUN_dispatch_table_rewrite_ptr, /* glReplacementCodeusvSUN */
    epoxy_glRequestResidentProgramsNV_dispatch_table_rewrite_ptr, /* glRequestResidentProgramsNV */
    epoxy_glResetHistogram_dispatch_table_rewrite_ptr, /* glResetHistogram */
    epoxy_glResetHistogramEXT_dispatch_table_rewrite_ptr, /* glResetHistogramEXT */
    epoxy_glResetMemoryObjectParameterNV_dispatch_table_rewrite_ptr, /* glResetMemoryObjectParameterNV */
    epoxy_glResetMinmax_dispatch_table_rewrite_ptr, /* glResetMinmax */
    epoxy_glResetMinmaxEXT_dispatch_table_rewrite_ptr, /* glResetMinmaxEXT */
    epoxy_glResizeBuffersMESA_dispatch_table_rewrite_ptr, /* glResizeBuffersMESA */
    epoxy_glResolveDepthValuesNV_dispatch_table_rewrite_ptr, /* glResolveDepthValuesNV */
    epoxy_glResolveMultisampleFramebufferAPPLE_dispatch_table_rewrite_ptr, /* glResolveMultisampleFramebufferAPPLE */
    epoxy_glResumeTransformFeedback_dispatch_table_rewrite_ptr, /* glResumeTransformFeedback */
    epoxy_glResumeTransformFeedbackNV_dispatch_table_rewrite_ptr, /* glResumeTransformFeedbackNV */
    epoxy_glRotated_dispatch_table_rewrite_ptr, /* glRotated */
    epoxy_glRotatef_dispatch_table_rewrite_ptr, /* glRotatef */
    epoxy_glRotatex_dispatch_table_rewrite_ptr, /* glRotatex */
    epoxy_glRotatexOES_dispatch_table_rewrite_ptr, /* glRotatexOES */
    epoxy_glSampleCoverage_dispatch_table_rewrite_ptr, /* glSampleCoverage */
    epoxy_glSampleCoverageARB_dispatch_table_rewrite_ptr, /* glSampleCoverageARB */
    epoxy_glSampleCoveragex_dispatch_table_rewrite_ptr, /* glSampleCoveragex */
    epoxy_glSampleCoveragexOES_dispatch_table_rewrite_ptr, /* glSampleCoveragexOES */
    epoxy_glSampleMapATI_dispatch_table_rewrite_ptr, /* glSampleMapATI */
    epoxy_glSampleMaskEXT_dispatch_table_rewrite_ptr, /* glSampleMaskEXT */
    epoxy_glSampleMaskIndexedNV_dispatch_table_rewrite_ptr, /* glSampleMaskIndexedNV */
    epoxy_glSampleMaskSGIS_dispatch_table_rewrite_ptr, /* glSampleMaskSGIS */
    epoxy_glSampleMaski_dispatch_table_rewrite_ptr, /* glSampleMaski */
    epoxy_glSamplePatternEXT_dispatch_table_rewrite_ptr, /* glSamplePatternEXT */
    epoxy_glSamplePatternSGIS_dispatch_table_rewrite_ptr, /* glSamplePatternSGIS */
    epoxy_glSamplerParameterIiv_dispatch_table_rewrite_ptr, /* glSamplerParameterIiv */
    epoxy_glSamplerParameterIivEXT_dispatch_table_rewrite_ptr, /* glSamplerParameterIivEXT */
    epoxy_glSamplerParameterIivOES_dispatch_table_rewrite_ptr, /* glSamplerParameterIivOES */
    epoxy_glSamplerParameterIuiv_dispatch_table_rewrite_ptr, /* glSamplerParameterIuiv */
    epoxy_glSamplerParameterIuivEXT_dispatch_table_rewrite_ptr, /* glSamplerParameterIuivEXT */
    epoxy_glSamplerParameterIuivOES_dispatch_table_rewrite_ptr, /* glSamplerParameterIuivOES */
    epoxy_glSamplerParameterf_dispatch_table_rewrite_ptr, /* glSamplerParameterf */
    epoxy_glSamplerParameterfv_dispatch_table_rewrite_ptr, /* glSamplerParameterfv */
    epoxy_glSamplerParameteri_dispatch_table_rewrite_ptr, /* glSamplerParameteri */
    epoxy_glSamplerParameteriv_dispatch_table_rewrite_ptr, /* glSamplerParameteriv */
    epoxy_glScaled_dispatch_table_rewrite_ptr, /* glScaled */
    epoxy_glScalef_dispatch_table_rewrite_ptr, /* glScalef */
    epoxy_glScalex_dispatch_table_rewrite_ptr, /* glScalex */
    epoxy_glScalexOES_dispatch_table_rewrite_ptr, /* glScalexOES */
    epoxy_glScissor_dispatch_table_rewrite_ptr, /* glScissor */
    epoxy_glScissorArrayv_dispatch_table_rewrite_ptr, /* glScissorArrayv */
    epoxy_glScissorArrayvNV_dispatch_table_rewrite_ptr, /* glScissorArrayvNV */
    epoxy_glScissorArrayvOES_dispatch_table_rewrite_ptr, /* glScissorArrayvOES */
    epoxy_glScissorExclusiveArrayvNV_dispatch_table_rewrite_ptr, /* glScissorExclusiveArrayvNV */
    epoxy_glScissorExclusiveNV_dispatch_table_rewrite_ptr, /* glScissorExclusiveNV */
    epoxy_glScissorIndexed_dispatch_table_rewrite_ptr, /* glScissorIndexed */
    epoxy_glScissorIndexedNV_dispatch_table_rewrite_ptr, /* glScissorIndexedNV */
    epoxy_glScissorIndexedOES_dispatch_table_rewrite_ptr, /* glScissorIndexedOES */
    epoxy_glScissorIndexedv_dispatch_table_rewrite_ptr, /* glScissorIndexedv */
    epoxy_glScissorIndexedvNV_dispatch_table_rewrite_ptr, /* glScissorIndexedvNV */
    epoxy_glScissorIndexedvOES_dispatch_table_rewrite_ptr, /* glScissorIndexedvOES */
    epoxy_glSecondaryColor3b_dispatch_table_rewrite_ptr, /* glSecondaryColor3b */
    epoxy_glSecondaryColor3bEXT_dispatch_table_rewrite_ptr, /* glSecondaryColor3bEXT */
    epoxy_glSecondaryColor3bv_dispatch_table_rewrite_ptr, /* glSecondaryColor3bv */
    epoxy_glSecondaryColor3bvEXT_dispatch_table_rewrite_ptr, /* glSecondaryColor3bvEXT */
    epoxy_glSecondaryColor3d_dispatch_table_rewrite_ptr, /* glSecondaryColor3d */
    epoxy_glSecondaryColor3dEXT_dispatch_table_rewrite_ptr, /* glSecondaryColor3dEXT */
    epoxy_glSecondaryColor3dv_dispatch_table_rewrite_ptr, /* glSecondaryColor3dv */
    epoxy_glSecondaryColor3dvEXT_dispatch_table_rewrite_ptr, /* glSecondaryColor3dvEXT */
    epoxy_glSecondaryColor3f_dispatch_table_rewrite_ptr, /* glSecondaryColor3f */
    epoxy_glSecondaryColor3fEXT_dispatch_table_rewrite_ptr, /* glSecondaryColor3fEXT */
    epoxy_glSecondaryColor3fv_dispatch_table_rewrite_ptr, /* glSecondaryColor3fv */
    epoxy_glSecondaryColor3fvEXT_dispatch_table_rewrite_ptr, /* glSecondaryColor3fvEXT */
    epoxy_glSecondaryColor3hNV_dispatch_table_rewrite_ptr, /* glSecondaryColor3hNV */
    epoxy_glSecondaryColor3hvNV_dispatch_table_rewrite_ptr, /* glSecondaryColor3hvNV */
    epoxy_glSecondaryColor3i_dispatch_table_rewrite_ptr, /* glSecondaryColor3i */
    epoxy_glSecondaryColor3iEXT_dispatch_table_rewrite_ptr, /* glSecondaryColor3iEXT */
    epoxy_glSecondaryColor3iv_dispatch_table_rewrite_ptr, /* glSecondaryColor3iv */
    epoxy_glSecondaryColor3ivEXT_dispatch_table_rewrite_ptr, /* glSecondaryColor3ivEXT */
    epoxy_glSecondaryColor3s_dispatch_table_rewrite_ptr, /* glSecondaryColor3s */
    epoxy_glSecondaryColor3sEXT_dispatch_table_rewrite_ptr, /* glSecondaryColor3sEXT */
    epoxy_glSecondaryColor3sv_dispatch_table_rewrite_ptr, /* glSecondaryColor3sv */
    epoxy_glSecondaryColor3svEXT_dispatch_table_rewrite_ptr, /* glSecondaryColor3svEXT */
    epoxy_glSecondaryColor3ub_dispatch_table_rewrite_ptr, /* glSecondaryColor3ub */
    epoxy_glSecondaryColor3ubEXT_dispatch_table_rewrite_ptr, /* glSecondaryColor3ubEXT */
    epoxy_glSecondaryColor3ubv_dispatch_table_rewrite_ptr, /* glSecondaryColor3ubv */
    epoxy_glSecondaryColor3ubvEXT_dispatch_table_rewrite_ptr, /* glSecondaryColor3ubvEXT */
    epoxy_glSecondaryColor3ui_dispatch_table_rewrite_ptr, /* glSecondaryColor3ui */
    epoxy_glSecondaryColor3uiEXT_dispatch_table_rewrite_ptr, /* glSecondaryColor3uiEXT */
    epoxy_glSecondaryColor3uiv_dispatch_table_rewrite_ptr, /* glSecondaryColor3uiv */
    epoxy_glSecondaryColor3uivEXT_dispatch_table_rewrite_ptr, /* glSecondaryColor3uivEXT */
    epoxy_glSecondaryColor3us_dispatch_table_rewrite_ptr, /* glSecondaryColor3us */
    epoxy_glSecondaryColor3usEXT_dispatch_table_rewrite_ptr, /* glSecondaryColor3usEXT */
    epoxy_glSecondaryColor3usv_dispatch_table_rewrite_ptr, /* glSecondaryColor3usv */
    epoxy_glSecondaryColor3usvEXT_dispatch_table_rewrite_ptr, /* glSecondaryColor3usvEXT */
    epoxy_glSecondaryColorFormatNV_dispatch_table_rewrite_ptr, /* glSecondaryColorFormatNV */
    epoxy_glSecondaryColorP3ui_dispatch_table_rewrite_ptr, /* glSecondaryColorP3ui */
    epoxy_glSecondaryColorP3uiv_dispatch_table_rewrite_ptr, /* glSecondaryColorP3uiv */
    epoxy_glSecondaryColorPointer_dispatch_table_rewrite_ptr, /* glSecondaryColorPointer */
    epoxy_glSecondaryColorPointerEXT_dispatch_table_rewrite_ptr, /* glSecondaryColorPointerEXT */
    epoxy_glSecondaryColorPointerListIBM_dispatch_table_rewrite_ptr, /* glSecondaryColorPointerListIBM */
    epoxy_glSelectBuffer_dispatch_table_rewrite_ptr, /* glSelectBuffer */
    epoxy_glSelectPerfMonitorCountersAMD_dispatch_table_rewrite_ptr, /* glSelectPerfMonitorCountersAMD */
    epoxy_glSemaphoreParameterui64vEXT_dispatch_table_rewrite_ptr, /* glSemaphoreParameterui64vEXT */
    epoxy_glSeparableFilter2D_dispatch_table_rewrite_ptr, /* glSeparableFilter2D */
    epoxy_glSeparableFilter2DEXT_dispatch_table_rewrite_ptr, /* glSeparableFilter2DEXT */
    epoxy_glSetFenceAPPLE_dispatch_table_rewrite_ptr, /* glSetFenceAPPLE */
    epoxy_glSetFenceNV_dispatch_table_rewrite_ptr, /* glSetFenceNV */
    epoxy_glSetFragmentShaderConstantATI_dispatch_table_rewrite_ptr, /* glSetFragmentShaderConstantATI */
    epoxy_glSetInvariantEXT_dispatch_table_rewrite_ptr, /* glSetInvariantEXT */
    epoxy_glSetLocalConstantEXT_dispatch_table_rewrite_ptr, /* glSetLocalConstantEXT */
    epoxy_glSetMultisamplefvAMD_dispatch_table_rewrite_ptr, /* glSetMultisamplefvAMD */
    epoxy_glShadeModel_dispatch_table_rewrite_ptr, /* glShadeModel */
    epoxy_glShaderBinary_dispatch_table_rewrite_ptr, /* glShaderBinary */
    epoxy_glShaderOp1EXT_dispatch_table_rewrite_ptr, /* glShaderOp1EXT */
    epoxy_glShaderOp2EXT_dispatch_table_rewrite_ptr, /* glShaderOp2EXT */
    epoxy_glShaderOp3EXT_dispatch_table_rewrite_ptr, /* glShaderOp3EXT */
    epoxy_glShaderSource_dispatch_table_rewrite_ptr, /* glShaderSource */
    epoxy_glShaderSourceARB_dispatch_table_rewrite_ptr, /* glShaderSourceARB */
    epoxy_glShaderStorageBlockBinding_dispatch_table_rewrite_ptr, /* glShaderStorageBlockBinding */
    epoxy_glShadingRateImageBarrierNV_dispatch_table_rewrite_ptr, /* glShadingRateImageBarrierNV */
    epoxy_glShadingRateImagePaletteNV_dispatch_table_rewrite_ptr, /* glShadingRateImagePaletteNV */
    epoxy_glShadingRateSampleOrderCustomNV_dispatch_table_rewrite_ptr, /* glShadingRateSampleOrderCustomNV */
    epoxy_glShadingRateSampleOrderNV_dispatch_table_rewrite_ptr, /* glShadingRateSampleOrderNV */
    epoxy_glSharpenTexFuncSGIS_dispatch_table_rewrite_ptr, /* glSharpenTexFuncSGIS */
    epoxy_glSignalSemaphoreEXT_dispatch_table_rewrite_ptr, /* glSignalSemaphoreEXT */
    epoxy_glSignalSemaphoreui64NVX_dispatch_table_rewrite_ptr, /* glSignalSemaphoreui64NVX */
    epoxy_glSignalVkFenceNV_dispatch_table_rewrite_ptr, /* glSignalVkFenceNV */
    epoxy_glSignalVkSemaphoreNV_dispatch_table_rewrite_ptr, /* glSignalVkSemaphoreNV */
    epoxy_glSpecializeShader_dispatch_table_rewrite_ptr, /* glSpecializeShader */
    epoxy_glSpecializeShaderARB_dispatch_table_rewrite_ptr, /* glSpecializeShaderARB */
    epoxy_glSpriteParameterfSGIX_dispatch_table_rewrite_ptr, /* glSpriteParameterfSGIX */
    epoxy_glSpriteParameterfvSGIX_dispatch_table_rewrite_ptr, /* glSpriteParameterfvSGIX */
    epoxy_glSpriteParameteriSGIX_dispatch_table_rewrite_ptr, /* glSpriteParameteriSGIX */
    epoxy_glSpriteParameterivSGIX_dispatch_table_rewrite_ptr, /* glSpriteParameterivSGIX */
    epoxy_glStartInstrumentsSGIX_dispatch_table_rewrite_ptr, /* glStartInstrumentsSGIX */
    epoxy_glStartTilingQCOM_dispatch_table_rewrite_ptr, /* glStartTilingQCOM */
    epoxy_glStateCaptureNV_dispatch_table_rewrite_ptr, /* glStateCaptureNV */
    epoxy_glStencilClearTagEXT_dispatch_table_rewrite_ptr, /* glStencilClearTagEXT */
    epoxy_glStencilFillPathInstancedNV_dispatch_table_rewrite_ptr, /* glStencilFillPathInstancedNV */
    epoxy_glStencilFillPathNV_dispatch_table_rewrite_ptr, /* glStencilFillPathNV */
    epoxy_glStencilFunc_dispatch_table_rewrite_ptr, /* glStencilFunc */
    epoxy_glStencilFuncSeparate_dispatch_table_rewrite_ptr, /* glStencilFuncSeparate */
    epoxy_glStencilFuncSeparateATI_dispatch_table_rewrite_ptr, /* glStencilFuncSeparateATI */
    epoxy_glStencilMask_dispatch_table_rewrite_ptr, /* glStencilMask */
    epoxy_glStencilMaskSeparate_dispatch_table_rewrite_ptr, /* glStencilMaskSeparate */
    epoxy_glStencilOp_dispatch_table_rewrite_ptr, /* glStencilOp */
    epoxy_glStencilOpSeparate_dispatch_table_rewrite_ptr, /* glStencilOpSeparate */
    epoxy_glStencilOpSeparateATI_dispatch_table_rewrite_ptr, /* glStencilOpSeparateATI */
    epoxy_glStencilOpValueAMD_dispatch_table_rewrite_ptr, /* glStencilOpValueAMD */
    epoxy_glStencilStrokePathInstancedNV_dispatch_table_rewrite_ptr, /* glStencilStrokePathInstancedNV */
    epoxy_glStencilStrokePathNV_dispatch_table_rewrite_ptr, /* glStencilStrokePathNV */
    epoxy_glStencilThenCoverFillPathInstancedNV_dispatch_table_rewrite_ptr, /* glStencilThenCoverFillPathInstancedNV */
    epoxy_glStencilThenCoverFillPathNV_dispatch_table_rewrite_ptr, /* glStencilThenCoverFillPathNV */
    epoxy_glStencilThenCoverStrokePathInstancedNV_dispatch_table_rewrite_ptr, /* glStencilThenCoverStrokePathInstancedNV */
    epoxy_glStencilThenCoverStrokePathNV_dispatch_table_rewrite_ptr, /* glStencilThenCoverStrokePathNV */
    epoxy_glStopInstrumentsSGIX_dispatch_table_rewrite_ptr, /* glStopInstrumentsSGIX */
    epoxy_glStringMarkerGREMEDY_dispatch_table_rewrite_ptr, /* glStringMarkerGREMEDY */
    epoxy_glSubpixelPrecisionBiasNV_dispatch_table_rewrite_ptr, /* glSubpixelPrecisionBiasNV */
    epoxy_glSwizzleEXT_dispatch_table_rewrite_ptr, /* glSwizzleEXT */
    epoxy_glSyncTextureINTEL_dispatch_table_rewrite_ptr, /* glSyncTextureINTEL */
    epoxy_glTagSampleBufferSGIX_dispatch_table_rewrite_ptr, /* glTagSampleBufferSGIX */
    epoxy_glTangent3bEXT_dispatch_table_rewrite_ptr, /* glTangent3bEXT */
    epoxy_glTangent3bvEXT_dispatch_table_rewrite_ptr, /* glTangent3bvEXT */
    epoxy_glTangent3dEXT_dispatch_table_rewrite_ptr, /* glTangent3dEXT */
    epoxy_glTangent3dvEXT_dispatch_table_rewrite_ptr, /* glTangent3dvEXT */
    epoxy_glTangent3fEXT_dispatch_table_rewrite_ptr, /* glTangent3fEXT */
    epoxy_glTangent3fvEXT_dispatch_table_rewrite_ptr, /* glTangent3fvEXT */
    epoxy_glTangent3iEXT_dispatch_table_rewrite_ptr, /* glTangent3iEXT */
    epoxy_glTangent3ivEXT_dispatch_table_rewrite_ptr, /* glTangent3ivEXT */
    epoxy_glTangent3sEXT_dispatch_table_rewrite_ptr, /* glTangent3sEXT */
    epoxy_glTangent3svEXT_dispatch_table_rewrite_ptr, /* glTangent3svEXT */
    epoxy_glTangentPointerEXT_dispatch_table_rewrite_ptr, /* glTangentPointerEXT */
    epoxy_glTbufferMask3DFX_dispatch_table_rewrite_ptr, /* glTbufferMask3DFX */
    epoxy_glTessellationFactorAMD_dispatch_table_rewrite_ptr, /* glTessellationFactorAMD */
    epoxy_glTessellationModeAMD_dispatch_table_rewrite_ptr, /* glTessellationModeAMD */
    epoxy_glTestFenceAPPLE_dispatch_table_rewrite_ptr, /* glTestFenceAPPLE */
    epoxy_glTestFenceNV_dispatch_table_rewrite_ptr, /* glTestFenceNV */
    epoxy_glTestObjectAPPLE_dispatch_table_rewrite_ptr, /* glTestObjectAPPLE */
    epoxy_glTexAttachMemoryNV_dispatch_table_rewrite_ptr, /* glTexAttachMemoryNV */
    epoxy_glTexBuffer_dispatch_table_rewrite_ptr, /* glTexBuffer */
    epoxy_glTexBufferARB_dispatch_table_rewrite_ptr, /* glTexBufferARB */
    epoxy_glTexBufferEXT_dispatch_table_rewrite_ptr, /* glTexBufferEXT */
    epoxy_glTexBufferOES_dispatch_table_rewrite_ptr, /* glTexBufferOES */
    epoxy_glTexBufferRange_dispatch_table_rewrite_ptr, /* glTexBufferRange */
    epoxy_glTexBufferRangeEXT_dispatch_table_rewrite_ptr, /* glTexBufferRangeEXT */
    epoxy_glTexBufferRangeOES_dispatch_table_rewrite_ptr, /* glTexBufferRangeOES */
    epoxy_glTexBumpParameterfvATI_dispatch_table_rewrite_ptr, /* glTexBumpParameterfvATI */
    epoxy_glTexBumpParameterivATI_dispatch_table_rewrite_ptr, /* glTexBumpParameterivATI */
    epoxy_glTexCoord1bOES_dispatch_table_rewrite_ptr, /* glTexCoord1bOES */
    epoxy_glTexCoord1bvOES_dispatch_table_rewrite_ptr, /* glTexCoord1bvOES */
    epoxy_glTexCoord1d_dispatch_table_rewrite_ptr, /* glTexCoord1d */
    epoxy_glTexCoord1dv_dispatch_table_rewrite_ptr, /* glTexCoord1dv */
    epoxy_glTexCoord1f_dispatch_table_rewrite_ptr, /* glTexCoord1f */
    epoxy_glTexCoord1fv_dispatch_table_rewrite_ptr, /* glTexCoord1fv */
    epoxy_glTexCoord1hNV_dispatch_table_rewrite_ptr, /* glTexCoord1hNV */
    epoxy_glTexCoord1hvNV_dispatch_table_rewrite_ptr, /* glTexCoord1hvNV */
    epoxy_glTexCoord1i_dispatch_table_rewrite_ptr, /* glTexCoord1i */
    epoxy_glTexCoord1iv_dispatch_table_rewrite_ptr, /* glTexCoord1iv */
    epoxy_glTexCoord1s_dispatch_table_rewrite_ptr, /* glTexCoord1s */
    epoxy_glTexCoord1sv_dispatch_table_rewrite_ptr, /* glTexCoord1sv */
    epoxy_glTexCoord1xOES_dispatch_table_rewrite_ptr, /* glTexCoord1xOES */
    epoxy_glTexCoord1xvOES_dispatch_table_rewrite_ptr, /* glTexCoord1xvOES */
    epoxy_glTexCoord2bOES_dispatch_table_rewrite_ptr, /* glTexCoord2bOES */
    epoxy_glTexCoord2bvOES_dispatch_table_rewrite_ptr, /* glTexCoord2bvOES */
    epoxy_glTexCoord2d_dispatch_table_rewrite_ptr, /* glTexCoord2d */
    epoxy_glTexCoord2dv_dispatch_table_rewrite_ptr, /* glTexCoord2dv */
    epoxy_glTexCoord2f_dispatch_table_rewrite_ptr, /* glTexCoord2f */
    epoxy_glTexCoord2fColor3fVertex3fSUN_dispatch_table_rewrite_ptr, /* glTexCoord2fColor3fVertex3fSUN */
    epoxy_glTexCoord2fColor3fVertex3fvSUN_dispatch_table_rewrite_ptr, /* glTexCoord2fColor3fVertex3fvSUN */
    epoxy_glTexCoord2fColor4fNormal3fVertex3fSUN_dispatch_table_rewrite_ptr, /* glTexCoord2fColor4fNormal3fVertex3fSUN */
    epoxy_glTexCoord2fColor4fNormal3fVertex3fvSUN_dispatch_table_rewrite_ptr, /* glTexCoord2fColor4fNormal3fVertex3fvSUN */
    epoxy_glTexCoord2fColor4ubVertex3fSUN_dispatch_table_rewrite_ptr, /* glTexCoord2fColor4ubVertex3fSUN */
    epoxy_glTexCoord2fColor4ubVertex3fvSUN_dispatch_table_rewrite_ptr, /* glTexCoord2fColor4ubVertex3fvSUN */
    epoxy_glTexCoord2fNormal3fVertex3fSUN_dispatch_table_rewrite_ptr, /* glTexCoord2fNormal3fVertex3fSUN */
    epoxy_glTexCoord2fNormal3fVertex3fvSUN_dispatch_table_rewrite_ptr, /* glTexCoord2fNormal3fVertex3fvSUN */
    epoxy_glTexCoord2fVertex3fSUN_dispatch_table_rewrite_ptr, /* glTexCoord2fVertex3fSUN */
    epoxy_glTexCoord2fVertex3fvSUN_dispatch_table_rewrite_ptr, /* glTexCoord2fVertex3fvSUN */
    epoxy_glTexCoord2fv_dispatch_table_rewrite_ptr, /* glTexCoord2fv */
    epoxy_glTexCoord2hNV_dispatch_table_rewrite_ptr, /* glTexCoord2hNV */
    epoxy_glTexCoord2hvNV_dispatch_table_rewrite_ptr, /* glTexCoord2hvNV */
    epoxy_glTexCoord2i_dispatch_table_rewrite_ptr, /* glTexCoord2i */
    epoxy_glTexCoord2iv_dispatch_table_rewrite_ptr, /* glTexCoord2iv */
    epoxy_glTexCoord2s_dispatch_table_rewrite_ptr, /* glTexCoord2s */
    epoxy_glTexCoord2sv_dispatch_table_rewrite_ptr, /* glTexCoord2sv */
    epoxy_glTexCoord2xOES_dispatch_table_rewrite_ptr, /* glTexCoord2xOES */
    epoxy_glTexCoord2xvOES_dispatch_table_rewrite_ptr, /* glTexCoord2xvOES */
    epoxy_glTexCoord3bOES_dispatch_table_rewrite_ptr, /* glTexCoord3bOES */
    epoxy_glTexCoord3bvOES_dispatch_table_rewrite_ptr, /* glTexCoord3bvOES */
    epoxy_glTexCoord3d_dispatch_table_rewrite_ptr, /* glTexCoord3d */
    epoxy_glTexCoord3dv_dispatch_table_rewrite_ptr, /* glTexCoord3dv */
    epoxy_glTexCoord3f_dispatch_table_rewrite_ptr, /* glTexCoord3f */
    epoxy_glTexCoord3fv_dispatch_table_rewrite_ptr, /* glTexCoord3fv */
    epoxy_glTexCoord3hNV_dispatch_table_rewrite_ptr, /* glTexCoord3hNV */
    epoxy_glTexCoord3hvNV_dispatch_table_rewrite_ptr, /* glTexCoord3hvNV */
    epoxy_glTexCoord3i_dispatch_table_rewrite_ptr, /* glTexCoord3i */
    epoxy_glTexCoord3iv_dispatch_table_rewrite_ptr, /* glTexCoord3iv */
    epoxy_glTexCoord3s_dispatch_table_rewrite_ptr, /* glTexCoord3s */
    epoxy_glTexCoord3sv_dispatch_table_rewrite_ptr, /* glTexCoord3sv */
    epoxy_glTexCoord3xOES_dispatch_table_rewrite_ptr, /* glTexCoord3xOES */
    epoxy_glTexCoord3xvOES_dispatch_table_rewrite_ptr, /* glTexCoord3xvOES */
    epoxy_glTexCoord4bOES_dispatch_table_rewrite_ptr, /* glTexCoord4bOES */
    epoxy_glTexCoord4bvOES_dispatch_table_rewrite_ptr, /* glTexCoord4bvOES */
    epoxy_glTexCoord4d_dispatch_table_rewrite_ptr, /* glTexCoord4d */
    epoxy_glTexCoord4dv_dispatch_table_rewrite_ptr, /* glTexCoord4dv */
    epoxy_glTexCoord4f_dispatch_table_rewrite_ptr, /* glTexCoord4f */
    epoxy_glTexCoord4fColor4fNormal3fVertex4fSUN_dispatch_table_rewrite_ptr, /* glTexCoord4fColor4fNormal3fVertex4fSUN */
    epoxy_glTexCoord4fColor4fNormal3fVertex4fvSUN_dispatch_table_rewrite_ptr, /* glTexCoord4fColor4fNormal3fVertex4fvSUN */
    epoxy_glTexCoord4fVertex4fSUN_dispatch_table_rewrite_ptr, /* glTexCoord4fVertex4fSUN */
    epoxy_glTexCoord4fVertex4fvSUN_dispatch_table_rewrite_ptr, /* glTexCoord4fVertex4fvSUN */
    epoxy_glTexCoord4fv_dispatch_table_rewrite_ptr, /* glTexCoord4fv */
    epoxy_glTexCoord4hNV_dispatch_table_rewrite_ptr, /* glTexCoord4hNV */
    epoxy_glTexCoord4hvNV_dispatch_table_rewrite_ptr, /* glTexCoord4hvNV */
    epoxy_glTexCoord4i_dispatch_table_rewrite_ptr, /* glTexCoord4i */
    epoxy_glTexCoord4iv_dispatch_table_rewrite_ptr, /* glTexCoord4iv */
    epoxy_glTexCoord4s_dispatch_table_rewrite_ptr, /* glTexCoord4s */
    epoxy_glTexCoord4sv_dispatch_table_rewrite_ptr, /* glTexCoord4sv */
    epoxy_glTexCoord4xOES_dispatch_table_rewrite_ptr, /* glTexCoord4xOES */
    epoxy_glTexCoord4xvOES_dispatch_table_rewrite_ptr, /* glTexCoord4xvOES */
    epoxy_glTexCoordFormatNV_dispatch_table_rewrite_ptr, /* glTexCoordFormatNV */
    epoxy_glTexCoordP1ui_dispatch_table_rewrite_ptr, /* glTexCoordP1ui */
    epoxy_glTexCoordP1uiv_dispatch_table_rewrite_ptr, /* glTexCoordP1uiv */
    epoxy_glTexCoordP2ui_dispatch_table_rewrite_ptr, /* glTexCoordP2ui */
    epoxy_glTexCoordP2uiv_dispatch_table_rewrite_ptr, /* glTexCoordP2uiv */
    epoxy_glTexCoordP3ui_dispatch_table_rewrite_ptr, /* glTexCoordP3ui */
    epoxy_glTexCoordP3uiv_dispatch_table_rewrite_ptr, /* glTexCoordP3uiv */
    epoxy_glTexCoordP4ui_dispatch_table_rewrite_ptr, /* glTexCoordP4ui */
    epoxy_glTexCoordP4uiv_dispatch_table_rewrite_ptr, /* glTexCoordP4uiv */
    epoxy_glTexCoordPointer_dispatch_table_rewrite_ptr, /* glTexCoordPointer */
    epoxy_glTexCoordPointerEXT_dispatch_table_rewrite_ptr, /* glTexCoordPointerEXT */
    epoxy_glTexCoordPointerListIBM_dispatch_table_rewrite_ptr, /* glTexCoordPointerListIBM */
    epoxy_glTexCoordPointervINTEL_dispatch_table_rewrite_ptr, /* glTexCoordPointervINTEL */
    epoxy_glTexEnvf_dispatch_table_rewrite_ptr, /* glTexEnvf */
    epoxy_glTexEnvfv_dispatch_table_rewrite_ptr, /* glTexEnvfv */
    epoxy_glTexEnvi_dispatch_table_rewrite_ptr, /* glTexEnvi */
    epoxy_glTexEnviv_dispatch_table_rewrite_ptr, /* glTexEnviv */
    epoxy_glTexEnvx_dispatch_table_rewrite_ptr, /* glTexEnvx */
    epoxy_glTexEnvxOES_dispatch_table_rewrite_ptr, /* glTexEnvxOES */
    epoxy_glTexEnvxv_dispatch_table_rewrite_ptr, /* glTexEnvxv */
    epoxy_glTexEnvxvOES_dispatch_table_rewrite_ptr, /* glTexEnvxvOES */
    epoxy_glTexFilterFuncSGIS_dispatch_table_rewrite_ptr, /* glTexFilterFuncSGIS */
    epoxy_glTexGend_dispatch_table_rewrite_ptr, /* glTexGend */
    epoxy_glTexGendv_dispatch_table_rewrite_ptr, /* glTexGendv */
    epoxy_glTexGenf_dispatch_table_rewrite_ptr, /* glTexGenf */
    epoxy_glTexGenfOES_dispatch_table_rewrite_ptr, /* glTexGenfOES */
    epoxy_glTexGenfv_dispatch_table_rewrite_ptr, /* glTexGenfv */
    epoxy_glTexGenfvOES_dispatch_table_rewrite_ptr, /* glTexGenfvOES */
    epoxy_glTexGeni_dispatch_table_rewrite_ptr, /* glTexGeni */
    epoxy_glTexGeniOES_dispatch_table_rewrite_ptr, /* glTexGeniOES */
    epoxy_glTexGeniv_dispatch_table_rewrite_ptr, /* glTexGeniv */
    epoxy_glTexGenivOES_dispatch_table_rewrite_ptr, /* glTexGenivOES */
    epoxy_glTexGenxOES_dispatch_table_rewrite_ptr, /* glTexGenxOES */
    epoxy_glTexGenxvOES_dispatch_table_rewrite_ptr, /* glTexGenxvOES */
    epoxy_glTexImage1D_dispatch_table_rewrite_ptr, /* glTexImage1D */
    epoxy_glTexImage2D_dispatch_table_rewrite_ptr, /* glTexImage2D */
    epoxy_glTexImage2DMultisample_dispatch_table_rewrite_ptr, /* glTexImage2DMultisample */
    epoxy_glTexImage2DMultisampleCoverageNV_dispatch_table_rewrite_ptr, /* glTexImage2DMultisampleCoverageNV */
    epoxy_glTexImage3D_dispatch_table_rewrite_ptr, /* glTexImage3D */
    epoxy_glTexImage3DEXT_dispatch_table_rewrite_ptr, /* glTexImage3DEXT */
    epoxy_glTexImage3DMultisample_dispatch_table_rewrite_ptr, /* glTexImage3DMultisample */
    epoxy_glTexImage3DMultisampleCoverageNV_dispatch_table_rewrite_ptr, /* glTexImage3DMultisampleCoverageNV */
    epoxy_glTexImage3DOES_dispatch_table_rewrite_ptr, /* glTexImage3DOES */
    epoxy_glTexImage4DSGIS_dispatch_table_rewrite_ptr, /* glTexImage4DSGIS */
    epoxy_glTexPageCommitmentARB_dispatch_table_rewrite_ptr, /* glTexPageCommitmentARB */
    epoxy_glTexPageCommitmentEXT_dispatch_table_rewrite_ptr, /* glTexPageCommitmentEXT */
    epoxy_glTexParameterIiv_dispatch_table_rewrite_ptr, /* glTexParameterIiv */
    epoxy_glTexParameterIivEXT_dispatch_table_rewrite_ptr, /* glTexParameterIivEXT */
    epoxy_glTexParameterIivOES_dispatch_table_rewrite_ptr, /* glTexParameterIivOES */
    epoxy_glTexParameterIuiv_dispatch_table_rewrite_ptr, /* glTexParameterIuiv */
    epoxy_glTexParameterIuivEXT_dispatch_table_rewrite_ptr, /* glTexParameterIuivEXT */
    epoxy_glTexParameterIuivOES_dispatch_table_rewrite_ptr, /* glTexParameterIuivOES */
    epoxy_glTexParameterf_dispatch_table_rewrite_ptr, /* glTexParameterf */
    epoxy_glTexParameterfv_dispatch_table_rewrite_ptr, /* glTexParameterfv */
    epoxy_glTexParameteri_dispatch_table_rewrite_ptr, /* glTexParameteri */
    epoxy_glTexParameteriv_dispatch_table_rewrite_ptr, /* glTexParameteriv */
    epoxy_glTexParameterx_dispatch_table_rewrite_ptr, /* glTexParameterx */
    epoxy_glTexParameterxOES_dispatch_table_rewrite_ptr, /* glTexParameterxOES */
    epoxy_glTexParameterxv_dispatch_table_rewrite_ptr, /* glTexParameterxv */
    epoxy_glTexParameterxvOES_dispatch_table_rewrite_ptr, /* glTexParameterxvOES */
    epoxy_glTexRenderbufferNV_dispatch_table_rewrite_ptr, /* glTexRenderbufferNV */
    epoxy_glTexStorage1D_dispatch_table_rewrite_ptr, /* glTexStorage1D */
    epoxy_glTexStorage1DEXT_dispatch_table_rewrite_ptr, /* glTexStorage1DEXT */
    epoxy_glTexStorage2D_dispatch_table_rewrite_ptr, /* glTexStorage2D */
    epoxy_glTexStorage2DEXT_dispatch_table_rewrite_ptr, /* glTexStorage2DEXT */
    epoxy_glTexStorage2DMultisample_dispatch_table_rewrite_ptr, /* glTexStorage2DMultisample */
    epoxy_glTexStorage3D_dispatch_table_rewrite_ptr, /* glTexStorage3D */
    epoxy_glTexStorage3DEXT_dispatch_table_rewrite_ptr, /* glTexStorage3DEXT */
    epoxy_glTexStorage3DMultisample_dispatch_table_rewrite_ptr, /* glTexStorage3DMultisample */
    epoxy_glTexStorage3DMultisampleOES_dispatch_table_rewrite_ptr, /* glTexStorage3DMultisampleOES */
    epoxy_glTexStorageMem1DEXT_dispatch_table_rewrite_ptr, /* glTexStorageMem1DEXT */
    epoxy_glTexStorageMem2DEXT_dispatch_table_rewrite_ptr, /* glTexStorageMem2DEXT */
    epoxy_glTexStorageMem2DMultisampleEXT_dispatch_table_rewrite_ptr, /* glTexStorageMem2DMultisampleEXT */
    epoxy_glTexStorageMem3DEXT_dispatch_table_rewrite_ptr, /* glTexStorageMem3DEXT */
    epoxy_glTexStorageMem3DMultisampleEXT_dispatch_table_rewrite_ptr, /* glTexStorageMem3DMultisampleEXT */
    epoxy_glTexStorageSparseAMD_dispatch_table_rewrite_ptr, /* glTexStorageSparseAMD */
    epoxy_glTexSubImage1D_dispatch_table_rewrite_ptr, /* glTexSubImage1D */
    epoxy_glTexSubImage1DEXT_dispatch_table_rewrite_ptr, /* glTexSubImage1DEXT */
    epoxy_glTexSubImage2D_dispatch_table_rewrite_ptr, /* glTexSubImage2D */
    epoxy_glTexSubImage2DEXT_dispatch_table_rewrite_ptr, /* glTexSubImage2DEXT */
    epoxy_glTexSubImage3D_dispatch_table_rewrite_ptr, /* glTexSubImage3D */
    epoxy_glTexSubImage3DEXT_dispatch_table_rewrite_ptr, /* glTexSubImage3DEXT */
    epoxy_glTexSubImage3DOES_dispatch_table_rewrite_ptr, /* glTexSubImage3DOES */
    epoxy_glTexSubImage4DSGIS_dispatch_table_rewrite_ptr, /* glTexSubImage4DSGIS */
    epoxy_glTextureAttachMemoryNV_dispatch_table_rewrite_ptr, /* glTextureAttachMemoryNV */
    epoxy_glTextureBarrier_dispatch_table_rewrite_ptr, /* glTextureBarrier */
    epoxy_glTextureBarrierNV_dispatch_table_rewrite_ptr, /* glTextureBarrierNV */
    epoxy_glTextureBuffer_dispatch_table_rewrite_ptr, /* glTextureBuffer */
    epoxy_glTextureBufferEXT_dispatch_table_rewrite_ptr, /* glTextureBufferEXT */
    epoxy_glTextureBufferRange_dispatch_table_rewrite_ptr, /* glTextureBufferRange */
    epoxy_glTextureBufferRangeEXT_dispatch_table_rewrite_ptr, /* glTextureBufferRangeEXT */
    epoxy_glTextureColorMaskSGIS_dispatch_table_rewrite_ptr, /* glTextureColorMaskSGIS */
    epoxy_glTextureFoveationParametersQCOM_dispatch_table_rewrite_ptr, /* glTextureFoveationParametersQCOM */
    epoxy_glTextureImage1DEXT_dispatch_table_rewrite_ptr, /* glTextureImage1DEXT */
    epoxy_glTextureImage2DEXT_dispatch_table_rewrite_ptr, /* glTextureImage2DEXT */
    epoxy_glTextureImage2DMultisampleCoverageNV_dispatch_table_rewrite_ptr, /* glTextureImage2DMultisampleCoverageNV */
    epoxy_glTextureImage2DMultisampleNV_dispatch_table_rewrite_ptr, /* glTextureImage2DMultisampleNV */
    epoxy_glTextureImage3DEXT_dispatch_table_rewrite_ptr, /* glTextureImage3DEXT */
    epoxy_glTextureImage3DMultisampleCoverageNV_dispatch_table_rewrite_ptr, /* glTextureImage3DMultisampleCoverageNV */
    epoxy_glTextureImage3DMultisampleNV_dispatch_table_rewrite_ptr, /* glTextureImage3DMultisampleNV */
    epoxy_glTextureLightEXT_dispatch_table_rewrite_ptr, /* glTextureLightEXT */
    epoxy_glTextureMaterialEXT_dispatch_table_rewrite_ptr, /* glTextureMaterialEXT */
    epoxy_glTextureNormalEXT_dispatch_table_rewrite_ptr, /* glTextureNormalEXT */
    epoxy_glTexturePageCommitmentEXT_dispatch_table_rewrite_ptr, /* glTexturePageCommitmentEXT */
    epoxy_glTextureParameterIiv_dispatch_table_rewrite_ptr, /* glTextureParameterIiv */
    epoxy_glTextureParameterIivEXT_dispatch_table_rewrite_ptr, /* glTextureParameterIivEXT */
    epoxy_glTextureParameterIuiv_dispatch_table_rewrite_ptr, /* glTextureParameterIuiv */
    epoxy_glTextureParameterIuivEXT_dispatch_table_rewrite_ptr, /* glTextureParameterIuivEXT */
    epoxy_glTextureParameterf_dispatch_table_rewrite_ptr, /* glTextureParameterf */
    epoxy_glTextureParameterfEXT_dispatch_table_rewrite_ptr, /* glTextureParameterfEXT */
    epoxy_glTextureParameterfv_dispatch_table_rewrite_ptr, /* glTextureParameterfv */
    epoxy_glTextureParameterfvEXT_dispatch_table_rewrite_ptr, /* glTextureParameterfvEXT */
    epoxy_glTextureParameteri_dispatch_table_rewrite_ptr, /* glTextureParameteri */
    epoxy_glTextureParameteriEXT_dispatch_table_rewrite_ptr, /* glTextureParameteriEXT */
    epoxy_glTextureParameteriv_dispatch_table_rewrite_ptr, /* glTextureParameteriv */
    epoxy_glTextureParameterivEXT_dispatch_table_rewrite_ptr, /* glTextureParameterivEXT */
    epoxy_glTextureRangeAPPLE_dispatch_table_rewrite_ptr, /* glTextureRangeAPPLE */
    epoxy_glTextureRenderbufferEXT_dispatch_table_rewrite_ptr, /* glTextureRenderbufferEXT */
    epoxy_glTextureStorage1D_dispatch_table_rewrite_ptr, /* glTextureStorage1D */
    epoxy_glTextureStorage1DEXT_dispatch_table_rewrite_ptr, /* glTextureStorage1DEXT */
    epoxy_glTextureStorage2D_dispatch_table_rewrite_ptr, /* glTextureStorage2D */
    epoxy_glTextureStorage2DEXT_dispatch_table_rewrite_ptr, /* glTextureStorage2DEXT */
    epoxy_glTextureStorage2DMultisample_dispatch_table_rewrite_ptr, /* glTextureStorage2DMultisample */
    epoxy_glTextureStorage2DMultisampleEXT_dispatch_table_rewrite_ptr, /* glTextureStorage2DMultisampleEXT */
    epoxy_glTextureStorage3D_dispatch_table_rewrite_ptr, /* glTextureStorage3D */
    epoxy_glTextureStorage3DEXT_dispatch_table_rewrite_ptr, /* glTextureStorage3DEXT */
    epoxy_glTextureStorage3DMultisample_dispatch_table_rewrite_ptr, /* glTextureStorage3DMultisample */
    epoxy_glTextureStorage3DMultisampleEXT_dispatch_table_rewrite_ptr, /* glTextureStorage3DMultisampleEXT */
    epoxy_glTextureStorageMem1DEXT_dispatch_table_rewrite_ptr, /* glTextureStorageMem1DEXT */
    epoxy_glTextureStorageMem2DEXT_dispatch_table_rewrite_ptr, /* glTextureStorageMem2DEXT */
    epoxy_glTextureStorageMem2DMultisampleEXT_dispatch_table_rewrite_ptr, /* glTextureStorageMem2DMultisampleEXT */
    epoxy_glTextureStorageMem3DEXT_dispatch_table_rewrite_ptr, /* glTextureStorageMem3DEXT */
    epoxy_glTextureStorageMem3DMultisampleEXT_dispatch_table_rewrite_ptr, /* glTextureStorageMem3DMultisampleEXT */
    epoxy_glTextureStorageSparseAMD_dispatch_table_rewrite_ptr, /* glTextureStorageSparseAMD */
    epoxy_glTextureSubImage1D_dispatch_table_rewrite_ptr, /* glTextureSubImage1D */
    epoxy_glTextureSubImage1DEXT_dispatch_table_rewrite_ptr, /* glTextureSubImage1DEXT */
    epoxy_glTextureSubImage2D_dispatch_table_rewrite_ptr, /* glTextureSubImage2D */
    epoxy_glTextureSubImage2DEXT_dispatch_table_rewrite_ptr, /* glTextureSubImage2DEXT */
    epoxy_glTextureSubImage3D_dispatch_table_rewrite_ptr, /* glTextureSubImage3D */
    epoxy_glTextureSubImage3DEXT_dispatch_table_rewrite_ptr, /* glTextureSubImage3DEXT */
    epoxy_glTextureView_dispatch_table_rewrite_ptr, /* glTextureView */
    epoxy_glTextureViewEXT_dispatch_table_rewrite_ptr, /* glTextureViewEXT */
    epoxy_glTextureViewOES_dispatch_table_rewrite_ptr, /* glTextureViewOES */
    epoxy_glTrackMatrixNV_dispatch_table_rewrite_ptr, /* glTrackMatrixNV */
    epoxy_glTransformFeedbackAttribsNV_dispatch_table_rewrite_ptr, /* glTransformFeedbackAttribsNV */
    epoxy_glTransformFeedbackBufferBase_dispatch_table_rewrite_ptr, /* glTransformFeedbackBufferBase */
    epoxy_glTransformFeedbackBufferRange_dispatch_table_rewrite_ptr, /* glTransformFeedbackBufferRange */
    epoxy_glTransformFeedbackStreamAttribsNV_dispatch_table_rewrite_ptr, /* glTransformFeedbackStreamAttribsNV */
    epoxy_glTransformFeedbackVaryings_dispatch_table_rewrite_ptr, /* glTransformFeedbackVaryings */
    epoxy_glTransformFeedbackVaryingsEXT_dispatch_table_rewrite_ptr, /* glTransformFeedbackVaryingsEXT */
    epoxy_glTransformFeedbackVaryingsNV_dispatch_table_rewrite_ptr, /* glTransformFeedbackVaryingsNV */
    epoxy_glTransformPathNV_dispatch_table_rewrite_ptr, /* glTransformPathNV */
    epoxy_glTranslated_dispatch_table_rewrite_ptr, /* glTranslated */
    epoxy_glTranslatef_dispatch_table_rewrite_ptr, /* glTranslatef */
    epoxy_glTranslatex_dispatch_table_rewrite_ptr, /* glTranslatex */
    epoxy_glTranslatexOES_dispatch_table_rewrite_ptr, /* glTranslatexOES */
    epoxy_glUniform1d_dispatch_table_rewrite_ptr, /* glUniform1d */
    epoxy_glUniform1dv_dispatch_table_rewrite_ptr, /* glUniform1dv */
    epoxy_glUniform1f_dispatch_table_rewrite_ptr, /* glUniform1f */
    epoxy_glUniform1fARB_dispatch_table_rewrite_ptr, /* glUniform1fARB */
    epoxy_glUniform1fv_dispatch_table_rewrite_ptr, /* glUniform1fv */
    epoxy_glUniform1fvARB_dispatch_table_rewrite_ptr, /* glUniform1fvARB */
    epoxy_glUniform1i_dispatch_table_rewrite_ptr, /* glUniform1i */
    epoxy_glUniform1i64ARB_dispatch_table_rewrite_ptr, /* glUniform1i64ARB */
    epoxy_glUniform1i64NV_dispatch_table_rewrite_ptr, /* glUniform1i64NV */
    epoxy_glUniform1i64vARB_dispatch_table_rewrite_ptr, /* glUniform1i64vARB */
    epoxy_glUniform1i64vNV_dispatch_table_rewrite_ptr, /* glUniform1i64vNV */
    epoxy_glUniform1iARB_dispatch_table_rewrite_ptr, /* glUniform1iARB */
    epoxy_glUniform1iv_dispatch_table_rewrite_ptr, /* glUniform1iv */
    epoxy_glUniform1ivARB_dispatch_table_rewrite_ptr, /* glUniform1ivARB */
    epoxy_glUniform1ui_dispatch_table_rewrite_ptr, /* glUniform1ui */
    epoxy_glUniform1ui64ARB_dispatch_table_rewrite_ptr, /* glUniform1ui64ARB */
    epoxy_glUniform1ui64NV_dispatch_table_rewrite_ptr, /* glUniform1ui64NV */
    epoxy_glUniform1ui64vARB_dispatch_table_rewrite_ptr, /* glUniform1ui64vARB */
    epoxy_glUniform1ui64vNV_dispatch_table_rewrite_ptr, /* glUniform1ui64vNV */
    epoxy_glUniform1uiEXT_dispatch_table_rewrite_ptr, /* glUniform1uiEXT */
    epoxy_glUniform1uiv_dispatch_table_rewrite_ptr, /* glUniform1uiv */
    epoxy_glUniform1uivEXT_dispatch_table_rewrite_ptr, /* glUniform1uivEXT */
    epoxy_glUniform2d_dispatch_table_rewrite_ptr, /* glUniform2d */
    epoxy_glUniform2dv_dispatch_table_rewrite_ptr, /* glUniform2dv */
    epoxy_glUniform2f_dispatch_table_rewrite_ptr, /* glUniform2f */
    epoxy_glUniform2fARB_dispatch_table_rewrite_ptr, /* glUniform2fARB */
    epoxy_glUniform2fv_dispatch_table_rewrite_ptr, /* glUniform2fv */
    epoxy_glUniform2fvARB_dispatch_table_rewrite_ptr, /* glUniform2fvARB */
    epoxy_glUniform2i_dispatch_table_rewrite_ptr, /* glUniform2i */
    epoxy_glUniform2i64ARB_dispatch_table_rewrite_ptr, /* glUniform2i64ARB */
    epoxy_glUniform2i64NV_dispatch_table_rewrite_ptr, /* glUniform2i64NV */
    epoxy_glUniform2i64vARB_dispatch_table_rewrite_ptr, /* glUniform2i64vARB */
    epoxy_glUniform2i64vNV_dispatch_table_rewrite_ptr, /* glUniform2i64vNV */
    epoxy_glUniform2iARB_dispatch_table_rewrite_ptr, /* glUniform2iARB */
    epoxy_glUniform2iv_dispatch_table_rewrite_ptr, /* glUniform2iv */
    epoxy_glUniform2ivARB_dispatch_table_rewrite_ptr, /* glUniform2ivARB */
    epoxy_glUniform2ui_dispatch_table_rewrite_ptr, /* glUniform2ui */
    epoxy_glUniform2ui64ARB_dispatch_table_rewrite_ptr, /* glUniform2ui64ARB */
    epoxy_glUniform2ui64NV_dispatch_table_rewrite_ptr, /* glUniform2ui64NV */
    epoxy_glUniform2ui64vARB_dispatch_table_rewrite_ptr, /* glUniform2ui64vARB */
    epoxy_glUniform2ui64vNV_dispatch_table_rewrite_ptr, /* glUniform2ui64vNV */
    epoxy_glUniform2uiEXT_dispatch_table_rewrite_ptr, /* glUniform2uiEXT */
    epoxy_glUniform2uiv_dispatch_table_rewrite_ptr, /* glUniform2uiv */
    epoxy_glUniform2uivEXT_dispatch_table_rewrite_ptr, /* glUniform2uivEXT */
    epoxy_glUniform3d_dispatch_table_rewrite_ptr, /* glUniform3d */
    epoxy_glUniform3dv_dispatch_table_rewrite_ptr, /* glUniform3dv */
    epoxy_glUniform3f_dispatch_table_rewrite_ptr, /* glUniform3f */
    epoxy_glUniform3fARB_dispatch_table_rewrite_ptr, /* glUniform3fARB */
    epoxy_glUniform3fv_dispatch_table_rewrite_ptr, /* glUniform3fv */
    epoxy_glUniform3fvARB_dispatch_table_rewrite_ptr, /* glUniform3fvARB */
    epoxy_glUniform3i_dispatch_table_rewrite_ptr, /* glUniform3i */
    epoxy_glUniform3i64ARB_dispatch_table_rewrite_ptr, /* glUniform3i64ARB */
    epoxy_glUniform3i64NV_dispatch_table_rewrite_ptr, /* glUniform3i64NV */
    epoxy_glUniform3i64vARB_dispatch_table_rewrite_ptr, /* glUniform3i64vARB */
    epoxy_glUniform3i64vNV_dispatch_table_rewrite_ptr, /* glUniform3i64vNV */
    epoxy_glUniform3iARB_dispatch_table_rewrite_ptr, /* glUniform3iARB */
    epoxy_glUniform3iv_dispatch_table_rewrite_ptr, /* glUniform3iv */
    epoxy_glUniform3ivARB_dispatch_table_rewrite_ptr, /* glUniform3ivARB */
    epoxy_glUniform3ui_dispatch_table_rewrite_ptr, /* glUniform3ui */
    epoxy_glUniform3ui64ARB_dispatch_table_rewrite_ptr, /* glUniform3ui64ARB */
    epoxy_glUniform3ui64NV_dispatch_table_rewrite_ptr, /* glUniform3ui64NV */
    epoxy_glUniform3ui64vARB_dispatch_table_rewrite_ptr, /* glUniform3ui64vARB */
    epoxy_glUniform3ui64vNV_dispatch_table_rewrite_ptr, /* glUniform3ui64vNV */
    epoxy_glUniform3uiEXT_dispatch_table_rewrite_ptr, /* glUniform3uiEXT */
    epoxy_glUniform3uiv_dispatch_table_rewrite_ptr, /* glUniform3uiv */
    epoxy_glUniform3uivEXT_dispatch_table_rewrite_ptr, /* glUniform3uivEXT */
    epoxy_glUniform4d_dispatch_table_rewrite_ptr, /* glUniform4d */
    epoxy_glUniform4dv_dispatch_table_rewrite_ptr, /* glUniform4dv */
    epoxy_glUniform4f_dispatch_table_rewrite_ptr, /* glUniform4f */
    epoxy_glUniform4fARB_dispatch_table_rewrite_ptr, /* glUniform4fARB */
    epoxy_glUniform4fv_dispatch_table_rewrite_ptr, /* glUniform4fv */
    epoxy_glUniform4fvARB_dispatch_table_rewrite_ptr, /* glUniform4fvARB */
    epoxy_glUniform4i_dispatch_table_rewrite_ptr, /* glUniform4i */
    epoxy_glUniform4i64ARB_dispatch_table_rewrite_ptr, /* glUniform4i64ARB */
    epoxy_glUniform4i64NV_dispatch_table_rewrite_ptr, /* glUniform4i64NV */
    epoxy_glUniform4i64vARB_dispatch_table_rewrite_ptr, /* glUniform4i64vARB */
    epoxy_glUniform4i64vNV_dispatch_table_rewrite_ptr, /* glUniform4i64vNV */
    epoxy_glUniform4iARB_dispatch_table_rewrite_ptr, /* glUniform4iARB */
    epoxy_glUniform4iv_dispatch_table_rewrite_ptr, /* glUniform4iv */
    epoxy_glUniform4ivARB_dispatch_table_rewrite_ptr, /* glUniform4ivARB */
    epoxy_glUniform4ui_dispatch_table_rewrite_ptr, /* glUniform4ui */
    epoxy_glUniform4ui64ARB_dispatch_table_rewrite_ptr, /* glUniform4ui64ARB */
    epoxy_glUniform4ui64NV_dispatch_table_rewrite_ptr, /* glUniform4ui64NV */
    epoxy_glUniform4ui64vARB_dispatch_table_rewrite_ptr, /* glUniform4ui64vARB */
    epoxy_glUniform4ui64vNV_dispatch_table_rewrite_ptr, /* glUniform4ui64vNV */
    epoxy_glUniform4uiEXT_dispatch_table_rewrite_ptr, /* glUniform4uiEXT */
    epoxy_glUniform4uiv_dispatch_table_rewrite_ptr, /* glUniform4uiv */
    epoxy_glUniform4uivEXT_dispatch_table_rewrite_ptr, /* glUniform4uivEXT */
    epoxy_glUniformBlockBinding_dispatch_table_rewrite_ptr, /* glUniformBlockBinding */
    epoxy_glUniformBufferEXT_dispatch_table_rewrite_ptr, /* glUniformBufferEXT */
    epoxy_glUniformHandleui64ARB_dispatch_table_rewrite_ptr, /* glUniformHandleui64ARB */
    epoxy_glUniformHandleui64IMG_dispatch_table_rewrite_ptr, /* glUniformHandleui64IMG */
    epoxy_glUniformHandleui64NV_dispatch_table_rewrite_ptr, /* glUniformHandleui64NV */
    epoxy_glUniformHandleui64vARB_dispatch_table_rewrite_ptr, /* glUniformHandleui64vARB */
    epoxy_glUniformHandleui64vIMG_dispatch_table_rewrite_ptr, /* glUniformHandleui64vIMG */
    epoxy_glUniformHandleui64vNV_dispatch_table_rewrite_ptr, /* glUniformHandleui64vNV */
    epoxy_glUniformMatrix2dv_dispatch_table_rewrite_ptr, /* glUniformMatrix2dv */
    epoxy_glUniformMatrix2fv_dispatch_table_rewrite_ptr, /* glUniformMatrix2fv */
    epoxy_glUniformMatrix2fvARB_dispatch_table_rewrite_ptr, /* glUniformMatrix2fvARB */
    epoxy_glUniformMatrix2x3dv_dispatch_table_rewrite_ptr, /* glUniformMatrix2x3dv */
    epoxy_glUniformMatrix2x3fv_dispatch_table_rewrite_ptr, /* glUniformMatrix2x3fv */
    epoxy_glUniformMatrix2x3fvNV_dispatch_table_rewrite_ptr, /* glUniformMatrix2x3fvNV */
    epoxy_glUniformMatrix2x4dv_dispatch_table_rewrite_ptr, /* glUniformMatrix2x4dv */
    epoxy_glUniformMatrix2x4fv_dispatch_table_rewrite_ptr, /* glUniformMatrix2x4fv */
    epoxy_glUniformMatrix2x4fvNV_dispatch_table_rewrite_ptr, /* glUniformMatrix2x4fvNV */
    epoxy_glUniformMatrix3dv_dispatch_table_rewrite_ptr, /* glUniformMatrix3dv */
    epoxy_glUniformMatrix3fv_dispatch_table_rewrite_ptr, /* glUniformMatrix3fv */
    epoxy_glUniformMatrix3fvARB_dispatch_table_rewrite_ptr, /* glUniformMatrix3fvARB */
    epoxy_glUniformMatrix3x2dv_dispatch_table_rewrite_ptr, /* glUniformMatrix3x2dv */
    epoxy_glUniformMatrix3x2fv_dispatch_table_rewrite_ptr, /* glUniformMatrix3x2fv */
    epoxy_glUniformMatrix3x2fvNV_dispatch_table_rewrite_ptr, /* glUniformMatrix3x2fvNV */
    epoxy_glUniformMatrix3x4dv_dispatch_table_rewrite_ptr, /* glUniformMatrix3x4dv */
    epoxy_glUniformMatrix3x4fv_dispatch_table_rewrite_ptr, /* glUniformMatrix3x4fv */
    epoxy_glUniformMatrix3x4fvNV_dispatch_table_rewrite_ptr, /* glUniformMatrix3x4fvNV */
    epoxy_glUniformMatrix4dv_dispatch_table_rewrite_ptr, /* glUniformMatrix4dv */
    epoxy_glUniformMatrix4fv_dispatch_table_rewrite_ptr, /* glUniformMatrix4fv */
    epoxy_glUniformMatrix4fvARB_dispatch_table_rewrite_ptr, /* glUniformMatrix4fvARB */
    epoxy_glUniformMatrix4x2dv_dispatch_table_rewrite_ptr, /* glUniformMatrix4x2dv */
    epoxy_glUniformMatrix4x2fv_dispatch_table_rewrite_ptr, /* glUniformMatrix4x2fv */
    epoxy_glUniformMatrix4x2fvNV_dispatch_table_rewrite_ptr, /* glUniformMatrix4x2fvNV */
    epoxy_glUniformMatrix4x3dv_dispatch_table_rewrite_ptr, /* glUniformMatrix4x3dv */
    epoxy_glUniformMatrix4x3fv_dispatch_table_rewrite_ptr, /* glUniformMatrix4x3fv */
    epoxy_glUniformMatrix4x3fvNV_dispatch_table_rewrite_ptr, /* glUniformMatrix4x3fvNV */
    epoxy_glUniformSubroutinesuiv_dispatch_table_rewrite_ptr, /* glUniformSubroutinesuiv */
    epoxy_glUniformui64NV_dispatch_table_rewrite_ptr, /* glUniformui64NV */
    epoxy_glUniformui64vNV_dispatch_table_rewrite_ptr, /* glUniformui64vNV */
    epoxy_glUnlockArraysEXT_dispatch_table_rewrite_ptr, /* glUnlockArraysEXT */
    epoxy_glUnmapBuffer_dispatch_table_rewrite_ptr, /* glUnmapBuffer */
    epoxy_glUnmapBufferARB_dispatch_table_rewrite_ptr, /* glUnmapBufferARB */
    epoxy_glUnmapBufferOES_dispatch_table_rewrite_ptr, /* glUnmapBufferOES */
    epoxy_glUnmapNamedBuffer_dispatch_table_rewrite_ptr, /* glUnmapNamedBuffer */
    epoxy_glUnmapNamedBufferEXT_dispatch_table_rewrite_ptr, /* glUnmapNamedBufferEXT */
    epoxy_glUnmapObjectBufferATI_dispatch_table_rewrite_ptr, /* glUnmapObjectBufferATI */
    epoxy_glUnmapTexture2DINTEL_dispatch_table_rewrite_ptr, /* glUnmapTexture2DINTEL */
    epoxy_glUpdateObjectBufferATI_dispatch_table_rewrite_ptr, /* glUpdateObjectBufferATI */
    epoxy_glUploadGpuMaskNVX_dispatch_table_rewrite_ptr, /* glUploadGpuMaskNVX */
    epoxy_glUseProgram_dispatch_table_rewrite_ptr, /* glUseProgram */
    epoxy_glUseProgramObjectARB_dispatch_table_rewrite_ptr, /* glUseProgramObjectARB */
    epoxy_glUseProgramStages_dispatch_table_rewrite_ptr, /* glUseProgramStages */
    epoxy_glUseProgramStagesEXT_dispatch_table_rewrite_ptr, /* glUseProgramStagesEXT */
    epoxy_glUseShaderProgramEXT_dispatch_table_rewrite_ptr, /* glUseShaderProgramEXT */
    epoxy_glVDPAUFiniNV_dispatch_table_rewrite_ptr, /* glVDPAUFiniNV */
    epoxy_glVDPAUGetSurfaceivNV_dispatch_table_rewrite_ptr, /* glVDPAUGetSurfaceivNV */
    epoxy_glVDPAUInitNV_dispatch_table_rewrite_ptr, /* glVDPAUInitNV */
    epoxy_glVDPAUIsSurfaceNV_dispatch_table_rewrite_ptr, /* glVDPAUIsSurfaceNV */
    epoxy_glVDPAUMapSurfacesNV_dispatch_table_rewrite_ptr, /* glVDPAUMapSurfacesNV */
    epoxy_glVDPAURegisterOutputSurfaceNV_dispatch_table_rewrite_ptr, /* glVDPAURegisterOutputSurfaceNV */
    epoxy_glVDPAURegisterVideoSurfaceNV_dispatch_table_rewrite_ptr, /* glVDPAURegisterVideoSurfaceNV */
    epoxy_glVDPAURegisterVideoSurfaceWithPictureStructureNV_dispatch_table_rewrite_ptr, /* glVDPAURegisterVideoSurfaceWithPictureStructureNV */
    epoxy_glVDPAUSurfaceAccessNV_dispatch_table_rewrite_ptr, /* glVDPAUSurfaceAccessNV */
    epoxy_glVDPAUUnmapSurfacesNV_dispatch_table_rewrite_ptr, /* glVDPAUUnmapSurfacesNV */
    epoxy_glVDPAUUnregisterSurfaceNV_dispatch_table_rewrite_ptr, /* glVDPAUUnregisterSurfaceNV */
    epoxy_glValidateProgram_dispatch_table_rewrite_ptr, /* glValidateProgram */
    epoxy_glValidateProgramARB_dispatch_table_rewrite_ptr, /* glValidateProgramARB */
    epoxy_glValidateProgramPipeline_dispatch_table_rewrite_ptr, /* glValidateProgramPipeline */
    epoxy_glValidateProgramPipelineEXT_dispatch_table_rewrite_ptr, /* glValidateProgramPipelineEXT */
    epoxy_glVariantArrayObjectATI_dispatch_table_rewrite_ptr, /* glVariantArrayObjectATI */
    epoxy_glVariantPointerEXT_dispatch_table_rewrite_ptr, /* glVariantPointerEXT */
    epoxy_glVariantbvEXT_dispatch_table_rewrite_ptr, /* glVariantbvEXT */
    epoxy_glVariantdvEXT_dispatch_table_rewrite_ptr, /* glVariantdvEXT */
    epoxy_glVariantfvEXT_dispatch_table_rewrite_ptr, /* glVariantfvEXT */
    epoxy_glVariantivEXT_dispatch_table_rewrite_ptr, /* glVariantivEXT */
    epoxy_glVariantsvEXT_dispatch_table_rewrite_ptr, /* glVariantsvEXT */
    epoxy_glVariantubvEXT_dispatch_table_rewrite_ptr, /* glVariantubvEXT */
    epoxy_glVariantuivEXT_dispatch_table_rewrite_ptr, /* glVariantuivEXT */
    epoxy_glVariantusvEXT_dispatch_table_rewrite_ptr, /* glVariantusvEXT */
    epoxy_glVertex2bOES_dispatch_table_rewrite_ptr, /* glVertex2bOES */
    epoxy_glVertex2bvOES_dispatch_table_rewrite_ptr, /* glVertex2bvOES */
    epoxy_glVertex2d_dispatch_table_rewrite_ptr, /* glVertex2d */
    epoxy_glVertex2dv_dispatch_table_rewrite_ptr, /* glVertex2dv */
    epoxy_glVertex2f_dispatch_table_rewrite_ptr, /* glVertex2f */
    epoxy_glVertex2fv_dispatch_table_rewrite_ptr, /* glVertex2fv */
    epoxy_glVertex2hNV_dispatch_table_rewrite_ptr, /* glVertex2hNV */
    epoxy_glVertex2hvNV_dispatch_table_rewrite_ptr, /* glVertex2hvNV */
    epoxy_glVertex2i_dispatch_table_rewrite_ptr, /* glVertex2i */
    epoxy_glVertex2iv_dispatch_table_rewrite_ptr, /* glVertex2iv */
    epoxy_glVertex2s_dispatch_table_rewrite_ptr, /* glVertex2s */
    epoxy_glVertex2sv_dispatch_table_rewrite_ptr, /* glVertex2sv */
    epoxy_glVertex2xOES_dispatch_table_rewrite_ptr, /* glVertex2xOES */
    epoxy_glVertex2xvOES_dispatch_table_rewrite_ptr, /* glVertex2xvOES */
    epoxy_glVertex3bOES_dispatch_table_rewrite_ptr, /* glVertex3bOES */
    epoxy_glVertex3bvOES_dispatch_table_rewrite_ptr, /* glVertex3bvOES */
    epoxy_glVertex3d_dispatch_table_rewrite_ptr, /* glVertex3d */
    epoxy_glVertex3dv_dispatch_table_rewrite_ptr, /* glVertex3dv */
    epoxy_glVertex3f_dispatch_table_rewrite_ptr, /* glVertex3f */
    epoxy_glVertex3fv_dispatch_table_rewrite_ptr, /* glVertex3fv */
    epoxy_glVertex3hNV_dispatch_table_rewrite_ptr, /* glVertex3hNV */
    epoxy_glVertex3hvNV_dispatch_table_rewrite_ptr, /* glVertex3hvNV */
    epoxy_glVertex3i_dispatch_table_rewrite_ptr, /* glVertex3i */
    epoxy_glVertex3iv_dispatch_table_rewrite_ptr, /* glVertex3iv */
    epoxy_glVertex3s_dispatch_table_rewrite_ptr, /* glVertex3s */
    epoxy_glVertex3sv_dispatch_table_rewrite_ptr, /* glVertex3sv */
    epoxy_glVertex3xOES_dispatch_table_rewrite_ptr, /* glVertex3xOES */
    epoxy_glVertex3xvOES_dispatch_table_rewrite_ptr, /* glVertex3xvOES */
    epoxy_glVertex4bOES_dispatch_table_rewrite_ptr, /* glVertex4bOES */
    epoxy_glVertex4bvOES_dispatch_table_rewrite_ptr, /* glVertex4bvOES */
    epoxy_glVertex4d_dispatch_table_rewrite_ptr, /* glVertex4d */
    epoxy_glVertex4dv_dispatch_table_rewrite_ptr, /* glVertex4dv */
    epoxy_glVertex4f_dispatch_table_rewrite_ptr, /* glVertex4f */
    epoxy_glVertex4fv_dispatch_table_rewrite_ptr, /* glVertex4fv */
    epoxy_glVertex4hNV_dispatch_table_rewrite_ptr, /* glVertex4hNV */
    epoxy_glVertex4hvNV_dispatch_table_rewrite_ptr, /* glVertex4hvNV */
    epoxy_glVertex4i_dispatch_table_rewrite_ptr, /* glVertex4i */
    epoxy_glVertex4iv_dispatch_table_rewrite_ptr, /* glVertex4iv */
    epoxy_glVertex4s_dispatch_table_rewrite_ptr, /* glVertex4s */
    epoxy_glVertex4sv_dispatch_table_rewrite_ptr, /* glVertex4sv */
    epoxy_glVertex4xOES_dispatch_table_rewrite_ptr, /* glVertex4xOES */
    epoxy_glVertex4xvOES_dispatch_table_rewrite_ptr, /* glVertex4xvOES */
    epoxy_glVertexArrayAttribBinding_dispatch_table_rewrite_ptr, /* glVertexArrayAttribBinding */
    epoxy_glVertexArrayAttribFormat_dispatch_table_rewrite_ptr, /* glVertexArrayAttribFormat */
    epoxy_glVertexArrayAttribIFormat_dispatch_table_rewrite_ptr, /* glVertexArrayAttribIFormat */
    epoxy_glVertexArrayAttribLFormat_dispatch_table_rewrite_ptr, /* glVertexArrayAttribLFormat */
    epoxy_glVertexArrayBindVertexBufferEXT_dispatch_table_rewrite_ptr, /* glVertexArrayBindVertexBufferEXT */
    epoxy_glVertexArrayBindingDivisor_dispatch_table_rewrite_ptr, /* glVertexArrayBindingDivisor */
    epoxy_glVertexArrayColorOffsetEXT_dispatch_table_rewrite_ptr, /* glVertexArrayColorOffsetEXT */
    epoxy_glVertexArrayEdgeFlagOffsetEXT_dispatch_table_rewrite_ptr, /* glVertexArrayEdgeFlagOffsetEXT */
    epoxy_glVertexArrayElementBuffer_dispatch_table_rewrite_ptr, /* glVertexArrayElementBuffer */
    epoxy_glVertexArrayFogCoordOffsetEXT_dispatch_table_rewrite_ptr, /* glVertexArrayFogCoordOffsetEXT */
    epoxy_glVertexArrayIndexOffsetEXT_dispatch_table_rewrite_ptr, /* glVertexArrayIndexOffsetEXT */
    epoxy_glVertexArrayMultiTexCoordOffsetEXT_dispatch_table_rewrite_ptr, /* glVertexArrayMultiTexCoordOffsetEXT */
    epoxy_glVertexArrayNormalOffsetEXT_dispatch_table_rewrite_ptr, /* glVertexArrayNormalOffsetEXT */
    epoxy_glVertexArrayParameteriAPPLE_dispatch_table_rewrite_ptr, /* glVertexArrayParameteriAPPLE */
    epoxy_glVertexArrayRangeAPPLE_dispatch_table_rewrite_ptr, /* glVertexArrayRangeAPPLE */
    epoxy_glVertexArrayRangeNV_dispatch_table_rewrite_ptr, /* glVertexArrayRangeNV */
    epoxy_glVertexArraySecondaryColorOffsetEXT_dispatch_table_rewrite_ptr, /* glVertexArraySecondaryColorOffsetEXT */
    epoxy_glVertexArrayTexCoordOffsetEXT_dispatch_table_rewrite_ptr, /* glVertexArrayTexCoordOffsetEXT */
    epoxy_glVertexArrayVertexAttribBindingEXT_dispatch_table_rewrite_ptr, /* glVertexArrayVertexAttribBindingEXT */
    epoxy_glVertexArrayVertexAttribDivisorEXT_dispatch_table_rewrite_ptr, /* glVertexArrayVertexAttribDivisorEXT */
    epoxy_glVertexArrayVertexAttribFormatEXT_dispatch_table_rewrite_ptr, /* glVertexArrayVertexAttribFormatEXT */
    epoxy_glVertexArrayVertexAttribIFormatEXT_dispatch_table_rewrite_ptr, /* glVertexArrayVertexAttribIFormatEXT */
    epoxy_glVertexArrayVertexAttribIOffsetEXT_dispatch_table_rewrite_ptr, /* glVertexArrayVertexAttribIOffsetEXT */
    epoxy_glVertexArrayVertexAttribLFormatEXT_dispatch_table_rewrite_ptr, /* glVertexArrayVertexAttribLFormatEXT */
    epoxy_glVertexArrayVertexAttribLOffsetEXT_dispatch_table_rewrite_ptr, /* glVertexArrayVertexAttribLOffsetEXT */
    epoxy_glVertexArrayVertexAttribOffsetEXT_dispatch_table_rewrite_ptr, /* glVertexArrayVertexAttribOffsetEXT */
    epoxy_glVertexArrayVertexBindingDivisorEXT_dispatch_table_rewrite_ptr, /* glVertexArrayVertexBindingDivisorEXT */
    epoxy_glVertexArrayVertexBuffer_dispatch_table_rewrite_ptr, /* glVertexArrayVertexBuffer */
    epoxy_glVertexArrayVertexBuffers_dispatch_table_rewrite_ptr, /* glVertexArrayVertexBuffers */
    epoxy_glVertexArrayVertexOffsetEXT_dispatch_table_rewrite_ptr, /* glVertexArrayVertexOffsetEXT */
    epoxy_glVertexAttrib1d_dispatch_table_rewrite_ptr, /* glVertexAttrib1d */
    epoxy_glVertexAttrib1dARB_dispatch_table_rewrite_ptr, /* glVertexAttrib1dARB */
    epoxy_glVertexAttrib1dNV_dispatch_table_rewrite_ptr, /* glVertexAttrib1dNV */
    epoxy_glVertexAttrib1dv_dispatch_table_rewrite_ptr, /* glVertexAttrib1dv */
    epoxy_glVertexAttrib1dvARB_dispatch_table_rewrite_ptr, /* glVertexAttrib1dvARB */
    epoxy_glVertexAttrib1dvNV_dispatch_table_rewrite_ptr, /* glVertexAttrib1dvNV */
    epoxy_glVertexAttrib1f_dispatch_table_rewrite_ptr, /* glVertexAttrib1f */
    epoxy_glVertexAttrib1fARB_dispatch_table_rewrite_ptr, /* glVertexAttrib1fARB */
    epoxy_glVertexAttrib1fNV_dispatch_table_rewrite_ptr, /* glVertexAttrib1fNV */
    epoxy_glVertexAttrib1fv_dispatch_table_rewrite_ptr, /* glVertexAttrib1fv */
    epoxy_glVertexAttrib1fvARB_dispatch_table_rewrite_ptr, /* glVertexAttrib1fvARB */
    epoxy_glVertexAttrib1fvNV_dispatch_table_rewrite_ptr, /* glVertexAttrib1fvNV */
    epoxy_glVertexAttrib1hNV_dispatch_table_rewrite_ptr, /* glVertexAttrib1hNV */
    epoxy_glVertexAttrib1hvNV_dispatch_table_rewrite_ptr, /* glVertexAttrib1hvNV */
    epoxy_glVertexAttrib1s_dispatch_table_rewrite_ptr, /* glVertexAttrib1s */
    epoxy_glVertexAttrib1sARB_dispatch_table_rewrite_ptr, /* glVertexAttrib1sARB */
    epoxy_glVertexAttrib1sNV_dispatch_table_rewrite_ptr, /* glVertexAttrib1sNV */
    epoxy_glVertexAttrib1sv_dispatch_table_rewrite_ptr, /* glVertexAttrib1sv */
    epoxy_glVertexAttrib1svARB_dispatch_table_rewrite_ptr, /* glVertexAttrib1svARB */
    epoxy_glVertexAttrib1svNV_dispatch_table_rewrite_ptr, /* glVertexAttrib1svNV */
    epoxy_glVertexAttrib2d_dispatch_table_rewrite_ptr, /* glVertexAttrib2d */
    epoxy_glVertexAttrib2dARB_dispatch_table_rewrite_ptr, /* glVertexAttrib2dARB */
    epoxy_glVertexAttrib2dNV_dispatch_table_rewrite_ptr, /* glVertexAttrib2dNV */
    epoxy_glVertexAttrib2dv_dispatch_table_rewrite_ptr, /* glVertexAttrib2dv */
    epoxy_glVertexAttrib2dvARB_dispatch_table_rewrite_ptr, /* glVertexAttrib2dvARB */
    epoxy_glVertexAttrib2dvNV_dispatch_table_rewrite_ptr, /* glVertexAttrib2dvNV */
    epoxy_glVertexAttrib2f_dispatch_table_rewrite_ptr, /* glVertexAttrib2f */
    epoxy_glVertexAttrib2fARB_dispatch_table_rewrite_ptr, /* glVertexAttrib2fARB */
    epoxy_glVertexAttrib2fNV_dispatch_table_rewrite_ptr, /* glVertexAttrib2fNV */
    epoxy_glVertexAttrib2fv_dispatch_table_rewrite_ptr, /* glVertexAttrib2fv */
    epoxy_glVertexAttrib2fvARB_dispatch_table_rewrite_ptr, /* glVertexAttrib2fvARB */
    epoxy_glVertexAttrib2fvNV_dispatch_table_rewrite_ptr, /* glVertexAttrib2fvNV */
    epoxy_glVertexAttrib2hNV_dispatch_table_rewrite_ptr, /* glVertexAttrib2hNV */
    epoxy_glVertexAttrib2hvNV_dispatch_table_rewrite_ptr, /* glVertexAttrib2hvNV */
    epoxy_glVertexAttrib2s_dispatch_table_rewrite_ptr, /* glVertexAttrib2s */
    epoxy_glVertexAttrib2sARB_dispatch_table_rewrite_ptr, /* glVertexAttrib2sARB */
    epoxy_glVertexAttrib2sNV_dispatch_table_rewrite_ptr, /* glVertexAttrib2sNV */
    epoxy_glVertexAttrib2sv_dispatch_table_rewrite_ptr, /* glVertexAttrib2sv */
    epoxy_glVertexAttrib2svARB_dispatch_table_rewrite_ptr, /* glVertexAttrib2svARB */
    epoxy_glVertexAttrib2svNV_dispatch_table_rewrite_ptr, /* glVertexAttrib2svNV */
    epoxy_glVertexAttrib3d_dispatch_table_rewrite_ptr, /* glVertexAttrib3d */
    epoxy_glVertexAttrib3dARB_dispatch_table_rewrite_ptr, /* glVertexAttrib3dARB */
    epoxy_glVertexAttrib3dNV_dispatch_table_rewrite_ptr, /* glVertexAttrib3dNV */
    epoxy_glVertexAttrib3dv_dispatch_table_rewrite_ptr, /* glVertexAttrib3dv */
    epoxy_glVertexAttrib3dvARB_dispatch_table_rewrite_ptr, /* glVertexAttrib3dvARB */
    epoxy_glVertexAttrib3dvNV_dispatch_table_rewrite_ptr, /* glVertexAttrib3dvNV */
    epoxy_glVertexAttrib3f_dispatch_table_rewrite_ptr, /* glVertexAttrib3f */
    epoxy_glVertexAttrib3fARB_dispatch_table_rewrite_ptr, /* glVertexAttrib3fARB */
    epoxy_glVertexAttrib3fNV_dispatch_table_rewrite_ptr, /* glVertexAttrib3fNV */
    epoxy_glVertexAttrib3fv_dispatch_table_rewrite_ptr, /* glVertexAttrib3fv */
    epoxy_glVertexAttrib3fvARB_dispatch_table_rewrite_ptr, /* glVertexAttrib3fvARB */
    epoxy_glVertexAttrib3fvNV_dispatch_table_rewrite_ptr, /* glVertexAttrib3fvNV */
    epoxy_glVertexAttrib3hNV_dispatch_table_rewrite_ptr, /* glVertexAttrib3hNV */
    epoxy_glVertexAttrib3hvNV_dispatch_table_rewrite_ptr, /* glVertexAttrib3hvNV */
    epoxy_glVertexAttrib3s_dispatch_table_rewrite_ptr, /* glVertexAttrib3s */
    epoxy_glVertexAttrib3sARB_dispatch_table_rewrite_ptr, /* glVertexAttrib3sARB */
    epoxy_glVertexAttrib3sNV_dispatch_table_rewrite_ptr, /* glVertexAttrib3sNV */
    epoxy_glVertexAttrib3sv_dispatch_table_rewrite_ptr, /* glVertexAttrib3sv */
    epoxy_glVertexAttrib3svARB_dispatch_table_rewrite_ptr, /* glVertexAttrib3svARB */
    epoxy_glVertexAttrib3svNV_dispatch_table_rewrite_ptr, /* glVertexAttrib3svNV */
    epoxy_glVertexAttrib4Nbv_dispatch_table_rewrite_ptr, /* glVertexAttrib4Nbv */
    epoxy_glVertexAttrib4NbvARB_dispatch_table_rewrite_ptr, /* glVertexAttrib4NbvARB */
    epoxy_glVertexAttrib4Niv_dispatch_table_rewrite_ptr, /* glVertexAttrib4Niv */
    epoxy_glVertexAttrib4NivARB_dispatch_table_rewrite_ptr, /* glVertexAttrib4NivARB */
    epoxy_glVertexAttrib4Nsv_dispatch_table_rewrite_ptr, /* glVertexAttrib4Nsv */
    epoxy_glVertexAttrib4NsvARB_dispatch_table_rewrite_ptr, /* glVertexAttrib4NsvARB */
    epoxy_glVertexAttrib4Nub_dispatch_table_rewrite_ptr, /* glVertexAttrib4Nub */
    epoxy_glVertexAttrib4NubARB_dispatch_table_rewrite_ptr, /* glVertexAttrib4NubARB */
    epoxy_glVertexAttrib4Nubv_dispatch_table_rewrite_ptr, /* glVertexAttrib4Nubv */
    epoxy_glVertexAttrib4NubvARB_dispatch_table_rewrite_ptr, /* glVertexAttrib4NubvARB */
    epoxy_glVertexAttrib4Nuiv_dispatch_table_rewrite_ptr, /* glVertexAttrib4Nuiv */
    epoxy_glVertexAttrib4NuivARB_dispatch_table_rewrite_ptr, /* glVertexAttrib4NuivARB */
    epoxy_glVertexAttrib4Nusv_dispatch_table_rewrite_ptr, /* glVertexAttrib4Nusv */
    epoxy_glVertexAttrib4NusvARB_dispatch_table_rewrite_ptr, /* glVertexAttrib4NusvARB */
    epoxy_glVertexAttrib4bv_dispatch_table_rewrite_ptr, /* glVertexAttrib4bv */
    epoxy_glVertexAttrib4bvARB_dispatch_table_rewrite_ptr, /* glVertexAttrib4bvARB */
    epoxy_glVertexAttrib4d_dispatch_table_rewrite_ptr, /* glVertexAttrib4d */
    epoxy_glVertexAttrib4dARB_dispatch_table_rewrite_ptr, /* glVertexAttrib4dARB */
    epoxy_glVertexAttrib4dNV_dispatch_table_rewrite_ptr, /* glVertexAttrib4dNV */
    epoxy_glVertexAttrib4dv_dispatch_table_rewrite_ptr, /* glVertexAttrib4dv */
    epoxy_glVertexAttrib4dvARB_dispatch_table_rewrite_ptr, /* glVertexAttrib4dvARB */
    epoxy_glVertexAttrib4dvNV_dispatch_table_rewrite_ptr, /* glVertexAttrib4dvNV */
    epoxy_glVertexAttrib4f_dispatch_table_rewrite_ptr, /* glVertexAttrib4f */
    epoxy_glVertexAttrib4fARB_dispatch_table_rewrite_ptr, /* glVertexAttrib4fARB */
    epoxy_glVertexAttrib4fNV_dispatch_table_rewrite_ptr, /* glVertexAttrib4fNV */
    epoxy_glVertexAttrib4fv_dispatch_table_rewrite_ptr, /* glVertexAttrib4fv */
    epoxy_glVertexAttrib4fvARB_dispatch_table_rewrite_ptr, /* glVertexAttrib4fvARB */
    epoxy_glVertexAttrib4fvNV_dispatch_table_rewrite_ptr, /* glVertexAttrib4fvNV */
    epoxy_glVertexAttrib4hNV_dispatch_table_rewrite_ptr, /* glVertexAttrib4hNV */
    epoxy_glVertexAttrib4hvNV_dispatch_table_rewrite_ptr, /* glVertexAttrib4hvNV */
    epoxy_glVertexAttrib4iv_dispatch_table_rewrite_ptr, /* glVertexAttrib4iv */
    epoxy_glVertexAttrib4ivARB_dispatch_table_rewrite_ptr, /* glVertexAttrib4ivARB */
    epoxy_glVertexAttrib4s_dispatch_table_rewrite_ptr, /* glVertexAttrib4s */
    epoxy_glVertexAttrib4sARB_dispatch_table_rewrite_ptr, /* glVertexAttrib4sARB */
    epoxy_glVertexAttrib4sNV_dispatch_table_rewrite_ptr, /* glVertexAttrib4sNV */
    epoxy_glVertexAttrib4sv_dispatch_table_rewrite_ptr, /* glVertexAttrib4sv */
    epoxy_glVertexAttrib4svARB_dispatch_table_rewrite_ptr, /* glVertexAttrib4svARB */
    epoxy_glVertexAttrib4svNV_dispatch_table_rewrite_ptr, /* glVertexAttrib4svNV */
    epoxy_glVertexAttrib4ubNV_dispatch_table_rewrite_ptr, /* glVertexAttrib4ubNV */
    epoxy_glVertexAttrib4ubv_dispatch_table_rewrite_ptr, /* glVertexAttrib4ubv */
    epoxy_glVertexAttrib4ubvARB_dispatch_table_rewrite_ptr, /* glVertexAttrib4ubvARB */
    epoxy_glVertexAttrib4ubvNV_dispatch_table_rewrite_ptr, /* glVertexAttrib4ubvNV */
    epoxy_glVertexAttrib4uiv_dispatch_table_rewrite_ptr, /* glVertexAttrib4uiv */
    epoxy_glVertexAttrib4uivARB_dispatch_table_rewrite_ptr, /* glVertexAttrib4uivARB */
    epoxy_glVertexAttrib4usv_dispatch_table_rewrite_ptr, /* glVertexAttrib4usv */
    epoxy_glVertexAttrib4usvARB_dispatch_table_rewrite_ptr, /* glVertexAttrib4usvARB */
    epoxy_glVertexAttribArrayObjectATI_dispatch_table_rewrite_ptr, /* glVertexAttribArrayObjectATI */
    epoxy_glVertexAttribBinding_dispatch_table_rewrite_ptr, /* glVertexAttribBinding */
    epoxy_glVertexAttribDivisor_dispatch_table_rewrite_ptr, /* glVertexAttribDivisor */
    epoxy_glVertexAttribDivisorANGLE_dispatch_table_rewrite_ptr, /* glVertexAttribDivisorANGLE */
    epoxy_glVertexAttribDivisorARB_dispatch_table_rewrite_ptr, /* glVertexAttribDivisorARB */
    epoxy_glVertexAttribDivisorEXT_dispatch_table_rewrite_ptr, /* glVertexAttribDivisorEXT */
    epoxy_glVertexAttribDivisorNV_dispatch_table_rewrite_ptr, /* glVertexAttribDivisorNV */
    epoxy_glVertexAttribFormat_dispatch_table_rewrite_ptr, /* glVertexAttribFormat */
    epoxy_glVertexAttribFormatNV_dispatch_table_rewrite_ptr, /* glVertexAttribFormatNV */
    epoxy_glVertexAttribI1i_dispatch_table_rewrite_ptr, /* glVertexAttribI1i */
    epoxy_glVertexAttribI1iEXT_dispatch_table_rewrite_ptr, /* glVertexAttribI1iEXT */
    epoxy_glVertexAttribI1iv_dispatch_table_rewrite_ptr, /* glVertexAttribI1iv */
    epoxy_glVertexAttribI1ivEXT_dispatch_table_rewrite_ptr, /* glVertexAttribI1ivEXT */
    epoxy_glVertexAttribI1ui_dispatch_table_rewrite_ptr, /* glVertexAttribI1ui */
    epoxy_glVertexAttribI1uiEXT_dispatch_table_rewrite_ptr, /* glVertexAttribI1uiEXT */
    epoxy_glVertexAttribI1uiv_dispatch_table_rewrite_ptr, /* glVertexAttribI1uiv */
    epoxy_glVertexAttribI1uivEXT_dispatch_table_rewrite_ptr, /* glVertexAttribI1uivEXT */
    epoxy_glVertexAttribI2i_dispatch_table_rewrite_ptr, /* glVertexAttribI2i */
    epoxy_glVertexAttribI2iEXT_dispatch_table_rewrite_ptr, /* glVertexAttribI2iEXT */
    epoxy_glVertexAttribI2iv_dispatch_table_rewrite_ptr, /* glVertexAttribI2iv */
    epoxy_glVertexAttribI2ivEXT_dispatch_table_rewrite_ptr, /* glVertexAttribI2ivEXT */
    epoxy_glVertexAttribI2ui_dispatch_table_rewrite_ptr, /* glVertexAttribI2ui */
    epoxy_glVertexAttribI2uiEXT_dispatch_table_rewrite_ptr, /* glVertexAttribI2uiEXT */
    epoxy_glVertexAttribI2uiv_dispatch_table_rewrite_ptr, /* glVertexAttribI2uiv */
    epoxy_glVertexAttribI2uivEXT_dispatch_table_rewrite_ptr, /* glVertexAttribI2uivEXT */
    epoxy_glVertexAttribI3i_dispatch_table_rewrite_ptr, /* glVertexAttribI3i */
    epoxy_glVertexAttribI3iEXT_dispatch_table_rewrite_ptr, /* glVertexAttribI3iEXT */
    epoxy_glVertexAttribI3iv_dispatch_table_rewrite_ptr, /* glVertexAttribI3iv */
    epoxy_glVertexAttribI3ivEXT_dispatch_table_rewrite_ptr, /* glVertexAttribI3ivEXT */
    epoxy_glVertexAttribI3ui_dispatch_table_rewrite_ptr, /* glVertexAttribI3ui */
    epoxy_glVertexAttribI3uiEXT_dispatch_table_rewrite_ptr, /* glVertexAttribI3uiEXT */
    epoxy_glVertexAttribI3uiv_dispatch_table_rewrite_ptr, /* glVertexAttribI3uiv */
    epoxy_glVertexAttribI3uivEXT_dispatch_table_rewrite_ptr, /* glVertexAttribI3uivEXT */
    epoxy_glVertexAttribI4bv_dispatch_table_rewrite_ptr, /* glVertexAttribI4bv */
    epoxy_glVertexAttribI4bvEXT_dispatch_table_rewrite_ptr, /* glVertexAttribI4bvEXT */
    epoxy_glVertexAttribI4i_dispatch_table_rewrite_ptr, /* glVertexAttribI4i */
    epoxy_glVertexAttribI4iEXT_dispatch_table_rewrite_ptr, /* glVertexAttribI4iEXT */
    epoxy_glVertexAttribI4iv_dispatch_table_rewrite_ptr, /* glVertexAttribI4iv */
    epoxy_glVertexAttribI4ivEXT_dispatch_table_rewrite_ptr, /* glVertexAttribI4ivEXT */
    epoxy_glVertexAttribI4sv_dispatch_table_rewrite_ptr, /* glVertexAttribI4sv */
    epoxy_glVertexAttribI4svEXT_dispatch_table_rewrite_ptr, /* glVertexAttribI4svEXT */
    epoxy_glVertexAttribI4ubv_dispatch_table_rewrite_ptr, /* glVertexAttribI4ubv */
    epoxy_glVertexAttribI4ubvEXT_dispatch_table_rewrite_ptr, /* glVertexAttribI4ubvEXT */
    epoxy_glVertexAttribI4ui_dispatch_table_rewrite_ptr, /* glVertexAttribI4ui */
    epoxy_glVertexAttribI4uiEXT_dispatch_table_rewrite_ptr, /* glVertexAttribI4uiEXT */
    epoxy_glVertexAttribI4uiv_dispatch_table_rewrite_ptr, /* glVertexAttribI4uiv */
    epoxy_glVertexAttribI4uivEXT_dispatch_table_rewrite_ptr, /* glVertexAttribI4uivEXT */
    epoxy_glVertexAttribI4usv_dispatch_table_rewrite_ptr, /* glVertexAttribI4usv */
    epoxy_glVertexAttribI4usvEXT_dispatch_table_rewrite_ptr, /* glVertexAttribI4usvEXT */
    epoxy_glVertexAttribIFormat_dispatch_table_rewrite_ptr, /* glVertexAttribIFormat */
    epoxy_glVertexAttribIFormatNV_dispatch_table_rewrite_ptr, /* glVertexAttribIFormatNV */
    epoxy_glVertexAttribIPointer_dispatch_table_rewrite_ptr, /* glVertexAttribIPointer */
    epoxy_glVertexAttribIPointerEXT_dispatch_table_rewrite_ptr, /* glVertexAttribIPointerEXT */
    epoxy_glVertexAttribL1d_dispatch_table_rewrite_ptr, /* glVertexAttribL1d */
    epoxy_glVertexAttribL1dEXT_dispatch_table_rewrite_ptr, /* glVertexAttribL1dEXT */
    epoxy_glVertexAttribL1dv_dispatch_table_rewrite_ptr, /* glVertexAttribL1dv */
    epoxy_glVertexAttribL1dvEXT_dispatch_table_rewrite_ptr, /* glVertexAttribL1dvEXT */
    epoxy_glVertexAttribL1i64NV_dispatch_table_rewrite_ptr, /* glVertexAttribL1i64NV */
    epoxy_glVertexAttribL1i64vNV_dispatch_table_rewrite_ptr, /* glVertexAttribL1i64vNV */
    epoxy_glVertexAttribL1ui64ARB_dispatch_table_rewrite_ptr, /* glVertexAttribL1ui64ARB */
    epoxy_glVertexAttribL1ui64NV_dispatch_table_rewrite_ptr, /* glVertexAttribL1ui64NV */
    epoxy_glVertexAttribL1ui64vARB_dispatch_table_rewrite_ptr, /* glVertexAttribL1ui64vARB */
    epoxy_glVertexAttribL1ui64vNV_dispatch_table_rewrite_ptr, /* glVertexAttribL1ui64vNV */
    epoxy_glVertexAttribL2d_dispatch_table_rewrite_ptr, /* glVertexAttribL2d */
    epoxy_glVertexAttribL2dEXT_dispatch_table_rewrite_ptr, /* glVertexAttribL2dEXT */
    epoxy_glVertexAttribL2dv_dispatch_table_rewrite_ptr, /* glVertexAttribL2dv */
    epoxy_glVertexAttribL2dvEXT_dispatch_table_rewrite_ptr, /* glVertexAttribL2dvEXT */
    epoxy_glVertexAttribL2i64NV_dispatch_table_rewrite_ptr, /* glVertexAttribL2i64NV */
    epoxy_glVertexAttribL2i64vNV_dispatch_table_rewrite_ptr, /* glVertexAttribL2i64vNV */
    epoxy_glVertexAttribL2ui64NV_dispatch_table_rewrite_ptr, /* glVertexAttribL2ui64NV */
    epoxy_glVertexAttribL2ui64vNV_dispatch_table_rewrite_ptr, /* glVertexAttribL2ui64vNV */
    epoxy_glVertexAttribL3d_dispatch_table_rewrite_ptr, /* glVertexAttribL3d */
    epoxy_glVertexAttribL3dEXT_dispatch_table_rewrite_ptr, /* glVertexAttribL3dEXT */
    epoxy_glVertexAttribL3dv_dispatch_table_rewrite_ptr, /* glVertexAttribL3dv */
    epoxy_glVertexAttribL3dvEXT_dispatch_table_rewrite_ptr, /* glVertexAttribL3dvEXT */
    epoxy_glVertexAttribL3i64NV_dispatch_table_rewrite_ptr, /* glVertexAttribL3i64NV */
    epoxy_glVertexAttribL3i64vNV_dispatch_table_rewrite_ptr, /* glVertexAttribL3i64vNV */
    epoxy_glVertexAttribL3ui64NV_dispatch_table_rewrite_ptr, /* glVertexAttribL3ui64NV */
    epoxy_glVertexAttribL3ui64vNV_dispatch_table_rewrite_ptr, /* glVertexAttribL3ui64vNV */
    epoxy_glVertexAttribL4d_dispatch_table_rewrite_ptr, /* glVertexAttribL4d */
    epoxy_glVertexAttribL4dEXT_dispatch_table_rewrite_ptr, /* glVertexAttribL4dEXT */
    epoxy_glVertexAttribL4dv_dispatch_table_rewrite_ptr, /* glVertexAttribL4dv */
    epoxy_glVertexAttribL4dvEXT_dispatch_table_rewrite_ptr, /* glVertexAttribL4dvEXT */
    epoxy_glVertexAttribL4i64NV_dispatch_table_rewrite_ptr, /* glVertexAttribL4i64NV */
    epoxy_glVertexAttribL4i64vNV_dispatch_table_rewrite_ptr, /* glVertexAttribL4i64vNV */
    epoxy_glVertexAttribL4ui64NV_dispatch_table_rewrite_ptr, /* glVertexAttribL4ui64NV */
    epoxy_glVertexAttribL4ui64vNV_dispatch_table_rewrite_ptr, /* glVertexAttribL4ui64vNV */
    epoxy_glVertexAttribLFormat_dispatch_table_rewrite_ptr, /* glVertexAttribLFormat */
    epoxy_glVertexAttribLFormatNV_dispatch_table_rewrite_ptr, /* glVertexAttribLFormatNV */
    epoxy_glVertexAttribLPointer_dispatch_table_rewrite_ptr, /* glVertexAttribLPointer */
    epoxy_glVertexAttribLPointerEXT_dispatch_table_rewrite_ptr, /* glVertexAttribLPointerEXT */
    epoxy_glVertexAttribP1ui_dispatch_table_rewrite_ptr, /* glVertexAttribP1ui */
    epoxy_glVertexAttribP1uiv_dispatch_table_rewrite_ptr, /* glVertexAttribP1uiv */
    epoxy_glVertexAttribP2ui_dispatch_table_rewrite_ptr, /* glVertexAttribP2ui */
    epoxy_glVertexAttribP2uiv_dispatch_table_rewrite_ptr, /* glVertexAttribP2uiv */
    epoxy_glVertexAttribP3ui_dispatch_table_rewrite_ptr, /* glVertexAttribP3ui */
    epoxy_glVertexAttribP3uiv_dispatch_table_rewrite_ptr, /* glVertexAttribP3uiv */
    epoxy_glVertexAttribP4ui_dispatch_table_rewrite_ptr, /* glVertexAttribP4ui */
    epoxy_glVertexAttribP4uiv_dispatch_table_rewrite_ptr, /* glVertexAttribP4uiv */
    epoxy_glVertexAttribParameteriAMD_dispatch_table_rewrite_ptr, /* glVertexAttribParameteriAMD */
    epoxy_glVertexAttribPointer_dispatch_table_rewrite_ptr, /* glVertexAttribPointer */
    epoxy_glVertexAttribPointerARB_dispatch_table_rewrite_ptr, /* glVertexAttribPointerARB */
    epoxy_glVertexAttribPointerNV_dispatch_table_rewrite_ptr, /* glVertexAttribPointerNV */
    epoxy_glVertexAttribs1dvNV_dispatch_table_rewrite_ptr, /* glVertexAttribs1dvNV */
    epoxy_glVertexAttribs1fvNV_dispatch_table_rewrite_ptr, /* glVertexAttribs1fvNV */
    epoxy_glVertexAttribs1hvNV_dispatch_table_rewrite_ptr, /* glVertexAttribs1hvNV */
    epoxy_glVertexAttribs1svNV_dispatch_table_rewrite_ptr, /* glVertexAttribs1svNV */
    epoxy_glVertexAttribs2dvNV_dispatch_table_rewrite_ptr, /* glVertexAttribs2dvNV */
    epoxy_glVertexAttribs2fvNV_dispatch_table_rewrite_ptr, /* glVertexAttribs2fvNV */
    epoxy_glVertexAttribs2hvNV_dispatch_table_rewrite_ptr, /* glVertexAttribs2hvNV */
    epoxy_glVertexAttribs2svNV_dispatch_table_rewrite_ptr, /* glVertexAttribs2svNV */
    epoxy_glVertexAttribs3dvNV_dispatch_table_rewrite_ptr, /* glVertexAttribs3dvNV */
    epoxy_glVertexAttribs3fvNV_dispatch_table_rewrite_ptr, /* glVertexAttribs3fvNV */
    epoxy_glVertexAttribs3hvNV_dispatch_table_rewrite_ptr, /* glVertexAttribs3hvNV */
    epoxy_glVertexAttribs3svNV_dispatch_table_rewrite_ptr, /* glVertexAttribs3svNV */
    epoxy_glVertexAttribs4dvNV_dispatch_table_rewrite_ptr, /* glVertexAttribs4dvNV */
    epoxy_glVertexAttribs4fvNV_dispatch_table_rewrite_ptr, /* glVertexAttribs4fvNV */
    epoxy_glVertexAttribs4hvNV_dispatch_table_rewrite_ptr, /* glVertexAttribs4hvNV */
    epoxy_glVertexAttribs4svNV_dispatch_table_rewrite_ptr, /* glVertexAttribs4svNV */
    epoxy_glVertexAttribs4ubvNV_dispatch_table_rewrite_ptr, /* glVertexAttribs4ubvNV */
    epoxy_glVertexBindingDivisor_dispatch_table_rewrite_ptr, /* glVertexBindingDivisor */
    epoxy_glVertexBlendARB_dispatch_table_rewrite_ptr, /* glVertexBlendARB */
    epoxy_glVertexBlendEnvfATI_dispatch_table_rewrite_ptr, /* glVertexBlendEnvfATI */
    epoxy_glVertexBlendEnviATI_dispatch_table_rewrite_ptr, /* glVertexBlendEnviATI */
    epoxy_glVertexFormatNV_dispatch_table_rewrite_ptr, /* glVertexFormatNV */
    epoxy_glVertexP2ui_dispatch_table_rewrite_ptr, /* glVertexP2ui */
    epoxy_glVertexP2uiv_dispatch_table_rewrite_ptr, /* glVertexP2uiv */
    epoxy_glVertexP3ui_dispatch_table_rewrite_ptr, /* glVertexP3ui */
    epoxy_glVertexP3uiv_dispatch_table_rewrite_ptr, /* glVertexP3uiv */
    epoxy_glVertexP4ui_dispatch_table_rewrite_ptr, /* glVertexP4ui */
    epoxy_glVertexP4uiv_dispatch_table_rewrite_ptr, /* glVertexP4uiv */
    epoxy_glVertexPointer_dispatch_table_rewrite_ptr, /* glVertexPointer */
    epoxy_glVertexPointerEXT_dispatch_table_rewrite_ptr, /* glVertexPointerEXT */
    epoxy_glVertexPointerListIBM_dispatch_table_rewrite_ptr, /* glVertexPointerListIBM */
    epoxy_glVertexPointervINTEL_dispatch_table_rewrite_ptr, /* glVertexPointervINTEL */
    epoxy_glVertexStream1dATI_dispatch_table_rewrite_ptr, /* glVertexStream1dATI */
    epoxy_glVertexStream1dvATI_dispatch_table_rewrite_ptr, /* glVertexStream1dvATI */
    epoxy_glVertexStream1fATI_dispatch_table_rewrite_ptr, /* glVertexStream1fATI */
    epoxy_glVertexStream1fvATI_dispatch_table_rewrite_ptr, /* glVertexStream1fvATI */
    epoxy_glVertexStream1iATI_dispatch_table_rewrite_ptr, /* glVertexStream1iATI */
    epoxy_glVertexStream1ivATI_dispatch_table_rewrite_ptr, /* glVertexStream1ivATI */
    epoxy_glVertexStream1sATI_dispatch_table_rewrite_ptr, /* glVertexStream1sATI */
    epoxy_glVertexStream1svATI_dispatch_table_rewrite_ptr, /* glVertexStream1svATI */
    epoxy_glVertexStream2dATI_dispatch_table_rewrite_ptr, /* glVertexStream2dATI */
    epoxy_glVertexStream2dvATI_dispatch_table_rewrite_ptr, /* glVertexStream2dvATI */
    epoxy_glVertexStream2fATI_dispatch_table_rewrite_ptr, /* glVertexStream2fATI */
    epoxy_glVertexStream2fvATI_dispatch_table_rewrite_ptr, /* glVertexStream2fvATI */
    epoxy_glVertexStream2iATI_dispatch_table_rewrite_ptr, /* glVertexStream2iATI */
    epoxy_glVertexStream2ivATI_dispatch_table_rewrite_ptr, /* glVertexStream2ivATI */
    epoxy_glVertexStream2sATI_dispatch_table_rewrite_ptr, /* glVertexStream2sATI */
    epoxy_glVertexStream2svATI_dispatch_table_rewrite_ptr, /* glVertexStream2svATI */
    epoxy_glVertexStream3dATI_dispatch_table_rewrite_ptr, /* glVertexStream3dATI */
    epoxy_glVertexStream3dvATI_dispatch_table_rewrite_ptr, /* glVertexStream3dvATI */
    epoxy_glVertexStream3fATI_dispatch_table_rewrite_ptr, /* glVertexStream3fATI */
    epoxy_glVertexStream3fvATI_dispatch_table_rewrite_ptr, /* glVertexStream3fvATI */
    epoxy_glVertexStream3iATI_dispatch_table_rewrite_ptr, /* glVertexStream3iATI */
    epoxy_glVertexStream3ivATI_dispatch_table_rewrite_ptr, /* glVertexStream3ivATI */
    epoxy_glVertexStream3sATI_dispatch_table_rewrite_ptr, /* glVertexStream3sATI */
    epoxy_glVertexStream3svATI_dispatch_table_rewrite_ptr, /* glVertexStream3svATI */
    epoxy_glVertexStream4dATI_dispatch_table_rewrite_ptr, /* glVertexStream4dATI */
    epoxy_glVertexStream4dvATI_dispatch_table_rewrite_ptr, /* glVertexStream4dvATI */
    epoxy_glVertexStream4fATI_dispatch_table_rewrite_ptr, /* glVertexStream4fATI */
    epoxy_glVertexStream4fvATI_dispatch_table_rewrite_ptr, /* glVertexStream4fvATI */
    epoxy_glVertexStream4iATI_dispatch_table_rewrite_ptr, /* glVertexStream4iATI */
    epoxy_glVertexStream4ivATI_dispatch_table_rewrite_ptr, /* glVertexStream4ivATI */
    epoxy_glVertexStream4sATI_dispatch_table_rewrite_ptr, /* glVertexStream4sATI */
    epoxy_glVertexStream4svATI_dispatch_table_rewrite_ptr, /* glVertexStream4svATI */
    epoxy_glVertexWeightPointerEXT_dispatch_table_rewrite_ptr, /* glVertexWeightPointerEXT */
    epoxy_glVertexWeightfEXT_dispatch_table_rewrite_ptr, /* glVertexWeightfEXT */
    epoxy_glVertexWeightfvEXT_dispatch_table_rewrite_ptr, /* glVertexWeightfvEXT */
    epoxy_glVertexWeighthNV_dispatch_table_rewrite_ptr, /* glVertexWeighthNV */
    epoxy_glVertexWeighthvNV_dispatch_table_rewrite_ptr, /* glVertexWeighthvNV */
    epoxy_glVideoCaptureNV_dispatch_table_rewrite_ptr, /* glVideoCaptureNV */
    epoxy_glVideoCaptureStreamParameterdvNV_dispatch_table_rewrite_ptr, /* glVideoCaptureStreamParameterdvNV */
    epoxy_glVideoCaptureStreamParameterfvNV_dispatch_table_rewrite_ptr, /* glVideoCaptureStreamParameterfvNV */
    epoxy_glVideoCaptureStreamParameterivNV_dispatch_table_rewrite_ptr, /* glVideoCaptureStreamParameterivNV */
    epoxy_glViewport_dispatch_table_rewrite_ptr, /* glViewport */
    epoxy_glViewportArrayv_dispatch_table_rewrite_ptr, /* glViewportArrayv */
    epoxy_glViewportArrayvNV_dispatch_table_rewrite_ptr, /* glViewportArrayvNV */
    epoxy_glViewportArrayvOES_dispatch_table_rewrite_ptr, /* glViewportArrayvOES */
    epoxy_glViewportIndexedf_dispatch_table_rewrite_ptr, /* glViewportIndexedf */
    epoxy_glViewportIndexedfNV_dispatch_table_rewrite_ptr, /* glViewportIndexedfNV */
    epoxy_glViewportIndexedfOES_dispatch_table_rewrite_ptr, /* glViewportIndexedfOES */
    epoxy_glViewportIndexedfv_dispatch_table_rewrite_ptr, /* glViewportIndexedfv */
    epoxy_glViewportIndexedfvNV_dispatch_table_rewrite_ptr, /* glViewportIndexedfvNV */
    epoxy_glViewportIndexedfvOES_dispatch_table_rewrite_ptr, /* glViewportIndexedfvOES */
    epoxy_glViewportPositionWScaleNV_dispatch_table_rewrite_ptr, /* glViewportPositionWScaleNV */
    epoxy_glViewportSwizzleNV_dispatch_table_rewrite_ptr, /* glViewportSwizzleNV */
    epoxy_glWaitSemaphoreEXT_dispatch_table_rewrite_ptr, /* glWaitSemaphoreEXT */
    epoxy_glWaitSemaphoreui64NVX_dispatch_table_rewrite_ptr, /* glWaitSemaphoreui64NVX */
    epoxy_glWaitSync_dispatch_table_rewrite_ptr, /* glWaitSync */
    epoxy_glWaitSyncAPPLE_dispatch_table_rewrite_ptr, /* glWaitSyncAPPLE */
    epoxy_glWaitVkSemaphoreNV_dispatch_table_rewrite_ptr, /* glWaitVkSemaphoreNV */
    epoxy_glWeightPathsNV_dispatch_table_rewrite_ptr, /* glWeightPathsNV */
    epoxy_glWeightPointerARB_dispatch_table_rewrite_ptr, /* glWeightPointerARB */
    epoxy_glWeightPointerOES_dispatch_table_rewrite_ptr, /* glWeightPointerOES */
    epoxy_glWeightbvARB_dispatch_table_rewrite_ptr, /* glWeightbvARB */
    epoxy_glWeightdvARB_dispatch_table_rewrite_ptr, /* glWeightdvARB */
    epoxy_glWeightfvARB_dispatch_table_rewrite_ptr, /* glWeightfvARB */
    epoxy_glWeightivARB_dispatch_table_rewrite_ptr, /* glWeightivARB */
    epoxy_glWeightsvARB_dispatch_table_rewrite_ptr, /* glWeightsvARB */
    epoxy_glWeightubvARB_dispatch_table_rewrite_ptr, /* glWeightubvARB */
    epoxy_glWeightuivARB_dispatch_table_rewrite_ptr, /* glWeightuivARB */
    epoxy_glWeightusvARB_dispatch_table_rewrite_ptr, /* glWeightusvARB */
    epoxy_glWindowPos2d_dispatch_table_rewrite_ptr, /* glWindowPos2d */
    epoxy_glWindowPos2dARB_dispatch_table_rewrite_ptr, /* glWindowPos2dARB */
    epoxy_glWindowPos2dMESA_dispatch_table_rewrite_ptr, /* glWindowPos2dMESA */
    epoxy_glWindowPos2dv_dispatch_table_rewrite_ptr, /* glWindowPos2dv */
    epoxy_glWindowPos2dvARB_dispatch_table_rewrite_ptr, /* glWindowPos2dvARB */
    epoxy_glWindowPos2dvMESA_dispatch_table_rewrite_ptr, /* glWindowPos2dvMESA */
    epoxy_glWindowPos2f_dispatch_table_rewrite_ptr, /* glWindowPos2f */
    epoxy_glWindowPos2fARB_dispatch_table_rewrite_ptr, /* glWindowPos2fARB */
    epoxy_glWindowPos2fMESA_dispatch_table_rewrite_ptr, /* glWindowPos2fMESA */
    epoxy_glWindowPos2fv_dispatch_table_rewrite_ptr, /* glWindowPos2fv */
    epoxy_glWindowPos2fvARB_dispatch_table_rewrite_ptr, /* glWindowPos2fvARB */
    epoxy_glWindowPos2fvMESA_dispatch_table_rewrite_ptr, /* glWindowPos2fvMESA */
    epoxy_glWindowPos2i_dispatch_table_rewrite_ptr, /* glWindowPos2i */
    epoxy_glWindowPos2iARB_dispatch_table_rewrite_ptr, /* glWindowPos2iARB */
    epoxy_glWindowPos2iMESA_dispatch_table_rewrite_ptr, /* glWindowPos2iMESA */
    epoxy_glWindowPos2iv_dispatch_table_rewrite_ptr, /* glWindowPos2iv */
    epoxy_glWindowPos2ivARB_dispatch_table_rewrite_ptr, /* glWindowPos2ivARB */
    epoxy_glWindowPos2ivMESA_dispatch_table_rewrite_ptr, /* glWindowPos2ivMESA */
    epoxy_glWindowPos2s_dispatch_table_rewrite_ptr, /* glWindowPos2s */
    epoxy_glWindowPos2sARB_dispatch_table_rewrite_ptr, /* glWindowPos2sARB */
    epoxy_glWindowPos2sMESA_dispatch_table_rewrite_ptr, /* glWindowPos2sMESA */
    epoxy_glWindowPos2sv_dispatch_table_rewrite_ptr, /* glWindowPos2sv */
    epoxy_glWindowPos2svARB_dispatch_table_rewrite_ptr, /* glWindowPos2svARB */
    epoxy_glWindowPos2svMESA_dispatch_table_rewrite_ptr, /* glWindowPos2svMESA */
    epoxy_glWindowPos3d_dispatch_table_rewrite_ptr, /* glWindowPos3d */
    epoxy_glWindowPos3dARB_dispatch_table_rewrite_ptr, /* glWindowPos3dARB */
    epoxy_glWindowPos3dMESA_dispatch_table_rewrite_ptr, /* glWindowPos3dMESA */
    epoxy_glWindowPos3dv_dispatch_table_rewrite_ptr, /* glWindowPos3dv */
    epoxy_glWindowPos3dvARB_dispatch_table_rewrite_ptr, /* glWindowPos3dvARB */
    epoxy_glWindowPos3dvMESA_dispatch_table_rewrite_ptr, /* glWindowPos3dvMESA */
    epoxy_glWindowPos3f_dispatch_table_rewrite_ptr, /* glWindowPos3f */
    epoxy_glWindowPos3fARB_dispatch_table_rewrite_ptr, /* glWindowPos3fARB */
    epoxy_glWindowPos3fMESA_dispatch_table_rewrite_ptr, /* glWindowPos3fMESA */
    epoxy_glWindowPos3fv_dispatch_table_rewrite_ptr, /* glWindowPos3fv */
    epoxy_glWindowPos3fvARB_dispatch_table_rewrite_ptr, /* glWindowPos3fvARB */
    epoxy_glWindowPos3fvMESA_dispatch_table_rewrite_ptr, /* glWindowPos3fvMESA */
    epoxy_glWindowPos3i_dispatch_table_rewrite_ptr, /* glWindowPos3i */
    epoxy_glWindowPos3iARB_dispatch_table_rewrite_ptr, /* glWindowPos3iARB */
    epoxy_glWindowPos3iMESA_dispatch_table_rewrite_ptr, /* glWindowPos3iMESA */
    epoxy_glWindowPos3iv_dispatch_table_rewrite_ptr, /* glWindowPos3iv */
    epoxy_glWindowPos3ivARB_dispatch_table_rewrite_ptr, /* glWindowPos3ivARB */
    epoxy_glWindowPos3ivMESA_dispatch_table_rewrite_ptr, /* glWindowPos3ivMESA */
    epoxy_glWindowPos3s_dispatch_table_rewrite_ptr, /* glWindowPos3s */
    epoxy_glWindowPos3sARB_dispatch_table_rewrite_ptr, /* glWindowPos3sARB */
    epoxy_glWindowPos3sMESA_dispatch_table_rewrite_ptr, /* glWindowPos3sMESA */
    epoxy_glWindowPos3sv_dispatch_table_rewrite_ptr, /* glWindowPos3sv */
    epoxy_glWindowPos3svARB_dispatch_table_rewrite_ptr, /* glWindowPos3svARB */
    epoxy_glWindowPos3svMESA_dispatch_table_rewrite_ptr, /* glWindowPos3svMESA */
    epoxy_glWindowPos4dMESA_dispatch_table_rewrite_ptr, /* glWindowPos4dMESA */
    epoxy_glWindowPos4dvMESA_dispatch_table_rewrite_ptr, /* glWindowPos4dvMESA */
    epoxy_glWindowPos4fMESA_dispatch_table_rewrite_ptr, /* glWindowPos4fMESA */
    epoxy_glWindowPos4fvMESA_dispatch_table_rewrite_ptr, /* glWindowPos4fvMESA */
    epoxy_glWindowPos4iMESA_dispatch_table_rewrite_ptr, /* glWindowPos4iMESA */
    epoxy_glWindowPos4ivMESA_dispatch_table_rewrite_ptr, /* glWindowPos4ivMESA */
    epoxy_glWindowPos4sMESA_dispatch_table_rewrite_ptr, /* glWindowPos4sMESA */
    epoxy_glWindowPos4svMESA_dispatch_table_rewrite_ptr, /* glWindowPos4svMESA */
    epoxy_glWindowRectanglesEXT_dispatch_table_rewrite_ptr, /* glWindowRectanglesEXT */
    epoxy_glWriteMaskEXT_dispatch_table_rewrite_ptr, /* glWriteMaskEXT */
};

uint32_t gl_tls_index;
uint32_t gl_tls_size = sizeof(struct dispatch_table);

static inline struct dispatch_table *
get_dispatch_table(void)
{
	return TlsGetValue(gl_tls_index);
}

void
gl_init_dispatch_table(void)
{
    struct dispatch_table *dispatch_table = get_dispatch_table();
    memcpy(dispatch_table, &resolver_table, sizeof(resolver_table));
}

void
gl_switch_to_dispatch_table(void)
{
    epoxy_glAccum = epoxy_glAccum_dispatch_table_thunk;
    epoxy_glAccumxOES = epoxy_glAccumxOES_dispatch_table_thunk;
    epoxy_glAcquireKeyedMutexWin32EXT = epoxy_glAcquireKeyedMutexWin32EXT_dispatch_table_thunk;
    epoxy_glActiveProgramEXT = epoxy_glActiveProgramEXT_dispatch_table_thunk;
    epoxy_glActiveShaderProgram = epoxy_glActiveShaderProgram_dispatch_table_thunk;
    epoxy_glActiveShaderProgramEXT = epoxy_glActiveShaderProgramEXT_dispatch_table_thunk;
    epoxy_glActiveStencilFaceEXT = epoxy_glActiveStencilFaceEXT_dispatch_table_thunk;
    epoxy_glActiveTexture = epoxy_glActiveTexture_dispatch_table_thunk;
    epoxy_glActiveTextureARB = epoxy_glActiveTextureARB_dispatch_table_thunk;
    epoxy_glActiveVaryingNV = epoxy_glActiveVaryingNV_dispatch_table_thunk;
    epoxy_glAlphaFragmentOp1ATI = epoxy_glAlphaFragmentOp1ATI_dispatch_table_thunk;
    epoxy_glAlphaFragmentOp2ATI = epoxy_glAlphaFragmentOp2ATI_dispatch_table_thunk;
    epoxy_glAlphaFragmentOp3ATI = epoxy_glAlphaFragmentOp3ATI_dispatch_table_thunk;
    epoxy_glAlphaFunc = epoxy_glAlphaFunc_dispatch_table_thunk;
    epoxy_glAlphaFuncQCOM = epoxy_glAlphaFuncQCOM_dispatch_table_thunk;
    epoxy_glAlphaFuncx = epoxy_glAlphaFuncx_dispatch_table_thunk;
    epoxy_glAlphaFuncxOES = epoxy_glAlphaFuncxOES_dispatch_table_thunk;
    epoxy_glAlphaToCoverageDitherControlNV = epoxy_glAlphaToCoverageDitherControlNV_dispatch_table_thunk;
    epoxy_glApplyFramebufferAttachmentCMAAINTEL = epoxy_glApplyFramebufferAttachmentCMAAINTEL_dispatch_table_thunk;
    epoxy_glApplyTextureEXT = epoxy_glApplyTextureEXT_dispatch_table_thunk;
    epoxy_glAreProgramsResidentNV = epoxy_glAreProgramsResidentNV_dispatch_table_thunk;
    epoxy_glAreTexturesResident = epoxy_glAreTexturesResident_dispatch_table_thunk;
    epoxy_glAreTexturesResidentEXT = epoxy_glAreTexturesResidentEXT_dispatch_table_thunk;
    epoxy_glArrayElement = epoxy_glArrayElement_dispatch_table_thunk;
    epoxy_glArrayElementEXT = epoxy_glArrayElementEXT_dispatch_table_thunk;
    epoxy_glArrayObjectATI = epoxy_glArrayObjectATI_dispatch_table_thunk;
    epoxy_glAsyncCopyBufferSubDataNVX = epoxy_glAsyncCopyBufferSubDataNVX_dispatch_table_thunk;
    epoxy_glAsyncCopyImageSubDataNVX = epoxy_glAsyncCopyImageSubDataNVX_dispatch_table_thunk;
    epoxy_glAsyncMarkerSGIX = epoxy_glAsyncMarkerSGIX_dispatch_table_thunk;
    epoxy_glAttachObjectARB = epoxy_glAttachObjectARB_dispatch_table_thunk;
    epoxy_glAttachShader = epoxy_glAttachShader_dispatch_table_thunk;
    epoxy_glBegin_unwrapped = epoxy_glBegin_unwrapped_dispatch_table_thunk;
    epoxy_glBeginConditionalRender = epoxy_glBeginConditionalRender_dispatch_table_thunk;
    epoxy_glBeginConditionalRenderNV = epoxy_glBeginConditionalRenderNV_dispatch_table_thunk;
    epoxy_glBeginConditionalRenderNVX = epoxy_glBeginConditionalRenderNVX_dispatch_table_thunk;
    epoxy_glBeginFragmentShaderATI = epoxy_glBeginFragmentShaderATI_dispatch_table_thunk;
    epoxy_glBeginOcclusionQueryNV = epoxy_glBeginOcclusionQueryNV_dispatch_table_thunk;
    epoxy_glBeginPerfMonitorAMD = epoxy_glBeginPerfMonitorAMD_dispatch_table_thunk;
    epoxy_glBeginPerfQueryINTEL = epoxy_glBeginPerfQueryINTEL_dispatch_table_thunk;
    epoxy_glBeginQuery = epoxy_glBeginQuery_dispatch_table_thunk;
    epoxy_glBeginQueryARB = epoxy_glBeginQueryARB_dispatch_table_thunk;
    epoxy_glBeginQueryEXT = epoxy_glBeginQueryEXT_dispatch_table_thunk;
    epoxy_glBeginQueryIndexed = epoxy_glBeginQueryIndexed_dispatch_table_thunk;
    epoxy_glBeginTransformFeedback = epoxy_glBeginTransformFeedback_dispatch_table_thunk;
    epoxy_glBeginTransformFeedbackEXT = epoxy_glBeginTransformFeedbackEXT_dispatch_table_thunk;
    epoxy_glBeginTransformFeedbackNV = epoxy_glBeginTransformFeedbackNV_dispatch_table_thunk;
    epoxy_glBeginVertexShaderEXT = epoxy_glBeginVertexShaderEXT_dispatch_table_thunk;
    epoxy_glBeginVideoCaptureNV = epoxy_glBeginVideoCaptureNV_dispatch_table_thunk;
    epoxy_glBindAttribLocation = epoxy_glBindAttribLocation_dispatch_table_thunk;
    epoxy_glBindAttribLocationARB = epoxy_glBindAttribLocationARB_dispatch_table_thunk;
    epoxy_glBindBuffer = epoxy_glBindBuffer_dispatch_table_thunk;
    epoxy_glBindBufferARB = epoxy_glBindBufferARB_dispatch_table_thunk;
    epoxy_glBindBufferBase = epoxy_glBindBufferBase_dispatch_table_thunk;
    epoxy_glBindBufferBaseEXT = epoxy_glBindBufferBaseEXT_dispatch_table_thunk;
    epoxy_glBindBufferBaseNV = epoxy_glBindBufferBaseNV_dispatch_table_thunk;
    epoxy_glBindBufferOffsetEXT = epoxy_glBindBufferOffsetEXT_dispatch_table_thunk;
    epoxy_glBindBufferOffsetNV = epoxy_glBindBufferOffsetNV_dispatch_table_thunk;
    epoxy_glBindBufferRange = epoxy_glBindBufferRange_dispatch_table_thunk;
    epoxy_glBindBufferRangeEXT = epoxy_glBindBufferRangeEXT_dispatch_table_thunk;
    epoxy_glBindBufferRangeNV = epoxy_glBindBufferRangeNV_dispatch_table_thunk;
    epoxy_glBindBuffersBase = epoxy_glBindBuffersBase_dispatch_table_thunk;
    epoxy_glBindBuffersRange = epoxy_glBindBuffersRange_dispatch_table_thunk;
    epoxy_glBindFragDataLocation = epoxy_glBindFragDataLocation_dispatch_table_thunk;
    epoxy_glBindFragDataLocationEXT = epoxy_glBindFragDataLocationEXT_dispatch_table_thunk;
    epoxy_glBindFragDataLocationIndexed = epoxy_glBindFragDataLocationIndexed_dispatch_table_thunk;
    epoxy_glBindFragDataLocationIndexedEXT = epoxy_glBindFragDataLocationIndexedEXT_dispatch_table_thunk;
    epoxy_glBindFragmentShaderATI = epoxy_glBindFragmentShaderATI_dispatch_table_thunk;
    epoxy_glBindFramebuffer = epoxy_glBindFramebuffer_dispatch_table_thunk;
    epoxy_glBindFramebufferEXT = epoxy_glBindFramebufferEXT_dispatch_table_thunk;
    epoxy_glBindFramebufferOES = epoxy_glBindFramebufferOES_dispatch_table_thunk;
    epoxy_glBindImageTexture = epoxy_glBindImageTexture_dispatch_table_thunk;
    epoxy_glBindImageTextureEXT = epoxy_glBindImageTextureEXT_dispatch_table_thunk;
    epoxy_glBindImageTextures = epoxy_glBindImageTextures_dispatch_table_thunk;
    epoxy_glBindLightParameterEXT = epoxy_glBindLightParameterEXT_dispatch_table_thunk;
    epoxy_glBindMaterialParameterEXT = epoxy_glBindMaterialParameterEXT_dispatch_table_thunk;
    epoxy_glBindMultiTextureEXT = epoxy_glBindMultiTextureEXT_dispatch_table_thunk;
    epoxy_glBindParameterEXT = epoxy_glBindParameterEXT_dispatch_table_thunk;
    epoxy_glBindProgramARB = epoxy_glBindProgramARB_dispatch_table_thunk;
    epoxy_glBindProgramNV = epoxy_glBindProgramNV_dispatch_table_thunk;
    epoxy_glBindProgramPipeline = epoxy_glBindProgramPipeline_dispatch_table_thunk;
    epoxy_glBindProgramPipelineEXT = epoxy_glBindProgramPipelineEXT_dispatch_table_thunk;
    epoxy_glBindRenderbuffer = epoxy_glBindRenderbuffer_dispatch_table_thunk;
    epoxy_glBindRenderbufferEXT = epoxy_glBindRenderbufferEXT_dispatch_table_thunk;
    epoxy_glBindRenderbufferOES = epoxy_glBindRenderbufferOES_dispatch_table_thunk;
    epoxy_glBindSampler = epoxy_glBindSampler_dispatch_table_thunk;
    epoxy_glBindSamplers = epoxy_glBindSamplers_dispatch_table_thunk;
    epoxy_glBindShadingRateImageNV = epoxy_glBindShadingRateImageNV_dispatch_table_thunk;
    epoxy_glBindTexGenParameterEXT = epoxy_glBindTexGenParameterEXT_dispatch_table_thunk;
    epoxy_glBindTexture = epoxy_glBindTexture_dispatch_table_thunk;
    epoxy_glBindTextureEXT = epoxy_glBindTextureEXT_dispatch_table_thunk;
    epoxy_glBindTextureUnit = epoxy_glBindTextureUnit_dispatch_table_thunk;
    epoxy_glBindTextureUnitParameterEXT = epoxy_glBindTextureUnitParameterEXT_dispatch_table_thunk;
    epoxy_glBindTextures = epoxy_glBindTextures_dispatch_table_thunk;
    epoxy_glBindTransformFeedback = epoxy_glBindTransformFeedback_dispatch_table_thunk;
    epoxy_glBindTransformFeedbackNV = epoxy_glBindTransformFeedbackNV_dispatch_table_thunk;
    epoxy_glBindVertexArray = epoxy_glBindVertexArray_dispatch_table_thunk;
    epoxy_glBindVertexArrayAPPLE = epoxy_glBindVertexArrayAPPLE_dispatch_table_thunk;
    epoxy_glBindVertexArrayOES = epoxy_glBindVertexArrayOES_dispatch_table_thunk;
    epoxy_glBindVertexBuffer = epoxy_glBindVertexBuffer_dispatch_table_thunk;
    epoxy_glBindVertexBuffers = epoxy_glBindVertexBuffers_dispatch_table_thunk;
    epoxy_glBindVertexShaderEXT = epoxy_glBindVertexShaderEXT_dispatch_table_thunk;
    epoxy_glBindVideoCaptureStreamBufferNV = epoxy_glBindVideoCaptureStreamBufferNV_dispatch_table_thunk;
    epoxy_glBindVideoCaptureStreamTextureNV = epoxy_glBindVideoCaptureStreamTextureNV_dispatch_table_thunk;
    epoxy_glBinormal3bEXT = epoxy_glBinormal3bEXT_dispatch_table_thunk;
    epoxy_glBinormal3bvEXT = epoxy_glBinormal3bvEXT_dispatch_table_thunk;
    epoxy_glBinormal3dEXT = epoxy_glBinormal3dEXT_dispatch_table_thunk;
    epoxy_glBinormal3dvEXT = epoxy_glBinormal3dvEXT_dispatch_table_thunk;
    epoxy_glBinormal3fEXT = epoxy_glBinormal3fEXT_dispatch_table_thunk;
    epoxy_glBinormal3fvEXT = epoxy_glBinormal3fvEXT_dispatch_table_thunk;
    epoxy_glBinormal3iEXT = epoxy_glBinormal3iEXT_dispatch_table_thunk;
    epoxy_glBinormal3ivEXT = epoxy_glBinormal3ivEXT_dispatch_table_thunk;
    epoxy_glBinormal3sEXT = epoxy_glBinormal3sEXT_dispatch_table_thunk;
    epoxy_glBinormal3svEXT = epoxy_glBinormal3svEXT_dispatch_table_thunk;
    epoxy_glBinormalPointerEXT = epoxy_glBinormalPointerEXT_dispatch_table_thunk;
    epoxy_glBitmap = epoxy_glBitmap_dispatch_table_thunk;
    epoxy_glBitmapxOES = epoxy_glBitmapxOES_dispatch_table_thunk;
    epoxy_glBlendBarrier = epoxy_glBlendBarrier_dispatch_table_thunk;
    epoxy_glBlendBarrierKHR = epoxy_glBlendBarrierKHR_dispatch_table_thunk;
    epoxy_glBlendBarrierNV = epoxy_glBlendBarrierNV_dispatch_table_thunk;
    epoxy_glBlendColor = epoxy_glBlendColor_dispatch_table_thunk;
    epoxy_glBlendColorEXT = epoxy_glBlendColorEXT_dispatch_table_thunk;
    epoxy_glBlendColorxOES = epoxy_glBlendColorxOES_dispatch_table_thunk;
    epoxy_glBlendEquation = epoxy_glBlendEquation_dispatch_table_thunk;
    epoxy_glBlendEquationEXT = epoxy_glBlendEquationEXT_dispatch_table_thunk;
    epoxy_glBlendEquationIndexedAMD = epoxy_glBlendEquationIndexedAMD_dispatch_table_thunk;
    epoxy_glBlendEquationOES = epoxy_glBlendEquationOES_dispatch_table_thunk;
    epoxy_glBlendEquationSeparate = epoxy_glBlendEquationSeparate_dispatch_table_thunk;
    epoxy_glBlendEquationSeparateEXT = epoxy_glBlendEquationSeparateEXT_dispatch_table_thunk;
    epoxy_glBlendEquationSeparateIndexedAMD = epoxy_glBlendEquationSeparateIndexedAMD_dispatch_table_thunk;
    epoxy_glBlendEquationSeparateOES = epoxy_glBlendEquationSeparateOES_dispatch_table_thunk;
    epoxy_glBlendEquationSeparatei = epoxy_glBlendEquationSeparatei_dispatch_table_thunk;
    epoxy_glBlendEquationSeparateiARB = epoxy_glBlendEquationSeparateiARB_dispatch_table_thunk;
    epoxy_glBlendEquationSeparateiEXT = epoxy_glBlendEquationSeparateiEXT_dispatch_table_thunk;
    epoxy_glBlendEquationSeparateiOES = epoxy_glBlendEquationSeparateiOES_dispatch_table_thunk;
    epoxy_glBlendEquationi = epoxy_glBlendEquationi_dispatch_table_thunk;
    epoxy_glBlendEquationiARB = epoxy_glBlendEquationiARB_dispatch_table_thunk;
    epoxy_glBlendEquationiEXT = epoxy_glBlendEquationiEXT_dispatch_table_thunk;
    epoxy_glBlendEquationiOES = epoxy_glBlendEquationiOES_dispatch_table_thunk;
    epoxy_glBlendFunc = epoxy_glBlendFunc_dispatch_table_thunk;
    epoxy_glBlendFuncIndexedAMD = epoxy_glBlendFuncIndexedAMD_dispatch_table_thunk;
    epoxy_glBlendFuncSeparate = epoxy_glBlendFuncSeparate_dispatch_table_thunk;
    epoxy_glBlendFuncSeparateEXT = epoxy_glBlendFuncSeparateEXT_dispatch_table_thunk;
    epoxy_glBlendFuncSeparateINGR = epoxy_glBlendFuncSeparateINGR_dispatch_table_thunk;
    epoxy_glBlendFuncSeparateIndexedAMD = epoxy_glBlendFuncSeparateIndexedAMD_dispatch_table_thunk;
    epoxy_glBlendFuncSeparateOES = epoxy_glBlendFuncSeparateOES_dispatch_table_thunk;
    epoxy_glBlendFuncSeparatei = epoxy_glBlendFuncSeparatei_dispatch_table_thunk;
    epoxy_glBlendFuncSeparateiARB = epoxy_glBlendFuncSeparateiARB_dispatch_table_thunk;
    epoxy_glBlendFuncSeparateiEXT = epoxy_glBlendFuncSeparateiEXT_dispatch_table_thunk;
    epoxy_glBlendFuncSeparateiOES = epoxy_glBlendFuncSeparateiOES_dispatch_table_thunk;
    epoxy_glBlendFunci = epoxy_glBlendFunci_dispatch_table_thunk;
    epoxy_glBlendFunciARB = epoxy_glBlendFunciARB_dispatch_table_thunk;
    epoxy_glBlendFunciEXT = epoxy_glBlendFunciEXT_dispatch_table_thunk;
    epoxy_glBlendFunciOES = epoxy_glBlendFunciOES_dispatch_table_thunk;
    epoxy_glBlendParameteriNV = epoxy_glBlendParameteriNV_dispatch_table_thunk;
    epoxy_glBlitFramebuffer = epoxy_glBlitFramebuffer_dispatch_table_thunk;
    epoxy_glBlitFramebufferANGLE = epoxy_glBlitFramebufferANGLE_dispatch_table_thunk;
    epoxy_glBlitFramebufferEXT = epoxy_glBlitFramebufferEXT_dispatch_table_thunk;
    epoxy_glBlitFramebufferNV = epoxy_glBlitFramebufferNV_dispatch_table_thunk;
    epoxy_glBlitNamedFramebuffer = epoxy_glBlitNamedFramebuffer_dispatch_table_thunk;
    epoxy_glBufferAddressRangeNV = epoxy_glBufferAddressRangeNV_dispatch_table_thunk;
    epoxy_glBufferAttachMemoryNV = epoxy_glBufferAttachMemoryNV_dispatch_table_thunk;
    epoxy_glBufferData = epoxy_glBufferData_dispatch_table_thunk;
    epoxy_glBufferDataARB = epoxy_glBufferDataARB_dispatch_table_thunk;
    epoxy_glBufferPageCommitmentARB = epoxy_glBufferPageCommitmentARB_dispatch_table_thunk;
    epoxy_glBufferParameteriAPPLE = epoxy_glBufferParameteriAPPLE_dispatch_table_thunk;
    epoxy_glBufferStorage = epoxy_glBufferStorage_dispatch_table_thunk;
    epoxy_glBufferStorageEXT = epoxy_glBufferStorageEXT_dispatch_table_thunk;
    epoxy_glBufferStorageExternalEXT = epoxy_glBufferStorageExternalEXT_dispatch_table_thunk;
    epoxy_glBufferStorageMemEXT = epoxy_glBufferStorageMemEXT_dispatch_table_thunk;
    epoxy_glBufferSubData = epoxy_glBufferSubData_dispatch_table_thunk;
    epoxy_glBufferSubDataARB = epoxy_glBufferSubDataARB_dispatch_table_thunk;
    epoxy_glCallCommandListNV = epoxy_glCallCommandListNV_dispatch_table_thunk;
    epoxy_glCallList = epoxy_glCallList_dispatch_table_thunk;
    epoxy_glCallLists = epoxy_glCallLists_dispatch_table_thunk;
    epoxy_glCheckFramebufferStatus = epoxy_glCheckFramebufferStatus_dispatch_table_thunk;
    epoxy_glCheckFramebufferStatusEXT = epoxy_glCheckFramebufferStatusEXT_dispatch_table_thunk;
    epoxy_glCheckFramebufferStatusOES = epoxy_glCheckFramebufferStatusOES_dispatch_table_thunk;
    epoxy_glCheckNamedFramebufferStatus = epoxy_glCheckNamedFramebufferStatus_dispatch_table_thunk;
    epoxy_glCheckNamedFramebufferStatusEXT = epoxy_glCheckNamedFramebufferStatusEXT_dispatch_table_thunk;
    epoxy_glClampColor = epoxy_glClampColor_dispatch_table_thunk;
    epoxy_glClampColorARB = epoxy_glClampColorARB_dispatch_table_thunk;
    epoxy_glClear = epoxy_glClear_dispatch_table_thunk;
    epoxy_glClearAccum = epoxy_glClearAccum_dispatch_table_thunk;
    epoxy_glClearAccumxOES = epoxy_glClearAccumxOES_dispatch_table_thunk;
    epoxy_glClearBufferData = epoxy_glClearBufferData_dispatch_table_thunk;
    epoxy_glClearBufferSubData = epoxy_glClearBufferSubData_dispatch_table_thunk;
    epoxy_glClearBufferfi = epoxy_glClearBufferfi_dispatch_table_thunk;
    epoxy_glClearBufferfv = epoxy_glClearBufferfv_dispatch_table_thunk;
    epoxy_glClearBufferiv = epoxy_glClearBufferiv_dispatch_table_thunk;
    epoxy_glClearBufferuiv = epoxy_glClearBufferuiv_dispatch_table_thunk;
    epoxy_glClearColor = epoxy_glClearColor_dispatch_table_thunk;
    epoxy_glClearColorIiEXT = epoxy_glClearColorIiEXT_dispatch_table_thunk;
    epoxy_glClearColorIuiEXT = epoxy_glClearColorIuiEXT_dispatch_table_thunk;
    epoxy_glClearColorx = epoxy_glClearColorx_dispatch_table_thunk;
    epoxy_glClearColorxOES = epoxy_glClearColorxOES_dispatch_table_thunk;
    epoxy_glClearDepth = epoxy_glClearDepth_dispatch_table_thunk;
    epoxy_glClearDepthdNV = epoxy_glClearDepthdNV_dispatch_table_thunk;
    epoxy_glClearDepthf = epoxy_glClearDepthf_dispatch_table_thunk;
    epoxy_glClearDepthfOES = epoxy_glClearDepthfOES_dispatch_table_thunk;
    epoxy_glClearDepthx = epoxy_glClearDepthx_dispatch_table_thunk;
    epoxy_glClearDepthxOES = epoxy_glClearDepthxOES_dispatch_table_thunk;
    epoxy_glClearIndex = epoxy_glClearIndex_dispatch_table_thunk;
    epoxy_glClearNamedBufferData = epoxy_glClearNamedBufferData_dispatch_table_thunk;
    epoxy_glClearNamedBufferDataEXT = epoxy_glClearNamedBufferDataEXT_dispatch_table_thunk;
    epoxy_glClearNamedBufferSubData = epoxy_glClearNamedBufferSubData_dispatch_table_thunk;
    epoxy_glClearNamedBufferSubDataEXT = epoxy_glClearNamedBufferSubDataEXT_dispatch_table_thunk;
    epoxy_glClearNamedFramebufferfi = epoxy_glClearNamedFramebufferfi_dispatch_table_thunk;
    epoxy_glClearNamedFramebufferfv = epoxy_glClearNamedFramebufferfv_dispatch_table_thunk;
    epoxy_glClearNamedFramebufferiv = epoxy_glClearNamedFramebufferiv_dispatch_table_thunk;
    epoxy_glClearNamedFramebufferuiv = epoxy_glClearNamedFramebufferuiv_dispatch_table_thunk;
    epoxy_glClearPixelLocalStorageuiEXT = epoxy_glClearPixelLocalStorageuiEXT_dispatch_table_thunk;
    epoxy_glClearStencil = epoxy_glClearStencil_dispatch_table_thunk;
    epoxy_glClearTexImage = epoxy_glClearTexImage_dispatch_table_thunk;
    epoxy_glClearTexImageEXT = epoxy_glClearTexImageEXT_dispatch_table_thunk;
    epoxy_glClearTexSubImage = epoxy_glClearTexSubImage_dispatch_table_thunk;
    epoxy_glClearTexSubImageEXT = epoxy_glClearTexSubImageEXT_dispatch_table_thunk;
    epoxy_glClientActiveTexture = epoxy_glClientActiveTexture_dispatch_table_thunk;
    epoxy_glClientActiveTextureARB = epoxy_glClientActiveTextureARB_dispatch_table_thunk;
    epoxy_glClientActiveVertexStreamATI = epoxy_glClientActiveVertexStreamATI_dispatch_table_thunk;
    epoxy_glClientAttribDefaultEXT = epoxy_glClientAttribDefaultEXT_dispatch_table_thunk;
    epoxy_glClientWaitSemaphoreui64NVX = epoxy_glClientWaitSemaphoreui64NVX_dispatch_table_thunk;
    epoxy_glClientWaitSync = epoxy_glClientWaitSync_dispatch_table_thunk;
    epoxy_glClientWaitSyncAPPLE = epoxy_glClientWaitSyncAPPLE_dispatch_table_thunk;
    epoxy_glClipControl = epoxy_glClipControl_dispatch_table_thunk;
    epoxy_glClipControlEXT = epoxy_glClipControlEXT_dispatch_table_thunk;
    epoxy_glClipPlane = epoxy_glClipPlane_dispatch_table_thunk;
    epoxy_glClipPlanef = epoxy_glClipPlanef_dispatch_table_thunk;
    epoxy_glClipPlanefIMG = epoxy_glClipPlanefIMG_dispatch_table_thunk;
    epoxy_glClipPlanefOES = epoxy_glClipPlanefOES_dispatch_table_thunk;
    epoxy_glClipPlanex = epoxy_glClipPlanex_dispatch_table_thunk;
    epoxy_glClipPlanexIMG = epoxy_glClipPlanexIMG_dispatch_table_thunk;
    epoxy_glClipPlanexOES = epoxy_glClipPlanexOES_dispatch_table_thunk;
    epoxy_glColor3b = epoxy_glColor3b_dispatch_table_thunk;
    epoxy_glColor3bv = epoxy_glColor3bv_dispatch_table_thunk;
    epoxy_glColor3d = epoxy_glColor3d_dispatch_table_thunk;
    epoxy_glColor3dv = epoxy_glColor3dv_dispatch_table_thunk;
    epoxy_glColor3f = epoxy_glColor3f_dispatch_table_thunk;
    epoxy_glColor3fVertex3fSUN = epoxy_glColor3fVertex3fSUN_dispatch_table_thunk;
    epoxy_glColor3fVertex3fvSUN = epoxy_glColor3fVertex3fvSUN_dispatch_table_thunk;
    epoxy_glColor3fv = epoxy_glColor3fv_dispatch_table_thunk;
    epoxy_glColor3hNV = epoxy_glColor3hNV_dispatch_table_thunk;
    epoxy_glColor3hvNV = epoxy_glColor3hvNV_dispatch_table_thunk;
    epoxy_glColor3i = epoxy_glColor3i_dispatch_table_thunk;
    epoxy_glColor3iv = epoxy_glColor3iv_dispatch_table_thunk;
    epoxy_glColor3s = epoxy_glColor3s_dispatch_table_thunk;
    epoxy_glColor3sv = epoxy_glColor3sv_dispatch_table_thunk;
    epoxy_glColor3ub = epoxy_glColor3ub_dispatch_table_thunk;
    epoxy_glColor3ubv = epoxy_glColor3ubv_dispatch_table_thunk;
    epoxy_glColor3ui = epoxy_glColor3ui_dispatch_table_thunk;
    epoxy_glColor3uiv = epoxy_glColor3uiv_dispatch_table_thunk;
    epoxy_glColor3us = epoxy_glColor3us_dispatch_table_thunk;
    epoxy_glColor3usv = epoxy_glColor3usv_dispatch_table_thunk;
    epoxy_glColor3xOES = epoxy_glColor3xOES_dispatch_table_thunk;
    epoxy_glColor3xvOES = epoxy_glColor3xvOES_dispatch_table_thunk;
    epoxy_glColor4b = epoxy_glColor4b_dispatch_table_thunk;
    epoxy_glColor4bv = epoxy_glColor4bv_dispatch_table_thunk;
    epoxy_glColor4d = epoxy_glColor4d_dispatch_table_thunk;
    epoxy_glColor4dv = epoxy_glColor4dv_dispatch_table_thunk;
    epoxy_glColor4f = epoxy_glColor4f_dispatch_table_thunk;
    epoxy_glColor4fNormal3fVertex3fSUN = epoxy_glColor4fNormal3fVertex3fSUN_dispatch_table_thunk;
    epoxy_glColor4fNormal3fVertex3fvSUN = epoxy_glColor4fNormal3fVertex3fvSUN_dispatch_table_thunk;
    epoxy_glColor4fv = epoxy_glColor4fv_dispatch_table_thunk;
    epoxy_glColor4hNV = epoxy_glColor4hNV_dispatch_table_thunk;
    epoxy_glColor4hvNV = epoxy_glColor4hvNV_dispatch_table_thunk;
    epoxy_glColor4i = epoxy_glColor4i_dispatch_table_thunk;
    epoxy_glColor4iv = epoxy_glColor4iv_dispatch_table_thunk;
    epoxy_glColor4s = epoxy_glColor4s_dispatch_table_thunk;
    epoxy_glColor4sv = epoxy_glColor4sv_dispatch_table_thunk;
    epoxy_glColor4ub = epoxy_glColor4ub_dispatch_table_thunk;
    epoxy_glColor4ubVertex2fSUN = epoxy_glColor4ubVertex2fSUN_dispatch_table_thunk;
    epoxy_glColor4ubVertex2fvSUN = epoxy_glColor4ubVertex2fvSUN_dispatch_table_thunk;
    epoxy_glColor4ubVertex3fSUN = epoxy_glColor4ubVertex3fSUN_dispatch_table_thunk;
    epoxy_glColor4ubVertex3fvSUN = epoxy_glColor4ubVertex3fvSUN_dispatch_table_thunk;
    epoxy_glColor4ubv = epoxy_glColor4ubv_dispatch_table_thunk;
    epoxy_glColor4ui = epoxy_glColor4ui_dispatch_table_thunk;
    epoxy_glColor4uiv = epoxy_glColor4uiv_dispatch_table_thunk;
    epoxy_glColor4us = epoxy_glColor4us_dispatch_table_thunk;
    epoxy_glColor4usv = epoxy_glColor4usv_dispatch_table_thunk;
    epoxy_glColor4x = epoxy_glColor4x_dispatch_table_thunk;
    epoxy_glColor4xOES = epoxy_glColor4xOES_dispatch_table_thunk;
    epoxy_glColor4xvOES = epoxy_glColor4xvOES_dispatch_table_thunk;
    epoxy_glColorFormatNV = epoxy_glColorFormatNV_dispatch_table_thunk;
    epoxy_glColorFragmentOp1ATI = epoxy_glColorFragmentOp1ATI_dispatch_table_thunk;
    epoxy_glColorFragmentOp2ATI = epoxy_glColorFragmentOp2ATI_dispatch_table_thunk;
    epoxy_glColorFragmentOp3ATI = epoxy_glColorFragmentOp3ATI_dispatch_table_thunk;
    epoxy_glColorMask = epoxy_glColorMask_dispatch_table_thunk;
    epoxy_glColorMaskIndexedEXT = epoxy_glColorMaskIndexedEXT_dispatch_table_thunk;
    epoxy_glColorMaski = epoxy_glColorMaski_dispatch_table_thunk;
    epoxy_glColorMaskiEXT = epoxy_glColorMaskiEXT_dispatch_table_thunk;
    epoxy_glColorMaskiOES = epoxy_glColorMaskiOES_dispatch_table_thunk;
    epoxy_glColorMaterial = epoxy_glColorMaterial_dispatch_table_thunk;
    epoxy_glColorP3ui = epoxy_glColorP3ui_dispatch_table_thunk;
    epoxy_glColorP3uiv = epoxy_glColorP3uiv_dispatch_table_thunk;
    epoxy_glColorP4ui = epoxy_glColorP4ui_dispatch_table_thunk;
    epoxy_glColorP4uiv = epoxy_glColorP4uiv_dispatch_table_thunk;
    epoxy_glColorPointer = epoxy_glColorPointer_dispatch_table_thunk;
    epoxy_glColorPointerEXT = epoxy_glColorPointerEXT_dispatch_table_thunk;
    epoxy_glColorPointerListIBM = epoxy_glColorPointerListIBM_dispatch_table_thunk;
    epoxy_glColorPointervINTEL = epoxy_glColorPointervINTEL_dispatch_table_thunk;
    epoxy_glColorSubTable = epoxy_glColorSubTable_dispatch_table_thunk;
    epoxy_glColorSubTableEXT = epoxy_glColorSubTableEXT_dispatch_table_thunk;
    epoxy_glColorTable = epoxy_glColorTable_dispatch_table_thunk;
    epoxy_glColorTableEXT = epoxy_glColorTableEXT_dispatch_table_thunk;
    epoxy_glColorTableParameterfv = epoxy_glColorTableParameterfv_dispatch_table_thunk;
    epoxy_glColorTableParameterfvSGI = epoxy_glColorTableParameterfvSGI_dispatch_table_thunk;
    epoxy_glColorTableParameteriv = epoxy_glColorTableParameteriv_dispatch_table_thunk;
    epoxy_glColorTableParameterivSGI = epoxy_glColorTableParameterivSGI_dispatch_table_thunk;
    epoxy_glColorTableSGI = epoxy_glColorTableSGI_dispatch_table_thunk;
    epoxy_glCombinerInputNV = epoxy_glCombinerInputNV_dispatch_table_thunk;
    epoxy_glCombinerOutputNV = epoxy_glCombinerOutputNV_dispatch_table_thunk;
    epoxy_glCombinerParameterfNV = epoxy_glCombinerParameterfNV_dispatch_table_thunk;
    epoxy_glCombinerParameterfvNV = epoxy_glCombinerParameterfvNV_dispatch_table_thunk;
    epoxy_glCombinerParameteriNV = epoxy_glCombinerParameteriNV_dispatch_table_thunk;
    epoxy_glCombinerParameterivNV = epoxy_glCombinerParameterivNV_dispatch_table_thunk;
    epoxy_glCombinerStageParameterfvNV = epoxy_glCombinerStageParameterfvNV_dispatch_table_thunk;
    epoxy_glCommandListSegmentsNV = epoxy_glCommandListSegmentsNV_dispatch_table_thunk;
    epoxy_glCompileCommandListNV = epoxy_glCompileCommandListNV_dispatch_table_thunk;
    epoxy_glCompileShader = epoxy_glCompileShader_dispatch_table_thunk;
    epoxy_glCompileShaderARB = epoxy_glCompileShaderARB_dispatch_table_thunk;
    epoxy_glCompileShaderIncludeARB = epoxy_glCompileShaderIncludeARB_dispatch_table_thunk;
    epoxy_glCompressedMultiTexImage1DEXT = epoxy_glCompressedMultiTexImage1DEXT_dispatch_table_thunk;
    epoxy_glCompressedMultiTexImage2DEXT = epoxy_glCompressedMultiTexImage2DEXT_dispatch_table_thunk;
    epoxy_glCompressedMultiTexImage3DEXT = epoxy_glCompressedMultiTexImage3DEXT_dispatch_table_thunk;
    epoxy_glCompressedMultiTexSubImage1DEXT = epoxy_glCompressedMultiTexSubImage1DEXT_dispatch_table_thunk;
    epoxy_glCompressedMultiTexSubImage2DEXT = epoxy_glCompressedMultiTexSubImage2DEXT_dispatch_table_thunk;
    epoxy_glCompressedMultiTexSubImage3DEXT = epoxy_glCompressedMultiTexSubImage3DEXT_dispatch_table_thunk;
    epoxy_glCompressedTexImage1D = epoxy_glCompressedTexImage1D_dispatch_table_thunk;
    epoxy_glCompressedTexImage1DARB = epoxy_glCompressedTexImage1DARB_dispatch_table_thunk;
    epoxy_glCompressedTexImage2D = epoxy_glCompressedTexImage2D_dispatch_table_thunk;
    epoxy_glCompressedTexImage2DARB = epoxy_glCompressedTexImage2DARB_dispatch_table_thunk;
    epoxy_glCompressedTexImage3D = epoxy_glCompressedTexImage3D_dispatch_table_thunk;
    epoxy_glCompressedTexImage3DARB = epoxy_glCompressedTexImage3DARB_dispatch_table_thunk;
    epoxy_glCompressedTexImage3DOES = epoxy_glCompressedTexImage3DOES_dispatch_table_thunk;
    epoxy_glCompressedTexSubImage1D = epoxy_glCompressedTexSubImage1D_dispatch_table_thunk;
    epoxy_glCompressedTexSubImage1DARB = epoxy_glCompressedTexSubImage1DARB_dispatch_table_thunk;
    epoxy_glCompressedTexSubImage2D = epoxy_glCompressedTexSubImage2D_dispatch_table_thunk;
    epoxy_glCompressedTexSubImage2DARB = epoxy_glCompressedTexSubImage2DARB_dispatch_table_thunk;
    epoxy_glCompressedTexSubImage3D = epoxy_glCompressedTexSubImage3D_dispatch_table_thunk;
    epoxy_glCompressedTexSubImage3DARB = epoxy_glCompressedTexSubImage3DARB_dispatch_table_thunk;
    epoxy_glCompressedTexSubImage3DOES = epoxy_glCompressedTexSubImage3DOES_dispatch_table_thunk;
    epoxy_glCompressedTextureImage1DEXT = epoxy_glCompressedTextureImage1DEXT_dispatch_table_thunk;
    epoxy_glCompressedTextureImage2DEXT = epoxy_glCompressedTextureImage2DEXT_dispatch_table_thunk;
    epoxy_glCompressedTextureImage3DEXT = epoxy_glCompressedTextureImage3DEXT_dispatch_table_thunk;
    epoxy_glCompressedTextureSubImage1D = epoxy_glCompressedTextureSubImage1D_dispatch_table_thunk;
    epoxy_glCompressedTextureSubImage1DEXT = epoxy_glCompressedTextureSubImage1DEXT_dispatch_table_thunk;
    epoxy_glCompressedTextureSubImage2D = epoxy_glCompressedTextureSubImage2D_dispatch_table_thunk;
    epoxy_glCompressedTextureSubImage2DEXT = epoxy_glCompressedTextureSubImage2DEXT_dispatch_table_thunk;
    epoxy_glCompressedTextureSubImage3D = epoxy_glCompressedTextureSubImage3D_dispatch_table_thunk;
    epoxy_glCompressedTextureSubImage3DEXT = epoxy_glCompressedTextureSubImage3DEXT_dispatch_table_thunk;
    epoxy_glConservativeRasterParameterfNV = epoxy_glConservativeRasterParameterfNV_dispatch_table_thunk;
    epoxy_glConservativeRasterParameteriNV = epoxy_glConservativeRasterParameteriNV_dispatch_table_thunk;
    epoxy_glConvolutionFilter1D = epoxy_glConvolutionFilter1D_dispatch_table_thunk;
    epoxy_glConvolutionFilter1DEXT = epoxy_glConvolutionFilter1DEXT_dispatch_table_thunk;
    epoxy_glConvolutionFilter2D = epoxy_glConvolutionFilter2D_dispatch_table_thunk;
    epoxy_glConvolutionFilter2DEXT = epoxy_glConvolutionFilter2DEXT_dispatch_table_thunk;
    epoxy_glConvolutionParameterf = epoxy_glConvolutionParameterf_dispatch_table_thunk;
    epoxy_glConvolutionParameterfEXT = epoxy_glConvolutionParameterfEXT_dispatch_table_thunk;
    epoxy_glConvolutionParameterfv = epoxy_glConvolutionParameterfv_dispatch_table_thunk;
    epoxy_glConvolutionParameterfvEXT = epoxy_glConvolutionParameterfvEXT_dispatch_table_thunk;
    epoxy_glConvolutionParameteri = epoxy_glConvolutionParameteri_dispatch_table_thunk;
    epoxy_glConvolutionParameteriEXT = epoxy_glConvolutionParameteriEXT_dispatch_table_thunk;
    epoxy_glConvolutionParameteriv = epoxy_glConvolutionParameteriv_dispatch_table_thunk;
    epoxy_glConvolutionParameterivEXT = epoxy_glConvolutionParameterivEXT_dispatch_table_thunk;
    epoxy_glConvolutionParameterxOES = epoxy_glConvolutionParameterxOES_dispatch_table_thunk;
    epoxy_glConvolutionParameterxvOES = epoxy_glConvolutionParameterxvOES_dispatch_table_thunk;
    epoxy_glCopyBufferSubData = epoxy_glCopyBufferSubData_dispatch_table_thunk;
    epoxy_glCopyBufferSubDataNV = epoxy_glCopyBufferSubDataNV_dispatch_table_thunk;
    epoxy_glCopyColorSubTable = epoxy_glCopyColorSubTable_dispatch_table_thunk;
    epoxy_glCopyColorSubTableEXT = epoxy_glCopyColorSubTableEXT_dispatch_table_thunk;
    epoxy_glCopyColorTable = epoxy_glCopyColorTable_dispatch_table_thunk;
    epoxy_glCopyColorTableSGI = epoxy_glCopyColorTableSGI_dispatch_table_thunk;
    epoxy_glCopyConvolutionFilter1D = epoxy_glCopyConvolutionFilter1D_dispatch_table_thunk;
    epoxy_glCopyConvolutionFilter1DEXT = epoxy_glCopyConvolutionFilter1DEXT_dispatch_table_thunk;
    epoxy_glCopyConvolutionFilter2D = epoxy_glCopyConvolutionFilter2D_dispatch_table_thunk;
    epoxy_glCopyConvolutionFilter2DEXT = epoxy_glCopyConvolutionFilter2DEXT_dispatch_table_thunk;
    epoxy_glCopyImageSubData = epoxy_glCopyImageSubData_dispatch_table_thunk;
    epoxy_glCopyImageSubDataEXT = epoxy_glCopyImageSubDataEXT_dispatch_table_thunk;
    epoxy_glCopyImageSubDataNV = epoxy_glCopyImageSubDataNV_dispatch_table_thunk;
    epoxy_glCopyImageSubDataOES = epoxy_glCopyImageSubDataOES_dispatch_table_thunk;
    epoxy_glCopyMultiTexImage1DEXT = epoxy_glCopyMultiTexImage1DEXT_dispatch_table_thunk;
    epoxy_glCopyMultiTexImage2DEXT = epoxy_glCopyMultiTexImage2DEXT_dispatch_table_thunk;
    epoxy_glCopyMultiTexSubImage1DEXT = epoxy_glCopyMultiTexSubImage1DEXT_dispatch_table_thunk;
    epoxy_glCopyMultiTexSubImage2DEXT = epoxy_glCopyMultiTexSubImage2DEXT_dispatch_table_thunk;
    epoxy_glCopyMultiTexSubImage3DEXT = epoxy_glCopyMultiTexSubImage3DEXT_dispatch_table_thunk;
    epoxy_glCopyNamedBufferSubData = epoxy_glCopyNamedBufferSubData_dispatch_table_thunk;
    epoxy_glCopyPathNV = epoxy_glCopyPathNV_dispatch_table_thunk;
    epoxy_glCopyPixels = epoxy_glCopyPixels_dispatch_table_thunk;
    epoxy_glCopyTexImage1D = epoxy_glCopyTexImage1D_dispatch_table_thunk;
    epoxy_glCopyTexImage1DEXT = epoxy_glCopyTexImage1DEXT_dispatch_table_thunk;
    epoxy_glCopyTexImage2D = epoxy_glCopyTexImage2D_dispatch_table_thunk;
    epoxy_glCopyTexImage2DEXT = epoxy_glCopyTexImage2DEXT_dispatch_table_thunk;
    epoxy_glCopyTexSubImage1D = epoxy_glCopyTexSubImage1D_dispatch_table_thunk;
    epoxy_glCopyTexSubImage1DEXT = epoxy_glCopyTexSubImage1DEXT_dispatch_table_thunk;
    epoxy_glCopyTexSubImage2D = epoxy_glCopyTexSubImage2D_dispatch_table_thunk;
    epoxy_glCopyTexSubImage2DEXT = epoxy_glCopyTexSubImage2DEXT_dispatch_table_thunk;
    epoxy_glCopyTexSubImage3D = epoxy_glCopyTexSubImage3D_dispatch_table_thunk;
    epoxy_glCopyTexSubImage3DEXT = epoxy_glCopyTexSubImage3DEXT_dispatch_table_thunk;
    epoxy_glCopyTexSubImage3DOES = epoxy_glCopyTexSubImage3DOES_dispatch_table_thunk;
    epoxy_glCopyTextureImage1DEXT = epoxy_glCopyTextureImage1DEXT_dispatch_table_thunk;
    epoxy_glCopyTextureImage2DEXT = epoxy_glCopyTextureImage2DEXT_dispatch_table_thunk;
    epoxy_glCopyTextureLevelsAPPLE = epoxy_glCopyTextureLevelsAPPLE_dispatch_table_thunk;
    epoxy_glCopyTextureSubImage1D = epoxy_glCopyTextureSubImage1D_dispatch_table_thunk;
    epoxy_glCopyTextureSubImage1DEXT = epoxy_glCopyTextureSubImage1DEXT_dispatch_table_thunk;
    epoxy_glCopyTextureSubImage2D = epoxy_glCopyTextureSubImage2D_dispatch_table_thunk;
    epoxy_glCopyTextureSubImage2DEXT = epoxy_glCopyTextureSubImage2DEXT_dispatch_table_thunk;
    epoxy_glCopyTextureSubImage3D = epoxy_glCopyTextureSubImage3D_dispatch_table_thunk;
    epoxy_glCopyTextureSubImage3DEXT = epoxy_glCopyTextureSubImage3DEXT_dispatch_table_thunk;
    epoxy_glCoverFillPathInstancedNV = epoxy_glCoverFillPathInstancedNV_dispatch_table_thunk;
    epoxy_glCoverFillPathNV = epoxy_glCoverFillPathNV_dispatch_table_thunk;
    epoxy_glCoverStrokePathInstancedNV = epoxy_glCoverStrokePathInstancedNV_dispatch_table_thunk;
    epoxy_glCoverStrokePathNV = epoxy_glCoverStrokePathNV_dispatch_table_thunk;
    epoxy_glCoverageMaskNV = epoxy_glCoverageMaskNV_dispatch_table_thunk;
    epoxy_glCoverageModulationNV = epoxy_glCoverageModulationNV_dispatch_table_thunk;
    epoxy_glCoverageModulationTableNV = epoxy_glCoverageModulationTableNV_dispatch_table_thunk;
    epoxy_glCoverageOperationNV = epoxy_glCoverageOperationNV_dispatch_table_thunk;
    epoxy_glCreateBuffers = epoxy_glCreateBuffers_dispatch_table_thunk;
    epoxy_glCreateCommandListsNV = epoxy_glCreateCommandListsNV_dispatch_table_thunk;
    epoxy_glCreateFramebuffers = epoxy_glCreateFramebuffers_dispatch_table_thunk;
    epoxy_glCreateMemoryObjectsEXT = epoxy_glCreateMemoryObjectsEXT_dispatch_table_thunk;
    epoxy_glCreatePerfQueryINTEL = epoxy_glCreatePerfQueryINTEL_dispatch_table_thunk;
    epoxy_glCreateProgram = epoxy_glCreateProgram_dispatch_table_thunk;
    epoxy_glCreateProgramObjectARB = epoxy_glCreateProgramObjectARB_dispatch_table_thunk;
    epoxy_glCreateProgramPipelines = epoxy_glCreateProgramPipelines_dispatch_table_thunk;
    epoxy_glCreateProgressFenceNVX = epoxy_glCreateProgressFenceNVX_dispatch_table_thunk;
    epoxy_glCreateQueries = epoxy_glCreateQueries_dispatch_table_thunk;
    epoxy_glCreateRenderbuffers = epoxy_glCreateRenderbuffers_dispatch_table_thunk;
    epoxy_glCreateSamplers = epoxy_glCreateSamplers_dispatch_table_thunk;
    epoxy_glCreateShader = epoxy_glCreateShader_dispatch_table_thunk;
    epoxy_glCreateShaderObjectARB = epoxy_glCreateShaderObjectARB_dispatch_table_thunk;
    epoxy_glCreateShaderProgramEXT = epoxy_glCreateShaderProgramEXT_dispatch_table_thunk;
    epoxy_glCreateShaderProgramv = epoxy_glCreateShaderProgramv_dispatch_table_thunk;
    epoxy_glCreateShaderProgramvEXT = epoxy_glCreateShaderProgramvEXT_dispatch_table_thunk;
    epoxy_glCreateStatesNV = epoxy_glCreateStatesNV_dispatch_table_thunk;
    epoxy_glCreateSyncFromCLeventARB = epoxy_glCreateSyncFromCLeventARB_dispatch_table_thunk;
    epoxy_glCreateTextures = epoxy_glCreateTextures_dispatch_table_thunk;
    epoxy_glCreateTransformFeedbacks = epoxy_glCreateTransformFeedbacks_dispatch_table_thunk;
    epoxy_glCreateVertexArrays = epoxy_glCreateVertexArrays_dispatch_table_thunk;
    epoxy_glCullFace = epoxy_glCullFace_dispatch_table_thunk;
    epoxy_glCullParameterdvEXT = epoxy_glCullParameterdvEXT_dispatch_table_thunk;
    epoxy_glCullParameterfvEXT = epoxy_glCullParameterfvEXT_dispatch_table_thunk;
    epoxy_glCurrentPaletteMatrixARB = epoxy_glCurrentPaletteMatrixARB_dispatch_table_thunk;
    epoxy_glCurrentPaletteMatrixOES = epoxy_glCurrentPaletteMatrixOES_dispatch_table_thunk;
    epoxy_glDebugMessageCallback = epoxy_glDebugMessageCallback_dispatch_table_thunk;
    epoxy_glDebugMessageCallbackAMD = epoxy_glDebugMessageCallbackAMD_dispatch_table_thunk;
    epoxy_glDebugMessageCallbackARB = epoxy_glDebugMessageCallbackARB_dispatch_table_thunk;
    epoxy_glDebugMessageCallbackKHR = epoxy_glDebugMessageCallbackKHR_dispatch_table_thunk;
    epoxy_glDebugMessageControl = epoxy_glDebugMessageControl_dispatch_table_thunk;
    epoxy_glDebugMessageControlARB = epoxy_glDebugMessageControlARB_dispatch_table_thunk;
    epoxy_glDebugMessageControlKHR = epoxy_glDebugMessageControlKHR_dispatch_table_thunk;
    epoxy_glDebugMessageEnableAMD = epoxy_glDebugMessageEnableAMD_dispatch_table_thunk;
    epoxy_glDebugMessageInsert = epoxy_glDebugMessageInsert_dispatch_table_thunk;
    epoxy_glDebugMessageInsertAMD = epoxy_glDebugMessageInsertAMD_dispatch_table_thunk;
    epoxy_glDebugMessageInsertARB = epoxy_glDebugMessageInsertARB_dispatch_table_thunk;
    epoxy_glDebugMessageInsertKHR = epoxy_glDebugMessageInsertKHR_dispatch_table_thunk;
    epoxy_glDeformSGIX = epoxy_glDeformSGIX_dispatch_table_thunk;
    epoxy_glDeformationMap3dSGIX = epoxy_glDeformationMap3dSGIX_dispatch_table_thunk;
    epoxy_glDeformationMap3fSGIX = epoxy_glDeformationMap3fSGIX_dispatch_table_thunk;
    epoxy_glDeleteAsyncMarkersSGIX = epoxy_glDeleteAsyncMarkersSGIX_dispatch_table_thunk;
    epoxy_glDeleteBuffers = epoxy_glDeleteBuffers_dispatch_table_thunk;
    epoxy_glDeleteBuffersARB = epoxy_glDeleteBuffersARB_dispatch_table_thunk;
    epoxy_glDeleteCommandListsNV = epoxy_glDeleteCommandListsNV_dispatch_table_thunk;
    epoxy_glDeleteFencesAPPLE = epoxy_glDeleteFencesAPPLE_dispatch_table_thunk;
    epoxy_glDeleteFencesNV = epoxy_glDeleteFencesNV_dispatch_table_thunk;
    epoxy_glDeleteFragmentShaderATI = epoxy_glDeleteFragmentShaderATI_dispatch_table_thunk;
    epoxy_glDeleteFramebuffers = epoxy_glDeleteFramebuffers_dispatch_table_thunk;
    epoxy_glDeleteFramebuffersEXT = epoxy_glDeleteFramebuffersEXT_dispatch_table_thunk;
    epoxy_glDeleteFramebuffersOES = epoxy_glDeleteFramebuffersOES_dispatch_table_thunk;
    epoxy_glDeleteLists = epoxy_glDeleteLists_dispatch_table_thunk;
    epoxy_glDeleteMemoryObjectsEXT = epoxy_glDeleteMemoryObjectsEXT_dispatch_table_thunk;
    epoxy_glDeleteNamedStringARB = epoxy_glDeleteNamedStringARB_dispatch_table_thunk;
    epoxy_glDeleteNamesAMD = epoxy_glDeleteNamesAMD_dispatch_table_thunk;
    epoxy_glDeleteObjectARB = epoxy_glDeleteObjectARB_dispatch_table_thunk;
    epoxy_glDeleteOcclusionQueriesNV = epoxy_glDeleteOcclusionQueriesNV_dispatch_table_thunk;
    epoxy_glDeletePathsNV = epoxy_glDeletePathsNV_dispatch_table_thunk;
    epoxy_glDeletePerfMonitorsAMD = epoxy_glDeletePerfMonitorsAMD_dispatch_table_thunk;
    epoxy_glDeletePerfQueryINTEL = epoxy_glDeletePerfQueryINTEL_dispatch_table_thunk;
    epoxy_glDeleteProgram = epoxy_glDeleteProgram_dispatch_table_thunk;
    epoxy_glDeleteProgramPipelines = epoxy_glDeleteProgramPipelines_dispatch_table_thunk;
    epoxy_glDeleteProgramPipelinesEXT = epoxy_glDeleteProgramPipelinesEXT_dispatch_table_thunk;
    epoxy_glDeleteProgramsARB = epoxy_glDeleteProgramsARB_dispatch_table_thunk;
    epoxy_glDeleteProgramsNV = epoxy_glDeleteProgramsNV_dispatch_table_thunk;
    epoxy_glDeleteQueries = epoxy_glDeleteQueries_dispatch_table_thunk;
    epoxy_glDeleteQueriesARB = epoxy_glDeleteQueriesARB_dispatch_table_thunk;
    epoxy_glDeleteQueriesEXT = epoxy_glDeleteQueriesEXT_dispatch_table_thunk;
    epoxy_glDeleteQueryResourceTagNV = epoxy_glDeleteQueryResourceTagNV_dispatch_table_thunk;
    epoxy_glDeleteRenderbuffers = epoxy_glDeleteRenderbuffers_dispatch_table_thunk;
    epoxy_glDeleteRenderbuffersEXT = epoxy_glDeleteRenderbuffersEXT_dispatch_table_thunk;
    epoxy_glDeleteRenderbuffersOES = epoxy_glDeleteRenderbuffersOES_dispatch_table_thunk;
    epoxy_glDeleteSamplers = epoxy_glDeleteSamplers_dispatch_table_thunk;
    epoxy_glDeleteSemaphoresEXT = epoxy_glDeleteSemaphoresEXT_dispatch_table_thunk;
    epoxy_glDeleteShader = epoxy_glDeleteShader_dispatch_table_thunk;
    epoxy_glDeleteStatesNV = epoxy_glDeleteStatesNV_dispatch_table_thunk;
    epoxy_glDeleteSync = epoxy_glDeleteSync_dispatch_table_thunk;
    epoxy_glDeleteSyncAPPLE = epoxy_glDeleteSyncAPPLE_dispatch_table_thunk;
    epoxy_glDeleteTextures = epoxy_glDeleteTextures_dispatch_table_thunk;
    epoxy_glDeleteTexturesEXT = epoxy_glDeleteTexturesEXT_dispatch_table_thunk;
    epoxy_glDeleteTransformFeedbacks = epoxy_glDeleteTransformFeedbacks_dispatch_table_thunk;
    epoxy_glDeleteTransformFeedbacksNV = epoxy_glDeleteTransformFeedbacksNV_dispatch_table_thunk;
    epoxy_glDeleteVertexArrays = epoxy_glDeleteVertexArrays_dispatch_table_thunk;
    epoxy_glDeleteVertexArraysAPPLE = epoxy_glDeleteVertexArraysAPPLE_dispatch_table_thunk;
    epoxy_glDeleteVertexArraysOES = epoxy_glDeleteVertexArraysOES_dispatch_table_thunk;
    epoxy_glDeleteVertexShaderEXT = epoxy_glDeleteVertexShaderEXT_dispatch_table_thunk;
    epoxy_glDepthBoundsEXT = epoxy_glDepthBoundsEXT_dispatch_table_thunk;
    epoxy_glDepthBoundsdNV = epoxy_glDepthBoundsdNV_dispatch_table_thunk;
    epoxy_glDepthFunc = epoxy_glDepthFunc_dispatch_table_thunk;
    epoxy_glDepthMask = epoxy_glDepthMask_dispatch_table_thunk;
    epoxy_glDepthRange = epoxy_glDepthRange_dispatch_table_thunk;
    epoxy_glDepthRangeArrayfvNV = epoxy_glDepthRangeArrayfvNV_dispatch_table_thunk;
    epoxy_glDepthRangeArrayfvOES = epoxy_glDepthRangeArrayfvOES_dispatch_table_thunk;
    epoxy_glDepthRangeArrayv = epoxy_glDepthRangeArrayv_dispatch_table_thunk;
    epoxy_glDepthRangeIndexed = epoxy_glDepthRangeIndexed_dispatch_table_thunk;
    epoxy_glDepthRangeIndexedfNV = epoxy_glDepthRangeIndexedfNV_dispatch_table_thunk;
    epoxy_glDepthRangeIndexedfOES = epoxy_glDepthRangeIndexedfOES_dispatch_table_thunk;
    epoxy_glDepthRangedNV = epoxy_glDepthRangedNV_dispatch_table_thunk;
    epoxy_glDepthRangef = epoxy_glDepthRangef_dispatch_table_thunk;
    epoxy_glDepthRangefOES = epoxy_glDepthRangefOES_dispatch_table_thunk;
    epoxy_glDepthRangex = epoxy_glDepthRangex_dispatch_table_thunk;
    epoxy_glDepthRangexOES = epoxy_glDepthRangexOES_dispatch_table_thunk;
    epoxy_glDetachObjectARB = epoxy_glDetachObjectARB_dispatch_table_thunk;
    epoxy_glDetachShader = epoxy_glDetachShader_dispatch_table_thunk;
    epoxy_glDetailTexFuncSGIS = epoxy_glDetailTexFuncSGIS_dispatch_table_thunk;
    epoxy_glDisable = epoxy_glDisable_dispatch_table_thunk;
    epoxy_glDisableClientState = epoxy_glDisableClientState_dispatch_table_thunk;
    epoxy_glDisableClientStateIndexedEXT = epoxy_glDisableClientStateIndexedEXT_dispatch_table_thunk;
    epoxy_glDisableClientStateiEXT = epoxy_glDisableClientStateiEXT_dispatch_table_thunk;
    epoxy_glDisableDriverControlQCOM = epoxy_glDisableDriverControlQCOM_dispatch_table_thunk;
    epoxy_glDisableIndexedEXT = epoxy_glDisableIndexedEXT_dispatch_table_thunk;
    epoxy_glDisableVariantClientStateEXT = epoxy_glDisableVariantClientStateEXT_dispatch_table_thunk;
    epoxy_glDisableVertexArrayAttrib = epoxy_glDisableVertexArrayAttrib_dispatch_table_thunk;
    epoxy_glDisableVertexArrayAttribEXT = epoxy_glDisableVertexArrayAttribEXT_dispatch_table_thunk;
    epoxy_glDisableVertexArrayEXT = epoxy_glDisableVertexArrayEXT_dispatch_table_thunk;
    epoxy_glDisableVertexAttribAPPLE = epoxy_glDisableVertexAttribAPPLE_dispatch_table_thunk;
    epoxy_glDisableVertexAttribArray = epoxy_glDisableVertexAttribArray_dispatch_table_thunk;
    epoxy_glDisableVertexAttribArrayARB = epoxy_glDisableVertexAttribArrayARB_dispatch_table_thunk;
    epoxy_glDisablei = epoxy_glDisablei_dispatch_table_thunk;
    epoxy_glDisableiEXT = epoxy_glDisableiEXT_dispatch_table_thunk;
    epoxy_glDisableiNV = epoxy_glDisableiNV_dispatch_table_thunk;
    epoxy_glDisableiOES = epoxy_glDisableiOES_dispatch_table_thunk;
    epoxy_glDiscardFramebufferEXT = epoxy_glDiscardFramebufferEXT_dispatch_table_thunk;
    epoxy_glDispatchCompute = epoxy_glDispatchCompute_dispatch_table_thunk;
    epoxy_glDispatchComputeGroupSizeARB = epoxy_glDispatchComputeGroupSizeARB_dispatch_table_thunk;
    epoxy_glDispatchComputeIndirect = epoxy_glDispatchComputeIndirect_dispatch_table_thunk;
    epoxy_glDrawArrays = epoxy_glDrawArrays_dispatch_table_thunk;
    epoxy_glDrawArraysEXT = epoxy_glDrawArraysEXT_dispatch_table_thunk;
    epoxy_glDrawArraysIndirect = epoxy_glDrawArraysIndirect_dispatch_table_thunk;
    epoxy_glDrawArraysInstanced = epoxy_glDrawArraysInstanced_dispatch_table_thunk;
    epoxy_glDrawArraysInstancedANGLE = epoxy_glDrawArraysInstancedANGLE_dispatch_table_thunk;
    epoxy_glDrawArraysInstancedARB = epoxy_glDrawArraysInstancedARB_dispatch_table_thunk;
    epoxy_glDrawArraysInstancedBaseInstance = epoxy_glDrawArraysInstancedBaseInstance_dispatch_table_thunk;
    epoxy_glDrawArraysInstancedBaseInstanceEXT = epoxy_glDrawArraysInstancedBaseInstanceEXT_dispatch_table_thunk;
    epoxy_glDrawArraysInstancedEXT = epoxy_glDrawArraysInstancedEXT_dispatch_table_thunk;
    epoxy_glDrawArraysInstancedNV = epoxy_glDrawArraysInstancedNV_dispatch_table_thunk;
    epoxy_glDrawBuffer = epoxy_glDrawBuffer_dispatch_table_thunk;
    epoxy_glDrawBuffers = epoxy_glDrawBuffers_dispatch_table_thunk;
    epoxy_glDrawBuffersARB = epoxy_glDrawBuffersARB_dispatch_table_thunk;
    epoxy_glDrawBuffersATI = epoxy_glDrawBuffersATI_dispatch_table_thunk;
    epoxy_glDrawBuffersEXT = epoxy_glDrawBuffersEXT_dispatch_table_thunk;
    epoxy_glDrawBuffersIndexedEXT = epoxy_glDrawBuffersIndexedEXT_dispatch_table_thunk;
    epoxy_glDrawBuffersNV = epoxy_glDrawBuffersNV_dispatch_table_thunk;
    epoxy_glDrawCommandsAddressNV = epoxy_glDrawCommandsAddressNV_dispatch_table_thunk;
    epoxy_glDrawCommandsNV = epoxy_glDrawCommandsNV_dispatch_table_thunk;
    epoxy_glDrawCommandsStatesAddressNV = epoxy_glDrawCommandsStatesAddressNV_dispatch_table_thunk;
    epoxy_glDrawCommandsStatesNV = epoxy_glDrawCommandsStatesNV_dispatch_table_thunk;
    epoxy_glDrawElementArrayAPPLE = epoxy_glDrawElementArrayAPPLE_dispatch_table_thunk;
    epoxy_glDrawElementArrayATI = epoxy_glDrawElementArrayATI_dispatch_table_thunk;
    epoxy_glDrawElements = epoxy_glDrawElements_dispatch_table_thunk;
    epoxy_glDrawElementsBaseVertex = epoxy_glDrawElementsBaseVertex_dispatch_table_thunk;
    epoxy_glDrawElementsBaseVertexEXT = epoxy_glDrawElementsBaseVertexEXT_dispatch_table_thunk;
    epoxy_glDrawElementsBaseVertexOES = epoxy_glDrawElementsBaseVertexOES_dispatch_table_thunk;
    epoxy_glDrawElementsIndirect = epoxy_glDrawElementsIndirect_dispatch_table_thunk;
    epoxy_glDrawElementsInstanced = epoxy_glDrawElementsInstanced_dispatch_table_thunk;
    epoxy_glDrawElementsInstancedANGLE = epoxy_glDrawElementsInstancedANGLE_dispatch_table_thunk;
    epoxy_glDrawElementsInstancedARB = epoxy_glDrawElementsInstancedARB_dispatch_table_thunk;
    epoxy_glDrawElementsInstancedBaseInstance = epoxy_glDrawElementsInstancedBaseInstance_dispatch_table_thunk;
    epoxy_glDrawElementsInstancedBaseInstanceEXT = epoxy_glDrawElementsInstancedBaseInstanceEXT_dispatch_table_thunk;
    epoxy_glDrawElementsInstancedBaseVertex = epoxy_glDrawElementsInstancedBaseVertex_dispatch_table_thunk;
    epoxy_glDrawElementsInstancedBaseVertexBaseInstance = epoxy_glDrawElementsInstancedBaseVertexBaseInstance_dispatch_table_thunk;
    epoxy_glDrawElementsInstancedBaseVertexBaseInstanceEXT = epoxy_glDrawElementsInstancedBaseVertexBaseInstanceEXT_dispatch_table_thunk;
    epoxy_glDrawElementsInstancedBaseVertexEXT = epoxy_glDrawElementsInstancedBaseVertexEXT_dispatch_table_thunk;
    epoxy_glDrawElementsInstancedBaseVertexOES = epoxy_glDrawElementsInstancedBaseVertexOES_dispatch_table_thunk;
    epoxy_glDrawElementsInstancedEXT = epoxy_glDrawElementsInstancedEXT_dispatch_table_thunk;
    epoxy_glDrawElementsInstancedNV = epoxy_glDrawElementsInstancedNV_dispatch_table_thunk;
    epoxy_glDrawMeshArraysSUN = epoxy_glDrawMeshArraysSUN_dispatch_table_thunk;
    epoxy_glDrawMeshTasksIndirectNV = epoxy_glDrawMeshTasksIndirectNV_dispatch_table_thunk;
    epoxy_glDrawMeshTasksNV = epoxy_glDrawMeshTasksNV_dispatch_table_thunk;
    epoxy_glDrawPixels = epoxy_glDrawPixels_dispatch_table_thunk;
    epoxy_glDrawRangeElementArrayAPPLE = epoxy_glDrawRangeElementArrayAPPLE_dispatch_table_thunk;
    epoxy_glDrawRangeElementArrayATI = epoxy_glDrawRangeElementArrayATI_dispatch_table_thunk;
    epoxy_glDrawRangeElements = epoxy_glDrawRangeElements_dispatch_table_thunk;
    epoxy_glDrawRangeElementsBaseVertex = epoxy_glDrawRangeElementsBaseVertex_dispatch_table_thunk;
    epoxy_glDrawRangeElementsBaseVertexEXT = epoxy_glDrawRangeElementsBaseVertexEXT_dispatch_table_thunk;
    epoxy_glDrawRangeElementsBaseVertexOES = epoxy_glDrawRangeElementsBaseVertexOES_dispatch_table_thunk;
    epoxy_glDrawRangeElementsEXT = epoxy_glDrawRangeElementsEXT_dispatch_table_thunk;
    epoxy_glDrawTexfOES = epoxy_glDrawTexfOES_dispatch_table_thunk;
    epoxy_glDrawTexfvOES = epoxy_glDrawTexfvOES_dispatch_table_thunk;
    epoxy_glDrawTexiOES = epoxy_glDrawTexiOES_dispatch_table_thunk;
    epoxy_glDrawTexivOES = epoxy_glDrawTexivOES_dispatch_table_thunk;
    epoxy_glDrawTexsOES = epoxy_glDrawTexsOES_dispatch_table_thunk;
    epoxy_glDrawTexsvOES = epoxy_glDrawTexsvOES_dispatch_table_thunk;
    epoxy_glDrawTextureNV = epoxy_glDrawTextureNV_dispatch_table_thunk;
    epoxy_glDrawTexxOES = epoxy_glDrawTexxOES_dispatch_table_thunk;
    epoxy_glDrawTexxvOES = epoxy_glDrawTexxvOES_dispatch_table_thunk;
    epoxy_glDrawTransformFeedback = epoxy_glDrawTransformFeedback_dispatch_table_thunk;
    epoxy_glDrawTransformFeedbackEXT = epoxy_glDrawTransformFeedbackEXT_dispatch_table_thunk;
    epoxy_glDrawTransformFeedbackInstanced = epoxy_glDrawTransformFeedbackInstanced_dispatch_table_thunk;
    epoxy_glDrawTransformFeedbackInstancedEXT = epoxy_glDrawTransformFeedbackInstancedEXT_dispatch_table_thunk;
    epoxy_glDrawTransformFeedbackNV = epoxy_glDrawTransformFeedbackNV_dispatch_table_thunk;
    epoxy_glDrawTransformFeedbackStream = epoxy_glDrawTransformFeedbackStream_dispatch_table_thunk;
    epoxy_glDrawTransformFeedbackStreamInstanced = epoxy_glDrawTransformFeedbackStreamInstanced_dispatch_table_thunk;
    epoxy_glDrawVkImageNV = epoxy_glDrawVkImageNV_dispatch_table_thunk;
    epoxy_glEGLImageTargetRenderbufferStorageOES = epoxy_glEGLImageTargetRenderbufferStorageOES_dispatch_table_thunk;
    epoxy_glEGLImageTargetTexStorageEXT = epoxy_glEGLImageTargetTexStorageEXT_dispatch_table_thunk;
    epoxy_glEGLImageTargetTexture2DOES = epoxy_glEGLImageTargetTexture2DOES_dispatch_table_thunk;
    epoxy_glEGLImageTargetTextureStorageEXT = epoxy_glEGLImageTargetTextureStorageEXT_dispatch_table_thunk;
    epoxy_glEdgeFlag = epoxy_glEdgeFlag_dispatch_table_thunk;
    epoxy_glEdgeFlagFormatNV = epoxy_glEdgeFlagFormatNV_dispatch_table_thunk;
    epoxy_glEdgeFlagPointer = epoxy_glEdgeFlagPointer_dispatch_table_thunk;
    epoxy_glEdgeFlagPointerEXT = epoxy_glEdgeFlagPointerEXT_dispatch_table_thunk;
    epoxy_glEdgeFlagPointerListIBM = epoxy_glEdgeFlagPointerListIBM_dispatch_table_thunk;
    epoxy_glEdgeFlagv = epoxy_glEdgeFlagv_dispatch_table_thunk;
    epoxy_glElementPointerAPPLE = epoxy_glElementPointerAPPLE_dispatch_table_thunk;
    epoxy_glElementPointerATI = epoxy_glElementPointerATI_dispatch_table_thunk;
    epoxy_glEnable = epoxy_glEnable_dispatch_table_thunk;
    epoxy_glEnableClientState = epoxy_glEnableClientState_dispatch_table_thunk;
    epoxy_glEnableClientStateIndexedEXT = epoxy_glEnableClientStateIndexedEXT_dispatch_table_thunk;
    epoxy_glEnableClientStateiEXT = epoxy_glEnableClientStateiEXT_dispatch_table_thunk;
    epoxy_glEnableDriverControlQCOM = epoxy_glEnableDriverControlQCOM_dispatch_table_thunk;
    epoxy_glEnableIndexedEXT = epoxy_glEnableIndexedEXT_dispatch_table_thunk;
    epoxy_glEnableVariantClientStateEXT = epoxy_glEnableVariantClientStateEXT_dispatch_table_thunk;
    epoxy_glEnableVertexArrayAttrib = epoxy_glEnableVertexArrayAttrib_dispatch_table_thunk;
    epoxy_glEnableVertexArrayAttribEXT = epoxy_glEnableVertexArrayAttribEXT_dispatch_table_thunk;
    epoxy_glEnableVertexArrayEXT = epoxy_glEnableVertexArrayEXT_dispatch_table_thunk;
    epoxy_glEnableVertexAttribAPPLE = epoxy_glEnableVertexAttribAPPLE_dispatch_table_thunk;
    epoxy_glEnableVertexAttribArray = epoxy_glEnableVertexAttribArray_dispatch_table_thunk;
    epoxy_glEnableVertexAttribArrayARB = epoxy_glEnableVertexAttribArrayARB_dispatch_table_thunk;
    epoxy_glEnablei = epoxy_glEnablei_dispatch_table_thunk;
    epoxy_glEnableiEXT = epoxy_glEnableiEXT_dispatch_table_thunk;
    epoxy_glEnableiNV = epoxy_glEnableiNV_dispatch_table_thunk;
    epoxy_glEnableiOES = epoxy_glEnableiOES_dispatch_table_thunk;
    epoxy_glEnd_unwrapped = epoxy_glEnd_unwrapped_dispatch_table_thunk;
    epoxy_glEndConditionalRender = epoxy_glEndConditionalRender_dispatch_table_thunk;
    epoxy_glEndConditionalRenderNV = epoxy_glEndConditionalRenderNV_dispatch_table_thunk;
    epoxy_glEndConditionalRenderNVX = epoxy_glEndConditionalRenderNVX_dispatch_table_thunk;
    epoxy_glEndFragmentShaderATI = epoxy_glEndFragmentShaderATI_dispatch_table_thunk;
    epoxy_glEndList = epoxy_glEndList_dispatch_table_thunk;
    epoxy_glEndOcclusionQueryNV = epoxy_glEndOcclusionQueryNV_dispatch_table_thunk;
    epoxy_glEndPerfMonitorAMD = epoxy_glEndPerfMonitorAMD_dispatch_table_thunk;
    epoxy_glEndPerfQueryINTEL = epoxy_glEndPerfQueryINTEL_dispatch_table_thunk;
    epoxy_glEndQuery = epoxy_glEndQuery_dispatch_table_thunk;
    epoxy_glEndQueryARB = epoxy_glEndQueryARB_dispatch_table_thunk;
    epoxy_glEndQueryEXT = epoxy_glEndQueryEXT_dispatch_table_thunk;
    epoxy_glEndQueryIndexed = epoxy_glEndQueryIndexed_dispatch_table_thunk;
    epoxy_glEndTilingQCOM = epoxy_glEndTilingQCOM_dispatch_table_thunk;
    epoxy_glEndTransformFeedback = epoxy_glEndTransformFeedback_dispatch_table_thunk;
    epoxy_glEndTransformFeedbackEXT = epoxy_glEndTransformFeedbackEXT_dispatch_table_thunk;
    epoxy_glEndTransformFeedbackNV = epoxy_glEndTransformFeedbackNV_dispatch_table_thunk;
    epoxy_glEndVertexShaderEXT = epoxy_glEndVertexShaderEXT_dispatch_table_thunk;
    epoxy_glEndVideoCaptureNV = epoxy_glEndVideoCaptureNV_dispatch_table_thunk;
    epoxy_glEvalCoord1d = epoxy_glEvalCoord1d_dispatch_table_thunk;
    epoxy_glEvalCoord1dv = epoxy_glEvalCoord1dv_dispatch_table_thunk;
    epoxy_glEvalCoord1f = epoxy_glEvalCoord1f_dispatch_table_thunk;
    epoxy_glEvalCoord1fv = epoxy_glEvalCoord1fv_dispatch_table_thunk;
    epoxy_glEvalCoord1xOES = epoxy_glEvalCoord1xOES_dispatch_table_thunk;
    epoxy_glEvalCoord1xvOES = epoxy_glEvalCoord1xvOES_dispatch_table_thunk;
    epoxy_glEvalCoord2d = epoxy_glEvalCoord2d_dispatch_table_thunk;
    epoxy_glEvalCoord2dv = epoxy_glEvalCoord2dv_dispatch_table_thunk;
    epoxy_glEvalCoord2f = epoxy_glEvalCoord2f_dispatch_table_thunk;
    epoxy_glEvalCoord2fv = epoxy_glEvalCoord2fv_dispatch_table_thunk;
    epoxy_glEvalCoord2xOES = epoxy_glEvalCoord2xOES_dispatch_table_thunk;
    epoxy_glEvalCoord2xvOES = epoxy_glEvalCoord2xvOES_dispatch_table_thunk;
    epoxy_glEvalMapsNV = epoxy_glEvalMapsNV_dispatch_table_thunk;
    epoxy_glEvalMesh1 = epoxy_glEvalMesh1_dispatch_table_thunk;
    epoxy_glEvalMesh2 = epoxy_glEvalMesh2_dispatch_table_thunk;
    epoxy_glEvalPoint1 = epoxy_glEvalPoint1_dispatch_table_thunk;
    epoxy_glEvalPoint2 = epoxy_glEvalPoint2_dispatch_table_thunk;
    epoxy_glEvaluateDepthValuesARB = epoxy_glEvaluateDepthValuesARB_dispatch_table_thunk;
    epoxy_glExecuteProgramNV = epoxy_glExecuteProgramNV_dispatch_table_thunk;
    epoxy_glExtGetBufferPointervQCOM = epoxy_glExtGetBufferPointervQCOM_dispatch_table_thunk;
    epoxy_glExtGetBuffersQCOM = epoxy_glExtGetBuffersQCOM_dispatch_table_thunk;
    epoxy_glExtGetFramebuffersQCOM = epoxy_glExtGetFramebuffersQCOM_dispatch_table_thunk;
    epoxy_glExtGetProgramBinarySourceQCOM = epoxy_glExtGetProgramBinarySourceQCOM_dispatch_table_thunk;
    epoxy_glExtGetProgramsQCOM = epoxy_glExtGetProgramsQCOM_dispatch_table_thunk;
    epoxy_glExtGetRenderbuffersQCOM = epoxy_glExtGetRenderbuffersQCOM_dispatch_table_thunk;
    epoxy_glExtGetShadersQCOM = epoxy_glExtGetShadersQCOM_dispatch_table_thunk;
    epoxy_glExtGetTexLevelParameterivQCOM = epoxy_glExtGetTexLevelParameterivQCOM_dispatch_table_thunk;
    epoxy_glExtGetTexSubImageQCOM = epoxy_glExtGetTexSubImageQCOM_dispatch_table_thunk;
    epoxy_glExtGetTexturesQCOM = epoxy_glExtGetTexturesQCOM_dispatch_table_thunk;
    epoxy_glExtIsProgramBinaryQCOM = epoxy_glExtIsProgramBinaryQCOM_dispatch_table_thunk;
    epoxy_glExtTexObjectStateOverrideiQCOM = epoxy_glExtTexObjectStateOverrideiQCOM_dispatch_table_thunk;
    epoxy_glExtractComponentEXT = epoxy_glExtractComponentEXT_dispatch_table_thunk;
    epoxy_glFeedbackBuffer = epoxy_glFeedbackBuffer_dispatch_table_thunk;
    epoxy_glFeedbackBufferxOES = epoxy_glFeedbackBufferxOES_dispatch_table_thunk;
    epoxy_glFenceSync = epoxy_glFenceSync_dispatch_table_thunk;
    epoxy_glFenceSyncAPPLE = epoxy_glFenceSyncAPPLE_dispatch_table_thunk;
    epoxy_glFinalCombinerInputNV = epoxy_glFinalCombinerInputNV_dispatch_table_thunk;
    epoxy_glFinish = epoxy_glFinish_dispatch_table_thunk;
    epoxy_glFinishAsyncSGIX = epoxy_glFinishAsyncSGIX_dispatch_table_thunk;
    epoxy_glFinishFenceAPPLE = epoxy_glFinishFenceAPPLE_dispatch_table_thunk;
    epoxy_glFinishFenceNV = epoxy_glFinishFenceNV_dispatch_table_thunk;
    epoxy_glFinishObjectAPPLE = epoxy_glFinishObjectAPPLE_dispatch_table_thunk;
    epoxy_glFinishTextureSUNX = epoxy_glFinishTextureSUNX_dispatch_table_thunk;
    epoxy_glFlush = epoxy_glFlush_dispatch_table_thunk;
    epoxy_glFlushMappedBufferRange = epoxy_glFlushMappedBufferRange_dispatch_table_thunk;
    epoxy_glFlushMappedBufferRangeAPPLE = epoxy_glFlushMappedBufferRangeAPPLE_dispatch_table_thunk;
    epoxy_glFlushMappedBufferRangeEXT = epoxy_glFlushMappedBufferRangeEXT_dispatch_table_thunk;
    epoxy_glFlushMappedNamedBufferRange = epoxy_glFlushMappedNamedBufferRange_dispatch_table_thunk;
    epoxy_glFlushMappedNamedBufferRangeEXT = epoxy_glFlushMappedNamedBufferRangeEXT_dispatch_table_thunk;
    epoxy_glFlushPixelDataRangeNV = epoxy_glFlushPixelDataRangeNV_dispatch_table_thunk;
    epoxy_glFlushRasterSGIX = epoxy_glFlushRasterSGIX_dispatch_table_thunk;
    epoxy_glFlushStaticDataIBM = epoxy_glFlushStaticDataIBM_dispatch_table_thunk;
    epoxy_glFlushVertexArrayRangeAPPLE = epoxy_glFlushVertexArrayRangeAPPLE_dispatch_table_thunk;
    epoxy_glFlushVertexArrayRangeNV = epoxy_glFlushVertexArrayRangeNV_dispatch_table_thunk;
    epoxy_glFogCoordFormatNV = epoxy_glFogCoordFormatNV_dispatch_table_thunk;
    epoxy_glFogCoordPointer = epoxy_glFogCoordPointer_dispatch_table_thunk;
    epoxy_glFogCoordPointerEXT = epoxy_glFogCoordPointerEXT_dispatch_table_thunk;
    epoxy_glFogCoordPointerListIBM = epoxy_glFogCoordPointerListIBM_dispatch_table_thunk;
    epoxy_glFogCoordd = epoxy_glFogCoordd_dispatch_table_thunk;
    epoxy_glFogCoorddEXT = epoxy_glFogCoorddEXT_dispatch_table_thunk;
    epoxy_glFogCoorddv = epoxy_glFogCoorddv_dispatch_table_thunk;
    epoxy_glFogCoorddvEXT = epoxy_glFogCoorddvEXT_dispatch_table_thunk;
    epoxy_glFogCoordf = epoxy_glFogCoordf_dispatch_table_thunk;
    epoxy_glFogCoordfEXT = epoxy_glFogCoordfEXT_dispatch_table_thunk;
    epoxy_glFogCoordfv = epoxy_glFogCoordfv_dispatch_table_thunk;
    epoxy_glFogCoordfvEXT = epoxy_glFogCoordfvEXT_dispatch_table_thunk;
    epoxy_glFogCoordhNV = epoxy_glFogCoordhNV_dispatch_table_thunk;
    epoxy_glFogCoordhvNV = epoxy_glFogCoordhvNV_dispatch_table_thunk;
    epoxy_glFogFuncSGIS = epoxy_glFogFuncSGIS_dispatch_table_thunk;
    epoxy_glFogf = epoxy_glFogf_dispatch_table_thunk;
    epoxy_glFogfv = epoxy_glFogfv_dispatch_table_thunk;
    epoxy_glFogi = epoxy_glFogi_dispatch_table_thunk;
    epoxy_glFogiv = epoxy_glFogiv_dispatch_table_thunk;
    epoxy_glFogx = epoxy_glFogx_dispatch_table_thunk;
    epoxy_glFogxOES = epoxy_glFogxOES_dispatch_table_thunk;
    epoxy_glFogxv = epoxy_glFogxv_dispatch_table_thunk;
    epoxy_glFogxvOES = epoxy_glFogxvOES_dispatch_table_thunk;
    epoxy_glFragmentColorMaterialSGIX = epoxy_glFragmentColorMaterialSGIX_dispatch_table_thunk;
    epoxy_glFragmentCoverageColorNV = epoxy_glFragmentCoverageColorNV_dispatch_table_thunk;
    epoxy_glFragmentLightModelfSGIX = epoxy_glFragmentLightModelfSGIX_dispatch_table_thunk;
    epoxy_glFragmentLightModelfvSGIX = epoxy_glFragmentLightModelfvSGIX_dispatch_table_thunk;
    epoxy_glFragmentLightModeliSGIX = epoxy_glFragmentLightModeliSGIX_dispatch_table_thunk;
    epoxy_glFragmentLightModelivSGIX = epoxy_glFragmentLightModelivSGIX_dispatch_table_thunk;
    epoxy_glFragmentLightfSGIX = epoxy_glFragmentLightfSGIX_dispatch_table_thunk;
    epoxy_glFragmentLightfvSGIX = epoxy_glFragmentLightfvSGIX_dispatch_table_thunk;
    epoxy_glFragmentLightiSGIX = epoxy_glFragmentLightiSGIX_dispatch_table_thunk;
    epoxy_glFragmentLightivSGIX = epoxy_glFragmentLightivSGIX_dispatch_table_thunk;
    epoxy_glFragmentMaterialfSGIX = epoxy_glFragmentMaterialfSGIX_dispatch_table_thunk;
    epoxy_glFragmentMaterialfvSGIX = epoxy_glFragmentMaterialfvSGIX_dispatch_table_thunk;
    epoxy_glFragmentMaterialiSGIX = epoxy_glFragmentMaterialiSGIX_dispatch_table_thunk;
    epoxy_glFragmentMaterialivSGIX = epoxy_glFragmentMaterialivSGIX_dispatch_table_thunk;
    epoxy_glFrameTerminatorGREMEDY = epoxy_glFrameTerminatorGREMEDY_dispatch_table_thunk;
    epoxy_glFrameZoomSGIX = epoxy_glFrameZoomSGIX_dispatch_table_thunk;
    epoxy_glFramebufferDrawBufferEXT = epoxy_glFramebufferDrawBufferEXT_dispatch_table_thunk;
    epoxy_glFramebufferDrawBuffersEXT = epoxy_glFramebufferDrawBuffersEXT_dispatch_table_thunk;
    epoxy_glFramebufferFetchBarrierEXT = epoxy_glFramebufferFetchBarrierEXT_dispatch_table_thunk;
    epoxy_glFramebufferFetchBarrierQCOM = epoxy_glFramebufferFetchBarrierQCOM_dispatch_table_thunk;
    epoxy_glFramebufferFoveationConfigQCOM = epoxy_glFramebufferFoveationConfigQCOM_dispatch_table_thunk;
    epoxy_glFramebufferFoveationParametersQCOM = epoxy_glFramebufferFoveationParametersQCOM_dispatch_table_thunk;
    epoxy_glFramebufferParameteri = epoxy_glFramebufferParameteri_dispatch_table_thunk;
    epoxy_glFramebufferParameteriMESA = epoxy_glFramebufferParameteriMESA_dispatch_table_thunk;
    epoxy_glFramebufferPixelLocalStorageSizeEXT = epoxy_glFramebufferPixelLocalStorageSizeEXT_dispatch_table_thunk;
    epoxy_glFramebufferReadBufferEXT = epoxy_glFramebufferReadBufferEXT_dispatch_table_thunk;
    epoxy_glFramebufferRenderbuffer = epoxy_glFramebufferRenderbuffer_dispatch_table_thunk;
    epoxy_glFramebufferRenderbufferEXT = epoxy_glFramebufferRenderbufferEXT_dispatch_table_thunk;
    epoxy_glFramebufferRenderbufferOES = epoxy_glFramebufferRenderbufferOES_dispatch_table_thunk;
    epoxy_glFramebufferSampleLocationsfvARB = epoxy_glFramebufferSampleLocationsfvARB_dispatch_table_thunk;
    epoxy_glFramebufferSampleLocationsfvNV = epoxy_glFramebufferSampleLocationsfvNV_dispatch_table_thunk;
    epoxy_glFramebufferSamplePositionsfvAMD = epoxy_glFramebufferSamplePositionsfvAMD_dispatch_table_thunk;
    epoxy_glFramebufferTexture = epoxy_glFramebufferTexture_dispatch_table_thunk;
    epoxy_glFramebufferTexture1D = epoxy_glFramebufferTexture1D_dispatch_table_thunk;
    epoxy_glFramebufferTexture1DEXT = epoxy_glFramebufferTexture1DEXT_dispatch_table_thunk;
    epoxy_glFramebufferTexture2D = epoxy_glFramebufferTexture2D_dispatch_table_thunk;
    epoxy_glFramebufferTexture2DDownsampleIMG = epoxy_glFramebufferTexture2DDownsampleIMG_dispatch_table_thunk;
    epoxy_glFramebufferTexture2DEXT = epoxy_glFramebufferTexture2DEXT_dispatch_table_thunk;
    epoxy_glFramebufferTexture2DMultisampleEXT = epoxy_glFramebufferTexture2DMultisampleEXT_dispatch_table_thunk;
    epoxy_glFramebufferTexture2DMultisampleIMG = epoxy_glFramebufferTexture2DMultisampleIMG_dispatch_table_thunk;
    epoxy_glFramebufferTexture2DOES = epoxy_glFramebufferTexture2DOES_dispatch_table_thunk;
    epoxy_glFramebufferTexture3D = epoxy_glFramebufferTexture3D_dispatch_table_thunk;
    epoxy_glFramebufferTexture3DEXT = epoxy_glFramebufferTexture3DEXT_dispatch_table_thunk;
    epoxy_glFramebufferTexture3DOES = epoxy_glFramebufferTexture3DOES_dispatch_table_thunk;
    epoxy_glFramebufferTextureARB = epoxy_glFramebufferTextureARB_dispatch_table_thunk;
    epoxy_glFramebufferTextureEXT = epoxy_glFramebufferTextureEXT_dispatch_table_thunk;
    epoxy_glFramebufferTextureFaceARB = epoxy_glFramebufferTextureFaceARB_dispatch_table_thunk;
    epoxy_glFramebufferTextureFaceEXT = epoxy_glFramebufferTextureFaceEXT_dispatch_table_thunk;
    epoxy_glFramebufferTextureLayer = epoxy_glFramebufferTextureLayer_dispatch_table_thunk;
    epoxy_glFramebufferTextureLayerARB = epoxy_glFramebufferTextureLayerARB_dispatch_table_thunk;
    epoxy_glFramebufferTextureLayerDownsampleIMG = epoxy_glFramebufferTextureLayerDownsampleIMG_dispatch_table_thunk;
    epoxy_glFramebufferTextureLayerEXT = epoxy_glFramebufferTextureLayerEXT_dispatch_table_thunk;
    epoxy_glFramebufferTextureMultisampleMultiviewOVR = epoxy_glFramebufferTextureMultisampleMultiviewOVR_dispatch_table_thunk;
    epoxy_glFramebufferTextureMultiviewOVR = epoxy_glFramebufferTextureMultiviewOVR_dispatch_table_thunk;
    epoxy_glFramebufferTextureOES = epoxy_glFramebufferTextureOES_dispatch_table_thunk;
    epoxy_glFreeObjectBufferATI = epoxy_glFreeObjectBufferATI_dispatch_table_thunk;
    epoxy_glFrontFace = epoxy_glFrontFace_dispatch_table_thunk;
    epoxy_glFrustum = epoxy_glFrustum_dispatch_table_thunk;
    epoxy_glFrustumf = epoxy_glFrustumf_dispatch_table_thunk;
    epoxy_glFrustumfOES = epoxy_glFrustumfOES_dispatch_table_thunk;
    epoxy_glFrustumx = epoxy_glFrustumx_dispatch_table_thunk;
    epoxy_glFrustumxOES = epoxy_glFrustumxOES_dispatch_table_thunk;
    epoxy_glGenAsyncMarkersSGIX = epoxy_glGenAsyncMarkersSGIX_dispatch_table_thunk;
    epoxy_glGenBuffers = epoxy_glGenBuffers_dispatch_table_thunk;
    epoxy_glGenBuffersARB = epoxy_glGenBuffersARB_dispatch_table_thunk;
    epoxy_glGenFencesAPPLE = epoxy_glGenFencesAPPLE_dispatch_table_thunk;
    epoxy_glGenFencesNV = epoxy_glGenFencesNV_dispatch_table_thunk;
    epoxy_glGenFragmentShadersATI = epoxy_glGenFragmentShadersATI_dispatch_table_thunk;
    epoxy_glGenFramebuffers = epoxy_glGenFramebuffers_dispatch_table_thunk;
    epoxy_glGenFramebuffersEXT = epoxy_glGenFramebuffersEXT_dispatch_table_thunk;
    epoxy_glGenFramebuffersOES = epoxy_glGenFramebuffersOES_dispatch_table_thunk;
    epoxy_glGenLists = epoxy_glGenLists_dispatch_table_thunk;
    epoxy_glGenNamesAMD = epoxy_glGenNamesAMD_dispatch_table_thunk;
    epoxy_glGenOcclusionQueriesNV = epoxy_glGenOcclusionQueriesNV_dispatch_table_thunk;
    epoxy_glGenPathsNV = epoxy_glGenPathsNV_dispatch_table_thunk;
    epoxy_glGenPerfMonitorsAMD = epoxy_glGenPerfMonitorsAMD_dispatch_table_thunk;
    epoxy_glGenProgramPipelines = epoxy_glGenProgramPipelines_dispatch_table_thunk;
    epoxy_glGenProgramPipelinesEXT = epoxy_glGenProgramPipelinesEXT_dispatch_table_thunk;
    epoxy_glGenProgramsARB = epoxy_glGenProgramsARB_dispatch_table_thunk;
    epoxy_glGenProgramsNV = epoxy_glGenProgramsNV_dispatch_table_thunk;
    epoxy_glGenQueries = epoxy_glGenQueries_dispatch_table_thunk;
    epoxy_glGenQueriesARB = epoxy_glGenQueriesARB_dispatch_table_thunk;
    epoxy_glGenQueriesEXT = epoxy_glGenQueriesEXT_dispatch_table_thunk;
    epoxy_glGenQueryResourceTagNV = epoxy_glGenQueryResourceTagNV_dispatch_table_thunk;
    epoxy_glGenRenderbuffers = epoxy_glGenRenderbuffers_dispatch_table_thunk;
    epoxy_glGenRenderbuffersEXT = epoxy_glGenRenderbuffersEXT_dispatch_table_thunk;
    epoxy_glGenRenderbuffersOES = epoxy_glGenRenderbuffersOES_dispatch_table_thunk;
    epoxy_glGenSamplers = epoxy_glGenSamplers_dispatch_table_thunk;
    epoxy_glGenSemaphoresEXT = epoxy_glGenSemaphoresEXT_dispatch_table_thunk;
    epoxy_glGenSymbolsEXT = epoxy_glGenSymbolsEXT_dispatch_table_thunk;
    epoxy_glGenTextures = epoxy_glGenTextures_dispatch_table_thunk;
    epoxy_glGenTexturesEXT = epoxy_glGenTexturesEXT_dispatch_table_thunk;
    epoxy_glGenTransformFeedbacks = epoxy_glGenTransformFeedbacks_dispatch_table_thunk;
    epoxy_glGenTransformFeedbacksNV = epoxy_glGenTransformFeedbacksNV_dispatch_table_thunk;
    epoxy_glGenVertexArrays = epoxy_glGenVertexArrays_dispatch_table_thunk;
    epoxy_glGenVertexArraysAPPLE = epoxy_glGenVertexArraysAPPLE_dispatch_table_thunk;
    epoxy_glGenVertexArraysOES = epoxy_glGenVertexArraysOES_dispatch_table_thunk;
    epoxy_glGenVertexShadersEXT = epoxy_glGenVertexShadersEXT_dispatch_table_thunk;
    epoxy_glGenerateMipmap = epoxy_glGenerateMipmap_dispatch_table_thunk;
    epoxy_glGenerateMipmapEXT = epoxy_glGenerateMipmapEXT_dispatch_table_thunk;
    epoxy_glGenerateMipmapOES = epoxy_glGenerateMipmapOES_dispatch_table_thunk;
    epoxy_glGenerateMultiTexMipmapEXT = epoxy_glGenerateMultiTexMipmapEXT_dispatch_table_thunk;
    epoxy_glGenerateTextureMipmap = epoxy_glGenerateTextureMipmap_dispatch_table_thunk;
    epoxy_glGenerateTextureMipmapEXT = epoxy_glGenerateTextureMipmapEXT_dispatch_table_thunk;
    epoxy_glGetActiveAtomicCounterBufferiv = epoxy_glGetActiveAtomicCounterBufferiv_dispatch_table_thunk;
    epoxy_glGetActiveAttrib = epoxy_glGetActiveAttrib_dispatch_table_thunk;
    epoxy_glGetActiveAttribARB = epoxy_glGetActiveAttribARB_dispatch_table_thunk;
    epoxy_glGetActiveSubroutineName = epoxy_glGetActiveSubroutineName_dispatch_table_thunk;
    epoxy_glGetActiveSubroutineUniformName = epoxy_glGetActiveSubroutineUniformName_dispatch_table_thunk;
    epoxy_glGetActiveSubroutineUniformiv = epoxy_glGetActiveSubroutineUniformiv_dispatch_table_thunk;
    epoxy_glGetActiveUniform = epoxy_glGetActiveUniform_dispatch_table_thunk;
    epoxy_glGetActiveUniformARB = epoxy_glGetActiveUniformARB_dispatch_table_thunk;
    epoxy_glGetActiveUniformBlockName = epoxy_glGetActiveUniformBlockName_dispatch_table_thunk;
    epoxy_glGetActiveUniformBlockiv = epoxy_glGetActiveUniformBlockiv_dispatch_table_thunk;
    epoxy_glGetActiveUniformName = epoxy_glGetActiveUniformName_dispatch_table_thunk;
    epoxy_glGetActiveUniformsiv = epoxy_glGetActiveUniformsiv_dispatch_table_thunk;
    epoxy_glGetActiveVaryingNV = epoxy_glGetActiveVaryingNV_dispatch_table_thunk;
    epoxy_glGetArrayObjectfvATI = epoxy_glGetArrayObjectfvATI_dispatch_table_thunk;
    epoxy_glGetArrayObjectivATI = epoxy_glGetArrayObjectivATI_dispatch_table_thunk;
    epoxy_glGetAttachedObjectsARB = epoxy_glGetAttachedObjectsARB_dispatch_table_thunk;
    epoxy_glGetAttachedShaders = epoxy_glGetAttachedShaders_dispatch_table_thunk;
    epoxy_glGetAttribLocation = epoxy_glGetAttribLocation_dispatch_table_thunk;
    epoxy_glGetAttribLocationARB = epoxy_glGetAttribLocationARB_dispatch_table_thunk;
    epoxy_glGetBooleanIndexedvEXT = epoxy_glGetBooleanIndexedvEXT_dispatch_table_thunk;
    epoxy_glGetBooleani_v = epoxy_glGetBooleani_v_dispatch_table_thunk;
    epoxy_glGetBooleanv = epoxy_glGetBooleanv_dispatch_table_thunk;
    epoxy_glGetBufferParameteri64v = epoxy_glGetBufferParameteri64v_dispatch_table_thunk;
    epoxy_glGetBufferParameteriv = epoxy_glGetBufferParameteriv_dispatch_table_thunk;
    epoxy_glGetBufferParameterivARB = epoxy_glGetBufferParameterivARB_dispatch_table_thunk;
    epoxy_glGetBufferParameterui64vNV = epoxy_glGetBufferParameterui64vNV_dispatch_table_thunk;
    epoxy_glGetBufferPointerv = epoxy_glGetBufferPointerv_dispatch_table_thunk;
    epoxy_glGetBufferPointervARB = epoxy_glGetBufferPointervARB_dispatch_table_thunk;
    epoxy_glGetBufferPointervOES = epoxy_glGetBufferPointervOES_dispatch_table_thunk;
    epoxy_glGetBufferSubData = epoxy_glGetBufferSubData_dispatch_table_thunk;
    epoxy_glGetBufferSubDataARB = epoxy_glGetBufferSubDataARB_dispatch_table_thunk;
    epoxy_glGetClipPlane = epoxy_glGetClipPlane_dispatch_table_thunk;
    epoxy_glGetClipPlanef = epoxy_glGetClipPlanef_dispatch_table_thunk;
    epoxy_glGetClipPlanefOES = epoxy_glGetClipPlanefOES_dispatch_table_thunk;
    epoxy_glGetClipPlanex = epoxy_glGetClipPlanex_dispatch_table_thunk;
    epoxy_glGetClipPlanexOES = epoxy_glGetClipPlanexOES_dispatch_table_thunk;
    epoxy_glGetColorTable = epoxy_glGetColorTable_dispatch_table_thunk;
    epoxy_glGetColorTableEXT = epoxy_glGetColorTableEXT_dispatch_table_thunk;
    epoxy_glGetColorTableParameterfv = epoxy_glGetColorTableParameterfv_dispatch_table_thunk;
    epoxy_glGetColorTableParameterfvEXT = epoxy_glGetColorTableParameterfvEXT_dispatch_table_thunk;
    epoxy_glGetColorTableParameterfvSGI = epoxy_glGetColorTableParameterfvSGI_dispatch_table_thunk;
    epoxy_glGetColorTableParameteriv = epoxy_glGetColorTableParameteriv_dispatch_table_thunk;
    epoxy_glGetColorTableParameterivEXT = epoxy_glGetColorTableParameterivEXT_dispatch_table_thunk;
    epoxy_glGetColorTableParameterivSGI = epoxy_glGetColorTableParameterivSGI_dispatch_table_thunk;
    epoxy_glGetColorTableSGI = epoxy_glGetColorTableSGI_dispatch_table_thunk;
    epoxy_glGetCombinerInputParameterfvNV = epoxy_glGetCombinerInputParameterfvNV_dispatch_table_thunk;
    epoxy_glGetCombinerInputParameterivNV = epoxy_glGetCombinerInputParameterivNV_dispatch_table_thunk;
    epoxy_glGetCombinerOutputParameterfvNV = epoxy_glGetCombinerOutputParameterfvNV_dispatch_table_thunk;
    epoxy_glGetCombinerOutputParameterivNV = epoxy_glGetCombinerOutputParameterivNV_dispatch_table_thunk;
    epoxy_glGetCombinerStageParameterfvNV = epoxy_glGetCombinerStageParameterfvNV_dispatch_table_thunk;
    epoxy_glGetCommandHeaderNV = epoxy_glGetCommandHeaderNV_dispatch_table_thunk;
    epoxy_glGetCompressedMultiTexImageEXT = epoxy_glGetCompressedMultiTexImageEXT_dispatch_table_thunk;
    epoxy_glGetCompressedTexImage = epoxy_glGetCompressedTexImage_dispatch_table_thunk;
    epoxy_glGetCompressedTexImageARB = epoxy_glGetCompressedTexImageARB_dispatch_table_thunk;
    epoxy_glGetCompressedTextureImage = epoxy_glGetCompressedTextureImage_dispatch_table_thunk;
    epoxy_glGetCompressedTextureImageEXT = epoxy_glGetCompressedTextureImageEXT_dispatch_table_thunk;
    epoxy_glGetCompressedTextureSubImage = epoxy_glGetCompressedTextureSubImage_dispatch_table_thunk;
    epoxy_glGetConvolutionFilter = epoxy_glGetConvolutionFilter_dispatch_table_thunk;
    epoxy_glGetConvolutionFilterEXT = epoxy_glGetConvolutionFilterEXT_dispatch_table_thunk;
    epoxy_glGetConvolutionParameterfv = epoxy_glGetConvolutionParameterfv_dispatch_table_thunk;
    epoxy_glGetConvolutionParameterfvEXT = epoxy_glGetConvolutionParameterfvEXT_dispatch_table_thunk;
    epoxy_glGetConvolutionParameteriv = epoxy_glGetConvolutionParameteriv_dispatch_table_thunk;
    epoxy_glGetConvolutionParameterivEXT = epoxy_glGetConvolutionParameterivEXT_dispatch_table_thunk;
    epoxy_glGetConvolutionParameterxvOES = epoxy_glGetConvolutionParameterxvOES_dispatch_table_thunk;
    epoxy_glGetCoverageModulationTableNV = epoxy_glGetCoverageModulationTableNV_dispatch_table_thunk;
    epoxy_glGetDebugMessageLog = epoxy_glGetDebugMessageLog_dispatch_table_thunk;
    epoxy_glGetDebugMessageLogAMD = epoxy_glGetDebugMessageLogAMD_dispatch_table_thunk;
    epoxy_glGetDebugMessageLogARB = epoxy_glGetDebugMessageLogARB_dispatch_table_thunk;
    epoxy_glGetDebugMessageLogKHR = epoxy_glGetDebugMessageLogKHR_dispatch_table_thunk;
    epoxy_glGetDetailTexFuncSGIS = epoxy_glGetDetailTexFuncSGIS_dispatch_table_thunk;
    epoxy_glGetDoubleIndexedvEXT = epoxy_glGetDoubleIndexedvEXT_dispatch_table_thunk;
    epoxy_glGetDoublei_v = epoxy_glGetDoublei_v_dispatch_table_thunk;
    epoxy_glGetDoublei_vEXT = epoxy_glGetDoublei_vEXT_dispatch_table_thunk;
    epoxy_glGetDoublev = epoxy_glGetDoublev_dispatch_table_thunk;
    epoxy_glGetDriverControlStringQCOM = epoxy_glGetDriverControlStringQCOM_dispatch_table_thunk;
    epoxy_glGetDriverControlsQCOM = epoxy_glGetDriverControlsQCOM_dispatch_table_thunk;
    epoxy_glGetError = epoxy_glGetError_dispatch_table_thunk;
    epoxy_glGetFenceivNV = epoxy_glGetFenceivNV_dispatch_table_thunk;
    epoxy_glGetFinalCombinerInputParameterfvNV = epoxy_glGetFinalCombinerInputParameterfvNV_dispatch_table_thunk;
    epoxy_glGetFinalCombinerInputParameterivNV = epoxy_glGetFinalCombinerInputParameterivNV_dispatch_table_thunk;
    epoxy_glGetFirstPerfQueryIdINTEL = epoxy_glGetFirstPerfQueryIdINTEL_dispatch_table_thunk;
    epoxy_glGetFixedv = epoxy_glGetFixedv_dispatch_table_thunk;
    epoxy_glGetFixedvOES = epoxy_glGetFixedvOES_dispatch_table_thunk;
    epoxy_glGetFloatIndexedvEXT = epoxy_glGetFloatIndexedvEXT_dispatch_table_thunk;
    epoxy_glGetFloati_v = epoxy_glGetFloati_v_dispatch_table_thunk;
    epoxy_glGetFloati_vEXT = epoxy_glGetFloati_vEXT_dispatch_table_thunk;
    epoxy_glGetFloati_vNV = epoxy_glGetFloati_vNV_dispatch_table_thunk;
    epoxy_glGetFloati_vOES = epoxy_glGetFloati_vOES_dispatch_table_thunk;
    epoxy_glGetFloatv = epoxy_glGetFloatv_dispatch_table_thunk;
    epoxy_glGetFogFuncSGIS = epoxy_glGetFogFuncSGIS_dispatch_table_thunk;
    epoxy_glGetFragDataIndex = epoxy_glGetFragDataIndex_dispatch_table_thunk;
    epoxy_glGetFragDataIndexEXT = epoxy_glGetFragDataIndexEXT_dispatch_table_thunk;
    epoxy_glGetFragDataLocation = epoxy_glGetFragDataLocation_dispatch_table_thunk;
    epoxy_glGetFragDataLocationEXT = epoxy_glGetFragDataLocationEXT_dispatch_table_thunk;
    epoxy_glGetFragmentLightfvSGIX = epoxy_glGetFragmentLightfvSGIX_dispatch_table_thunk;
    epoxy_glGetFragmentLightivSGIX = epoxy_glGetFragmentLightivSGIX_dispatch_table_thunk;
    epoxy_glGetFragmentMaterialfvSGIX = epoxy_glGetFragmentMaterialfvSGIX_dispatch_table_thunk;
    epoxy_glGetFragmentMaterialivSGIX = epoxy_glGetFragmentMaterialivSGIX_dispatch_table_thunk;
    epoxy_glGetFramebufferAttachmentParameteriv = epoxy_glGetFramebufferAttachmentParameteriv_dispatch_table_thunk;
    epoxy_glGetFramebufferAttachmentParameterivEXT = epoxy_glGetFramebufferAttachmentParameterivEXT_dispatch_table_thunk;
    epoxy_glGetFramebufferAttachmentParameterivOES = epoxy_glGetFramebufferAttachmentParameterivOES_dispatch_table_thunk;
    epoxy_glGetFramebufferParameterfvAMD = epoxy_glGetFramebufferParameterfvAMD_dispatch_table_thunk;
    epoxy_glGetFramebufferParameteriv = epoxy_glGetFramebufferParameteriv_dispatch_table_thunk;
    epoxy_glGetFramebufferParameterivEXT = epoxy_glGetFramebufferParameterivEXT_dispatch_table_thunk;
    epoxy_glGetFramebufferParameterivMESA = epoxy_glGetFramebufferParameterivMESA_dispatch_table_thunk;
    epoxy_glGetFramebufferPixelLocalStorageSizeEXT = epoxy_glGetFramebufferPixelLocalStorageSizeEXT_dispatch_table_thunk;
    epoxy_glGetGraphicsResetStatus = epoxy_glGetGraphicsResetStatus_dispatch_table_thunk;
    epoxy_glGetGraphicsResetStatusARB = epoxy_glGetGraphicsResetStatusARB_dispatch_table_thunk;
    epoxy_glGetGraphicsResetStatusEXT = epoxy_glGetGraphicsResetStatusEXT_dispatch_table_thunk;
    epoxy_glGetGraphicsResetStatusKHR = epoxy_glGetGraphicsResetStatusKHR_dispatch_table_thunk;
    epoxy_glGetHandleARB = epoxy_glGetHandleARB_dispatch_table_thunk;
    epoxy_glGetHistogram = epoxy_glGetHistogram_dispatch_table_thunk;
    epoxy_glGetHistogramEXT = epoxy_glGetHistogramEXT_dispatch_table_thunk;
    epoxy_glGetHistogramParameterfv = epoxy_glGetHistogramParameterfv_dispatch_table_thunk;
    epoxy_glGetHistogramParameterfvEXT = epoxy_glGetHistogramParameterfvEXT_dispatch_table_thunk;
    epoxy_glGetHistogramParameteriv = epoxy_glGetHistogramParameteriv_dispatch_table_thunk;
    epoxy_glGetHistogramParameterivEXT = epoxy_glGetHistogramParameterivEXT_dispatch_table_thunk;
    epoxy_glGetHistogramParameterxvOES = epoxy_glGetHistogramParameterxvOES_dispatch_table_thunk;
    epoxy_glGetImageHandleARB = epoxy_glGetImageHandleARB_dispatch_table_thunk;
    epoxy_glGetImageHandleNV = epoxy_glGetImageHandleNV_dispatch_table_thunk;
    epoxy_glGetImageTransformParameterfvHP = epoxy_glGetImageTransformParameterfvHP_dispatch_table_thunk;
    epoxy_glGetImageTransformParameterivHP = epoxy_glGetImageTransformParameterivHP_dispatch_table_thunk;
    epoxy_glGetInfoLogARB = epoxy_glGetInfoLogARB_dispatch_table_thunk;
    epoxy_glGetInstrumentsSGIX = epoxy_glGetInstrumentsSGIX_dispatch_table_thunk;
    epoxy_glGetInteger64i_v = epoxy_glGetInteger64i_v_dispatch_table_thunk;
    epoxy_glGetInteger64v = epoxy_glGetInteger64v_dispatch_table_thunk;
    epoxy_glGetInteger64vAPPLE = epoxy_glGetInteger64vAPPLE_dispatch_table_thunk;
    epoxy_glGetIntegerIndexedvEXT = epoxy_glGetIntegerIndexedvEXT_dispatch_table_thunk;
    epoxy_glGetIntegeri_v = epoxy_glGetIntegeri_v_dispatch_table_thunk;
    epoxy_glGetIntegeri_vEXT = epoxy_glGetIntegeri_vEXT_dispatch_table_thunk;
    epoxy_glGetIntegerui64i_vNV = epoxy_glGetIntegerui64i_vNV_dispatch_table_thunk;
    epoxy_glGetIntegerui64vNV = epoxy_glGetIntegerui64vNV_dispatch_table_thunk;
    epoxy_glGetIntegerv = epoxy_glGetIntegerv_dispatch_table_thunk;
    epoxy_glGetInternalformatSampleivNV = epoxy_glGetInternalformatSampleivNV_dispatch_table_thunk;
    epoxy_glGetInternalformati64v = epoxy_glGetInternalformati64v_dispatch_table_thunk;
    epoxy_glGetInternalformativ = epoxy_glGetInternalformativ_dispatch_table_thunk;
    epoxy_glGetInvariantBooleanvEXT = epoxy_glGetInvariantBooleanvEXT_dispatch_table_thunk;
    epoxy_glGetInvariantFloatvEXT = epoxy_glGetInvariantFloatvEXT_dispatch_table_thunk;
    epoxy_glGetInvariantIntegervEXT = epoxy_glGetInvariantIntegervEXT_dispatch_table_thunk;
    epoxy_glGetLightfv = epoxy_glGetLightfv_dispatch_table_thunk;
    epoxy_glGetLightiv = epoxy_glGetLightiv_dispatch_table_thunk;
    epoxy_glGetLightxOES = epoxy_glGetLightxOES_dispatch_table_thunk;
    epoxy_glGetLightxv = epoxy_glGetLightxv_dispatch_table_thunk;
    epoxy_glGetLightxvOES = epoxy_glGetLightxvOES_dispatch_table_thunk;
    epoxy_glGetListParameterfvSGIX = epoxy_glGetListParameterfvSGIX_dispatch_table_thunk;
    epoxy_glGetListParameterivSGIX = epoxy_glGetListParameterivSGIX_dispatch_table_thunk;
    epoxy_glGetLocalConstantBooleanvEXT = epoxy_glGetLocalConstantBooleanvEXT_dispatch_table_thunk;
    epoxy_glGetLocalConstantFloatvEXT = epoxy_glGetLocalConstantFloatvEXT_dispatch_table_thunk;
    epoxy_glGetLocalConstantIntegervEXT = epoxy_glGetLocalConstantIntegervEXT_dispatch_table_thunk;
    epoxy_glGetMapAttribParameterfvNV = epoxy_glGetMapAttribParameterfvNV_dispatch_table_thunk;
    epoxy_glGetMapAttribParameterivNV = epoxy_glGetMapAttribParameterivNV_dispatch_table_thunk;
    epoxy_glGetMapControlPointsNV = epoxy_glGetMapControlPointsNV_dispatch_table_thunk;
    epoxy_glGetMapParameterfvNV = epoxy_glGetMapParameterfvNV_dispatch_table_thunk;
    epoxy_glGetMapParameterivNV = epoxy_glGetMapParameterivNV_dispatch_table_thunk;
    epoxy_glGetMapdv = epoxy_glGetMapdv_dispatch_table_thunk;
    epoxy_glGetMapfv = epoxy_glGetMapfv_dispatch_table_thunk;
    epoxy_glGetMapiv = epoxy_glGetMapiv_dispatch_table_thunk;
    epoxy_glGetMapxvOES = epoxy_glGetMapxvOES_dispatch_table_thunk;
    epoxy_glGetMaterialfv = epoxy_glGetMaterialfv_dispatch_table_thunk;
    epoxy_glGetMaterialiv = epoxy_glGetMaterialiv_dispatch_table_thunk;
    epoxy_glGetMaterialxOES = epoxy_glGetMaterialxOES_dispatch_table_thunk;
    epoxy_glGetMaterialxv = epoxy_glGetMaterialxv_dispatch_table_thunk;
    epoxy_glGetMaterialxvOES = epoxy_glGetMaterialxvOES_dispatch_table_thunk;
    epoxy_glGetMemoryObjectDetachedResourcesuivNV = epoxy_glGetMemoryObjectDetachedResourcesuivNV_dispatch_table_thunk;
    epoxy_glGetMemoryObjectParameterivEXT = epoxy_glGetMemoryObjectParameterivEXT_dispatch_table_thunk;
    epoxy_glGetMinmax = epoxy_glGetMinmax_dispatch_table_thunk;
    epoxy_glGetMinmaxEXT = epoxy_glGetMinmaxEXT_dispatch_table_thunk;
    epoxy_glGetMinmaxParameterfv = epoxy_glGetMinmaxParameterfv_dispatch_table_thunk;
    epoxy_glGetMinmaxParameterfvEXT = epoxy_glGetMinmaxParameterfvEXT_dispatch_table_thunk;
    epoxy_glGetMinmaxParameteriv = epoxy_glGetMinmaxParameteriv_dispatch_table_thunk;
    epoxy_glGetMinmaxParameterivEXT = epoxy_glGetMinmaxParameterivEXT_dispatch_table_thunk;
    epoxy_glGetMultiTexEnvfvEXT = epoxy_glGetMultiTexEnvfvEXT_dispatch_table_thunk;
    epoxy_glGetMultiTexEnvivEXT = epoxy_glGetMultiTexEnvivEXT_dispatch_table_thunk;
    epoxy_glGetMultiTexGendvEXT = epoxy_glGetMultiTexGendvEXT_dispatch_table_thunk;
    epoxy_glGetMultiTexGenfvEXT = epoxy_glGetMultiTexGenfvEXT_dispatch_table_thunk;
    epoxy_glGetMultiTexGenivEXT = epoxy_glGetMultiTexGenivEXT_dispatch_table_thunk;
    epoxy_glGetMultiTexImageEXT = epoxy_glGetMultiTexImageEXT_dispatch_table_thunk;
    epoxy_glGetMultiTexLevelParameterfvEXT = epoxy_glGetMultiTexLevelParameterfvEXT_dispatch_table_thunk;
    epoxy_glGetMultiTexLevelParameterivEXT = epoxy_glGetMultiTexLevelParameterivEXT_dispatch_table_thunk;
    epoxy_glGetMultiTexParameterIivEXT = epoxy_glGetMultiTexParameterIivEXT_dispatch_table_thunk;
    epoxy_glGetMultiTexParameterIuivEXT = epoxy_glGetMultiTexParameterIuivEXT_dispatch_table_thunk;
    epoxy_glGetMultiTexParameterfvEXT = epoxy_glGetMultiTexParameterfvEXT_dispatch_table_thunk;
    epoxy_glGetMultiTexParameterivEXT = epoxy_glGetMultiTexParameterivEXT_dispatch_table_thunk;
    epoxy_glGetMultisamplefv = epoxy_glGetMultisamplefv_dispatch_table_thunk;
    epoxy_glGetMultisamplefvNV = epoxy_glGetMultisamplefvNV_dispatch_table_thunk;
    epoxy_glGetNamedBufferParameteri64v = epoxy_glGetNamedBufferParameteri64v_dispatch_table_thunk;
    epoxy_glGetNamedBufferParameteriv = epoxy_glGetNamedBufferParameteriv_dispatch_table_thunk;
    epoxy_glGetNamedBufferParameterivEXT = epoxy_glGetNamedBufferParameterivEXT_dispatch_table_thunk;
    epoxy_glGetNamedBufferParameterui64vNV = epoxy_glGetNamedBufferParameterui64vNV_dispatch_table_thunk;
    epoxy_glGetNamedBufferPointerv = epoxy_glGetNamedBufferPointerv_dispatch_table_thunk;
    epoxy_glGetNamedBufferPointervEXT = epoxy_glGetNamedBufferPointervEXT_dispatch_table_thunk;
    epoxy_glGetNamedBufferSubData = epoxy_glGetNamedBufferSubData_dispatch_table_thunk;
    epoxy_glGetNamedBufferSubDataEXT = epoxy_glGetNamedBufferSubDataEXT_dispatch_table_thunk;
    epoxy_glGetNamedFramebufferAttachmentParameteriv = epoxy_glGetNamedFramebufferAttachmentParameteriv_dispatch_table_thunk;
    epoxy_glGetNamedFramebufferAttachmentParameterivEXT = epoxy_glGetNamedFramebufferAttachmentParameterivEXT_dispatch_table_thunk;
    epoxy_glGetNamedFramebufferParameterfvAMD = epoxy_glGetNamedFramebufferParameterfvAMD_dispatch_table_thunk;
    epoxy_glGetNamedFramebufferParameteriv = epoxy_glGetNamedFramebufferParameteriv_dispatch_table_thunk;
    epoxy_glGetNamedFramebufferParameterivEXT = epoxy_glGetNamedFramebufferParameterivEXT_dispatch_table_thunk;
    epoxy_glGetNamedProgramLocalParameterIivEXT = epoxy_glGetNamedProgramLocalParameterIivEXT_dispatch_table_thunk;
    epoxy_glGetNamedProgramLocalParameterIuivEXT = epoxy_glGetNamedProgramLocalParameterIuivEXT_dispatch_table_thunk;
    epoxy_glGetNamedProgramLocalParameterdvEXT = epoxy_glGetNamedProgramLocalParameterdvEXT_dispatch_table_thunk;
    epoxy_glGetNamedProgramLocalParameterfvEXT = epoxy_glGetNamedProgramLocalParameterfvEXT_dispatch_table_thunk;
    epoxy_glGetNamedProgramStringEXT = epoxy_glGetNamedProgramStringEXT_dispatch_table_thunk;
    epoxy_glGetNamedProgramivEXT = epoxy_glGetNamedProgramivEXT_dispatch_table_thunk;
    epoxy_glGetNamedRenderbufferParameteriv = epoxy_glGetNamedRenderbufferParameteriv_dispatch_table_thunk;
    epoxy_glGetNamedRenderbufferParameterivEXT = epoxy_glGetNamedRenderbufferParameterivEXT_dispatch_table_thunk;
    epoxy_glGetNamedStringARB = epoxy_glGetNamedStringARB_dispatch_table_thunk;
    epoxy_glGetNamedStringivARB = epoxy_glGetNamedStringivARB_dispatch_table_thunk;
    epoxy_glGetNextPerfQueryIdINTEL = epoxy_glGetNextPerfQueryIdINTEL_dispatch_table_thunk;
    epoxy_glGetObjectBufferfvATI = epoxy_glGetObjectBufferfvATI_dispatch_table_thunk;
    epoxy_glGetObjectBufferivATI = epoxy_glGetObjectBufferivATI_dispatch_table_thunk;
    epoxy_glGetObjectLabel = epoxy_glGetObjectLabel_dispatch_table_thunk;
    epoxy_glGetObjectLabelEXT = epoxy_glGetObjectLabelEXT_dispatch_table_thunk;
    epoxy_glGetObjectLabelKHR = epoxy_glGetObjectLabelKHR_dispatch_table_thunk;
    epoxy_glGetObjectParameterfvARB = epoxy_glGetObjectParameterfvARB_dispatch_table_thunk;
    epoxy_glGetObjectParameterivAPPLE = epoxy_glGetObjectParameterivAPPLE_dispatch_table_thunk;
    epoxy_glGetObjectParameterivARB = epoxy_glGetObjectParameterivARB_dispatch_table_thunk;
    epoxy_glGetObjectPtrLabel = epoxy_glGetObjectPtrLabel_dispatch_table_thunk;
    epoxy_glGetObjectPtrLabelKHR = epoxy_glGetObjectPtrLabelKHR_dispatch_table_thunk;
    epoxy_glGetOcclusionQueryivNV = epoxy_glGetOcclusionQueryivNV_dispatch_table_thunk;
    epoxy_glGetOcclusionQueryuivNV = epoxy_glGetOcclusionQueryuivNV_dispatch_table_thunk;
    epoxy_glGetPathColorGenfvNV = epoxy_glGetPathColorGenfvNV_dispatch_table_thunk;
    epoxy_glGetPathColorGenivNV = epoxy_glGetPathColorGenivNV_dispatch_table_thunk;
    epoxy_glGetPathCommandsNV = epoxy_glGetPathCommandsNV_dispatch_table_thunk;
    epoxy_glGetPathCoordsNV = epoxy_glGetPathCoordsNV_dispatch_table_thunk;
    epoxy_glGetPathDashArrayNV = epoxy_glGetPathDashArrayNV_dispatch_table_thunk;
    epoxy_glGetPathLengthNV = epoxy_glGetPathLengthNV_dispatch_table_thunk;
    epoxy_glGetPathMetricRangeNV = epoxy_glGetPathMetricRangeNV_dispatch_table_thunk;
    epoxy_glGetPathMetricsNV = epoxy_glGetPathMetricsNV_dispatch_table_thunk;
    epoxy_glGetPathParameterfvNV = epoxy_glGetPathParameterfvNV_dispatch_table_thunk;
    epoxy_glGetPathParameterivNV = epoxy_glGetPathParameterivNV_dispatch_table_thunk;
    epoxy_glGetPathSpacingNV = epoxy_glGetPathSpacingNV_dispatch_table_thunk;
    epoxy_glGetPathTexGenfvNV = epoxy_glGetPathTexGenfvNV_dispatch_table_thunk;
    epoxy_glGetPathTexGenivNV = epoxy_glGetPathTexGenivNV_dispatch_table_thunk;
    epoxy_glGetPerfCounterInfoINTEL = epoxy_glGetPerfCounterInfoINTEL_dispatch_table_thunk;
    epoxy_glGetPerfMonitorCounterDataAMD = epoxy_glGetPerfMonitorCounterDataAMD_dispatch_table_thunk;
    epoxy_glGetPerfMonitorCounterInfoAMD = epoxy_glGetPerfMonitorCounterInfoAMD_dispatch_table_thunk;
    epoxy_glGetPerfMonitorCounterStringAMD = epoxy_glGetPerfMonitorCounterStringAMD_dispatch_table_thunk;
    epoxy_glGetPerfMonitorCountersAMD = epoxy_glGetPerfMonitorCountersAMD_dispatch_table_thunk;
    epoxy_glGetPerfMonitorGroupStringAMD = epoxy_glGetPerfMonitorGroupStringAMD_dispatch_table_thunk;
    epoxy_glGetPerfMonitorGroupsAMD = epoxy_glGetPerfMonitorGroupsAMD_dispatch_table_thunk;
    epoxy_glGetPerfQueryDataINTEL = epoxy_glGetPerfQueryDataINTEL_dispatch_table_thunk;
    epoxy_glGetPerfQueryIdByNameINTEL = epoxy_glGetPerfQueryIdByNameINTEL_dispatch_table_thunk;
    epoxy_glGetPerfQueryInfoINTEL = epoxy_glGetPerfQueryInfoINTEL_dispatch_table_thunk;
    epoxy_glGetPixelMapfv = epoxy_glGetPixelMapfv_dispatch_table_thunk;
    epoxy_glGetPixelMapuiv = epoxy_glGetPixelMapuiv_dispatch_table_thunk;
    epoxy_glGetPixelMapusv = epoxy_glGetPixelMapusv_dispatch_table_thunk;
    epoxy_glGetPixelMapxv = epoxy_glGetPixelMapxv_dispatch_table_thunk;
    epoxy_glGetPixelTexGenParameterfvSGIS = epoxy_glGetPixelTexGenParameterfvSGIS_dispatch_table_thunk;
    epoxy_glGetPixelTexGenParameterivSGIS = epoxy_glGetPixelTexGenParameterivSGIS_dispatch_table_thunk;
    epoxy_glGetPixelTransformParameterfvEXT = epoxy_glGetPixelTransformParameterfvEXT_dispatch_table_thunk;
    epoxy_glGetPixelTransformParameterivEXT = epoxy_glGetPixelTransformParameterivEXT_dispatch_table_thunk;
    epoxy_glGetPointerIndexedvEXT = epoxy_glGetPointerIndexedvEXT_dispatch_table_thunk;
    epoxy_glGetPointeri_vEXT = epoxy_glGetPointeri_vEXT_dispatch_table_thunk;
    epoxy_glGetPointerv = epoxy_glGetPointerv_dispatch_table_thunk;
    epoxy_glGetPointervEXT = epoxy_glGetPointervEXT_dispatch_table_thunk;
    epoxy_glGetPointervKHR = epoxy_glGetPointervKHR_dispatch_table_thunk;
    epoxy_glGetPolygonStipple = epoxy_glGetPolygonStipple_dispatch_table_thunk;
    epoxy_glGetProgramBinary = epoxy_glGetProgramBinary_dispatch_table_thunk;
    epoxy_glGetProgramBinaryOES = epoxy_glGetProgramBinaryOES_dispatch_table_thunk;
    epoxy_glGetProgramEnvParameterIivNV = epoxy_glGetProgramEnvParameterIivNV_dispatch_table_thunk;
    epoxy_glGetProgramEnvParameterIuivNV = epoxy_glGetProgramEnvParameterIuivNV_dispatch_table_thunk;
    epoxy_glGetProgramEnvParameterdvARB = epoxy_glGetProgramEnvParameterdvARB_dispatch_table_thunk;
    epoxy_glGetProgramEnvParameterfvARB = epoxy_glGetProgramEnvParameterfvARB_dispatch_table_thunk;
    epoxy_glGetProgramInfoLog = epoxy_glGetProgramInfoLog_dispatch_table_thunk;
    epoxy_glGetProgramInterfaceiv = epoxy_glGetProgramInterfaceiv_dispatch_table_thunk;
    epoxy_glGetProgramLocalParameterIivNV = epoxy_glGetProgramLocalParameterIivNV_dispatch_table_thunk;
    epoxy_glGetProgramLocalParameterIuivNV = epoxy_glGetProgramLocalParameterIuivNV_dispatch_table_thunk;
    epoxy_glGetProgramLocalParameterdvARB = epoxy_glGetProgramLocalParameterdvARB_dispatch_table_thunk;
    epoxy_glGetProgramLocalParameterfvARB = epoxy_glGetProgramLocalParameterfvARB_dispatch_table_thunk;
    epoxy_glGetProgramNamedParameterdvNV = epoxy_glGetProgramNamedParameterdvNV_dispatch_table_thunk;
    epoxy_glGetProgramNamedParameterfvNV = epoxy_glGetProgramNamedParameterfvNV_dispatch_table_thunk;
    epoxy_glGetProgramParameterdvNV = epoxy_glGetProgramParameterdvNV_dispatch_table_thunk;
    epoxy_glGetProgramParameterfvNV = epoxy_glGetProgramParameterfvNV_dispatch_table_thunk;
    epoxy_glGetProgramPipelineInfoLog = epoxy_glGetProgramPipelineInfoLog_dispatch_table_thunk;
    epoxy_glGetProgramPipelineInfoLogEXT = epoxy_glGetProgramPipelineInfoLogEXT_dispatch_table_thunk;
    epoxy_glGetProgramPipelineiv = epoxy_glGetProgramPipelineiv_dispatch_table_thunk;
    epoxy_glGetProgramPipelineivEXT = epoxy_glGetProgramPipelineivEXT_dispatch_table_thunk;
    epoxy_glGetProgramResourceIndex = epoxy_glGetProgramResourceIndex_dispatch_table_thunk;
    epoxy_glGetProgramResourceLocation = epoxy_glGetProgramResourceLocation_dispatch_table_thunk;
    epoxy_glGetProgramResourceLocationIndex = epoxy_glGetProgramResourceLocationIndex_dispatch_table_thunk;
    epoxy_glGetProgramResourceLocationIndexEXT = epoxy_glGetProgramResourceLocationIndexEXT_dispatch_table_thunk;
    epoxy_glGetProgramResourceName = epoxy_glGetProgramResourceName_dispatch_table_thunk;
    epoxy_glGetProgramResourcefvNV = epoxy_glGetProgramResourcefvNV_dispatch_table_thunk;
    epoxy_glGetProgramResourceiv = epoxy_glGetProgramResourceiv_dispatch_table_thunk;
    epoxy_glGetProgramStageiv = epoxy_glGetProgramStageiv_dispatch_table_thunk;
    epoxy_glGetProgramStringARB = epoxy_glGetProgramStringARB_dispatch_table_thunk;
    epoxy_glGetProgramStringNV = epoxy_glGetProgramStringNV_dispatch_table_thunk;
    epoxy_glGetProgramSubroutineParameteruivNV = epoxy_glGetProgramSubroutineParameteruivNV_dispatch_table_thunk;
    epoxy_glGetProgramiv = epoxy_glGetProgramiv_dispatch_table_thunk;
    epoxy_glGetProgramivARB = epoxy_glGetProgramivARB_dispatch_table_thunk;
    epoxy_glGetProgramivNV = epoxy_glGetProgramivNV_dispatch_table_thunk;
    epoxy_glGetQueryBufferObjecti64v = epoxy_glGetQueryBufferObjecti64v_dispatch_table_thunk;
    epoxy_glGetQueryBufferObjectiv = epoxy_glGetQueryBufferObjectiv_dispatch_table_thunk;
    epoxy_glGetQueryBufferObjectui64v = epoxy_glGetQueryBufferObjectui64v_dispatch_table_thunk;
    epoxy_glGetQueryBufferObjectuiv = epoxy_glGetQueryBufferObjectuiv_dispatch_table_thunk;
    epoxy_glGetQueryIndexediv = epoxy_glGetQueryIndexediv_dispatch_table_thunk;
    epoxy_glGetQueryObjecti64v = epoxy_glGetQueryObjecti64v_dispatch_table_thunk;
    epoxy_glGetQueryObjecti64vEXT = epoxy_glGetQueryObjecti64vEXT_dispatch_table_thunk;
    epoxy_glGetQueryObjectiv = epoxy_glGetQueryObjectiv_dispatch_table_thunk;
    epoxy_glGetQueryObjectivARB = epoxy_glGetQueryObjectivARB_dispatch_table_thunk;
    epoxy_glGetQueryObjectivEXT = epoxy_glGetQueryObjectivEXT_dispatch_table_thunk;
    epoxy_glGetQueryObjectui64v = epoxy_glGetQueryObjectui64v_dispatch_table_thunk;
    epoxy_glGetQueryObjectui64vEXT = epoxy_glGetQueryObjectui64vEXT_dispatch_table_thunk;
    epoxy_glGetQueryObjectuiv = epoxy_glGetQueryObjectuiv_dispatch_table_thunk;
    epoxy_glGetQueryObjectuivARB = epoxy_glGetQueryObjectuivARB_dispatch_table_thunk;
    epoxy_glGetQueryObjectuivEXT = epoxy_glGetQueryObjectuivEXT_dispatch_table_thunk;
    epoxy_glGetQueryiv = epoxy_glGetQueryiv_dispatch_table_thunk;
    epoxy_glGetQueryivARB = epoxy_glGetQueryivARB_dispatch_table_thunk;
    epoxy_glGetQueryivEXT = epoxy_glGetQueryivEXT_dispatch_table_thunk;
    epoxy_glGetRenderbufferParameteriv = epoxy_glGetRenderbufferParameteriv_dispatch_table_thunk;
    epoxy_glGetRenderbufferParameterivEXT = epoxy_glGetRenderbufferParameterivEXT_dispatch_table_thunk;
    epoxy_glGetRenderbufferParameterivOES = epoxy_glGetRenderbufferParameterivOES_dispatch_table_thunk;
    epoxy_glGetSamplerParameterIiv = epoxy_glGetSamplerParameterIiv_dispatch_table_thunk;
    epoxy_glGetSamplerParameterIivEXT = epoxy_glGetSamplerParameterIivEXT_dispatch_table_thunk;
    epoxy_glGetSamplerParameterIivOES = epoxy_glGetSamplerParameterIivOES_dispatch_table_thunk;
    epoxy_glGetSamplerParameterIuiv = epoxy_glGetSamplerParameterIuiv_dispatch_table_thunk;
    epoxy_glGetSamplerParameterIuivEXT = epoxy_glGetSamplerParameterIuivEXT_dispatch_table_thunk;
    epoxy_glGetSamplerParameterIuivOES = epoxy_glGetSamplerParameterIuivOES_dispatch_table_thunk;
    epoxy_glGetSamplerParameterfv = epoxy_glGetSamplerParameterfv_dispatch_table_thunk;
    epoxy_glGetSamplerParameteriv = epoxy_glGetSamplerParameteriv_dispatch_table_thunk;
    epoxy_glGetSemaphoreParameterui64vEXT = epoxy_glGetSemaphoreParameterui64vEXT_dispatch_table_thunk;
    epoxy_glGetSeparableFilter = epoxy_glGetSeparableFilter_dispatch_table_thunk;
    epoxy_glGetSeparableFilterEXT = epoxy_glGetSeparableFilterEXT_dispatch_table_thunk;
    epoxy_glGetShaderInfoLog = epoxy_glGetShaderInfoLog_dispatch_table_thunk;
    epoxy_glGetShaderPrecisionFormat = epoxy_glGetShaderPrecisionFormat_dispatch_table_thunk;
    epoxy_glGetShaderSource = epoxy_glGetShaderSource_dispatch_table_thunk;
    epoxy_glGetShaderSourceARB = epoxy_glGetShaderSourceARB_dispatch_table_thunk;
    epoxy_glGetShaderiv = epoxy_glGetShaderiv_dispatch_table_thunk;
    epoxy_glGetShadingRateImagePaletteNV = epoxy_glGetShadingRateImagePaletteNV_dispatch_table_thunk;
    epoxy_glGetShadingRateSampleLocationivNV = epoxy_glGetShadingRateSampleLocationivNV_dispatch_table_thunk;
    epoxy_glGetSharpenTexFuncSGIS = epoxy_glGetSharpenTexFuncSGIS_dispatch_table_thunk;
    epoxy_glGetStageIndexNV = epoxy_glGetStageIndexNV_dispatch_table_thunk;
    epoxy_glGetString = epoxy_glGetString_dispatch_table_thunk;
    epoxy_glGetStringi = epoxy_glGetStringi_dispatch_table_thunk;
    epoxy_glGetSubroutineIndex = epoxy_glGetSubroutineIndex_dispatch_table_thunk;
    epoxy_glGetSubroutineUniformLocation = epoxy_glGetSubroutineUniformLocation_dispatch_table_thunk;
    epoxy_glGetSynciv = epoxy_glGetSynciv_dispatch_table_thunk;
    epoxy_glGetSyncivAPPLE = epoxy_glGetSyncivAPPLE_dispatch_table_thunk;
    epoxy_glGetTexBumpParameterfvATI = epoxy_glGetTexBumpParameterfvATI_dispatch_table_thunk;
    epoxy_glGetTexBumpParameterivATI = epoxy_glGetTexBumpParameterivATI_dispatch_table_thunk;
    epoxy_glGetTexEnvfv = epoxy_glGetTexEnvfv_dispatch_table_thunk;
    epoxy_glGetTexEnviv = epoxy_glGetTexEnviv_dispatch_table_thunk;
    epoxy_glGetTexEnvxv = epoxy_glGetTexEnvxv_dispatch_table_thunk;
    epoxy_glGetTexEnvxvOES = epoxy_glGetTexEnvxvOES_dispatch_table_thunk;
    epoxy_glGetTexFilterFuncSGIS = epoxy_glGetTexFilterFuncSGIS_dispatch_table_thunk;
    epoxy_glGetTexGendv = epoxy_glGetTexGendv_dispatch_table_thunk;
    epoxy_glGetTexGenfv = epoxy_glGetTexGenfv_dispatch_table_thunk;
    epoxy_glGetTexGenfvOES = epoxy_glGetTexGenfvOES_dispatch_table_thunk;
    epoxy_glGetTexGeniv = epoxy_glGetTexGeniv_dispatch_table_thunk;
    epoxy_glGetTexGenivOES = epoxy_glGetTexGenivOES_dispatch_table_thunk;
    epoxy_glGetTexGenxvOES = epoxy_glGetTexGenxvOES_dispatch_table_thunk;
    epoxy_glGetTexImage = epoxy_glGetTexImage_dispatch_table_thunk;
    epoxy_glGetTexLevelParameterfv = epoxy_glGetTexLevelParameterfv_dispatch_table_thunk;
    epoxy_glGetTexLevelParameteriv = epoxy_glGetTexLevelParameteriv_dispatch_table_thunk;
    epoxy_glGetTexLevelParameterxvOES = epoxy_glGetTexLevelParameterxvOES_dispatch_table_thunk;
    epoxy_glGetTexParameterIiv = epoxy_glGetTexParameterIiv_dispatch_table_thunk;
    epoxy_glGetTexParameterIivEXT = epoxy_glGetTexParameterIivEXT_dispatch_table_thunk;
    epoxy_glGetTexParameterIivOES = epoxy_glGetTexParameterIivOES_dispatch_table_thunk;
    epoxy_glGetTexParameterIuiv = epoxy_glGetTexParameterIuiv_dispatch_table_thunk;
    epoxy_glGetTexParameterIuivEXT = epoxy_glGetTexParameterIuivEXT_dispatch_table_thunk;
    epoxy_glGetTexParameterIuivOES = epoxy_glGetTexParameterIuivOES_dispatch_table_thunk;
    epoxy_glGetTexParameterPointervAPPLE = epoxy_glGetTexParameterPointervAPPLE_dispatch_table_thunk;
    epoxy_glGetTexParameterfv = epoxy_glGetTexParameterfv_dispatch_table_thunk;
    epoxy_glGetTexParameteriv = epoxy_glGetTexParameteriv_dispatch_table_thunk;
    epoxy_glGetTexParameterxv = epoxy_glGetTexParameterxv_dispatch_table_thunk;
    epoxy_glGetTexParameterxvOES = epoxy_glGetTexParameterxvOES_dispatch_table_thunk;
    epoxy_glGetTextureHandleARB = epoxy_glGetTextureHandleARB_dispatch_table_thunk;
    epoxy_glGetTextureHandleIMG = epoxy_glGetTextureHandleIMG_dispatch_table_thunk;
    epoxy_glGetTextureHandleNV = epoxy_glGetTextureHandleNV_dispatch_table_thunk;
    epoxy_glGetTextureImage = epoxy_glGetTextureImage_dispatch_table_thunk;
    epoxy_glGetTextureImageEXT = epoxy_glGetTextureImageEXT_dispatch_table_thunk;
    epoxy_glGetTextureLevelParameterfv = epoxy_glGetTextureLevelParameterfv_dispatch_table_thunk;
    epoxy_glGetTextureLevelParameterfvEXT = epoxy_glGetTextureLevelParameterfvEXT_dispatch_table_thunk;
    epoxy_glGetTextureLevelParameteriv = epoxy_glGetTextureLevelParameteriv_dispatch_table_thunk;
    epoxy_glGetTextureLevelParameterivEXT = epoxy_glGetTextureLevelParameterivEXT_dispatch_table_thunk;
    epoxy_glGetTextureParameterIiv = epoxy_glGetTextureParameterIiv_dispatch_table_thunk;
    epoxy_glGetTextureParameterIivEXT = epoxy_glGetTextureParameterIivEXT_dispatch_table_thunk;
    epoxy_glGetTextureParameterIuiv = epoxy_glGetTextureParameterIuiv_dispatch_table_thunk;
    epoxy_glGetTextureParameterIuivEXT = epoxy_glGetTextureParameterIuivEXT_dispatch_table_thunk;
    epoxy_glGetTextureParameterfv = epoxy_glGetTextureParameterfv_dispatch_table_thunk;
    epoxy_glGetTextureParameterfvEXT = epoxy_glGetTextureParameterfvEXT_dispatch_table_thunk;
    epoxy_glGetTextureParameteriv = epoxy_glGetTextureParameteriv_dispatch_table_thunk;
    epoxy_glGetTextureParameterivEXT = epoxy_glGetTextureParameterivEXT_dispatch_table_thunk;
    epoxy_glGetTextureSamplerHandleARB = epoxy_glGetTextureSamplerHandleARB_dispatch_table_thunk;
    epoxy_glGetTextureSamplerHandleIMG = epoxy_glGetTextureSamplerHandleIMG_dispatch_table_thunk;
    epoxy_glGetTextureSamplerHandleNV = epoxy_glGetTextureSamplerHandleNV_dispatch_table_thunk;
    epoxy_glGetTextureSubImage = epoxy_glGetTextureSubImage_dispatch_table_thunk;
    epoxy_glGetTrackMatrixivNV = epoxy_glGetTrackMatrixivNV_dispatch_table_thunk;
    epoxy_glGetTransformFeedbackVarying = epoxy_glGetTransformFeedbackVarying_dispatch_table_thunk;
    epoxy_glGetTransformFeedbackVaryingEXT = epoxy_glGetTransformFeedbackVaryingEXT_dispatch_table_thunk;
    epoxy_glGetTransformFeedbackVaryingNV = epoxy_glGetTransformFeedbackVaryingNV_dispatch_table_thunk;
    epoxy_glGetTransformFeedbacki64_v = epoxy_glGetTransformFeedbacki64_v_dispatch_table_thunk;
    epoxy_glGetTransformFeedbacki_v = epoxy_glGetTransformFeedbacki_v_dispatch_table_thunk;
    epoxy_glGetTransformFeedbackiv = epoxy_glGetTransformFeedbackiv_dispatch_table_thunk;
    epoxy_glGetTranslatedShaderSourceANGLE = epoxy_glGetTranslatedShaderSourceANGLE_dispatch_table_thunk;
    epoxy_glGetUniformBlockIndex = epoxy_glGetUniformBlockIndex_dispatch_table_thunk;
    epoxy_glGetUniformBufferSizeEXT = epoxy_glGetUniformBufferSizeEXT_dispatch_table_thunk;
    epoxy_glGetUniformIndices = epoxy_glGetUniformIndices_dispatch_table_thunk;
    epoxy_glGetUniformLocation = epoxy_glGetUniformLocation_dispatch_table_thunk;
    epoxy_glGetUniformLocationARB = epoxy_glGetUniformLocationARB_dispatch_table_thunk;
    epoxy_glGetUniformOffsetEXT = epoxy_glGetUniformOffsetEXT_dispatch_table_thunk;
    epoxy_glGetUniformSubroutineuiv = epoxy_glGetUniformSubroutineuiv_dispatch_table_thunk;
    epoxy_glGetUniformdv = epoxy_glGetUniformdv_dispatch_table_thunk;
    epoxy_glGetUniformfv = epoxy_glGetUniformfv_dispatch_table_thunk;
    epoxy_glGetUniformfvARB = epoxy_glGetUniformfvARB_dispatch_table_thunk;
    epoxy_glGetUniformi64vARB = epoxy_glGetUniformi64vARB_dispatch_table_thunk;
    epoxy_glGetUniformi64vNV = epoxy_glGetUniformi64vNV_dispatch_table_thunk;
    epoxy_glGetUniformiv = epoxy_glGetUniformiv_dispatch_table_thunk;
    epoxy_glGetUniformivARB = epoxy_glGetUniformivARB_dispatch_table_thunk;
    epoxy_glGetUniformui64vARB = epoxy_glGetUniformui64vARB_dispatch_table_thunk;
    epoxy_glGetUniformui64vNV = epoxy_glGetUniformui64vNV_dispatch_table_thunk;
    epoxy_glGetUniformuiv = epoxy_glGetUniformuiv_dispatch_table_thunk;
    epoxy_glGetUniformuivEXT = epoxy_glGetUniformuivEXT_dispatch_table_thunk;
    epoxy_glGetUnsignedBytei_vEXT = epoxy_glGetUnsignedBytei_vEXT_dispatch_table_thunk;
    epoxy_glGetUnsignedBytevEXT = epoxy_glGetUnsignedBytevEXT_dispatch_table_thunk;
    epoxy_glGetVariantArrayObjectfvATI = epoxy_glGetVariantArrayObjectfvATI_dispatch_table_thunk;
    epoxy_glGetVariantArrayObjectivATI = epoxy_glGetVariantArrayObjectivATI_dispatch_table_thunk;
    epoxy_glGetVariantBooleanvEXT = epoxy_glGetVariantBooleanvEXT_dispatch_table_thunk;
    epoxy_glGetVariantFloatvEXT = epoxy_glGetVariantFloatvEXT_dispatch_table_thunk;
    epoxy_glGetVariantIntegervEXT = epoxy_glGetVariantIntegervEXT_dispatch_table_thunk;
    epoxy_glGetVariantPointervEXT = epoxy_glGetVariantPointervEXT_dispatch_table_thunk;
    epoxy_glGetVaryingLocationNV = epoxy_glGetVaryingLocationNV_dispatch_table_thunk;
    epoxy_glGetVertexArrayIndexed64iv = epoxy_glGetVertexArrayIndexed64iv_dispatch_table_thunk;
    epoxy_glGetVertexArrayIndexediv = epoxy_glGetVertexArrayIndexediv_dispatch_table_thunk;
    epoxy_glGetVertexArrayIntegeri_vEXT = epoxy_glGetVertexArrayIntegeri_vEXT_dispatch_table_thunk;
    epoxy_glGetVertexArrayIntegervEXT = epoxy_glGetVertexArrayIntegervEXT_dispatch_table_thunk;
    epoxy_glGetVertexArrayPointeri_vEXT = epoxy_glGetVertexArrayPointeri_vEXT_dispatch_table_thunk;
    epoxy_glGetVertexArrayPointervEXT = epoxy_glGetVertexArrayPointervEXT_dispatch_table_thunk;
    epoxy_glGetVertexArrayiv = epoxy_glGetVertexArrayiv_dispatch_table_thunk;
    epoxy_glGetVertexAttribArrayObjectfvATI = epoxy_glGetVertexAttribArrayObjectfvATI_dispatch_table_thunk;
    epoxy_glGetVertexAttribArrayObjectivATI = epoxy_glGetVertexAttribArrayObjectivATI_dispatch_table_thunk;
    epoxy_glGetVertexAttribIiv = epoxy_glGetVertexAttribIiv_dispatch_table_thunk;
    epoxy_glGetVertexAttribIivEXT = epoxy_glGetVertexAttribIivEXT_dispatch_table_thunk;
    epoxy_glGetVertexAttribIuiv = epoxy_glGetVertexAttribIuiv_dispatch_table_thunk;
    epoxy_glGetVertexAttribIuivEXT = epoxy_glGetVertexAttribIuivEXT_dispatch_table_thunk;
    epoxy_glGetVertexAttribLdv = epoxy_glGetVertexAttribLdv_dispatch_table_thunk;
    epoxy_glGetVertexAttribLdvEXT = epoxy_glGetVertexAttribLdvEXT_dispatch_table_thunk;
    epoxy_glGetVertexAttribLi64vNV = epoxy_glGetVertexAttribLi64vNV_dispatch_table_thunk;
    epoxy_glGetVertexAttribLui64vARB = epoxy_glGetVertexAttribLui64vARB_dispatch_table_thunk;
    epoxy_glGetVertexAttribLui64vNV = epoxy_glGetVertexAttribLui64vNV_dispatch_table_thunk;
    epoxy_glGetVertexAttribPointerv = epoxy_glGetVertexAttribPointerv_dispatch_table_thunk;
    epoxy_glGetVertexAttribPointervARB = epoxy_glGetVertexAttribPointervARB_dispatch_table_thunk;
    epoxy_glGetVertexAttribPointervNV = epoxy_glGetVertexAttribPointervNV_dispatch_table_thunk;
    epoxy_glGetVertexAttribdv = epoxy_glGetVertexAttribdv_dispatch_table_thunk;
    epoxy_glGetVertexAttribdvARB = epoxy_glGetVertexAttribdvARB_dispatch_table_thunk;
    epoxy_glGetVertexAttribdvNV = epoxy_glGetVertexAttribdvNV_dispatch_table_thunk;
    epoxy_glGetVertexAttribfv = epoxy_glGetVertexAttribfv_dispatch_table_thunk;
    epoxy_glGetVertexAttribfvARB = epoxy_glGetVertexAttribfvARB_dispatch_table_thunk;
    epoxy_glGetVertexAttribfvNV = epoxy_glGetVertexAttribfvNV_dispatch_table_thunk;
    epoxy_glGetVertexAttribiv = epoxy_glGetVertexAttribiv_dispatch_table_thunk;
    epoxy_glGetVertexAttribivARB = epoxy_glGetVertexAttribivARB_dispatch_table_thunk;
    epoxy_glGetVertexAttribivNV = epoxy_glGetVertexAttribivNV_dispatch_table_thunk;
    epoxy_glGetVideoCaptureStreamdvNV = epoxy_glGetVideoCaptureStreamdvNV_dispatch_table_thunk;
    epoxy_glGetVideoCaptureStreamfvNV = epoxy_glGetVideoCaptureStreamfvNV_dispatch_table_thunk;
    epoxy_glGetVideoCaptureStreamivNV = epoxy_glGetVideoCaptureStreamivNV_dispatch_table_thunk;
    epoxy_glGetVideoCaptureivNV = epoxy_glGetVideoCaptureivNV_dispatch_table_thunk;
    epoxy_glGetVideoi64vNV = epoxy_glGetVideoi64vNV_dispatch_table_thunk;
    epoxy_glGetVideoivNV = epoxy_glGetVideoivNV_dispatch_table_thunk;
    epoxy_glGetVideoui64vNV = epoxy_glGetVideoui64vNV_dispatch_table_thunk;
    epoxy_glGetVideouivNV = epoxy_glGetVideouivNV_dispatch_table_thunk;
    epoxy_glGetVkProcAddrNV = epoxy_glGetVkProcAddrNV_dispatch_table_thunk;
    epoxy_glGetnColorTable = epoxy_glGetnColorTable_dispatch_table_thunk;
    epoxy_glGetnColorTableARB = epoxy_glGetnColorTableARB_dispatch_table_thunk;
    epoxy_glGetnCompressedTexImage = epoxy_glGetnCompressedTexImage_dispatch_table_thunk;
    epoxy_glGetnCompressedTexImageARB = epoxy_glGetnCompressedTexImageARB_dispatch_table_thunk;
    epoxy_glGetnConvolutionFilter = epoxy_glGetnConvolutionFilter_dispatch_table_thunk;
    epoxy_glGetnConvolutionFilterARB = epoxy_glGetnConvolutionFilterARB_dispatch_table_thunk;
    epoxy_glGetnHistogram = epoxy_glGetnHistogram_dispatch_table_thunk;
    epoxy_glGetnHistogramARB = epoxy_glGetnHistogramARB_dispatch_table_thunk;
    epoxy_glGetnMapdv = epoxy_glGetnMapdv_dispatch_table_thunk;
    epoxy_glGetnMapdvARB = epoxy_glGetnMapdvARB_dispatch_table_thunk;
    epoxy_glGetnMapfv = epoxy_glGetnMapfv_dispatch_table_thunk;
    epoxy_glGetnMapfvARB = epoxy_glGetnMapfvARB_dispatch_table_thunk;
    epoxy_glGetnMapiv = epoxy_glGetnMapiv_dispatch_table_thunk;
    epoxy_glGetnMapivARB = epoxy_glGetnMapivARB_dispatch_table_thunk;
    epoxy_glGetnMinmax = epoxy_glGetnMinmax_dispatch_table_thunk;
    epoxy_glGetnMinmaxARB = epoxy_glGetnMinmaxARB_dispatch_table_thunk;
    epoxy_glGetnPixelMapfv = epoxy_glGetnPixelMapfv_dispatch_table_thunk;
    epoxy_glGetnPixelMapfvARB = epoxy_glGetnPixelMapfvARB_dispatch_table_thunk;
    epoxy_glGetnPixelMapuiv = epoxy_glGetnPixelMapuiv_dispatch_table_thunk;
    epoxy_glGetnPixelMapuivARB = epoxy_glGetnPixelMapuivARB_dispatch_table_thunk;
    epoxy_glGetnPixelMapusv = epoxy_glGetnPixelMapusv_dispatch_table_thunk;
    epoxy_glGetnPixelMapusvARB = epoxy_glGetnPixelMapusvARB_dispatch_table_thunk;
    epoxy_glGetnPolygonStipple = epoxy_glGetnPolygonStipple_dispatch_table_thunk;
    epoxy_glGetnPolygonStippleARB = epoxy_glGetnPolygonStippleARB_dispatch_table_thunk;
    epoxy_glGetnSeparableFilter = epoxy_glGetnSeparableFilter_dispatch_table_thunk;
    epoxy_glGetnSeparableFilterARB = epoxy_glGetnSeparableFilterARB_dispatch_table_thunk;
    epoxy_glGetnTexImage = epoxy_glGetnTexImage_dispatch_table_thunk;
    epoxy_glGetnTexImageARB = epoxy_glGetnTexImageARB_dispatch_table_thunk;
    epoxy_glGetnUniformdv = epoxy_glGetnUniformdv_dispatch_table_thunk;
    epoxy_glGetnUniformdvARB = epoxy_glGetnUniformdvARB_dispatch_table_thunk;
    epoxy_glGetnUniformfv = epoxy_glGetnUniformfv_dispatch_table_thunk;
    epoxy_glGetnUniformfvARB = epoxy_glGetnUniformfvARB_dispatch_table_thunk;
    epoxy_glGetnUniformfvEXT = epoxy_glGetnUniformfvEXT_dispatch_table_thunk;
    epoxy_glGetnUniformfvKHR = epoxy_glGetnUniformfvKHR_dispatch_table_thunk;
    epoxy_glGetnUniformi64vARB = epoxy_glGetnUniformi64vARB_dispatch_table_thunk;
    epoxy_glGetnUniformiv = epoxy_glGetnUniformiv_dispatch_table_thunk;
    epoxy_glGetnUniformivARB = epoxy_glGetnUniformivARB_dispatch_table_thunk;
    epoxy_glGetnUniformivEXT = epoxy_glGetnUniformivEXT_dispatch_table_thunk;
    epoxy_glGetnUniformivKHR = epoxy_glGetnUniformivKHR_dispatch_table_thunk;
    epoxy_glGetnUniformui64vARB = epoxy_glGetnUniformui64vARB_dispatch_table_thunk;
    epoxy_glGetnUniformuiv = epoxy_glGetnUniformuiv_dispatch_table_thunk;
    epoxy_glGetnUniformuivARB = epoxy_glGetnUniformuivARB_dispatch_table_thunk;
    epoxy_glGetnUniformuivKHR = epoxy_glGetnUniformuivKHR_dispatch_table_thunk;
    epoxy_glGlobalAlphaFactorbSUN = epoxy_glGlobalAlphaFactorbSUN_dispatch_table_thunk;
    epoxy_glGlobalAlphaFactordSUN = epoxy_glGlobalAlphaFactordSUN_dispatch_table_thunk;
    epoxy_glGlobalAlphaFactorfSUN = epoxy_glGlobalAlphaFactorfSUN_dispatch_table_thunk;
    epoxy_glGlobalAlphaFactoriSUN = epoxy_glGlobalAlphaFactoriSUN_dispatch_table_thunk;
    epoxy_glGlobalAlphaFactorsSUN = epoxy_glGlobalAlphaFactorsSUN_dispatch_table_thunk;
    epoxy_glGlobalAlphaFactorubSUN = epoxy_glGlobalAlphaFactorubSUN_dispatch_table_thunk;
    epoxy_glGlobalAlphaFactoruiSUN = epoxy_glGlobalAlphaFactoruiSUN_dispatch_table_thunk;
    epoxy_glGlobalAlphaFactorusSUN = epoxy_glGlobalAlphaFactorusSUN_dispatch_table_thunk;
    epoxy_glHint = epoxy_glHint_dispatch_table_thunk;
    epoxy_glHintPGI = epoxy_glHintPGI_dispatch_table_thunk;
    epoxy_glHistogram = epoxy_glHistogram_dispatch_table_thunk;
    epoxy_glHistogramEXT = epoxy_glHistogramEXT_dispatch_table_thunk;
    epoxy_glIglooInterfaceSGIX = epoxy_glIglooInterfaceSGIX_dispatch_table_thunk;
    epoxy_glImageTransformParameterfHP = epoxy_glImageTransformParameterfHP_dispatch_table_thunk;
    epoxy_glImageTransformParameterfvHP = epoxy_glImageTransformParameterfvHP_dispatch_table_thunk;
    epoxy_glImageTransformParameteriHP = epoxy_glImageTransformParameteriHP_dispatch_table_thunk;
    epoxy_glImageTransformParameterivHP = epoxy_glImageTransformParameterivHP_dispatch_table_thunk;
    epoxy_glImportMemoryFdEXT = epoxy_glImportMemoryFdEXT_dispatch_table_thunk;
    epoxy_glImportMemoryWin32HandleEXT = epoxy_glImportMemoryWin32HandleEXT_dispatch_table_thunk;
    epoxy_glImportMemoryWin32NameEXT = epoxy_glImportMemoryWin32NameEXT_dispatch_table_thunk;
    epoxy_glImportSemaphoreFdEXT = epoxy_glImportSemaphoreFdEXT_dispatch_table_thunk;
    epoxy_glImportSemaphoreWin32HandleEXT = epoxy_glImportSemaphoreWin32HandleEXT_dispatch_table_thunk;
    epoxy_glImportSemaphoreWin32NameEXT = epoxy_glImportSemaphoreWin32NameEXT_dispatch_table_thunk;
    epoxy_glImportSyncEXT = epoxy_glImportSyncEXT_dispatch_table_thunk;
    epoxy_glIndexFormatNV = epoxy_glIndexFormatNV_dispatch_table_thunk;
    epoxy_glIndexFuncEXT = epoxy_glIndexFuncEXT_dispatch_table_thunk;
    epoxy_glIndexMask = epoxy_glIndexMask_dispatch_table_thunk;
    epoxy_glIndexMaterialEXT = epoxy_glIndexMaterialEXT_dispatch_table_thunk;
    epoxy_glIndexPointer = epoxy_glIndexPointer_dispatch_table_thunk;
    epoxy_glIndexPointerEXT = epoxy_glIndexPointerEXT_dispatch_table_thunk;
    epoxy_glIndexPointerListIBM = epoxy_glIndexPointerListIBM_dispatch_table_thunk;
    epoxy_glIndexd = epoxy_glIndexd_dispatch_table_thunk;
    epoxy_glIndexdv = epoxy_glIndexdv_dispatch_table_thunk;
    epoxy_glIndexf = epoxy_glIndexf_dispatch_table_thunk;
    epoxy_glIndexfv = epoxy_glIndexfv_dispatch_table_thunk;
    epoxy_glIndexi = epoxy_glIndexi_dispatch_table_thunk;
    epoxy_glIndexiv = epoxy_glIndexiv_dispatch_table_thunk;
    epoxy_glIndexs = epoxy_glIndexs_dispatch_table_thunk;
    epoxy_glIndexsv = epoxy_glIndexsv_dispatch_table_thunk;
    epoxy_glIndexub = epoxy_glIndexub_dispatch_table_thunk;
    epoxy_glIndexubv = epoxy_glIndexubv_dispatch_table_thunk;
    epoxy_glIndexxOES = epoxy_glIndexxOES_dispatch_table_thunk;
    epoxy_glIndexxvOES = epoxy_glIndexxvOES_dispatch_table_thunk;
    epoxy_glInitNames = epoxy_glInitNames_dispatch_table_thunk;
    epoxy_glInsertComponentEXT = epoxy_glInsertComponentEXT_dispatch_table_thunk;
    epoxy_glInsertEventMarkerEXT = epoxy_glInsertEventMarkerEXT_dispatch_table_thunk;
    epoxy_glInstrumentsBufferSGIX = epoxy_glInstrumentsBufferSGIX_dispatch_table_thunk;
    epoxy_glInterleavedArrays = epoxy_glInterleavedArrays_dispatch_table_thunk;
    epoxy_glInterpolatePathsNV = epoxy_glInterpolatePathsNV_dispatch_table_thunk;
    epoxy_glInvalidateBufferData = epoxy_glInvalidateBufferData_dispatch_table_thunk;
    epoxy_glInvalidateBufferSubData = epoxy_glInvalidateBufferSubData_dispatch_table_thunk;
    epoxy_glInvalidateFramebuffer = epoxy_glInvalidateFramebuffer_dispatch_table_thunk;
    epoxy_glInvalidateNamedFramebufferData = epoxy_glInvalidateNamedFramebufferData_dispatch_table_thunk;
    epoxy_glInvalidateNamedFramebufferSubData = epoxy_glInvalidateNamedFramebufferSubData_dispatch_table_thunk;
    epoxy_glInvalidateSubFramebuffer = epoxy_glInvalidateSubFramebuffer_dispatch_table_thunk;
    epoxy_glInvalidateTexImage = epoxy_glInvalidateTexImage_dispatch_table_thunk;
    epoxy_glInvalidateTexSubImage = epoxy_glInvalidateTexSubImage_dispatch_table_thunk;
    epoxy_glIsAsyncMarkerSGIX = epoxy_glIsAsyncMarkerSGIX_dispatch_table_thunk;
    epoxy_glIsBuffer = epoxy_glIsBuffer_dispatch_table_thunk;
    epoxy_glIsBufferARB = epoxy_glIsBufferARB_dispatch_table_thunk;
    epoxy_glIsBufferResidentNV = epoxy_glIsBufferResidentNV_dispatch_table_thunk;
    epoxy_glIsCommandListNV = epoxy_glIsCommandListNV_dispatch_table_thunk;
    epoxy_glIsEnabled = epoxy_glIsEnabled_dispatch_table_thunk;
    epoxy_glIsEnabledIndexedEXT = epoxy_glIsEnabledIndexedEXT_dispatch_table_thunk;
    epoxy_glIsEnabledi = epoxy_glIsEnabledi_dispatch_table_thunk;
    epoxy_glIsEnablediEXT = epoxy_glIsEnablediEXT_dispatch_table_thunk;
    epoxy_glIsEnablediNV = epoxy_glIsEnablediNV_dispatch_table_thunk;
    epoxy_glIsEnablediOES = epoxy_glIsEnablediOES_dispatch_table_thunk;
    epoxy_glIsFenceAPPLE = epoxy_glIsFenceAPPLE_dispatch_table_thunk;
    epoxy_glIsFenceNV = epoxy_glIsFenceNV_dispatch_table_thunk;
    epoxy_glIsFramebuffer = epoxy_glIsFramebuffer_dispatch_table_thunk;
    epoxy_glIsFramebufferEXT = epoxy_glIsFramebufferEXT_dispatch_table_thunk;
    epoxy_glIsFramebufferOES = epoxy_glIsFramebufferOES_dispatch_table_thunk;
    epoxy_glIsImageHandleResidentARB = epoxy_glIsImageHandleResidentARB_dispatch_table_thunk;
    epoxy_glIsImageHandleResidentNV = epoxy_glIsImageHandleResidentNV_dispatch_table_thunk;
    epoxy_glIsList = epoxy_glIsList_dispatch_table_thunk;
    epoxy_glIsMemoryObjectEXT = epoxy_glIsMemoryObjectEXT_dispatch_table_thunk;
    epoxy_glIsNameAMD = epoxy_glIsNameAMD_dispatch_table_thunk;
    epoxy_glIsNamedBufferResidentNV = epoxy_glIsNamedBufferResidentNV_dispatch_table_thunk;
    epoxy_glIsNamedStringARB = epoxy_glIsNamedStringARB_dispatch_table_thunk;
    epoxy_glIsObjectBufferATI = epoxy_glIsObjectBufferATI_dispatch_table_thunk;
    epoxy_glIsOcclusionQueryNV = epoxy_glIsOcclusionQueryNV_dispatch_table_thunk;
    epoxy_glIsPathNV = epoxy_glIsPathNV_dispatch_table_thunk;
    epoxy_glIsPointInFillPathNV = epoxy_glIsPointInFillPathNV_dispatch_table_thunk;
    epoxy_glIsPointInStrokePathNV = epoxy_glIsPointInStrokePathNV_dispatch_table_thunk;
    epoxy_glIsProgram = epoxy_glIsProgram_dispatch_table_thunk;
    epoxy_glIsProgramARB = epoxy_glIsProgramARB_dispatch_table_thunk;
    epoxy_glIsProgramNV = epoxy_glIsProgramNV_dispatch_table_thunk;
    epoxy_glIsProgramPipeline = epoxy_glIsProgramPipeline_dispatch_table_thunk;
    epoxy_glIsProgramPipelineEXT = epoxy_glIsProgramPipelineEXT_dispatch_table_thunk;
    epoxy_glIsQuery = epoxy_glIsQuery_dispatch_table_thunk;
    epoxy_glIsQueryARB = epoxy_glIsQueryARB_dispatch_table_thunk;
    epoxy_glIsQueryEXT = epoxy_glIsQueryEXT_dispatch_table_thunk;
    epoxy_glIsRenderbuffer = epoxy_glIsRenderbuffer_dispatch_table_thunk;
    epoxy_glIsRenderbufferEXT = epoxy_glIsRenderbufferEXT_dispatch_table_thunk;
    epoxy_glIsRenderbufferOES = epoxy_glIsRenderbufferOES_dispatch_table_thunk;
    epoxy_glIsSampler = epoxy_glIsSampler_dispatch_table_thunk;
    epoxy_glIsSemaphoreEXT = epoxy_glIsSemaphoreEXT_dispatch_table_thunk;
    epoxy_glIsShader = epoxy_glIsShader_dispatch_table_thunk;
    epoxy_glIsStateNV = epoxy_glIsStateNV_dispatch_table_thunk;
    epoxy_glIsSync = epoxy_glIsSync_dispatch_table_thunk;
    epoxy_glIsSyncAPPLE = epoxy_glIsSyncAPPLE_dispatch_table_thunk;
    epoxy_glIsTexture = epoxy_glIsTexture_dispatch_table_thunk;
    epoxy_glIsTextureEXT = epoxy_glIsTextureEXT_dispatch_table_thunk;
    epoxy_glIsTextureHandleResidentARB = epoxy_glIsTextureHandleResidentARB_dispatch_table_thunk;
    epoxy_glIsTextureHandleResidentNV = epoxy_glIsTextureHandleResidentNV_dispatch_table_thunk;
    epoxy_glIsTransformFeedback = epoxy_glIsTransformFeedback_dispatch_table_thunk;
    epoxy_glIsTransformFeedbackNV = epoxy_glIsTransformFeedbackNV_dispatch_table_thunk;
    epoxy_glIsVariantEnabledEXT = epoxy_glIsVariantEnabledEXT_dispatch_table_thunk;
    epoxy_glIsVertexArray = epoxy_glIsVertexArray_dispatch_table_thunk;
    epoxy_glIsVertexArrayAPPLE = epoxy_glIsVertexArrayAPPLE_dispatch_table_thunk;
    epoxy_glIsVertexArrayOES = epoxy_glIsVertexArrayOES_dispatch_table_thunk;
    epoxy_glIsVertexAttribEnabledAPPLE = epoxy_glIsVertexAttribEnabledAPPLE_dispatch_table_thunk;
    epoxy_glLGPUCopyImageSubDataNVX = epoxy_glLGPUCopyImageSubDataNVX_dispatch_table_thunk;
    epoxy_glLGPUInterlockNVX = epoxy_glLGPUInterlockNVX_dispatch_table_thunk;
    epoxy_glLGPUNamedBufferSubDataNVX = epoxy_glLGPUNamedBufferSubDataNVX_dispatch_table_thunk;
    epoxy_glLabelObjectEXT = epoxy_glLabelObjectEXT_dispatch_table_thunk;
    epoxy_glLightEnviSGIX = epoxy_glLightEnviSGIX_dispatch_table_thunk;
    epoxy_glLightModelf = epoxy_glLightModelf_dispatch_table_thunk;
    epoxy_glLightModelfv = epoxy_glLightModelfv_dispatch_table_thunk;
    epoxy_glLightModeli = epoxy_glLightModeli_dispatch_table_thunk;
    epoxy_glLightModeliv = epoxy_glLightModeliv_dispatch_table_thunk;
    epoxy_glLightModelx = epoxy_glLightModelx_dispatch_table_thunk;
    epoxy_glLightModelxOES = epoxy_glLightModelxOES_dispatch_table_thunk;
    epoxy_glLightModelxv = epoxy_glLightModelxv_dispatch_table_thunk;
    epoxy_glLightModelxvOES = epoxy_glLightModelxvOES_dispatch_table_thunk;
    epoxy_glLightf = epoxy_glLightf_dispatch_table_thunk;
    epoxy_glLightfv = epoxy_glLightfv_dispatch_table_thunk;
    epoxy_glLighti = epoxy_glLighti_dispatch_table_thunk;
    epoxy_glLightiv = epoxy_glLightiv_dispatch_table_thunk;
    epoxy_glLightx = epoxy_glLightx_dispatch_table_thunk;
    epoxy_glLightxOES = epoxy_glLightxOES_dispatch_table_thunk;
    epoxy_glLightxv = epoxy_glLightxv_dispatch_table_thunk;
    epoxy_glLightxvOES = epoxy_glLightxvOES_dispatch_table_thunk;
    epoxy_glLineStipple = epoxy_glLineStipple_dispatch_table_thunk;
    epoxy_glLineWidth = epoxy_glLineWidth_dispatch_table_thunk;
    epoxy_glLineWidthx = epoxy_glLineWidthx_dispatch_table_thunk;
    epoxy_glLineWidthxOES = epoxy_glLineWidthxOES_dispatch_table_thunk;
    epoxy_glLinkProgram = epoxy_glLinkProgram_dispatch_table_thunk;
    epoxy_glLinkProgramARB = epoxy_glLinkProgramARB_dispatch_table_thunk;
    epoxy_glListBase = epoxy_glListBase_dispatch_table_thunk;
    epoxy_glListDrawCommandsStatesClientNV = epoxy_glListDrawCommandsStatesClientNV_dispatch_table_thunk;
    epoxy_glListParameterfSGIX = epoxy_glListParameterfSGIX_dispatch_table_thunk;
    epoxy_glListParameterfvSGIX = epoxy_glListParameterfvSGIX_dispatch_table_thunk;
    epoxy_glListParameteriSGIX = epoxy_glListParameteriSGIX_dispatch_table_thunk;
    epoxy_glListParameterivSGIX = epoxy_glListParameterivSGIX_dispatch_table_thunk;
    epoxy_glLoadIdentity = epoxy_glLoadIdentity_dispatch_table_thunk;
    epoxy_glLoadIdentityDeformationMapSGIX = epoxy_glLoadIdentityDeformationMapSGIX_dispatch_table_thunk;
    epoxy_glLoadMatrixd = epoxy_glLoadMatrixd_dispatch_table_thunk;
    epoxy_glLoadMatrixf = epoxy_glLoadMatrixf_dispatch_table_thunk;
    epoxy_glLoadMatrixx = epoxy_glLoadMatrixx_dispatch_table_thunk;
    epoxy_glLoadMatrixxOES = epoxy_glLoadMatrixxOES_dispatch_table_thunk;
    epoxy_glLoadName = epoxy_glLoadName_dispatch_table_thunk;
    epoxy_glLoadPaletteFromModelViewMatrixOES = epoxy_glLoadPaletteFromModelViewMatrixOES_dispatch_table_thunk;
    epoxy_glLoadProgramNV = epoxy_glLoadProgramNV_dispatch_table_thunk;
    epoxy_glLoadTransposeMatrixd = epoxy_glLoadTransposeMatrixd_dispatch_table_thunk;
    epoxy_glLoadTransposeMatrixdARB = epoxy_glLoadTransposeMatrixdARB_dispatch_table_thunk;
    epoxy_glLoadTransposeMatrixf = epoxy_glLoadTransposeMatrixf_dispatch_table_thunk;
    epoxy_glLoadTransposeMatrixfARB = epoxy_glLoadTransposeMatrixfARB_dispatch_table_thunk;
    epoxy_glLoadTransposeMatrixxOES = epoxy_glLoadTransposeMatrixxOES_dispatch_table_thunk;
    epoxy_glLockArraysEXT = epoxy_glLockArraysEXT_dispatch_table_thunk;
    epoxy_glLogicOp = epoxy_glLogicOp_dispatch_table_thunk;
    epoxy_glMakeBufferNonResidentNV = epoxy_glMakeBufferNonResidentNV_dispatch_table_thunk;
    epoxy_glMakeBufferResidentNV = epoxy_glMakeBufferResidentNV_dispatch_table_thunk;
    epoxy_glMakeImageHandleNonResidentARB = epoxy_glMakeImageHandleNonResidentARB_dispatch_table_thunk;
    epoxy_glMakeImageHandleNonResidentNV = epoxy_glMakeImageHandleNonResidentNV_dispatch_table_thunk;
    epoxy_glMakeImageHandleResidentARB = epoxy_glMakeImageHandleResidentARB_dispatch_table_thunk;
    epoxy_glMakeImageHandleResidentNV = epoxy_glMakeImageHandleResidentNV_dispatch_table_thunk;
    epoxy_glMakeNamedBufferNonResidentNV = epoxy_glMakeNamedBufferNonResidentNV_dispatch_table_thunk;
    epoxy_glMakeNamedBufferResidentNV = epoxy_glMakeNamedBufferResidentNV_dispatch_table_thunk;
    epoxy_glMakeTextureHandleNonResidentARB = epoxy_glMakeTextureHandleNonResidentARB_dispatch_table_thunk;
    epoxy_glMakeTextureHandleNonResidentNV = epoxy_glMakeTextureHandleNonResidentNV_dispatch_table_thunk;
    epoxy_glMakeTextureHandleResidentARB = epoxy_glMakeTextureHandleResidentARB_dispatch_table_thunk;
    epoxy_glMakeTextureHandleResidentNV = epoxy_glMakeTextureHandleResidentNV_dispatch_table_thunk;
    epoxy_glMap1d = epoxy_glMap1d_dispatch_table_thunk;
    epoxy_glMap1f = epoxy_glMap1f_dispatch_table_thunk;
    epoxy_glMap1xOES = epoxy_glMap1xOES_dispatch_table_thunk;
    epoxy_glMap2d = epoxy_glMap2d_dispatch_table_thunk;
    epoxy_glMap2f = epoxy_glMap2f_dispatch_table_thunk;
    epoxy_glMap2xOES = epoxy_glMap2xOES_dispatch_table_thunk;
    epoxy_glMapBuffer = epoxy_glMapBuffer_dispatch_table_thunk;
    epoxy_glMapBufferARB = epoxy_glMapBufferARB_dispatch_table_thunk;
    epoxy_glMapBufferOES = epoxy_glMapBufferOES_dispatch_table_thunk;
    epoxy_glMapBufferRange = epoxy_glMapBufferRange_dispatch_table_thunk;
    epoxy_glMapBufferRangeEXT = epoxy_glMapBufferRangeEXT_dispatch_table_thunk;
    epoxy_glMapControlPointsNV = epoxy_glMapControlPointsNV_dispatch_table_thunk;
    epoxy_glMapGrid1d = epoxy_glMapGrid1d_dispatch_table_thunk;
    epoxy_glMapGrid1f = epoxy_glMapGrid1f_dispatch_table_thunk;
    epoxy_glMapGrid1xOES = epoxy_glMapGrid1xOES_dispatch_table_thunk;
    epoxy_glMapGrid2d = epoxy_glMapGrid2d_dispatch_table_thunk;
    epoxy_glMapGrid2f = epoxy_glMapGrid2f_dispatch_table_thunk;
    epoxy_glMapGrid2xOES = epoxy_glMapGrid2xOES_dispatch_table_thunk;
    epoxy_glMapNamedBuffer = epoxy_glMapNamedBuffer_dispatch_table_thunk;
    epoxy_glMapNamedBufferEXT = epoxy_glMapNamedBufferEXT_dispatch_table_thunk;
    epoxy_glMapNamedBufferRange = epoxy_glMapNamedBufferRange_dispatch_table_thunk;
    epoxy_glMapNamedBufferRangeEXT = epoxy_glMapNamedBufferRangeEXT_dispatch_table_thunk;
    epoxy_glMapObjectBufferATI = epoxy_glMapObjectBufferATI_dispatch_table_thunk;
    epoxy_glMapParameterfvNV = epoxy_glMapParameterfvNV_dispatch_table_thunk;
    epoxy_glMapParameterivNV = epoxy_glMapParameterivNV_dispatch_table_thunk;
    epoxy_glMapTexture2DINTEL = epoxy_glMapTexture2DINTEL_dispatch_table_thunk;
    epoxy_glMapVertexAttrib1dAPPLE = epoxy_glMapVertexAttrib1dAPPLE_dispatch_table_thunk;
    epoxy_glMapVertexAttrib1fAPPLE = epoxy_glMapVertexAttrib1fAPPLE_dispatch_table_thunk;
    epoxy_glMapVertexAttrib2dAPPLE = epoxy_glMapVertexAttrib2dAPPLE_dispatch_table_thunk;
    epoxy_glMapVertexAttrib2fAPPLE = epoxy_glMapVertexAttrib2fAPPLE_dispatch_table_thunk;
    epoxy_glMaterialf = epoxy_glMaterialf_dispatch_table_thunk;
    epoxy_glMaterialfv = epoxy_glMaterialfv_dispatch_table_thunk;
    epoxy_glMateriali = epoxy_glMateriali_dispatch_table_thunk;
    epoxy_glMaterialiv = epoxy_glMaterialiv_dispatch_table_thunk;
    epoxy_glMaterialx = epoxy_glMaterialx_dispatch_table_thunk;
    epoxy_glMaterialxOES = epoxy_glMaterialxOES_dispatch_table_thunk;
    epoxy_glMaterialxv = epoxy_glMaterialxv_dispatch_table_thunk;
    epoxy_glMaterialxvOES = epoxy_glMaterialxvOES_dispatch_table_thunk;
    epoxy_glMatrixFrustumEXT = epoxy_glMatrixFrustumEXT_dispatch_table_thunk;
    epoxy_glMatrixIndexPointerARB = epoxy_glMatrixIndexPointerARB_dispatch_table_thunk;
    epoxy_glMatrixIndexPointerOES = epoxy_glMatrixIndexPointerOES_dispatch_table_thunk;
    epoxy_glMatrixIndexubvARB = epoxy_glMatrixIndexubvARB_dispatch_table_thunk;
    epoxy_glMatrixIndexuivARB = epoxy_glMatrixIndexuivARB_dispatch_table_thunk;
    epoxy_glMatrixIndexusvARB = epoxy_glMatrixIndexusvARB_dispatch_table_thunk;
    epoxy_glMatrixLoad3x2fNV = epoxy_glMatrixLoad3x2fNV_dispatch_table_thunk;
    epoxy_glMatrixLoad3x3fNV = epoxy_glMatrixLoad3x3fNV_dispatch_table_thunk;
    epoxy_glMatrixLoadIdentityEXT = epoxy_glMatrixLoadIdentityEXT_dispatch_table_thunk;
    epoxy_glMatrixLoadTranspose3x3fNV = epoxy_glMatrixLoadTranspose3x3fNV_dispatch_table_thunk;
    epoxy_glMatrixLoadTransposedEXT = epoxy_glMatrixLoadTransposedEXT_dispatch_table_thunk;
    epoxy_glMatrixLoadTransposefEXT = epoxy_glMatrixLoadTransposefEXT_dispatch_table_thunk;
    epoxy_glMatrixLoaddEXT = epoxy_glMatrixLoaddEXT_dispatch_table_thunk;
    epoxy_glMatrixLoadfEXT = epoxy_glMatrixLoadfEXT_dispatch_table_thunk;
    epoxy_glMatrixMode = epoxy_glMatrixMode_dispatch_table_thunk;
    epoxy_glMatrixMult3x2fNV = epoxy_glMatrixMult3x2fNV_dispatch_table_thunk;
    epoxy_glMatrixMult3x3fNV = epoxy_glMatrixMult3x3fNV_dispatch_table_thunk;
    epoxy_glMatrixMultTranspose3x3fNV = epoxy_glMatrixMultTranspose3x3fNV_dispatch_table_thunk;
    epoxy_glMatrixMultTransposedEXT = epoxy_glMatrixMultTransposedEXT_dispatch_table_thunk;
    epoxy_glMatrixMultTransposefEXT = epoxy_glMatrixMultTransposefEXT_dispatch_table_thunk;
    epoxy_glMatrixMultdEXT = epoxy_glMatrixMultdEXT_dispatch_table_thunk;
    epoxy_glMatrixMultfEXT = epoxy_glMatrixMultfEXT_dispatch_table_thunk;
    epoxy_glMatrixOrthoEXT = epoxy_glMatrixOrthoEXT_dispatch_table_thunk;
    epoxy_glMatrixPopEXT = epoxy_glMatrixPopEXT_dispatch_table_thunk;
    epoxy_glMatrixPushEXT = epoxy_glMatrixPushEXT_dispatch_table_thunk;
    epoxy_glMatrixRotatedEXT = epoxy_glMatrixRotatedEXT_dispatch_table_thunk;
    epoxy_glMatrixRotatefEXT = epoxy_glMatrixRotatefEXT_dispatch_table_thunk;
    epoxy_glMatrixScaledEXT = epoxy_glMatrixScaledEXT_dispatch_table_thunk;
    epoxy_glMatrixScalefEXT = epoxy_glMatrixScalefEXT_dispatch_table_thunk;
    epoxy_glMatrixTranslatedEXT = epoxy_glMatrixTranslatedEXT_dispatch_table_thunk;
    epoxy_glMatrixTranslatefEXT = epoxy_glMatrixTranslatefEXT_dispatch_table_thunk;
    epoxy_glMaxShaderCompilerThreadsARB = epoxy_glMaxShaderCompilerThreadsARB_dispatch_table_thunk;
    epoxy_glMaxShaderCompilerThreadsKHR = epoxy_glMaxShaderCompilerThreadsKHR_dispatch_table_thunk;
    epoxy_glMemoryBarrier = epoxy_glMemoryBarrier_dispatch_table_thunk;
    epoxy_glMemoryBarrierByRegion = epoxy_glMemoryBarrierByRegion_dispatch_table_thunk;
    epoxy_glMemoryBarrierEXT = epoxy_glMemoryBarrierEXT_dispatch_table_thunk;
    epoxy_glMemoryObjectParameterivEXT = epoxy_glMemoryObjectParameterivEXT_dispatch_table_thunk;
    epoxy_glMinSampleShading = epoxy_glMinSampleShading_dispatch_table_thunk;
    epoxy_glMinSampleShadingARB = epoxy_glMinSampleShadingARB_dispatch_table_thunk;
    epoxy_glMinSampleShadingOES = epoxy_glMinSampleShadingOES_dispatch_table_thunk;
    epoxy_glMinmax = epoxy_glMinmax_dispatch_table_thunk;
    epoxy_glMinmaxEXT = epoxy_glMinmaxEXT_dispatch_table_thunk;
    epoxy_glMultMatrixd = epoxy_glMultMatrixd_dispatch_table_thunk;
    epoxy_glMultMatrixf = epoxy_glMultMatrixf_dispatch_table_thunk;
    epoxy_glMultMatrixx = epoxy_glMultMatrixx_dispatch_table_thunk;
    epoxy_glMultMatrixxOES = epoxy_glMultMatrixxOES_dispatch_table_thunk;
    epoxy_glMultTransposeMatrixd = epoxy_glMultTransposeMatrixd_dispatch_table_thunk;
    epoxy_glMultTransposeMatrixdARB = epoxy_glMultTransposeMatrixdARB_dispatch_table_thunk;
    epoxy_glMultTransposeMatrixf = epoxy_glMultTransposeMatrixf_dispatch_table_thunk;
    epoxy_glMultTransposeMatrixfARB = epoxy_glMultTransposeMatrixfARB_dispatch_table_thunk;
    epoxy_glMultTransposeMatrixxOES = epoxy_glMultTransposeMatrixxOES_dispatch_table_thunk;
    epoxy_glMultiDrawArrays = epoxy_glMultiDrawArrays_dispatch_table_thunk;
    epoxy_glMultiDrawArraysEXT = epoxy_glMultiDrawArraysEXT_dispatch_table_thunk;
    epoxy_glMultiDrawArraysIndirect = epoxy_glMultiDrawArraysIndirect_dispatch_table_thunk;
    epoxy_glMultiDrawArraysIndirectAMD = epoxy_glMultiDrawArraysIndirectAMD_dispatch_table_thunk;
    epoxy_glMultiDrawArraysIndirectBindlessCountNV = epoxy_glMultiDrawArraysIndirectBindlessCountNV_dispatch_table_thunk;
    epoxy_glMultiDrawArraysIndirectBindlessNV = epoxy_glMultiDrawArraysIndirectBindlessNV_dispatch_table_thunk;
    epoxy_glMultiDrawArraysIndirectCount = epoxy_glMultiDrawArraysIndirectCount_dispatch_table_thunk;
    epoxy_glMultiDrawArraysIndirectCountARB = epoxy_glMultiDrawArraysIndirectCountARB_dispatch_table_thunk;
    epoxy_glMultiDrawArraysIndirectEXT = epoxy_glMultiDrawArraysIndirectEXT_dispatch_table_thunk;
    epoxy_glMultiDrawElementArrayAPPLE = epoxy_glMultiDrawElementArrayAPPLE_dispatch_table_thunk;
    epoxy_glMultiDrawElements = epoxy_glMultiDrawElements_dispatch_table_thunk;
    epoxy_glMultiDrawElementsBaseVertex = epoxy_glMultiDrawElementsBaseVertex_dispatch_table_thunk;
    epoxy_glMultiDrawElementsBaseVertexEXT = epoxy_glMultiDrawElementsBaseVertexEXT_dispatch_table_thunk;
    epoxy_glMultiDrawElementsEXT = epoxy_glMultiDrawElementsEXT_dispatch_table_thunk;
    epoxy_glMultiDrawElementsIndirect = epoxy_glMultiDrawElementsIndirect_dispatch_table_thunk;
    epoxy_glMultiDrawElementsIndirectAMD = epoxy_glMultiDrawElementsIndirectAMD_dispatch_table_thunk;
    epoxy_glMultiDrawElementsIndirectBindlessCountNV = epoxy_glMultiDrawElementsIndirectBindlessCountNV_dispatch_table_thunk;
    epoxy_glMultiDrawElementsIndirectBindlessNV = epoxy_glMultiDrawElementsIndirectBindlessNV_dispatch_table_thunk;
    epoxy_glMultiDrawElementsIndirectCount = epoxy_glMultiDrawElementsIndirectCount_dispatch_table_thunk;
    epoxy_glMultiDrawElementsIndirectCountARB = epoxy_glMultiDrawElementsIndirectCountARB_dispatch_table_thunk;
    epoxy_glMultiDrawElementsIndirectEXT = epoxy_glMultiDrawElementsIndirectEXT_dispatch_table_thunk;
    epoxy_glMultiDrawMeshTasksIndirectCountNV = epoxy_glMultiDrawMeshTasksIndirectCountNV_dispatch_table_thunk;
    epoxy_glMultiDrawMeshTasksIndirectNV = epoxy_glMultiDrawMeshTasksIndirectNV_dispatch_table_thunk;
    epoxy_glMultiDrawRangeElementArrayAPPLE = epoxy_glMultiDrawRangeElementArrayAPPLE_dispatch_table_thunk;
    epoxy_glMultiModeDrawArraysIBM = epoxy_glMultiModeDrawArraysIBM_dispatch_table_thunk;
    epoxy_glMultiModeDrawElementsIBM = epoxy_glMultiModeDrawElementsIBM_dispatch_table_thunk;
    epoxy_glMultiTexBufferEXT = epoxy_glMultiTexBufferEXT_dispatch_table_thunk;
    epoxy_glMultiTexCoord1bOES = epoxy_glMultiTexCoord1bOES_dispatch_table_thunk;
    epoxy_glMultiTexCoord1bvOES = epoxy_glMultiTexCoord1bvOES_dispatch_table_thunk;
    epoxy_glMultiTexCoord1d = epoxy_glMultiTexCoord1d_dispatch_table_thunk;
    epoxy_glMultiTexCoord1dARB = epoxy_glMultiTexCoord1dARB_dispatch_table_thunk;
    epoxy_glMultiTexCoord1dv = epoxy_glMultiTexCoord1dv_dispatch_table_thunk;
    epoxy_glMultiTexCoord1dvARB = epoxy_glMultiTexCoord1dvARB_dispatch_table_thunk;
    epoxy_glMultiTexCoord1f = epoxy_glMultiTexCoord1f_dispatch_table_thunk;
    epoxy_glMultiTexCoord1fARB = epoxy_glMultiTexCoord1fARB_dispatch_table_thunk;
    epoxy_glMultiTexCoord1fv = epoxy_glMultiTexCoord1fv_dispatch_table_thunk;
    epoxy_glMultiTexCoord1fvARB = epoxy_glMultiTexCoord1fvARB_dispatch_table_thunk;
    epoxy_glMultiTexCoord1hNV = epoxy_glMultiTexCoord1hNV_dispatch_table_thunk;
    epoxy_glMultiTexCoord1hvNV = epoxy_glMultiTexCoord1hvNV_dispatch_table_thunk;
    epoxy_glMultiTexCoord1i = epoxy_glMultiTexCoord1i_dispatch_table_thunk;
    epoxy_glMultiTexCoord1iARB = epoxy_glMultiTexCoord1iARB_dispatch_table_thunk;
    epoxy_glMultiTexCoord1iv = epoxy_glMultiTexCoord1iv_dispatch_table_thunk;
    epoxy_glMultiTexCoord1ivARB = epoxy_glMultiTexCoord1ivARB_dispatch_table_thunk;
    epoxy_glMultiTexCoord1s = epoxy_glMultiTexCoord1s_dispatch_table_thunk;
    epoxy_glMultiTexCoord1sARB = epoxy_glMultiTexCoord1sARB_dispatch_table_thunk;
    epoxy_glMultiTexCoord1sv = epoxy_glMultiTexCoord1sv_dispatch_table_thunk;
    epoxy_glMultiTexCoord1svARB = epoxy_glMultiTexCoord1svARB_dispatch_table_thunk;
    epoxy_glMultiTexCoord1xOES = epoxy_glMultiTexCoord1xOES_dispatch_table_thunk;
    epoxy_glMultiTexCoord1xvOES = epoxy_glMultiTexCoord1xvOES_dispatch_table_thunk;
    epoxy_glMultiTexCoord2bOES = epoxy_glMultiTexCoord2bOES_dispatch_table_thunk;
    epoxy_glMultiTexCoord2bvOES = epoxy_glMultiTexCoord2bvOES_dispatch_table_thunk;
    epoxy_glMultiTexCoord2d = epoxy_glMultiTexCoord2d_dispatch_table_thunk;
    epoxy_glMultiTexCoord2dARB = epoxy_glMultiTexCoord2dARB_dispatch_table_thunk;
    epoxy_glMultiTexCoord2dv = epoxy_glMultiTexCoord2dv_dispatch_table_thunk;
    epoxy_glMultiTexCoord2dvARB = epoxy_glMultiTexCoord2dvARB_dispatch_table_thunk;
    epoxy_glMultiTexCoord2f = epoxy_glMultiTexCoord2f_dispatch_table_thunk;
    epoxy_glMultiTexCoord2fARB = epoxy_glMultiTexCoord2fARB_dispatch_table_thunk;
    epoxy_glMultiTexCoord2fv = epoxy_glMultiTexCoord2fv_dispatch_table_thunk;
    epoxy_glMultiTexCoord2fvARB = epoxy_glMultiTexCoord2fvARB_dispatch_table_thunk;
    epoxy_glMultiTexCoord2hNV = epoxy_glMultiTexCoord2hNV_dispatch_table_thunk;
    epoxy_glMultiTexCoord2hvNV = epoxy_glMultiTexCoord2hvNV_dispatch_table_thunk;
    epoxy_glMultiTexCoord2i = epoxy_glMultiTexCoord2i_dispatch_table_thunk;
    epoxy_glMultiTexCoord2iARB = epoxy_glMultiTexCoord2iARB_dispatch_table_thunk;
    epoxy_glMultiTexCoord2iv = epoxy_glMultiTexCoord2iv_dispatch_table_thunk;
    epoxy_glMultiTexCoord2ivARB = epoxy_glMultiTexCoord2ivARB_dispatch_table_thunk;
    epoxy_glMultiTexCoord2s = epoxy_glMultiTexCoord2s_dispatch_table_thunk;
    epoxy_glMultiTexCoord2sARB = epoxy_glMultiTexCoord2sARB_dispatch_table_thunk;
    epoxy_glMultiTexCoord2sv = epoxy_glMultiTexCoord2sv_dispatch_table_thunk;
    epoxy_glMultiTexCoord2svARB = epoxy_glMultiTexCoord2svARB_dispatch_table_thunk;
    epoxy_glMultiTexCoord2xOES = epoxy_glMultiTexCoord2xOES_dispatch_table_thunk;
    epoxy_glMultiTexCoord2xvOES = epoxy_glMultiTexCoord2xvOES_dispatch_table_thunk;
    epoxy_glMultiTexCoord3bOES = epoxy_glMultiTexCoord3bOES_dispatch_table_thunk;
    epoxy_glMultiTexCoord3bvOES = epoxy_glMultiTexCoord3bvOES_dispatch_table_thunk;
    epoxy_glMultiTexCoord3d = epoxy_glMultiTexCoord3d_dispatch_table_thunk;
    epoxy_glMultiTexCoord3dARB = epoxy_glMultiTexCoord3dARB_dispatch_table_thunk;
    epoxy_glMultiTexCoord3dv = epoxy_glMultiTexCoord3dv_dispatch_table_thunk;
    epoxy_glMultiTexCoord3dvARB = epoxy_glMultiTexCoord3dvARB_dispatch_table_thunk;
    epoxy_glMultiTexCoord3f = epoxy_glMultiTexCoord3f_dispatch_table_thunk;
    epoxy_glMultiTexCoord3fARB = epoxy_glMultiTexCoord3fARB_dispatch_table_thunk;
    epoxy_glMultiTexCoord3fv = epoxy_glMultiTexCoord3fv_dispatch_table_thunk;
    epoxy_glMultiTexCoord3fvARB = epoxy_glMultiTexCoord3fvARB_dispatch_table_thunk;
    epoxy_glMultiTexCoord3hNV = epoxy_glMultiTexCoord3hNV_dispatch_table_thunk;
    epoxy_glMultiTexCoord3hvNV = epoxy_glMultiTexCoord3hvNV_dispatch_table_thunk;
    epoxy_glMultiTexCoord3i = epoxy_glMultiTexCoord3i_dispatch_table_thunk;
    epoxy_glMultiTexCoord3iARB = epoxy_glMultiTexCoord3iARB_dispatch_table_thunk;
    epoxy_glMultiTexCoord3iv = epoxy_glMultiTexCoord3iv_dispatch_table_thunk;
    epoxy_glMultiTexCoord3ivARB = epoxy_glMultiTexCoord3ivARB_dispatch_table_thunk;
    epoxy_glMultiTexCoord3s = epoxy_glMultiTexCoord3s_dispatch_table_thunk;
    epoxy_glMultiTexCoord3sARB = epoxy_glMultiTexCoord3sARB_dispatch_table_thunk;
    epoxy_glMultiTexCoord3sv = epoxy_glMultiTexCoord3sv_dispatch_table_thunk;
    epoxy_glMultiTexCoord3svARB = epoxy_glMultiTexCoord3svARB_dispatch_table_thunk;
    epoxy_glMultiTexCoord3xOES = epoxy_glMultiTexCoord3xOES_dispatch_table_thunk;
    epoxy_glMultiTexCoord3xvOES = epoxy_glMultiTexCoord3xvOES_dispatch_table_thunk;
    epoxy_glMultiTexCoord4bOES = epoxy_glMultiTexCoord4bOES_dispatch_table_thunk;
    epoxy_glMultiTexCoord4bvOES = epoxy_glMultiTexCoord4bvOES_dispatch_table_thunk;
    epoxy_glMultiTexCoord4d = epoxy_glMultiTexCoord4d_dispatch_table_thunk;
    epoxy_glMultiTexCoord4dARB = epoxy_glMultiTexCoord4dARB_dispatch_table_thunk;
    epoxy_glMultiTexCoord4dv = epoxy_glMultiTexCoord4dv_dispatch_table_thunk;
    epoxy_glMultiTexCoord4dvARB = epoxy_glMultiTexCoord4dvARB_dispatch_table_thunk;
    epoxy_glMultiTexCoord4f = epoxy_glMultiTexCoord4f_dispatch_table_thunk;
    epoxy_glMultiTexCoord4fARB = epoxy_glMultiTexCoord4fARB_dispatch_table_thunk;
    epoxy_glMultiTexCoord4fv = epoxy_glMultiTexCoord4fv_dispatch_table_thunk;
    epoxy_glMultiTexCoord4fvARB = epoxy_glMultiTexCoord4fvARB_dispatch_table_thunk;
    epoxy_glMultiTexCoord4hNV = epoxy_glMultiTexCoord4hNV_dispatch_table_thunk;
    epoxy_glMultiTexCoord4hvNV = epoxy_glMultiTexCoord4hvNV_dispatch_table_thunk;
    epoxy_glMultiTexCoord4i = epoxy_glMultiTexCoord4i_dispatch_table_thunk;
    epoxy_glMultiTexCoord4iARB = epoxy_glMultiTexCoord4iARB_dispatch_table_thunk;
    epoxy_glMultiTexCoord4iv = epoxy_glMultiTexCoord4iv_dispatch_table_thunk;
    epoxy_glMultiTexCoord4ivARB = epoxy_glMultiTexCoord4ivARB_dispatch_table_thunk;
    epoxy_glMultiTexCoord4s = epoxy_glMultiTexCoord4s_dispatch_table_thunk;
    epoxy_glMultiTexCoord4sARB = epoxy_glMultiTexCoord4sARB_dispatch_table_thunk;
    epoxy_glMultiTexCoord4sv = epoxy_glMultiTexCoord4sv_dispatch_table_thunk;
    epoxy_glMultiTexCoord4svARB = epoxy_glMultiTexCoord4svARB_dispatch_table_thunk;
    epoxy_glMultiTexCoord4x = epoxy_glMultiTexCoord4x_dispatch_table_thunk;
    epoxy_glMultiTexCoord4xOES = epoxy_glMultiTexCoord4xOES_dispatch_table_thunk;
    epoxy_glMultiTexCoord4xvOES = epoxy_glMultiTexCoord4xvOES_dispatch_table_thunk;
    epoxy_glMultiTexCoordP1ui = epoxy_glMultiTexCoordP1ui_dispatch_table_thunk;
    epoxy_glMultiTexCoordP1uiv = epoxy_glMultiTexCoordP1uiv_dispatch_table_thunk;
    epoxy_glMultiTexCoordP2ui = epoxy_glMultiTexCoordP2ui_dispatch_table_thunk;
    epoxy_glMultiTexCoordP2uiv = epoxy_glMultiTexCoordP2uiv_dispatch_table_thunk;
    epoxy_glMultiTexCoordP3ui = epoxy_glMultiTexCoordP3ui_dispatch_table_thunk;
    epoxy_glMultiTexCoordP3uiv = epoxy_glMultiTexCoordP3uiv_dispatch_table_thunk;
    epoxy_glMultiTexCoordP4ui = epoxy_glMultiTexCoordP4ui_dispatch_table_thunk;
    epoxy_glMultiTexCoordP4uiv = epoxy_glMultiTexCoordP4uiv_dispatch_table_thunk;
    epoxy_glMultiTexCoordPointerEXT = epoxy_glMultiTexCoordPointerEXT_dispatch_table_thunk;
    epoxy_glMultiTexEnvfEXT = epoxy_glMultiTexEnvfEXT_dispatch_table_thunk;
    epoxy_glMultiTexEnvfvEXT = epoxy_glMultiTexEnvfvEXT_dispatch_table_thunk;
    epoxy_glMultiTexEnviEXT = epoxy_glMultiTexEnviEXT_dispatch_table_thunk;
    epoxy_glMultiTexEnvivEXT = epoxy_glMultiTexEnvivEXT_dispatch_table_thunk;
    epoxy_glMultiTexGendEXT = epoxy_glMultiTexGendEXT_dispatch_table_thunk;
    epoxy_glMultiTexGendvEXT = epoxy_glMultiTexGendvEXT_dispatch_table_thunk;
    epoxy_glMultiTexGenfEXT = epoxy_glMultiTexGenfEXT_dispatch_table_thunk;
    epoxy_glMultiTexGenfvEXT = epoxy_glMultiTexGenfvEXT_dispatch_table_thunk;
    epoxy_glMultiTexGeniEXT = epoxy_glMultiTexGeniEXT_dispatch_table_thunk;
    epoxy_glMultiTexGenivEXT = epoxy_glMultiTexGenivEXT_dispatch_table_thunk;
    epoxy_glMultiTexImage1DEXT = epoxy_glMultiTexImage1DEXT_dispatch_table_thunk;
    epoxy_glMultiTexImage2DEXT = epoxy_glMultiTexImage2DEXT_dispatch_table_thunk;
    epoxy_glMultiTexImage3DEXT = epoxy_glMultiTexImage3DEXT_dispatch_table_thunk;
    epoxy_glMultiTexParameterIivEXT = epoxy_glMultiTexParameterIivEXT_dispatch_table_thunk;
    epoxy_glMultiTexParameterIuivEXT = epoxy_glMultiTexParameterIuivEXT_dispatch_table_thunk;
    epoxy_glMultiTexParameterfEXT = epoxy_glMultiTexParameterfEXT_dispatch_table_thunk;
    epoxy_glMultiTexParameterfvEXT = epoxy_glMultiTexParameterfvEXT_dispatch_table_thunk;
    epoxy_glMultiTexParameteriEXT = epoxy_glMultiTexParameteriEXT_dispatch_table_thunk;
    epoxy_glMultiTexParameterivEXT = epoxy_glMultiTexParameterivEXT_dispatch_table_thunk;
    epoxy_glMultiTexRenderbufferEXT = epoxy_glMultiTexRenderbufferEXT_dispatch_table_thunk;
    epoxy_glMultiTexSubImage1DEXT = epoxy_glMultiTexSubImage1DEXT_dispatch_table_thunk;
    epoxy_glMultiTexSubImage2DEXT = epoxy_glMultiTexSubImage2DEXT_dispatch_table_thunk;
    epoxy_glMultiTexSubImage3DEXT = epoxy_glMultiTexSubImage3DEXT_dispatch_table_thunk;
    epoxy_glMulticastBarrierNV = epoxy_glMulticastBarrierNV_dispatch_table_thunk;
    epoxy_glMulticastBlitFramebufferNV = epoxy_glMulticastBlitFramebufferNV_dispatch_table_thunk;
    epoxy_glMulticastBufferSubDataNV = epoxy_glMulticastBufferSubDataNV_dispatch_table_thunk;
    epoxy_glMulticastCopyBufferSubDataNV = epoxy_glMulticastCopyBufferSubDataNV_dispatch_table_thunk;
    epoxy_glMulticastCopyImageSubDataNV = epoxy_glMulticastCopyImageSubDataNV_dispatch_table_thunk;
    epoxy_glMulticastFramebufferSampleLocationsfvNV = epoxy_glMulticastFramebufferSampleLocationsfvNV_dispatch_table_thunk;
    epoxy_glMulticastGetQueryObjecti64vNV = epoxy_glMulticastGetQueryObjecti64vNV_dispatch_table_thunk;
    epoxy_glMulticastGetQueryObjectivNV = epoxy_glMulticastGetQueryObjectivNV_dispatch_table_thunk;
    epoxy_glMulticastGetQueryObjectui64vNV = epoxy_glMulticastGetQueryObjectui64vNV_dispatch_table_thunk;
    epoxy_glMulticastGetQueryObjectuivNV = epoxy_glMulticastGetQueryObjectuivNV_dispatch_table_thunk;
    epoxy_glMulticastScissorArrayvNVX = epoxy_glMulticastScissorArrayvNVX_dispatch_table_thunk;
    epoxy_glMulticastViewportArrayvNVX = epoxy_glMulticastViewportArrayvNVX_dispatch_table_thunk;
    epoxy_glMulticastViewportPositionWScaleNVX = epoxy_glMulticastViewportPositionWScaleNVX_dispatch_table_thunk;
    epoxy_glMulticastWaitSyncNV = epoxy_glMulticastWaitSyncNV_dispatch_table_thunk;
    epoxy_glNamedBufferAttachMemoryNV = epoxy_glNamedBufferAttachMemoryNV_dispatch_table_thunk;
    epoxy_glNamedBufferData = epoxy_glNamedBufferData_dispatch_table_thunk;
    epoxy_glNamedBufferDataEXT = epoxy_glNamedBufferDataEXT_dispatch_table_thunk;
    epoxy_glNamedBufferPageCommitmentARB = epoxy_glNamedBufferPageCommitmentARB_dispatch_table_thunk;
    epoxy_glNamedBufferPageCommitmentEXT = epoxy_glNamedBufferPageCommitmentEXT_dispatch_table_thunk;
    epoxy_glNamedBufferStorage = epoxy_glNamedBufferStorage_dispatch_table_thunk;
    epoxy_glNamedBufferStorageEXT = epoxy_glNamedBufferStorageEXT_dispatch_table_thunk;
    epoxy_glNamedBufferStorageExternalEXT = epoxy_glNamedBufferStorageExternalEXT_dispatch_table_thunk;
    epoxy_glNamedBufferStorageMemEXT = epoxy_glNamedBufferStorageMemEXT_dispatch_table_thunk;
    epoxy_glNamedBufferSubData = epoxy_glNamedBufferSubData_dispatch_table_thunk;
    epoxy_glNamedBufferSubDataEXT = epoxy_glNamedBufferSubDataEXT_dispatch_table_thunk;
    epoxy_glNamedCopyBufferSubDataEXT = epoxy_glNamedCopyBufferSubDataEXT_dispatch_table_thunk;
    epoxy_glNamedFramebufferDrawBuffer = epoxy_glNamedFramebufferDrawBuffer_dispatch_table_thunk;
    epoxy_glNamedFramebufferDrawBuffers = epoxy_glNamedFramebufferDrawBuffers_dispatch_table_thunk;
    epoxy_glNamedFramebufferParameteri = epoxy_glNamedFramebufferParameteri_dispatch_table_thunk;
    epoxy_glNamedFramebufferParameteriEXT = epoxy_glNamedFramebufferParameteriEXT_dispatch_table_thunk;
    epoxy_glNamedFramebufferReadBuffer = epoxy_glNamedFramebufferReadBuffer_dispatch_table_thunk;
    epoxy_glNamedFramebufferRenderbuffer = epoxy_glNamedFramebufferRenderbuffer_dispatch_table_thunk;
    epoxy_glNamedFramebufferRenderbufferEXT = epoxy_glNamedFramebufferRenderbufferEXT_dispatch_table_thunk;
    epoxy_glNamedFramebufferSampleLocationsfvARB = epoxy_glNamedFramebufferSampleLocationsfvARB_dispatch_table_thunk;
    epoxy_glNamedFramebufferSampleLocationsfvNV = epoxy_glNamedFramebufferSampleLocationsfvNV_dispatch_table_thunk;
    epoxy_glNamedFramebufferSamplePositionsfvAMD = epoxy_glNamedFramebufferSamplePositionsfvAMD_dispatch_table_thunk;
    epoxy_glNamedFramebufferTexture = epoxy_glNamedFramebufferTexture_dispatch_table_thunk;
    epoxy_glNamedFramebufferTexture1DEXT = epoxy_glNamedFramebufferTexture1DEXT_dispatch_table_thunk;
    epoxy_glNamedFramebufferTexture2DEXT = epoxy_glNamedFramebufferTexture2DEXT_dispatch_table_thunk;
    epoxy_glNamedFramebufferTexture3DEXT = epoxy_glNamedFramebufferTexture3DEXT_dispatch_table_thunk;
    epoxy_glNamedFramebufferTextureEXT = epoxy_glNamedFramebufferTextureEXT_dispatch_table_thunk;
    epoxy_glNamedFramebufferTextureFaceEXT = epoxy_glNamedFramebufferTextureFaceEXT_dispatch_table_thunk;
    epoxy_glNamedFramebufferTextureLayer = epoxy_glNamedFramebufferTextureLayer_dispatch_table_thunk;
    epoxy_glNamedFramebufferTextureLayerEXT = epoxy_glNamedFramebufferTextureLayerEXT_dispatch_table_thunk;
    epoxy_glNamedProgramLocalParameter4dEXT = epoxy_glNamedProgramLocalParameter4dEXT_dispatch_table_thunk;
    epoxy_glNamedProgramLocalParameter4dvEXT = epoxy_glNamedProgramLocalParameter4dvEXT_dispatch_table_thunk;
    epoxy_glNamedProgramLocalParameter4fEXT = epoxy_glNamedProgramLocalParameter4fEXT_dispatch_table_thunk;
    epoxy_glNamedProgramLocalParameter4fvEXT = epoxy_glNamedProgramLocalParameter4fvEXT_dispatch_table_thunk;
    epoxy_glNamedProgramLocalParameterI4iEXT = epoxy_glNamedProgramLocalParameterI4iEXT_dispatch_table_thunk;
    epoxy_glNamedProgramLocalParameterI4ivEXT = epoxy_glNamedProgramLocalParameterI4ivEXT_dispatch_table_thunk;
    epoxy_glNamedProgramLocalParameterI4uiEXT = epoxy_glNamedProgramLocalParameterI4uiEXT_dispatch_table_thunk;
    epoxy_glNamedProgramLocalParameterI4uivEXT = epoxy_glNamedProgramLocalParameterI4uivEXT_dispatch_table_thunk;
    epoxy_glNamedProgramLocalParameters4fvEXT = epoxy_glNamedProgramLocalParameters4fvEXT_dispatch_table_thunk;
    epoxy_glNamedProgramLocalParametersI4ivEXT = epoxy_glNamedProgramLocalParametersI4ivEXT_dispatch_table_thunk;
    epoxy_glNamedProgramLocalParametersI4uivEXT = epoxy_glNamedProgramLocalParametersI4uivEXT_dispatch_table_thunk;
    epoxy_glNamedProgramStringEXT = epoxy_glNamedProgramStringEXT_dispatch_table_thunk;
    epoxy_glNamedRenderbufferStorage = epoxy_glNamedRenderbufferStorage_dispatch_table_thunk;
    epoxy_glNamedRenderbufferStorageEXT = epoxy_glNamedRenderbufferStorageEXT_dispatch_table_thunk;
    epoxy_glNamedRenderbufferStorageMultisample = epoxy_glNamedRenderbufferStorageMultisample_dispatch_table_thunk;
    epoxy_glNamedRenderbufferStorageMultisampleAdvancedAMD = epoxy_glNamedRenderbufferStorageMultisampleAdvancedAMD_dispatch_table_thunk;
    epoxy_glNamedRenderbufferStorageMultisampleCoverageEXT = epoxy_glNamedRenderbufferStorageMultisampleCoverageEXT_dispatch_table_thunk;
    epoxy_glNamedRenderbufferStorageMultisampleEXT = epoxy_glNamedRenderbufferStorageMultisampleEXT_dispatch_table_thunk;
    epoxy_glNamedStringARB = epoxy_glNamedStringARB_dispatch_table_thunk;
    epoxy_glNewList = epoxy_glNewList_dispatch_table_thunk;
    epoxy_glNewObjectBufferATI = epoxy_glNewObjectBufferATI_dispatch_table_thunk;
    epoxy_glNormal3b = epoxy_glNormal3b_dispatch_table_thunk;
    epoxy_glNormal3bv = epoxy_glNormal3bv_dispatch_table_thunk;
    epoxy_glNormal3d = epoxy_glNormal3d_dispatch_table_thunk;
    epoxy_glNormal3dv = epoxy_glNormal3dv_dispatch_table_thunk;
    epoxy_glNormal3f = epoxy_glNormal3f_dispatch_table_thunk;
    epoxy_glNormal3fVertex3fSUN = epoxy_glNormal3fVertex3fSUN_dispatch_table_thunk;
    epoxy_glNormal3fVertex3fvSUN = epoxy_glNormal3fVertex3fvSUN_dispatch_table_thunk;
    epoxy_glNormal3fv = epoxy_glNormal3fv_dispatch_table_thunk;
    epoxy_glNormal3hNV = epoxy_glNormal3hNV_dispatch_table_thunk;
    epoxy_glNormal3hvNV = epoxy_glNormal3hvNV_dispatch_table_thunk;
    epoxy_glNormal3i = epoxy_glNormal3i_dispatch_table_thunk;
    epoxy_glNormal3iv = epoxy_glNormal3iv_dispatch_table_thunk;
    epoxy_glNormal3s = epoxy_glNormal3s_dispatch_table_thunk;
    epoxy_glNormal3sv = epoxy_glNormal3sv_dispatch_table_thunk;
    epoxy_glNormal3x = epoxy_glNormal3x_dispatch_table_thunk;
    epoxy_glNormal3xOES = epoxy_glNormal3xOES_dispatch_table_thunk;
    epoxy_glNormal3xvOES = epoxy_glNormal3xvOES_dispatch_table_thunk;
    epoxy_glNormalFormatNV = epoxy_glNormalFormatNV_dispatch_table_thunk;
    epoxy_glNormalP3ui = epoxy_glNormalP3ui_dispatch_table_thunk;
    epoxy_glNormalP3uiv = epoxy_glNormalP3uiv_dispatch_table_thunk;
    epoxy_glNormalPointer = epoxy_glNormalPointer_dispatch_table_thunk;
    epoxy_glNormalPointerEXT = epoxy_glNormalPointerEXT_dispatch_table_thunk;
    epoxy_glNormalPointerListIBM = epoxy_glNormalPointerListIBM_dispatch_table_thunk;
    epoxy_glNormalPointervINTEL = epoxy_glNormalPointervINTEL_dispatch_table_thunk;
    epoxy_glNormalStream3bATI = epoxy_glNormalStream3bATI_dispatch_table_thunk;
    epoxy_glNormalStream3bvATI = epoxy_glNormalStream3bvATI_dispatch_table_thunk;
    epoxy_glNormalStream3dATI = epoxy_glNormalStream3dATI_dispatch_table_thunk;
    epoxy_glNormalStream3dvATI = epoxy_glNormalStream3dvATI_dispatch_table_thunk;
    epoxy_glNormalStream3fATI = epoxy_glNormalStream3fATI_dispatch_table_thunk;
    epoxy_glNormalStream3fvATI = epoxy_glNormalStream3fvATI_dispatch_table_thunk;
    epoxy_glNormalStream3iATI = epoxy_glNormalStream3iATI_dispatch_table_thunk;
    epoxy_glNormalStream3ivATI = epoxy_glNormalStream3ivATI_dispatch_table_thunk;
    epoxy_glNormalStream3sATI = epoxy_glNormalStream3sATI_dispatch_table_thunk;
    epoxy_glNormalStream3svATI = epoxy_glNormalStream3svATI_dispatch_table_thunk;
    epoxy_glObjectLabel = epoxy_glObjectLabel_dispatch_table_thunk;
    epoxy_glObjectLabelKHR = epoxy_glObjectLabelKHR_dispatch_table_thunk;
    epoxy_glObjectPtrLabel = epoxy_glObjectPtrLabel_dispatch_table_thunk;
    epoxy_glObjectPtrLabelKHR = epoxy_glObjectPtrLabelKHR_dispatch_table_thunk;
    epoxy_glObjectPurgeableAPPLE = epoxy_glObjectPurgeableAPPLE_dispatch_table_thunk;
    epoxy_glObjectUnpurgeableAPPLE = epoxy_glObjectUnpurgeableAPPLE_dispatch_table_thunk;
    epoxy_glOrtho = epoxy_glOrtho_dispatch_table_thunk;
    epoxy_glOrthof = epoxy_glOrthof_dispatch_table_thunk;
    epoxy_glOrthofOES = epoxy_glOrthofOES_dispatch_table_thunk;
    epoxy_glOrthox = epoxy_glOrthox_dispatch_table_thunk;
    epoxy_glOrthoxOES = epoxy_glOrthoxOES_dispatch_table_thunk;
    epoxy_glPNTrianglesfATI = epoxy_glPNTrianglesfATI_dispatch_table_thunk;
    epoxy_glPNTrianglesiATI = epoxy_glPNTrianglesiATI_dispatch_table_thunk;
    epoxy_glPassTexCoordATI = epoxy_glPassTexCoordATI_dispatch_table_thunk;
    epoxy_glPassThrough = epoxy_glPassThrough_dispatch_table_thunk;
    epoxy_glPassThroughxOES = epoxy_glPassThroughxOES_dispatch_table_thunk;
    epoxy_glPatchParameterfv = epoxy_glPatchParameterfv_dispatch_table_thunk;
    epoxy_glPatchParameteri = epoxy_glPatchParameteri_dispatch_table_thunk;
    epoxy_glPatchParameteriEXT = epoxy_glPatchParameteriEXT_dispatch_table_thunk;
    epoxy_glPatchParameteriOES = epoxy_glPatchParameteriOES_dispatch_table_thunk;
    epoxy_glPathColorGenNV = epoxy_glPathColorGenNV_dispatch_table_thunk;
    epoxy_glPathCommandsNV = epoxy_glPathCommandsNV_dispatch_table_thunk;
    epoxy_glPathCoordsNV = epoxy_glPathCoordsNV_dispatch_table_thunk;
    epoxy_glPathCoverDepthFuncNV = epoxy_glPathCoverDepthFuncNV_dispatch_table_thunk;
    epoxy_glPathDashArrayNV = epoxy_glPathDashArrayNV_dispatch_table_thunk;
    epoxy_glPathFogGenNV = epoxy_glPathFogGenNV_dispatch_table_thunk;
    epoxy_glPathGlyphIndexArrayNV = epoxy_glPathGlyphIndexArrayNV_dispatch_table_thunk;
    epoxy_glPathGlyphIndexRangeNV = epoxy_glPathGlyphIndexRangeNV_dispatch_table_thunk;
    epoxy_glPathGlyphRangeNV = epoxy_glPathGlyphRangeNV_dispatch_table_thunk;
    epoxy_glPathGlyphsNV = epoxy_glPathGlyphsNV_dispatch_table_thunk;
    epoxy_glPathMemoryGlyphIndexArrayNV = epoxy_glPathMemoryGlyphIndexArrayNV_dispatch_table_thunk;
    epoxy_glPathParameterfNV = epoxy_glPathParameterfNV_dispatch_table_thunk;
    epoxy_glPathParameterfvNV = epoxy_glPathParameterfvNV_dispatch_table_thunk;
    epoxy_glPathParameteriNV = epoxy_glPathParameteriNV_dispatch_table_thunk;
    epoxy_glPathParameterivNV = epoxy_glPathParameterivNV_dispatch_table_thunk;
    epoxy_glPathStencilDepthOffsetNV = epoxy_glPathStencilDepthOffsetNV_dispatch_table_thunk;
    epoxy_glPathStencilFuncNV = epoxy_glPathStencilFuncNV_dispatch_table_thunk;
    epoxy_glPathStringNV = epoxy_glPathStringNV_dispatch_table_thunk;
    epoxy_glPathSubCommandsNV = epoxy_glPathSubCommandsNV_dispatch_table_thunk;
    epoxy_glPathSubCoordsNV = epoxy_glPathSubCoordsNV_dispatch_table_thunk;
    epoxy_glPathTexGenNV = epoxy_glPathTexGenNV_dispatch_table_thunk;
    epoxy_glPauseTransformFeedback = epoxy_glPauseTransformFeedback_dispatch_table_thunk;
    epoxy_glPauseTransformFeedbackNV = epoxy_glPauseTransformFeedbackNV_dispatch_table_thunk;
    epoxy_glPixelDataRangeNV = epoxy_glPixelDataRangeNV_dispatch_table_thunk;
    epoxy_glPixelMapfv = epoxy_glPixelMapfv_dispatch_table_thunk;
    epoxy_glPixelMapuiv = epoxy_glPixelMapuiv_dispatch_table_thunk;
    epoxy_glPixelMapusv = epoxy_glPixelMapusv_dispatch_table_thunk;
    epoxy_glPixelMapx = epoxy_glPixelMapx_dispatch_table_thunk;
    epoxy_glPixelStoref = epoxy_glPixelStoref_dispatch_table_thunk;
    epoxy_glPixelStorei = epoxy_glPixelStorei_dispatch_table_thunk;
    epoxy_glPixelStorex = epoxy_glPixelStorex_dispatch_table_thunk;
    epoxy_glPixelTexGenParameterfSGIS = epoxy_glPixelTexGenParameterfSGIS_dispatch_table_thunk;
    epoxy_glPixelTexGenParameterfvSGIS = epoxy_glPixelTexGenParameterfvSGIS_dispatch_table_thunk;
    epoxy_glPixelTexGenParameteriSGIS = epoxy_glPixelTexGenParameteriSGIS_dispatch_table_thunk;
    epoxy_glPixelTexGenParameterivSGIS = epoxy_glPixelTexGenParameterivSGIS_dispatch_table_thunk;
    epoxy_glPixelTexGenSGIX = epoxy_glPixelTexGenSGIX_dispatch_table_thunk;
    epoxy_glPixelTransferf = epoxy_glPixelTransferf_dispatch_table_thunk;
    epoxy_glPixelTransferi = epoxy_glPixelTransferi_dispatch_table_thunk;
    epoxy_glPixelTransferxOES = epoxy_glPixelTransferxOES_dispatch_table_thunk;
    epoxy_glPixelTransformParameterfEXT = epoxy_glPixelTransformParameterfEXT_dispatch_table_thunk;
    epoxy_glPixelTransformParameterfvEXT = epoxy_glPixelTransformParameterfvEXT_dispatch_table_thunk;
    epoxy_glPixelTransformParameteriEXT = epoxy_glPixelTransformParameteriEXT_dispatch_table_thunk;
    epoxy_glPixelTransformParameterivEXT = epoxy_glPixelTransformParameterivEXT_dispatch_table_thunk;
    epoxy_glPixelZoom = epoxy_glPixelZoom_dispatch_table_thunk;
    epoxy_glPixelZoomxOES = epoxy_glPixelZoomxOES_dispatch_table_thunk;
    epoxy_glPointAlongPathNV = epoxy_glPointAlongPathNV_dispatch_table_thunk;
    epoxy_glPointParameterf = epoxy_glPointParameterf_dispatch_table_thunk;
    epoxy_glPointParameterfARB = epoxy_glPointParameterfARB_dispatch_table_thunk;
    epoxy_glPointParameterfEXT = epoxy_glPointParameterfEXT_dispatch_table_thunk;
    epoxy_glPointParameterfSGIS = epoxy_glPointParameterfSGIS_dispatch_table_thunk;
    epoxy_glPointParameterfv = epoxy_glPointParameterfv_dispatch_table_thunk;
    epoxy_glPointParameterfvARB = epoxy_glPointParameterfvARB_dispatch_table_thunk;
    epoxy_glPointParameterfvEXT = epoxy_glPointParameterfvEXT_dispatch_table_thunk;
    epoxy_glPointParameterfvSGIS = epoxy_glPointParameterfvSGIS_dispatch_table_thunk;
    epoxy_glPointParameteri = epoxy_glPointParameteri_dispatch_table_thunk;
    epoxy_glPointParameteriNV = epoxy_glPointParameteriNV_dispatch_table_thunk;
    epoxy_glPointParameteriv = epoxy_glPointParameteriv_dispatch_table_thunk;
    epoxy_glPointParameterivNV = epoxy_glPointParameterivNV_dispatch_table_thunk;
    epoxy_glPointParameterx = epoxy_glPointParameterx_dispatch_table_thunk;
    epoxy_glPointParameterxOES = epoxy_glPointParameterxOES_dispatch_table_thunk;
    epoxy_glPointParameterxv = epoxy_glPointParameterxv_dispatch_table_thunk;
    epoxy_glPointParameterxvOES = epoxy_glPointParameterxvOES_dispatch_table_thunk;
    epoxy_glPointSize = epoxy_glPointSize_dispatch_table_thunk;
    epoxy_glPointSizePointerOES = epoxy_glPointSizePointerOES_dispatch_table_thunk;
    epoxy_glPointSizex = epoxy_glPointSizex_dispatch_table_thunk;
    epoxy_glPointSizexOES = epoxy_glPointSizexOES_dispatch_table_thunk;
    epoxy_glPollAsyncSGIX = epoxy_glPollAsyncSGIX_dispatch_table_thunk;
    epoxy_glPollInstrumentsSGIX = epoxy_glPollInstrumentsSGIX_dispatch_table_thunk;
    epoxy_glPolygonMode = epoxy_glPolygonMode_dispatch_table_thunk;
    epoxy_glPolygonModeNV = epoxy_glPolygonModeNV_dispatch_table_thunk;
    epoxy_glPolygonOffset = epoxy_glPolygonOffset_dispatch_table_thunk;
    epoxy_glPolygonOffsetClamp = epoxy_glPolygonOffsetClamp_dispatch_table_thunk;
    epoxy_glPolygonOffsetClampEXT = epoxy_glPolygonOffsetClampEXT_dispatch_table_thunk;
    epoxy_glPolygonOffsetEXT = epoxy_glPolygonOffsetEXT_dispatch_table_thunk;
    epoxy_glPolygonOffsetx = epoxy_glPolygonOffsetx_dispatch_table_thunk;
    epoxy_glPolygonOffsetxOES = epoxy_glPolygonOffsetxOES_dispatch_table_thunk;
    epoxy_glPolygonStipple = epoxy_glPolygonStipple_dispatch_table_thunk;
    epoxy_glPopAttrib = epoxy_glPopAttrib_dispatch_table_thunk;
    epoxy_glPopClientAttrib = epoxy_glPopClientAttrib_dispatch_table_thunk;
    epoxy_glPopDebugGroup = epoxy_glPopDebugGroup_dispatch_table_thunk;
    epoxy_glPopDebugGroupKHR = epoxy_glPopDebugGroupKHR_dispatch_table_thunk;
    epoxy_glPopGroupMarkerEXT = epoxy_glPopGroupMarkerEXT_dispatch_table_thunk;
    epoxy_glPopMatrix = epoxy_glPopMatrix_dispatch_table_thunk;
    epoxy_glPopName = epoxy_glPopName_dispatch_table_thunk;
    epoxy_glPresentFrameDualFillNV = epoxy_glPresentFrameDualFillNV_dispatch_table_thunk;
    epoxy_glPresentFrameKeyedNV = epoxy_glPresentFrameKeyedNV_dispatch_table_thunk;
    epoxy_glPrimitiveBoundingBox = epoxy_glPrimitiveBoundingBox_dispatch_table_thunk;
    epoxy_glPrimitiveBoundingBoxARB = epoxy_glPrimitiveBoundingBoxARB_dispatch_table_thunk;
    epoxy_glPrimitiveBoundingBoxEXT = epoxy_glPrimitiveBoundingBoxEXT_dispatch_table_thunk;
    epoxy_glPrimitiveBoundingBoxOES = epoxy_glPrimitiveBoundingBoxOES_dispatch_table_thunk;
    epoxy_glPrimitiveRestartIndex = epoxy_glPrimitiveRestartIndex_dispatch_table_thunk;
    epoxy_glPrimitiveRestartIndexNV = epoxy_glPrimitiveRestartIndexNV_dispatch_table_thunk;
    epoxy_glPrimitiveRestartNV = epoxy_glPrimitiveRestartNV_dispatch_table_thunk;
    epoxy_glPrioritizeTextures = epoxy_glPrioritizeTextures_dispatch_table_thunk;
    epoxy_glPrioritizeTexturesEXT = epoxy_glPrioritizeTexturesEXT_dispatch_table_thunk;
    epoxy_glPrioritizeTexturesxOES = epoxy_glPrioritizeTexturesxOES_dispatch_table_thunk;
    epoxy_glProgramBinary = epoxy_glProgramBinary_dispatch_table_thunk;
    epoxy_glProgramBinaryOES = epoxy_glProgramBinaryOES_dispatch_table_thunk;
    epoxy_glProgramBufferParametersIivNV = epoxy_glProgramBufferParametersIivNV_dispatch_table_thunk;
    epoxy_glProgramBufferParametersIuivNV = epoxy_glProgramBufferParametersIuivNV_dispatch_table_thunk;
    epoxy_glProgramBufferParametersfvNV = epoxy_glProgramBufferParametersfvNV_dispatch_table_thunk;
    epoxy_glProgramEnvParameter4dARB = epoxy_glProgramEnvParameter4dARB_dispatch_table_thunk;
    epoxy_glProgramEnvParameter4dvARB = epoxy_glProgramEnvParameter4dvARB_dispatch_table_thunk;
    epoxy_glProgramEnvParameter4fARB = epoxy_glProgramEnvParameter4fARB_dispatch_table_thunk;
    epoxy_glProgramEnvParameter4fvARB = epoxy_glProgramEnvParameter4fvARB_dispatch_table_thunk;
    epoxy_glProgramEnvParameterI4iNV = epoxy_glProgramEnvParameterI4iNV_dispatch_table_thunk;
    epoxy_glProgramEnvParameterI4ivNV = epoxy_glProgramEnvParameterI4ivNV_dispatch_table_thunk;
    epoxy_glProgramEnvParameterI4uiNV = epoxy_glProgramEnvParameterI4uiNV_dispatch_table_thunk;
    epoxy_glProgramEnvParameterI4uivNV = epoxy_glProgramEnvParameterI4uivNV_dispatch_table_thunk;
    epoxy_glProgramEnvParameters4fvEXT = epoxy_glProgramEnvParameters4fvEXT_dispatch_table_thunk;
    epoxy_glProgramEnvParametersI4ivNV = epoxy_glProgramEnvParametersI4ivNV_dispatch_table_thunk;
    epoxy_glProgramEnvParametersI4uivNV = epoxy_glProgramEnvParametersI4uivNV_dispatch_table_thunk;
    epoxy_glProgramLocalParameter4dARB = epoxy_glProgramLocalParameter4dARB_dispatch_table_thunk;
    epoxy_glProgramLocalParameter4dvARB = epoxy_glProgramLocalParameter4dvARB_dispatch_table_thunk;
    epoxy_glProgramLocalParameter4fARB = epoxy_glProgramLocalParameter4fARB_dispatch_table_thunk;
    epoxy_glProgramLocalParameter4fvARB = epoxy_glProgramLocalParameter4fvARB_dispatch_table_thunk;
    epoxy_glProgramLocalParameterI4iNV = epoxy_glProgramLocalParameterI4iNV_dispatch_table_thunk;
    epoxy_glProgramLocalParameterI4ivNV = epoxy_glProgramLocalParameterI4ivNV_dispatch_table_thunk;
    epoxy_glProgramLocalParameterI4uiNV = epoxy_glProgramLocalParameterI4uiNV_dispatch_table_thunk;
    epoxy_glProgramLocalParameterI4uivNV = epoxy_glProgramLocalParameterI4uivNV_dispatch_table_thunk;
    epoxy_glProgramLocalParameters4fvEXT = epoxy_glProgramLocalParameters4fvEXT_dispatch_table_thunk;
    epoxy_glProgramLocalParametersI4ivNV = epoxy_glProgramLocalParametersI4ivNV_dispatch_table_thunk;
    epoxy_glProgramLocalParametersI4uivNV = epoxy_glProgramLocalParametersI4uivNV_dispatch_table_thunk;
    epoxy_glProgramNamedParameter4dNV = epoxy_glProgramNamedParameter4dNV_dispatch_table_thunk;
    epoxy_glProgramNamedParameter4dvNV = epoxy_glProgramNamedParameter4dvNV_dispatch_table_thunk;
    epoxy_glProgramNamedParameter4fNV = epoxy_glProgramNamedParameter4fNV_dispatch_table_thunk;
    epoxy_glProgramNamedParameter4fvNV = epoxy_glProgramNamedParameter4fvNV_dispatch_table_thunk;
    epoxy_glProgramParameter4dNV = epoxy_glProgramParameter4dNV_dispatch_table_thunk;
    epoxy_glProgramParameter4dvNV = epoxy_glProgramParameter4dvNV_dispatch_table_thunk;
    epoxy_glProgramParameter4fNV = epoxy_glProgramParameter4fNV_dispatch_table_thunk;
    epoxy_glProgramParameter4fvNV = epoxy_glProgramParameter4fvNV_dispatch_table_thunk;
    epoxy_glProgramParameteri = epoxy_glProgramParameteri_dispatch_table_thunk;
    epoxy_glProgramParameteriARB = epoxy_glProgramParameteriARB_dispatch_table_thunk;
    epoxy_glProgramParameteriEXT = epoxy_glProgramParameteriEXT_dispatch_table_thunk;
    epoxy_glProgramParameters4dvNV = epoxy_glProgramParameters4dvNV_dispatch_table_thunk;
    epoxy_glProgramParameters4fvNV = epoxy_glProgramParameters4fvNV_dispatch_table_thunk;
    epoxy_glProgramPathFragmentInputGenNV = epoxy_glProgramPathFragmentInputGenNV_dispatch_table_thunk;
    epoxy_glProgramStringARB = epoxy_glProgramStringARB_dispatch_table_thunk;
    epoxy_glProgramSubroutineParametersuivNV = epoxy_glProgramSubroutineParametersuivNV_dispatch_table_thunk;
    epoxy_glProgramUniform1d = epoxy_glProgramUniform1d_dispatch_table_thunk;
    epoxy_glProgramUniform1dEXT = epoxy_glProgramUniform1dEXT_dispatch_table_thunk;
    epoxy_glProgramUniform1dv = epoxy_glProgramUniform1dv_dispatch_table_thunk;
    epoxy_glProgramUniform1dvEXT = epoxy_glProgramUniform1dvEXT_dispatch_table_thunk;
    epoxy_glProgramUniform1f = epoxy_glProgramUniform1f_dispatch_table_thunk;
    epoxy_glProgramUniform1fEXT = epoxy_glProgramUniform1fEXT_dispatch_table_thunk;
    epoxy_glProgramUniform1fv = epoxy_glProgramUniform1fv_dispatch_table_thunk;
    epoxy_glProgramUniform1fvEXT = epoxy_glProgramUniform1fvEXT_dispatch_table_thunk;
    epoxy_glProgramUniform1i = epoxy_glProgramUniform1i_dispatch_table_thunk;
    epoxy_glProgramUniform1i64ARB = epoxy_glProgramUniform1i64ARB_dispatch_table_thunk;
    epoxy_glProgramUniform1i64NV = epoxy_glProgramUniform1i64NV_dispatch_table_thunk;
    epoxy_glProgramUniform1i64vARB = epoxy_glProgramUniform1i64vARB_dispatch_table_thunk;
    epoxy_glProgramUniform1i64vNV = epoxy_glProgramUniform1i64vNV_dispatch_table_thunk;
    epoxy_glProgramUniform1iEXT = epoxy_glProgramUniform1iEXT_dispatch_table_thunk;
    epoxy_glProgramUniform1iv = epoxy_glProgramUniform1iv_dispatch_table_thunk;
    epoxy_glProgramUniform1ivEXT = epoxy_glProgramUniform1ivEXT_dispatch_table_thunk;
    epoxy_glProgramUniform1ui = epoxy_glProgramUniform1ui_dispatch_table_thunk;
    epoxy_glProgramUniform1ui64ARB = epoxy_glProgramUniform1ui64ARB_dispatch_table_thunk;
    epoxy_glProgramUniform1ui64NV = epoxy_glProgramUniform1ui64NV_dispatch_table_thunk;
    epoxy_glProgramUniform1ui64vARB = epoxy_glProgramUniform1ui64vARB_dispatch_table_thunk;
    epoxy_glProgramUniform1ui64vNV = epoxy_glProgramUniform1ui64vNV_dispatch_table_thunk;
    epoxy_glProgramUniform1uiEXT = epoxy_glProgramUniform1uiEXT_dispatch_table_thunk;
    epoxy_glProgramUniform1uiv = epoxy_glProgramUniform1uiv_dispatch_table_thunk;
    epoxy_glProgramUniform1uivEXT = epoxy_glProgramUniform1uivEXT_dispatch_table_thunk;
    epoxy_glProgramUniform2d = epoxy_glProgramUniform2d_dispatch_table_thunk;
    epoxy_glProgramUniform2dEXT = epoxy_glProgramUniform2dEXT_dispatch_table_thunk;
    epoxy_glProgramUniform2dv = epoxy_glProgramUniform2dv_dispatch_table_thunk;
    epoxy_glProgramUniform2dvEXT = epoxy_glProgramUniform2dvEXT_dispatch_table_thunk;
    epoxy_glProgramUniform2f = epoxy_glProgramUniform2f_dispatch_table_thunk;
    epoxy_glProgramUniform2fEXT = epoxy_glProgramUniform2fEXT_dispatch_table_thunk;
    epoxy_glProgramUniform2fv = epoxy_glProgramUniform2fv_dispatch_table_thunk;
    epoxy_glProgramUniform2fvEXT = epoxy_glProgramUniform2fvEXT_dispatch_table_thunk;
    epoxy_glProgramUniform2i = epoxy_glProgramUniform2i_dispatch_table_thunk;
    epoxy_glProgramUniform2i64ARB = epoxy_glProgramUniform2i64ARB_dispatch_table_thunk;
    epoxy_glProgramUniform2i64NV = epoxy_glProgramUniform2i64NV_dispatch_table_thunk;
    epoxy_glProgramUniform2i64vARB = epoxy_glProgramUniform2i64vARB_dispatch_table_thunk;
    epoxy_glProgramUniform2i64vNV = epoxy_glProgramUniform2i64vNV_dispatch_table_thunk;
    epoxy_glProgramUniform2iEXT = epoxy_glProgramUniform2iEXT_dispatch_table_thunk;
    epoxy_glProgramUniform2iv = epoxy_glProgramUniform2iv_dispatch_table_thunk;
    epoxy_glProgramUniform2ivEXT = epoxy_glProgramUniform2ivEXT_dispatch_table_thunk;
    epoxy_glProgramUniform2ui = epoxy_glProgramUniform2ui_dispatch_table_thunk;
    epoxy_glProgramUniform2ui64ARB = epoxy_glProgramUniform2ui64ARB_dispatch_table_thunk;
    epoxy_glProgramUniform2ui64NV = epoxy_glProgramUniform2ui64NV_dispatch_table_thunk;
    epoxy_glProgramUniform2ui64vARB = epoxy_glProgramUniform2ui64vARB_dispatch_table_thunk;
    epoxy_glProgramUniform2ui64vNV = epoxy_glProgramUniform2ui64vNV_dispatch_table_thunk;
    epoxy_glProgramUniform2uiEXT = epoxy_glProgramUniform2uiEXT_dispatch_table_thunk;
    epoxy_glProgramUniform2uiv = epoxy_glProgramUniform2uiv_dispatch_table_thunk;
    epoxy_glProgramUniform2uivEXT = epoxy_glProgramUniform2uivEXT_dispatch_table_thunk;
    epoxy_glProgramUniform3d = epoxy_glProgramUniform3d_dispatch_table_thunk;
    epoxy_glProgramUniform3dEXT = epoxy_glProgramUniform3dEXT_dispatch_table_thunk;
    epoxy_glProgramUniform3dv = epoxy_glProgramUniform3dv_dispatch_table_thunk;
    epoxy_glProgramUniform3dvEXT = epoxy_glProgramUniform3dvEXT_dispatch_table_thunk;
    epoxy_glProgramUniform3f = epoxy_glProgramUniform3f_dispatch_table_thunk;
    epoxy_glProgramUniform3fEXT = epoxy_glProgramUniform3fEXT_dispatch_table_thunk;
    epoxy_glProgramUniform3fv = epoxy_glProgramUniform3fv_dispatch_table_thunk;
    epoxy_glProgramUniform3fvEXT = epoxy_glProgramUniform3fvEXT_dispatch_table_thunk;
    epoxy_glProgramUniform3i = epoxy_glProgramUniform3i_dispatch_table_thunk;
    epoxy_glProgramUniform3i64ARB = epoxy_glProgramUniform3i64ARB_dispatch_table_thunk;
    epoxy_glProgramUniform3i64NV = epoxy_glProgramUniform3i64NV_dispatch_table_thunk;
    epoxy_glProgramUniform3i64vARB = epoxy_glProgramUniform3i64vARB_dispatch_table_thunk;
    epoxy_glProgramUniform3i64vNV = epoxy_glProgramUniform3i64vNV_dispatch_table_thunk;
    epoxy_glProgramUniform3iEXT = epoxy_glProgramUniform3iEXT_dispatch_table_thunk;
    epoxy_glProgramUniform3iv = epoxy_glProgramUniform3iv_dispatch_table_thunk;
    epoxy_glProgramUniform3ivEXT = epoxy_glProgramUniform3ivEXT_dispatch_table_thunk;
    epoxy_glProgramUniform3ui = epoxy_glProgramUniform3ui_dispatch_table_thunk;
    epoxy_glProgramUniform3ui64ARB = epoxy_glProgramUniform3ui64ARB_dispatch_table_thunk;
    epoxy_glProgramUniform3ui64NV = epoxy_glProgramUniform3ui64NV_dispatch_table_thunk;
    epoxy_glProgramUniform3ui64vARB = epoxy_glProgramUniform3ui64vARB_dispatch_table_thunk;
    epoxy_glProgramUniform3ui64vNV = epoxy_glProgramUniform3ui64vNV_dispatch_table_thunk;
    epoxy_glProgramUniform3uiEXT = epoxy_glProgramUniform3uiEXT_dispatch_table_thunk;
    epoxy_glProgramUniform3uiv = epoxy_glProgramUniform3uiv_dispatch_table_thunk;
    epoxy_glProgramUniform3uivEXT = epoxy_glProgramUniform3uivEXT_dispatch_table_thunk;
    epoxy_glProgramUniform4d = epoxy_glProgramUniform4d_dispatch_table_thunk;
    epoxy_glProgramUniform4dEXT = epoxy_glProgramUniform4dEXT_dispatch_table_thunk;
    epoxy_glProgramUniform4dv = epoxy_glProgramUniform4dv_dispatch_table_thunk;
    epoxy_glProgramUniform4dvEXT = epoxy_glProgramUniform4dvEXT_dispatch_table_thunk;
    epoxy_glProgramUniform4f = epoxy_glProgramUniform4f_dispatch_table_thunk;
    epoxy_glProgramUniform4fEXT = epoxy_glProgramUniform4fEXT_dispatch_table_thunk;
    epoxy_glProgramUniform4fv = epoxy_glProgramUniform4fv_dispatch_table_thunk;
    epoxy_glProgramUniform4fvEXT = epoxy_glProgramUniform4fvEXT_dispatch_table_thunk;
    epoxy_glProgramUniform4i = epoxy_glProgramUniform4i_dispatch_table_thunk;
    epoxy_glProgramUniform4i64ARB = epoxy_glProgramUniform4i64ARB_dispatch_table_thunk;
    epoxy_glProgramUniform4i64NV = epoxy_glProgramUniform4i64NV_dispatch_table_thunk;
    epoxy_glProgramUniform4i64vARB = epoxy_glProgramUniform4i64vARB_dispatch_table_thunk;
    epoxy_glProgramUniform4i64vNV = epoxy_glProgramUniform4i64vNV_dispatch_table_thunk;
    epoxy_glProgramUniform4iEXT = epoxy_glProgramUniform4iEXT_dispatch_table_thunk;
    epoxy_glProgramUniform4iv = epoxy_glProgramUniform4iv_dispatch_table_thunk;
    epoxy_glProgramUniform4ivEXT = epoxy_glProgramUniform4ivEXT_dispatch_table_thunk;
    epoxy_glProgramUniform4ui = epoxy_glProgramUniform4ui_dispatch_table_thunk;
    epoxy_glProgramUniform4ui64ARB = epoxy_glProgramUniform4ui64ARB_dispatch_table_thunk;
    epoxy_glProgramUniform4ui64NV = epoxy_glProgramUniform4ui64NV_dispatch_table_thunk;
    epoxy_glProgramUniform4ui64vARB = epoxy_glProgramUniform4ui64vARB_dispatch_table_thunk;
    epoxy_glProgramUniform4ui64vNV = epoxy_glProgramUniform4ui64vNV_dispatch_table_thunk;
    epoxy_glProgramUniform4uiEXT = epoxy_glProgramUniform4uiEXT_dispatch_table_thunk;
    epoxy_glProgramUniform4uiv = epoxy_glProgramUniform4uiv_dispatch_table_thunk;
    epoxy_glProgramUniform4uivEXT = epoxy_glProgramUniform4uivEXT_dispatch_table_thunk;
    epoxy_glProgramUniformHandleui64ARB = epoxy_glProgramUniformHandleui64ARB_dispatch_table_thunk;
    epoxy_glProgramUniformHandleui64IMG = epoxy_glProgramUniformHandleui64IMG_dispatch_table_thunk;
    epoxy_glProgramUniformHandleui64NV = epoxy_glProgramUniformHandleui64NV_dispatch_table_thunk;
    epoxy_glProgramUniformHandleui64vARB = epoxy_glProgramUniformHandleui64vARB_dispatch_table_thunk;
    epoxy_glProgramUniformHandleui64vIMG = epoxy_glProgramUniformHandleui64vIMG_dispatch_table_thunk;
    epoxy_glProgramUniformHandleui64vNV = epoxy_glProgramUniformHandleui64vNV_dispatch_table_thunk;
    epoxy_glProgramUniformMatrix2dv = epoxy_glProgramUniformMatrix2dv_dispatch_table_thunk;
    epoxy_glProgramUniformMatrix2dvEXT = epoxy_glProgramUniformMatrix2dvEXT_dispatch_table_thunk;
    epoxy_glProgramUniformMatrix2fv = epoxy_glProgramUniformMatrix2fv_dispatch_table_thunk;
    epoxy_glProgramUniformMatrix2fvEXT = epoxy_glProgramUniformMatrix2fvEXT_dispatch_table_thunk;
    epoxy_glProgramUniformMatrix2x3dv = epoxy_glProgramUniformMatrix2x3dv_dispatch_table_thunk;
    epoxy_glProgramUniformMatrix2x3dvEXT = epoxy_glProgramUniformMatrix2x3dvEXT_dispatch_table_thunk;
    epoxy_glProgramUniformMatrix2x3fv = epoxy_glProgramUniformMatrix2x3fv_dispatch_table_thunk;
    epoxy_glProgramUniformMatrix2x3fvEXT = epoxy_glProgramUniformMatrix2x3fvEXT_dispatch_table_thunk;
    epoxy_glProgramUniformMatrix2x4dv = epoxy_glProgramUniformMatrix2x4dv_dispatch_table_thunk;
    epoxy_glProgramUniformMatrix2x4dvEXT = epoxy_glProgramUniformMatrix2x4dvEXT_dispatch_table_thunk;
    epoxy_glProgramUniformMatrix2x4fv = epoxy_glProgramUniformMatrix2x4fv_dispatch_table_thunk;
    epoxy_glProgramUniformMatrix2x4fvEXT = epoxy_glProgramUniformMatrix2x4fvEXT_dispatch_table_thunk;
    epoxy_glProgramUniformMatrix3dv = epoxy_glProgramUniformMatrix3dv_dispatch_table_thunk;
    epoxy_glProgramUniformMatrix3dvEXT = epoxy_glProgramUniformMatrix3dvEXT_dispatch_table_thunk;
    epoxy_glProgramUniformMatrix3fv = epoxy_glProgramUniformMatrix3fv_dispatch_table_thunk;
    epoxy_glProgramUniformMatrix3fvEXT = epoxy_glProgramUniformMatrix3fvEXT_dispatch_table_thunk;
    epoxy_glProgramUniformMatrix3x2dv = epoxy_glProgramUniformMatrix3x2dv_dispatch_table_thunk;
    epoxy_glProgramUniformMatrix3x2dvEXT = epoxy_glProgramUniformMatrix3x2dvEXT_dispatch_table_thunk;
    epoxy_glProgramUniformMatrix3x2fv = epoxy_glProgramUniformMatrix3x2fv_dispatch_table_thunk;
    epoxy_glProgramUniformMatrix3x2fvEXT = epoxy_glProgramUniformMatrix3x2fvEXT_dispatch_table_thunk;
    epoxy_glProgramUniformMatrix3x4dv = epoxy_glProgramUniformMatrix3x4dv_dispatch_table_thunk;
    epoxy_glProgramUniformMatrix3x4dvEXT = epoxy_glProgramUniformMatrix3x4dvEXT_dispatch_table_thunk;
    epoxy_glProgramUniformMatrix3x4fv = epoxy_glProgramUniformMatrix3x4fv_dispatch_table_thunk;
    epoxy_glProgramUniformMatrix3x4fvEXT = epoxy_glProgramUniformMatrix3x4fvEXT_dispatch_table_thunk;
    epoxy_glProgramUniformMatrix4dv = epoxy_glProgramUniformMatrix4dv_dispatch_table_thunk;
    epoxy_glProgramUniformMatrix4dvEXT = epoxy_glProgramUniformMatrix4dvEXT_dispatch_table_thunk;
    epoxy_glProgramUniformMatrix4fv = epoxy_glProgramUniformMatrix4fv_dispatch_table_thunk;
    epoxy_glProgramUniformMatrix4fvEXT = epoxy_glProgramUniformMatrix4fvEXT_dispatch_table_thunk;
    epoxy_glProgramUniformMatrix4x2dv = epoxy_glProgramUniformMatrix4x2dv_dispatch_table_thunk;
    epoxy_glProgramUniformMatrix4x2dvEXT = epoxy_glProgramUniformMatrix4x2dvEXT_dispatch_table_thunk;
    epoxy_glProgramUniformMatrix4x2fv = epoxy_glProgramUniformMatrix4x2fv_dispatch_table_thunk;
    epoxy_glProgramUniformMatrix4x2fvEXT = epoxy_glProgramUniformMatrix4x2fvEXT_dispatch_table_thunk;
    epoxy_glProgramUniformMatrix4x3dv = epoxy_glProgramUniformMatrix4x3dv_dispatch_table_thunk;
    epoxy_glProgramUniformMatrix4x3dvEXT = epoxy_glProgramUniformMatrix4x3dvEXT_dispatch_table_thunk;
    epoxy_glProgramUniformMatrix4x3fv = epoxy_glProgramUniformMatrix4x3fv_dispatch_table_thunk;
    epoxy_glProgramUniformMatrix4x3fvEXT = epoxy_glProgramUniformMatrix4x3fvEXT_dispatch_table_thunk;
    epoxy_glProgramUniformui64NV = epoxy_glProgramUniformui64NV_dispatch_table_thunk;
    epoxy_glProgramUniformui64vNV = epoxy_glProgramUniformui64vNV_dispatch_table_thunk;
    epoxy_glProgramVertexLimitNV = epoxy_glProgramVertexLimitNV_dispatch_table_thunk;
    epoxy_glProvokingVertex = epoxy_glProvokingVertex_dispatch_table_thunk;
    epoxy_glProvokingVertexEXT = epoxy_glProvokingVertexEXT_dispatch_table_thunk;
    epoxy_glPushAttrib = epoxy_glPushAttrib_dispatch_table_thunk;
    epoxy_glPushClientAttrib = epoxy_glPushClientAttrib_dispatch_table_thunk;
    epoxy_glPushClientAttribDefaultEXT = epoxy_glPushClientAttribDefaultEXT_dispatch_table_thunk;
    epoxy_glPushDebugGroup = epoxy_glPushDebugGroup_dispatch_table_thunk;
    epoxy_glPushDebugGroupKHR = epoxy_glPushDebugGroupKHR_dispatch_table_thunk;
    epoxy_glPushGroupMarkerEXT = epoxy_glPushGroupMarkerEXT_dispatch_table_thunk;
    epoxy_glPushMatrix = epoxy_glPushMatrix_dispatch_table_thunk;
    epoxy_glPushName = epoxy_glPushName_dispatch_table_thunk;
    epoxy_glQueryCounter = epoxy_glQueryCounter_dispatch_table_thunk;
    epoxy_glQueryCounterEXT = epoxy_glQueryCounterEXT_dispatch_table_thunk;
    epoxy_glQueryMatrixxOES = epoxy_glQueryMatrixxOES_dispatch_table_thunk;
    epoxy_glQueryObjectParameteruiAMD = epoxy_glQueryObjectParameteruiAMD_dispatch_table_thunk;
    epoxy_glQueryResourceNV = epoxy_glQueryResourceNV_dispatch_table_thunk;
    epoxy_glQueryResourceTagNV = epoxy_glQueryResourceTagNV_dispatch_table_thunk;
    epoxy_glRasterPos2d = epoxy_glRasterPos2d_dispatch_table_thunk;
    epoxy_glRasterPos2dv = epoxy_glRasterPos2dv_dispatch_table_thunk;
    epoxy_glRasterPos2f = epoxy_glRasterPos2f_dispatch_table_thunk;
    epoxy_glRasterPos2fv = epoxy_glRasterPos2fv_dispatch_table_thunk;
    epoxy_glRasterPos2i = epoxy_glRasterPos2i_dispatch_table_thunk;
    epoxy_glRasterPos2iv = epoxy_glRasterPos2iv_dispatch_table_thunk;
    epoxy_glRasterPos2s = epoxy_glRasterPos2s_dispatch_table_thunk;
    epoxy_glRasterPos2sv = epoxy_glRasterPos2sv_dispatch_table_thunk;
    epoxy_glRasterPos2xOES = epoxy_glRasterPos2xOES_dispatch_table_thunk;
    epoxy_glRasterPos2xvOES = epoxy_glRasterPos2xvOES_dispatch_table_thunk;
    epoxy_glRasterPos3d = epoxy_glRasterPos3d_dispatch_table_thunk;
    epoxy_glRasterPos3dv = epoxy_glRasterPos3dv_dispatch_table_thunk;
    epoxy_glRasterPos3f = epoxy_glRasterPos3f_dispatch_table_thunk;
    epoxy_glRasterPos3fv = epoxy_glRasterPos3fv_dispatch_table_thunk;
    epoxy_glRasterPos3i = epoxy_glRasterPos3i_dispatch_table_thunk;
    epoxy_glRasterPos3iv = epoxy_glRasterPos3iv_dispatch_table_thunk;
    epoxy_glRasterPos3s = epoxy_glRasterPos3s_dispatch_table_thunk;
    epoxy_glRasterPos3sv = epoxy_glRasterPos3sv_dispatch_table_thunk;
    epoxy_glRasterPos3xOES = epoxy_glRasterPos3xOES_dispatch_table_thunk;
    epoxy_glRasterPos3xvOES = epoxy_glRasterPos3xvOES_dispatch_table_thunk;
    epoxy_glRasterPos4d = epoxy_glRasterPos4d_dispatch_table_thunk;
    epoxy_glRasterPos4dv = epoxy_glRasterPos4dv_dispatch_table_thunk;
    epoxy_glRasterPos4f = epoxy_glRasterPos4f_dispatch_table_thunk;
    epoxy_glRasterPos4fv = epoxy_glRasterPos4fv_dispatch_table_thunk;
    epoxy_glRasterPos4i = epoxy_glRasterPos4i_dispatch_table_thunk;
    epoxy_glRasterPos4iv = epoxy_glRasterPos4iv_dispatch_table_thunk;
    epoxy_glRasterPos4s = epoxy_glRasterPos4s_dispatch_table_thunk;
    epoxy_glRasterPos4sv = epoxy_glRasterPos4sv_dispatch_table_thunk;
    epoxy_glRasterPos4xOES = epoxy_glRasterPos4xOES_dispatch_table_thunk;
    epoxy_glRasterPos4xvOES = epoxy_glRasterPos4xvOES_dispatch_table_thunk;
    epoxy_glRasterSamplesEXT = epoxy_glRasterSamplesEXT_dispatch_table_thunk;
    epoxy_glReadBuffer = epoxy_glReadBuffer_dispatch_table_thunk;
    epoxy_glReadBufferIndexedEXT = epoxy_glReadBufferIndexedEXT_dispatch_table_thunk;
    epoxy_glReadBufferNV = epoxy_glReadBufferNV_dispatch_table_thunk;
    epoxy_glReadInstrumentsSGIX = epoxy_glReadInstrumentsSGIX_dispatch_table_thunk;
    epoxy_glReadPixels = epoxy_glReadPixels_dispatch_table_thunk;
    epoxy_glReadnPixels = epoxy_glReadnPixels_dispatch_table_thunk;
    epoxy_glReadnPixelsARB = epoxy_glReadnPixelsARB_dispatch_table_thunk;
    epoxy_glReadnPixelsEXT = epoxy_glReadnPixelsEXT_dispatch_table_thunk;
    epoxy_glReadnPixelsKHR = epoxy_glReadnPixelsKHR_dispatch_table_thunk;
    epoxy_glRectd = epoxy_glRectd_dispatch_table_thunk;
    epoxy_glRectdv = epoxy_glRectdv_dispatch_table_thunk;
    epoxy_glRectf = epoxy_glRectf_dispatch_table_thunk;
    epoxy_glRectfv = epoxy_glRectfv_dispatch_table_thunk;
    epoxy_glRecti = epoxy_glRecti_dispatch_table_thunk;
    epoxy_glRectiv = epoxy_glRectiv_dispatch_table_thunk;
    epoxy_glRects = epoxy_glRects_dispatch_table_thunk;
    epoxy_glRectsv = epoxy_glRectsv_dispatch_table_thunk;
    epoxy_glRectxOES = epoxy_glRectxOES_dispatch_table_thunk;
    epoxy_glRectxvOES = epoxy_glRectxvOES_dispatch_table_thunk;
    epoxy_glReferencePlaneSGIX = epoxy_glReferencePlaneSGIX_dispatch_table_thunk;
    epoxy_glReleaseKeyedMutexWin32EXT = epoxy_glReleaseKeyedMutexWin32EXT_dispatch_table_thunk;
    epoxy_glReleaseShaderCompiler = epoxy_glReleaseShaderCompiler_dispatch_table_thunk;
    epoxy_glRenderGpuMaskNV = epoxy_glRenderGpuMaskNV_dispatch_table_thunk;
    epoxy_glRenderMode = epoxy_glRenderMode_dispatch_table_thunk;
    epoxy_glRenderbufferStorage = epoxy_glRenderbufferStorage_dispatch_table_thunk;
    epoxy_glRenderbufferStorageEXT = epoxy_glRenderbufferStorageEXT_dispatch_table_thunk;
    epoxy_glRenderbufferStorageMultisample = epoxy_glRenderbufferStorageMultisample_dispatch_table_thunk;
    epoxy_glRenderbufferStorageMultisampleANGLE = epoxy_glRenderbufferStorageMultisampleANGLE_dispatch_table_thunk;
    epoxy_glRenderbufferStorageMultisampleAPPLE = epoxy_glRenderbufferStorageMultisampleAPPLE_dispatch_table_thunk;
    epoxy_glRenderbufferStorageMultisampleAdvancedAMD = epoxy_glRenderbufferStorageMultisampleAdvancedAMD_dispatch_table_thunk;
    epoxy_glRenderbufferStorageMultisampleCoverageNV = epoxy_glRenderbufferStorageMultisampleCoverageNV_dispatch_table_thunk;
    epoxy_glRenderbufferStorageMultisampleEXT = epoxy_glRenderbufferStorageMultisampleEXT_dispatch_table_thunk;
    epoxy_glRenderbufferStorageMultisampleIMG = epoxy_glRenderbufferStorageMultisampleIMG_dispatch_table_thunk;
    epoxy_glRenderbufferStorageMultisampleNV = epoxy_glRenderbufferStorageMultisampleNV_dispatch_table_thunk;
    epoxy_glRenderbufferStorageOES = epoxy_glRenderbufferStorageOES_dispatch_table_thunk;
    epoxy_glReplacementCodePointerSUN = epoxy_glReplacementCodePointerSUN_dispatch_table_thunk;
    epoxy_glReplacementCodeubSUN = epoxy_glReplacementCodeubSUN_dispatch_table_thunk;
    epoxy_glReplacementCodeubvSUN = epoxy_glReplacementCodeubvSUN_dispatch_table_thunk;
    epoxy_glReplacementCodeuiColor3fVertex3fSUN = epoxy_glReplacementCodeuiColor3fVertex3fSUN_dispatch_table_thunk;
    epoxy_glReplacementCodeuiColor3fVertex3fvSUN = epoxy_glReplacementCodeuiColor3fVertex3fvSUN_dispatch_table_thunk;
    epoxy_glReplacementCodeuiColor4fNormal3fVertex3fSUN = epoxy_glReplacementCodeuiColor4fNormal3fVertex3fSUN_dispatch_table_thunk;
    epoxy_glReplacementCodeuiColor4fNormal3fVertex3fvSUN = epoxy_glReplacementCodeuiColor4fNormal3fVertex3fvSUN_dispatch_table_thunk;
    epoxy_glReplacementCodeuiColor4ubVertex3fSUN = epoxy_glReplacementCodeuiColor4ubVertex3fSUN_dispatch_table_thunk;
    epoxy_glReplacementCodeuiColor4ubVertex3fvSUN = epoxy_glReplacementCodeuiColor4ubVertex3fvSUN_dispatch_table_thunk;
    epoxy_glReplacementCodeuiNormal3fVertex3fSUN = epoxy_glReplacementCodeuiNormal3fVertex3fSUN_dispatch_table_thunk;
    epoxy_glReplacementCodeuiNormal3fVertex3fvSUN = epoxy_glReplacementCodeuiNormal3fVertex3fvSUN_dispatch_table_thunk;
    epoxy_glReplacementCodeuiSUN = epoxy_glReplacementCodeuiSUN_dispatch_table_thunk;
    epoxy_glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fSUN = epoxy_glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fSUN_dispatch_table_thunk;
    epoxy_glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fvSUN = epoxy_glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fvSUN_dispatch_table_thunk;
    epoxy_glReplacementCodeuiTexCoord2fNormal3fVertex3fSUN = epoxy_glReplacementCodeuiTexCoord2fNormal3fVertex3fSUN_dispatch_table_thunk;
    epoxy_glReplacementCodeuiTexCoord2fNormal3fVertex3fvSUN = epoxy_glReplacementCodeuiTexCoord2fNormal3fVertex3fvSUN_dispatch_table_thunk;
    epoxy_glReplacementCodeuiTexCoord2fVertex3fSUN = epoxy_glReplacementCodeuiTexCoord2fVertex3fSUN_dispatch_table_thunk;
    epoxy_glReplacementCodeuiTexCoord2fVertex3fvSUN = epoxy_glReplacementCodeuiTexCoord2fVertex3fvSUN_dispatch_table_thunk;
    epoxy_glReplacementCodeuiVertex3fSUN = epoxy_glReplacementCodeuiVertex3fSUN_dispatch_table_thunk;
    epoxy_glReplacementCodeuiVertex3fvSUN = epoxy_glReplacementCodeuiVertex3fvSUN_dispatch_table_thunk;
    epoxy_glReplacementCodeuivSUN = epoxy_glReplacementCodeuivSUN_dispatch_table_thunk;
    epoxy_glReplacementCodeusSUN = epoxy_glReplacementCodeusSUN_dispatch_table_thunk;
    epoxy_glReplacementCodeusvSUN = epoxy_glReplacementCodeusvSUN_dispatch_table_thunk;
    epoxy_glRequestResidentProgramsNV = epoxy_glRequestResidentProgramsNV_dispatch_table_thunk;
    epoxy_glResetHistogram = epoxy_glResetHistogram_dispatch_table_thunk;
    epoxy_glResetHistogramEXT = epoxy_glResetHistogramEXT_dispatch_table_thunk;
    epoxy_glResetMemoryObjectParameterNV = epoxy_glResetMemoryObjectParameterNV_dispatch_table_thunk;
    epoxy_glResetMinmax = epoxy_glResetMinmax_dispatch_table_thunk;
    epoxy_glResetMinmaxEXT = epoxy_glResetMinmaxEXT_dispatch_table_thunk;
    epoxy_glResizeBuffersMESA = epoxy_glResizeBuffersMESA_dispatch_table_thunk;
    epoxy_glResolveDepthValuesNV = epoxy_glResolveDepthValuesNV_dispatch_table_thunk;
    epoxy_glResolveMultisampleFramebufferAPPLE = epoxy_glResolveMultisampleFramebufferAPPLE_dispatch_table_thunk;
    epoxy_glResumeTransformFeedback = epoxy_glResumeTransformFeedback_dispatch_table_thunk;
    epoxy_glResumeTransformFeedbackNV = epoxy_glResumeTransformFeedbackNV_dispatch_table_thunk;
    epoxy_glRotated = epoxy_glRotated_dispatch_table_thunk;
    epoxy_glRotatef = epoxy_glRotatef_dispatch_table_thunk;
    epoxy_glRotatex = epoxy_glRotatex_dispatch_table_thunk;
    epoxy_glRotatexOES = epoxy_glRotatexOES_dispatch_table_thunk;
    epoxy_glSampleCoverage = epoxy_glSampleCoverage_dispatch_table_thunk;
    epoxy_glSampleCoverageARB = epoxy_glSampleCoverageARB_dispatch_table_thunk;
    epoxy_glSampleCoveragex = epoxy_glSampleCoveragex_dispatch_table_thunk;
    epoxy_glSampleCoveragexOES = epoxy_glSampleCoveragexOES_dispatch_table_thunk;
    epoxy_glSampleMapATI = epoxy_glSampleMapATI_dispatch_table_thunk;
    epoxy_glSampleMaskEXT = epoxy_glSampleMaskEXT_dispatch_table_thunk;
    epoxy_glSampleMaskIndexedNV = epoxy_glSampleMaskIndexedNV_dispatch_table_thunk;
    epoxy_glSampleMaskSGIS = epoxy_glSampleMaskSGIS_dispatch_table_thunk;
    epoxy_glSampleMaski = epoxy_glSampleMaski_dispatch_table_thunk;
    epoxy_glSamplePatternEXT = epoxy_glSamplePatternEXT_dispatch_table_thunk;
    epoxy_glSamplePatternSGIS = epoxy_glSamplePatternSGIS_dispatch_table_thunk;
    epoxy_glSamplerParameterIiv = epoxy_glSamplerParameterIiv_dispatch_table_thunk;
    epoxy_glSamplerParameterIivEXT = epoxy_glSamplerParameterIivEXT_dispatch_table_thunk;
    epoxy_glSamplerParameterIivOES = epoxy_glSamplerParameterIivOES_dispatch_table_thunk;
    epoxy_glSamplerParameterIuiv = epoxy_glSamplerParameterIuiv_dispatch_table_thunk;
    epoxy_glSamplerParameterIuivEXT = epoxy_glSamplerParameterIuivEXT_dispatch_table_thunk;
    epoxy_glSamplerParameterIuivOES = epoxy_glSamplerParameterIuivOES_dispatch_table_thunk;
    epoxy_glSamplerParameterf = epoxy_glSamplerParameterf_dispatch_table_thunk;
    epoxy_glSamplerParameterfv = epoxy_glSamplerParameterfv_dispatch_table_thunk;
    epoxy_glSamplerParameteri = epoxy_glSamplerParameteri_dispatch_table_thunk;
    epoxy_glSamplerParameteriv = epoxy_glSamplerParameteriv_dispatch_table_thunk;
    epoxy_glScaled = epoxy_glScaled_dispatch_table_thunk;
    epoxy_glScalef = epoxy_glScalef_dispatch_table_thunk;
    epoxy_glScalex = epoxy_glScalex_dispatch_table_thunk;
    epoxy_glScalexOES = epoxy_glScalexOES_dispatch_table_thunk;
    epoxy_glScissor = epoxy_glScissor_dispatch_table_thunk;
    epoxy_glScissorArrayv = epoxy_glScissorArrayv_dispatch_table_thunk;
    epoxy_glScissorArrayvNV = epoxy_glScissorArrayvNV_dispatch_table_thunk;
    epoxy_glScissorArrayvOES = epoxy_glScissorArrayvOES_dispatch_table_thunk;
    epoxy_glScissorExclusiveArrayvNV = epoxy_glScissorExclusiveArrayvNV_dispatch_table_thunk;
    epoxy_glScissorExclusiveNV = epoxy_glScissorExclusiveNV_dispatch_table_thunk;
    epoxy_glScissorIndexed = epoxy_glScissorIndexed_dispatch_table_thunk;
    epoxy_glScissorIndexedNV = epoxy_glScissorIndexedNV_dispatch_table_thunk;
    epoxy_glScissorIndexedOES = epoxy_glScissorIndexedOES_dispatch_table_thunk;
    epoxy_glScissorIndexedv = epoxy_glScissorIndexedv_dispatch_table_thunk;
    epoxy_glScissorIndexedvNV = epoxy_glScissorIndexedvNV_dispatch_table_thunk;
    epoxy_glScissorIndexedvOES = epoxy_glScissorIndexedvOES_dispatch_table_thunk;
    epoxy_glSecondaryColor3b = epoxy_glSecondaryColor3b_dispatch_table_thunk;
    epoxy_glSecondaryColor3bEXT = epoxy_glSecondaryColor3bEXT_dispatch_table_thunk;
    epoxy_glSecondaryColor3bv = epoxy_glSecondaryColor3bv_dispatch_table_thunk;
    epoxy_glSecondaryColor3bvEXT = epoxy_glSecondaryColor3bvEXT_dispatch_table_thunk;
    epoxy_glSecondaryColor3d = epoxy_glSecondaryColor3d_dispatch_table_thunk;
    epoxy_glSecondaryColor3dEXT = epoxy_glSecondaryColor3dEXT_dispatch_table_thunk;
    epoxy_glSecondaryColor3dv = epoxy_glSecondaryColor3dv_dispatch_table_thunk;
    epoxy_glSecondaryColor3dvEXT = epoxy_glSecondaryColor3dvEXT_dispatch_table_thunk;
    epoxy_glSecondaryColor3f = epoxy_glSecondaryColor3f_dispatch_table_thunk;
    epoxy_glSecondaryColor3fEXT = epoxy_glSecondaryColor3fEXT_dispatch_table_thunk;
    epoxy_glSecondaryColor3fv = epoxy_glSecondaryColor3fv_dispatch_table_thunk;
    epoxy_glSecondaryColor3fvEXT = epoxy_glSecondaryColor3fvEXT_dispatch_table_thunk;
    epoxy_glSecondaryColor3hNV = epoxy_glSecondaryColor3hNV_dispatch_table_thunk;
    epoxy_glSecondaryColor3hvNV = epoxy_glSecondaryColor3hvNV_dispatch_table_thunk;
    epoxy_glSecondaryColor3i = epoxy_glSecondaryColor3i_dispatch_table_thunk;
    epoxy_glSecondaryColor3iEXT = epoxy_glSecondaryColor3iEXT_dispatch_table_thunk;
    epoxy_glSecondaryColor3iv = epoxy_glSecondaryColor3iv_dispatch_table_thunk;
    epoxy_glSecondaryColor3ivEXT = epoxy_glSecondaryColor3ivEXT_dispatch_table_thunk;
    epoxy_glSecondaryColor3s = epoxy_glSecondaryColor3s_dispatch_table_thunk;
    epoxy_glSecondaryColor3sEXT = epoxy_glSecondaryColor3sEXT_dispatch_table_thunk;
    epoxy_glSecondaryColor3sv = epoxy_glSecondaryColor3sv_dispatch_table_thunk;
    epoxy_glSecondaryColor3svEXT = epoxy_glSecondaryColor3svEXT_dispatch_table_thunk;
    epoxy_glSecondaryColor3ub = epoxy_glSecondaryColor3ub_dispatch_table_thunk;
    epoxy_glSecondaryColor3ubEXT = epoxy_glSecondaryColor3ubEXT_dispatch_table_thunk;
    epoxy_glSecondaryColor3ubv = epoxy_glSecondaryColor3ubv_dispatch_table_thunk;
    epoxy_glSecondaryColor3ubvEXT = epoxy_glSecondaryColor3ubvEXT_dispatch_table_thunk;
    epoxy_glSecondaryColor3ui = epoxy_glSecondaryColor3ui_dispatch_table_thunk;
    epoxy_glSecondaryColor3uiEXT = epoxy_glSecondaryColor3uiEXT_dispatch_table_thunk;
    epoxy_glSecondaryColor3uiv = epoxy_glSecondaryColor3uiv_dispatch_table_thunk;
    epoxy_glSecondaryColor3uivEXT = epoxy_glSecondaryColor3uivEXT_dispatch_table_thunk;
    epoxy_glSecondaryColor3us = epoxy_glSecondaryColor3us_dispatch_table_thunk;
    epoxy_glSecondaryColor3usEXT = epoxy_glSecondaryColor3usEXT_dispatch_table_thunk;
    epoxy_glSecondaryColor3usv = epoxy_glSecondaryColor3usv_dispatch_table_thunk;
    epoxy_glSecondaryColor3usvEXT = epoxy_glSecondaryColor3usvEXT_dispatch_table_thunk;
    epoxy_glSecondaryColorFormatNV = epoxy_glSecondaryColorFormatNV_dispatch_table_thunk;
    epoxy_glSecondaryColorP3ui = epoxy_glSecondaryColorP3ui_dispatch_table_thunk;
    epoxy_glSecondaryColorP3uiv = epoxy_glSecondaryColorP3uiv_dispatch_table_thunk;
    epoxy_glSecondaryColorPointer = epoxy_glSecondaryColorPointer_dispatch_table_thunk;
    epoxy_glSecondaryColorPointerEXT = epoxy_glSecondaryColorPointerEXT_dispatch_table_thunk;
    epoxy_glSecondaryColorPointerListIBM = epoxy_glSecondaryColorPointerListIBM_dispatch_table_thunk;
    epoxy_glSelectBuffer = epoxy_glSelectBuffer_dispatch_table_thunk;
    epoxy_glSelectPerfMonitorCountersAMD = epoxy_glSelectPerfMonitorCountersAMD_dispatch_table_thunk;
    epoxy_glSemaphoreParameterui64vEXT = epoxy_glSemaphoreParameterui64vEXT_dispatch_table_thunk;
    epoxy_glSeparableFilter2D = epoxy_glSeparableFilter2D_dispatch_table_thunk;
    epoxy_glSeparableFilter2DEXT = epoxy_glSeparableFilter2DEXT_dispatch_table_thunk;
    epoxy_glSetFenceAPPLE = epoxy_glSetFenceAPPLE_dispatch_table_thunk;
    epoxy_glSetFenceNV = epoxy_glSetFenceNV_dispatch_table_thunk;
    epoxy_glSetFragmentShaderConstantATI = epoxy_glSetFragmentShaderConstantATI_dispatch_table_thunk;
    epoxy_glSetInvariantEXT = epoxy_glSetInvariantEXT_dispatch_table_thunk;
    epoxy_glSetLocalConstantEXT = epoxy_glSetLocalConstantEXT_dispatch_table_thunk;
    epoxy_glSetMultisamplefvAMD = epoxy_glSetMultisamplefvAMD_dispatch_table_thunk;
    epoxy_glShadeModel = epoxy_glShadeModel_dispatch_table_thunk;
    epoxy_glShaderBinary = epoxy_glShaderBinary_dispatch_table_thunk;
    epoxy_glShaderOp1EXT = epoxy_glShaderOp1EXT_dispatch_table_thunk;
    epoxy_glShaderOp2EXT = epoxy_glShaderOp2EXT_dispatch_table_thunk;
    epoxy_glShaderOp3EXT = epoxy_glShaderOp3EXT_dispatch_table_thunk;
    epoxy_glShaderSource = epoxy_glShaderSource_dispatch_table_thunk;
    epoxy_glShaderSourceARB = epoxy_glShaderSourceARB_dispatch_table_thunk;
    epoxy_glShaderStorageBlockBinding = epoxy_glShaderStorageBlockBinding_dispatch_table_thunk;
    epoxy_glShadingRateImageBarrierNV = epoxy_glShadingRateImageBarrierNV_dispatch_table_thunk;
    epoxy_glShadingRateImagePaletteNV = epoxy_glShadingRateImagePaletteNV_dispatch_table_thunk;
    epoxy_glShadingRateSampleOrderCustomNV = epoxy_glShadingRateSampleOrderCustomNV_dispatch_table_thunk;
    epoxy_glShadingRateSampleOrderNV = epoxy_glShadingRateSampleOrderNV_dispatch_table_thunk;
    epoxy_glSharpenTexFuncSGIS = epoxy_glSharpenTexFuncSGIS_dispatch_table_thunk;
    epoxy_glSignalSemaphoreEXT = epoxy_glSignalSemaphoreEXT_dispatch_table_thunk;
    epoxy_glSignalSemaphoreui64NVX = epoxy_glSignalSemaphoreui64NVX_dispatch_table_thunk;
    epoxy_glSignalVkFenceNV = epoxy_glSignalVkFenceNV_dispatch_table_thunk;
    epoxy_glSignalVkSemaphoreNV = epoxy_glSignalVkSemaphoreNV_dispatch_table_thunk;
    epoxy_glSpecializeShader = epoxy_glSpecializeShader_dispatch_table_thunk;
    epoxy_glSpecializeShaderARB = epoxy_glSpecializeShaderARB_dispatch_table_thunk;
    epoxy_glSpriteParameterfSGIX = epoxy_glSpriteParameterfSGIX_dispatch_table_thunk;
    epoxy_glSpriteParameterfvSGIX = epoxy_glSpriteParameterfvSGIX_dispatch_table_thunk;
    epoxy_glSpriteParameteriSGIX = epoxy_glSpriteParameteriSGIX_dispatch_table_thunk;
    epoxy_glSpriteParameterivSGIX = epoxy_glSpriteParameterivSGIX_dispatch_table_thunk;
    epoxy_glStartInstrumentsSGIX = epoxy_glStartInstrumentsSGIX_dispatch_table_thunk;
    epoxy_glStartTilingQCOM = epoxy_glStartTilingQCOM_dispatch_table_thunk;
    epoxy_glStateCaptureNV = epoxy_glStateCaptureNV_dispatch_table_thunk;
    epoxy_glStencilClearTagEXT = epoxy_glStencilClearTagEXT_dispatch_table_thunk;
    epoxy_glStencilFillPathInstancedNV = epoxy_glStencilFillPathInstancedNV_dispatch_table_thunk;
    epoxy_glStencilFillPathNV = epoxy_glStencilFillPathNV_dispatch_table_thunk;
    epoxy_glStencilFunc = epoxy_glStencilFunc_dispatch_table_thunk;
    epoxy_glStencilFuncSeparate = epoxy_glStencilFuncSeparate_dispatch_table_thunk;
    epoxy_glStencilFuncSeparateATI = epoxy_glStencilFuncSeparateATI_dispatch_table_thunk;
    epoxy_glStencilMask = epoxy_glStencilMask_dispatch_table_thunk;
    epoxy_glStencilMaskSeparate = epoxy_glStencilMaskSeparate_dispatch_table_thunk;
    epoxy_glStencilOp = epoxy_glStencilOp_dispatch_table_thunk;
    epoxy_glStencilOpSeparate = epoxy_glStencilOpSeparate_dispatch_table_thunk;
    epoxy_glStencilOpSeparateATI = epoxy_glStencilOpSeparateATI_dispatch_table_thunk;
    epoxy_glStencilOpValueAMD = epoxy_glStencilOpValueAMD_dispatch_table_thunk;
    epoxy_glStencilStrokePathInstancedNV = epoxy_glStencilStrokePathInstancedNV_dispatch_table_thunk;
    epoxy_glStencilStrokePathNV = epoxy_glStencilStrokePathNV_dispatch_table_thunk;
    epoxy_glStencilThenCoverFillPathInstancedNV = epoxy_glStencilThenCoverFillPathInstancedNV_dispatch_table_thunk;
    epoxy_glStencilThenCoverFillPathNV = epoxy_glStencilThenCoverFillPathNV_dispatch_table_thunk;
    epoxy_glStencilThenCoverStrokePathInstancedNV = epoxy_glStencilThenCoverStrokePathInstancedNV_dispatch_table_thunk;
    epoxy_glStencilThenCoverStrokePathNV = epoxy_glStencilThenCoverStrokePathNV_dispatch_table_thunk;
    epoxy_glStopInstrumentsSGIX = epoxy_glStopInstrumentsSGIX_dispatch_table_thunk;
    epoxy_glStringMarkerGREMEDY = epoxy_glStringMarkerGREMEDY_dispatch_table_thunk;
    epoxy_glSubpixelPrecisionBiasNV = epoxy_glSubpixelPrecisionBiasNV_dispatch_table_thunk;
    epoxy_glSwizzleEXT = epoxy_glSwizzleEXT_dispatch_table_thunk;
    epoxy_glSyncTextureINTEL = epoxy_glSyncTextureINTEL_dispatch_table_thunk;
    epoxy_glTagSampleBufferSGIX = epoxy_glTagSampleBufferSGIX_dispatch_table_thunk;
    epoxy_glTangent3bEXT = epoxy_glTangent3bEXT_dispatch_table_thunk;
    epoxy_glTangent3bvEXT = epoxy_glTangent3bvEXT_dispatch_table_thunk;
    epoxy_glTangent3dEXT = epoxy_glTangent3dEXT_dispatch_table_thunk;
    epoxy_glTangent3dvEXT = epoxy_glTangent3dvEXT_dispatch_table_thunk;
    epoxy_glTangent3fEXT = epoxy_glTangent3fEXT_dispatch_table_thunk;
    epoxy_glTangent3fvEXT = epoxy_glTangent3fvEXT_dispatch_table_thunk;
    epoxy_glTangent3iEXT = epoxy_glTangent3iEXT_dispatch_table_thunk;
    epoxy_glTangent3ivEXT = epoxy_glTangent3ivEXT_dispatch_table_thunk;
    epoxy_glTangent3sEXT = epoxy_glTangent3sEXT_dispatch_table_thunk;
    epoxy_glTangent3svEXT = epoxy_glTangent3svEXT_dispatch_table_thunk;
    epoxy_glTangentPointerEXT = epoxy_glTangentPointerEXT_dispatch_table_thunk;
    epoxy_glTbufferMask3DFX = epoxy_glTbufferMask3DFX_dispatch_table_thunk;
    epoxy_glTessellationFactorAMD = epoxy_glTessellationFactorAMD_dispatch_table_thunk;
    epoxy_glTessellationModeAMD = epoxy_glTessellationModeAMD_dispatch_table_thunk;
    epoxy_glTestFenceAPPLE = epoxy_glTestFenceAPPLE_dispatch_table_thunk;
    epoxy_glTestFenceNV = epoxy_glTestFenceNV_dispatch_table_thunk;
    epoxy_glTestObjectAPPLE = epoxy_glTestObjectAPPLE_dispatch_table_thunk;
    epoxy_glTexAttachMemoryNV = epoxy_glTexAttachMemoryNV_dispatch_table_thunk;
    epoxy_glTexBuffer = epoxy_glTexBuffer_dispatch_table_thunk;
    epoxy_glTexBufferARB = epoxy_glTexBufferARB_dispatch_table_thunk;
    epoxy_glTexBufferEXT = epoxy_glTexBufferEXT_dispatch_table_thunk;
    epoxy_glTexBufferOES = epoxy_glTexBufferOES_dispatch_table_thunk;
    epoxy_glTexBufferRange = epoxy_glTexBufferRange_dispatch_table_thunk;
    epoxy_glTexBufferRangeEXT = epoxy_glTexBufferRangeEXT_dispatch_table_thunk;
    epoxy_glTexBufferRangeOES = epoxy_glTexBufferRangeOES_dispatch_table_thunk;
    epoxy_glTexBumpParameterfvATI = epoxy_glTexBumpParameterfvATI_dispatch_table_thunk;
    epoxy_glTexBumpParameterivATI = epoxy_glTexBumpParameterivATI_dispatch_table_thunk;
    epoxy_glTexCoord1bOES = epoxy_glTexCoord1bOES_dispatch_table_thunk;
    epoxy_glTexCoord1bvOES = epoxy_glTexCoord1bvOES_dispatch_table_thunk;
    epoxy_glTexCoord1d = epoxy_glTexCoord1d_dispatch_table_thunk;
    epoxy_glTexCoord1dv = epoxy_glTexCoord1dv_dispatch_table_thunk;
    epoxy_glTexCoord1f = epoxy_glTexCoord1f_dispatch_table_thunk;
    epoxy_glTexCoord1fv = epoxy_glTexCoord1fv_dispatch_table_thunk;
    epoxy_glTexCoord1hNV = epoxy_glTexCoord1hNV_dispatch_table_thunk;
    epoxy_glTexCoord1hvNV = epoxy_glTexCoord1hvNV_dispatch_table_thunk;
    epoxy_glTexCoord1i = epoxy_glTexCoord1i_dispatch_table_thunk;
    epoxy_glTexCoord1iv = epoxy_glTexCoord1iv_dispatch_table_thunk;
    epoxy_glTexCoord1s = epoxy_glTexCoord1s_dispatch_table_thunk;
    epoxy_glTexCoord1sv = epoxy_glTexCoord1sv_dispatch_table_thunk;
    epoxy_glTexCoord1xOES = epoxy_glTexCoord1xOES_dispatch_table_thunk;
    epoxy_glTexCoord1xvOES = epoxy_glTexCoord1xvOES_dispatch_table_thunk;
    epoxy_glTexCoord2bOES = epoxy_glTexCoord2bOES_dispatch_table_thunk;
    epoxy_glTexCoord2bvOES = epoxy_glTexCoord2bvOES_dispatch_table_thunk;
    epoxy_glTexCoord2d = epoxy_glTexCoord2d_dispatch_table_thunk;
    epoxy_glTexCoord2dv = epoxy_glTexCoord2dv_dispatch_table_thunk;
    epoxy_glTexCoord2f = epoxy_glTexCoord2f_dispatch_table_thunk;
    epoxy_glTexCoord2fColor3fVertex3fSUN = epoxy_glTexCoord2fColor3fVertex3fSUN_dispatch_table_thunk;
    epoxy_glTexCoord2fColor3fVertex3fvSUN = epoxy_glTexCoord2fColor3fVertex3fvSUN_dispatch_table_thunk;
    epoxy_glTexCoord2fColor4fNormal3fVertex3fSUN = epoxy_glTexCoord2fColor4fNormal3fVertex3fSUN_dispatch_table_thunk;
    epoxy_glTexCoord2fColor4fNormal3fVertex3fvSUN = epoxy_glTexCoord2fColor4fNormal3fVertex3fvSUN_dispatch_table_thunk;
    epoxy_glTexCoord2fColor4ubVertex3fSUN = epoxy_glTexCoord2fColor4ubVertex3fSUN_dispatch_table_thunk;
    epoxy_glTexCoord2fColor4ubVertex3fvSUN = epoxy_glTexCoord2fColor4ubVertex3fvSUN_dispatch_table_thunk;
    epoxy_glTexCoord2fNormal3fVertex3fSUN = epoxy_glTexCoord2fNormal3fVertex3fSUN_dispatch_table_thunk;
    epoxy_glTexCoord2fNormal3fVertex3fvSUN = epoxy_glTexCoord2fNormal3fVertex3fvSUN_dispatch_table_thunk;
    epoxy_glTexCoord2fVertex3fSUN = epoxy_glTexCoord2fVertex3fSUN_dispatch_table_thunk;
    epoxy_glTexCoord2fVertex3fvSUN = epoxy_glTexCoord2fVertex3fvSUN_dispatch_table_thunk;
    epoxy_glTexCoord2fv = epoxy_glTexCoord2fv_dispatch_table_thunk;
    epoxy_glTexCoord2hNV = epoxy_glTexCoord2hNV_dispatch_table_thunk;
    epoxy_glTexCoord2hvNV = epoxy_glTexCoord2hvNV_dispatch_table_thunk;
    epoxy_glTexCoord2i = epoxy_glTexCoord2i_dispatch_table_thunk;
    epoxy_glTexCoord2iv = epoxy_glTexCoord2iv_dispatch_table_thunk;
    epoxy_glTexCoord2s = epoxy_glTexCoord2s_dispatch_table_thunk;
    epoxy_glTexCoord2sv = epoxy_glTexCoord2sv_dispatch_table_thunk;
    epoxy_glTexCoord2xOES = epoxy_glTexCoord2xOES_dispatch_table_thunk;
    epoxy_glTexCoord2xvOES = epoxy_glTexCoord2xvOES_dispatch_table_thunk;
    epoxy_glTexCoord3bOES = epoxy_glTexCoord3bOES_dispatch_table_thunk;
    epoxy_glTexCoord3bvOES = epoxy_glTexCoord3bvOES_dispatch_table_thunk;
    epoxy_glTexCoord3d = epoxy_glTexCoord3d_dispatch_table_thunk;
    epoxy_glTexCoord3dv = epoxy_glTexCoord3dv_dispatch_table_thunk;
    epoxy_glTexCoord3f = epoxy_glTexCoord3f_dispatch_table_thunk;
    epoxy_glTexCoord3fv = epoxy_glTexCoord3fv_dispatch_table_thunk;
    epoxy_glTexCoord3hNV = epoxy_glTexCoord3hNV_dispatch_table_thunk;
    epoxy_glTexCoord3hvNV = epoxy_glTexCoord3hvNV_dispatch_table_thunk;
    epoxy_glTexCoord3i = epoxy_glTexCoord3i_dispatch_table_thunk;
    epoxy_glTexCoord3iv = epoxy_glTexCoord3iv_dispatch_table_thunk;
    epoxy_glTexCoord3s = epoxy_glTexCoord3s_dispatch_table_thunk;
    epoxy_glTexCoord3sv = epoxy_glTexCoord3sv_dispatch_table_thunk;
    epoxy_glTexCoord3xOES = epoxy_glTexCoord3xOES_dispatch_table_thunk;
    epoxy_glTexCoord3xvOES = epoxy_glTexCoord3xvOES_dispatch_table_thunk;
    epoxy_glTexCoord4bOES = epoxy_glTexCoord4bOES_dispatch_table_thunk;
    epoxy_glTexCoord4bvOES = epoxy_glTexCoord4bvOES_dispatch_table_thunk;
    epoxy_glTexCoord4d = epoxy_glTexCoord4d_dispatch_table_thunk;
    epoxy_glTexCoord4dv = epoxy_glTexCoord4dv_dispatch_table_thunk;
    epoxy_glTexCoord4f = epoxy_glTexCoord4f_dispatch_table_thunk;
    epoxy_glTexCoord4fColor4fNormal3fVertex4fSUN = epoxy_glTexCoord4fColor4fNormal3fVertex4fSUN_dispatch_table_thunk;
    epoxy_glTexCoord4fColor4fNormal3fVertex4fvSUN = epoxy_glTexCoord4fColor4fNormal3fVertex4fvSUN_dispatch_table_thunk;
    epoxy_glTexCoord4fVertex4fSUN = epoxy_glTexCoord4fVertex4fSUN_dispatch_table_thunk;
    epoxy_glTexCoord4fVertex4fvSUN = epoxy_glTexCoord4fVertex4fvSUN_dispatch_table_thunk;
    epoxy_glTexCoord4fv = epoxy_glTexCoord4fv_dispatch_table_thunk;
    epoxy_glTexCoord4hNV = epoxy_glTexCoord4hNV_dispatch_table_thunk;
    epoxy_glTexCoord4hvNV = epoxy_glTexCoord4hvNV_dispatch_table_thunk;
    epoxy_glTexCoord4i = epoxy_glTexCoord4i_dispatch_table_thunk;
    epoxy_glTexCoord4iv = epoxy_glTexCoord4iv_dispatch_table_thunk;
    epoxy_glTexCoord4s = epoxy_glTexCoord4s_dispatch_table_thunk;
    epoxy_glTexCoord4sv = epoxy_glTexCoord4sv_dispatch_table_thunk;
    epoxy_glTexCoord4xOES = epoxy_glTexCoord4xOES_dispatch_table_thunk;
    epoxy_glTexCoord4xvOES = epoxy_glTexCoord4xvOES_dispatch_table_thunk;
    epoxy_glTexCoordFormatNV = epoxy_glTexCoordFormatNV_dispatch_table_thunk;
    epoxy_glTexCoordP1ui = epoxy_glTexCoordP1ui_dispatch_table_thunk;
    epoxy_glTexCoordP1uiv = epoxy_glTexCoordP1uiv_dispatch_table_thunk;
    epoxy_glTexCoordP2ui = epoxy_glTexCoordP2ui_dispatch_table_thunk;
    epoxy_glTexCoordP2uiv = epoxy_glTexCoordP2uiv_dispatch_table_thunk;
    epoxy_glTexCoordP3ui = epoxy_glTexCoordP3ui_dispatch_table_thunk;
    epoxy_glTexCoordP3uiv = epoxy_glTexCoordP3uiv_dispatch_table_thunk;
    epoxy_glTexCoordP4ui = epoxy_glTexCoordP4ui_dispatch_table_thunk;
    epoxy_glTexCoordP4uiv = epoxy_glTexCoordP4uiv_dispatch_table_thunk;
    epoxy_glTexCoordPointer = epoxy_glTexCoordPointer_dispatch_table_thunk;
    epoxy_glTexCoordPointerEXT = epoxy_glTexCoordPointerEXT_dispatch_table_thunk;
    epoxy_glTexCoordPointerListIBM = epoxy_glTexCoordPointerListIBM_dispatch_table_thunk;
    epoxy_glTexCoordPointervINTEL = epoxy_glTexCoordPointervINTEL_dispatch_table_thunk;
    epoxy_glTexEnvf = epoxy_glTexEnvf_dispatch_table_thunk;
    epoxy_glTexEnvfv = epoxy_glTexEnvfv_dispatch_table_thunk;
    epoxy_glTexEnvi = epoxy_glTexEnvi_dispatch_table_thunk;
    epoxy_glTexEnviv = epoxy_glTexEnviv_dispatch_table_thunk;
    epoxy_glTexEnvx = epoxy_glTexEnvx_dispatch_table_thunk;
    epoxy_glTexEnvxOES = epoxy_glTexEnvxOES_dispatch_table_thunk;
    epoxy_glTexEnvxv = epoxy_glTexEnvxv_dispatch_table_thunk;
    epoxy_glTexEnvxvOES = epoxy_glTexEnvxvOES_dispatch_table_thunk;
    epoxy_glTexFilterFuncSGIS = epoxy_glTexFilterFuncSGIS_dispatch_table_thunk;
    epoxy_glTexGend = epoxy_glTexGend_dispatch_table_thunk;
    epoxy_glTexGendv = epoxy_glTexGendv_dispatch_table_thunk;
    epoxy_glTexGenf = epoxy_glTexGenf_dispatch_table_thunk;
    epoxy_glTexGenfOES = epoxy_glTexGenfOES_dispatch_table_thunk;
    epoxy_glTexGenfv = epoxy_glTexGenfv_dispatch_table_thunk;
    epoxy_glTexGenfvOES = epoxy_glTexGenfvOES_dispatch_table_thunk;
    epoxy_glTexGeni = epoxy_glTexGeni_dispatch_table_thunk;
    epoxy_glTexGeniOES = epoxy_glTexGeniOES_dispatch_table_thunk;
    epoxy_glTexGeniv = epoxy_glTexGeniv_dispatch_table_thunk;
    epoxy_glTexGenivOES = epoxy_glTexGenivOES_dispatch_table_thunk;
    epoxy_glTexGenxOES = epoxy_glTexGenxOES_dispatch_table_thunk;
    epoxy_glTexGenxvOES = epoxy_glTexGenxvOES_dispatch_table_thunk;
    epoxy_glTexImage1D = epoxy_glTexImage1D_dispatch_table_thunk;
    epoxy_glTexImage2D = epoxy_glTexImage2D_dispatch_table_thunk;
    epoxy_glTexImage2DMultisample = epoxy_glTexImage2DMultisample_dispatch_table_thunk;
    epoxy_glTexImage2DMultisampleCoverageNV = epoxy_glTexImage2DMultisampleCoverageNV_dispatch_table_thunk;
    epoxy_glTexImage3D = epoxy_glTexImage3D_dispatch_table_thunk;
    epoxy_glTexImage3DEXT = epoxy_glTexImage3DEXT_dispatch_table_thunk;
    epoxy_glTexImage3DMultisample = epoxy_glTexImage3DMultisample_dispatch_table_thunk;
    epoxy_glTexImage3DMultisampleCoverageNV = epoxy_glTexImage3DMultisampleCoverageNV_dispatch_table_thunk;
    epoxy_glTexImage3DOES = epoxy_glTexImage3DOES_dispatch_table_thunk;
    epoxy_glTexImage4DSGIS = epoxy_glTexImage4DSGIS_dispatch_table_thunk;
    epoxy_glTexPageCommitmentARB = epoxy_glTexPageCommitmentARB_dispatch_table_thunk;
    epoxy_glTexPageCommitmentEXT = epoxy_glTexPageCommitmentEXT_dispatch_table_thunk;
    epoxy_glTexParameterIiv = epoxy_glTexParameterIiv_dispatch_table_thunk;
    epoxy_glTexParameterIivEXT = epoxy_glTexParameterIivEXT_dispatch_table_thunk;
    epoxy_glTexParameterIivOES = epoxy_glTexParameterIivOES_dispatch_table_thunk;
    epoxy_glTexParameterIuiv = epoxy_glTexParameterIuiv_dispatch_table_thunk;
    epoxy_glTexParameterIuivEXT = epoxy_glTexParameterIuivEXT_dispatch_table_thunk;
    epoxy_glTexParameterIuivOES = epoxy_glTexParameterIuivOES_dispatch_table_thunk;
    epoxy_glTexParameterf = epoxy_glTexParameterf_dispatch_table_thunk;
    epoxy_glTexParameterfv = epoxy_glTexParameterfv_dispatch_table_thunk;
    epoxy_glTexParameteri = epoxy_glTexParameteri_dispatch_table_thunk;
    epoxy_glTexParameteriv = epoxy_glTexParameteriv_dispatch_table_thunk;
    epoxy_glTexParameterx = epoxy_glTexParameterx_dispatch_table_thunk;
    epoxy_glTexParameterxOES = epoxy_glTexParameterxOES_dispatch_table_thunk;
    epoxy_glTexParameterxv = epoxy_glTexParameterxv_dispatch_table_thunk;
    epoxy_glTexParameterxvOES = epoxy_glTexParameterxvOES_dispatch_table_thunk;
    epoxy_glTexRenderbufferNV = epoxy_glTexRenderbufferNV_dispatch_table_thunk;
    epoxy_glTexStorage1D = epoxy_glTexStorage1D_dispatch_table_thunk;
    epoxy_glTexStorage1DEXT = epoxy_glTexStorage1DEXT_dispatch_table_thunk;
    epoxy_glTexStorage2D = epoxy_glTexStorage2D_dispatch_table_thunk;
    epoxy_glTexStorage2DEXT = epoxy_glTexStorage2DEXT_dispatch_table_thunk;
    epoxy_glTexStorage2DMultisample = epoxy_glTexStorage2DMultisample_dispatch_table_thunk;
    epoxy_glTexStorage3D = epoxy_glTexStorage3D_dispatch_table_thunk;
    epoxy_glTexStorage3DEXT = epoxy_glTexStorage3DEXT_dispatch_table_thunk;
    epoxy_glTexStorage3DMultisample = epoxy_glTexStorage3DMultisample_dispatch_table_thunk;
    epoxy_glTexStorage3DMultisampleOES = epoxy_glTexStorage3DMultisampleOES_dispatch_table_thunk;
    epoxy_glTexStorageMem1DEXT = epoxy_glTexStorageMem1DEXT_dispatch_table_thunk;
    epoxy_glTexStorageMem2DEXT = epoxy_glTexStorageMem2DEXT_dispatch_table_thunk;
    epoxy_glTexStorageMem2DMultisampleEXT = epoxy_glTexStorageMem2DMultisampleEXT_dispatch_table_thunk;
    epoxy_glTexStorageMem3DEXT = epoxy_glTexStorageMem3DEXT_dispatch_table_thunk;
    epoxy_glTexStorageMem3DMultisampleEXT = epoxy_glTexStorageMem3DMultisampleEXT_dispatch_table_thunk;
    epoxy_glTexStorageSparseAMD = epoxy_glTexStorageSparseAMD_dispatch_table_thunk;
    epoxy_glTexSubImage1D = epoxy_glTexSubImage1D_dispatch_table_thunk;
    epoxy_glTexSubImage1DEXT = epoxy_glTexSubImage1DEXT_dispatch_table_thunk;
    epoxy_glTexSubImage2D = epoxy_glTexSubImage2D_dispatch_table_thunk;
    epoxy_glTexSubImage2DEXT = epoxy_glTexSubImage2DEXT_dispatch_table_thunk;
    epoxy_glTexSubImage3D = epoxy_glTexSubImage3D_dispatch_table_thunk;
    epoxy_glTexSubImage3DEXT = epoxy_glTexSubImage3DEXT_dispatch_table_thunk;
    epoxy_glTexSubImage3DOES = epoxy_glTexSubImage3DOES_dispatch_table_thunk;
    epoxy_glTexSubImage4DSGIS = epoxy_glTexSubImage4DSGIS_dispatch_table_thunk;
    epoxy_glTextureAttachMemoryNV = epoxy_glTextureAttachMemoryNV_dispatch_table_thunk;
    epoxy_glTextureBarrier = epoxy_glTextureBarrier_dispatch_table_thunk;
    epoxy_glTextureBarrierNV = epoxy_glTextureBarrierNV_dispatch_table_thunk;
    epoxy_glTextureBuffer = epoxy_glTextureBuffer_dispatch_table_thunk;
    epoxy_glTextureBufferEXT = epoxy_glTextureBufferEXT_dispatch_table_thunk;
    epoxy_glTextureBufferRange = epoxy_glTextureBufferRange_dispatch_table_thunk;
    epoxy_glTextureBufferRangeEXT = epoxy_glTextureBufferRangeEXT_dispatch_table_thunk;
    epoxy_glTextureColorMaskSGIS = epoxy_glTextureColorMaskSGIS_dispatch_table_thunk;
    epoxy_glTextureFoveationParametersQCOM = epoxy_glTextureFoveationParametersQCOM_dispatch_table_thunk;
    epoxy_glTextureImage1DEXT = epoxy_glTextureImage1DEXT_dispatch_table_thunk;
    epoxy_glTextureImage2DEXT = epoxy_glTextureImage2DEXT_dispatch_table_thunk;
    epoxy_glTextureImage2DMultisampleCoverageNV = epoxy_glTextureImage2DMultisampleCoverageNV_dispatch_table_thunk;
    epoxy_glTextureImage2DMultisampleNV = epoxy_glTextureImage2DMultisampleNV_dispatch_table_thunk;
    epoxy_glTextureImage3DEXT = epoxy_glTextureImage3DEXT_dispatch_table_thunk;
    epoxy_glTextureImage3DMultisampleCoverageNV = epoxy_glTextureImage3DMultisampleCoverageNV_dispatch_table_thunk;
    epoxy_glTextureImage3DMultisampleNV = epoxy_glTextureImage3DMultisampleNV_dispatch_table_thunk;
    epoxy_glTextureLightEXT = epoxy_glTextureLightEXT_dispatch_table_thunk;
    epoxy_glTextureMaterialEXT = epoxy_glTextureMaterialEXT_dispatch_table_thunk;
    epoxy_glTextureNormalEXT = epoxy_glTextureNormalEXT_dispatch_table_thunk;
    epoxy_glTexturePageCommitmentEXT = epoxy_glTexturePageCommitmentEXT_dispatch_table_thunk;
    epoxy_glTextureParameterIiv = epoxy_glTextureParameterIiv_dispatch_table_thunk;
    epoxy_glTextureParameterIivEXT = epoxy_glTextureParameterIivEXT_dispatch_table_thunk;
    epoxy_glTextureParameterIuiv = epoxy_glTextureParameterIuiv_dispatch_table_thunk;
    epoxy_glTextureParameterIuivEXT = epoxy_glTextureParameterIuivEXT_dispatch_table_thunk;
    epoxy_glTextureParameterf = epoxy_glTextureParameterf_dispatch_table_thunk;
    epoxy_glTextureParameterfEXT = epoxy_glTextureParameterfEXT_dispatch_table_thunk;
    epoxy_glTextureParameterfv = epoxy_glTextureParameterfv_dispatch_table_thunk;
    epoxy_glTextureParameterfvEXT = epoxy_glTextureParameterfvEXT_dispatch_table_thunk;
    epoxy_glTextureParameteri = epoxy_glTextureParameteri_dispatch_table_thunk;
    epoxy_glTextureParameteriEXT = epoxy_glTextureParameteriEXT_dispatch_table_thunk;
    epoxy_glTextureParameteriv = epoxy_glTextureParameteriv_dispatch_table_thunk;
    epoxy_glTextureParameterivEXT = epoxy_glTextureParameterivEXT_dispatch_table_thunk;
    epoxy_glTextureRangeAPPLE = epoxy_glTextureRangeAPPLE_dispatch_table_thunk;
    epoxy_glTextureRenderbufferEXT = epoxy_glTextureRenderbufferEXT_dispatch_table_thunk;
    epoxy_glTextureStorage1D = epoxy_glTextureStorage1D_dispatch_table_thunk;
    epoxy_glTextureStorage1DEXT = epoxy_glTextureStorage1DEXT_dispatch_table_thunk;
    epoxy_glTextureStorage2D = epoxy_glTextureStorage2D_dispatch_table_thunk;
    epoxy_glTextureStorage2DEXT = epoxy_glTextureStorage2DEXT_dispatch_table_thunk;
    epoxy_glTextureStorage2DMultisample = epoxy_glTextureStorage2DMultisample_dispatch_table_thunk;
    epoxy_glTextureStorage2DMultisampleEXT = epoxy_glTextureStorage2DMultisampleEXT_dispatch_table_thunk;
    epoxy_glTextureStorage3D = epoxy_glTextureStorage3D_dispatch_table_thunk;
    epoxy_glTextureStorage3DEXT = epoxy_glTextureStorage3DEXT_dispatch_table_thunk;
    epoxy_glTextureStorage3DMultisample = epoxy_glTextureStorage3DMultisample_dispatch_table_thunk;
    epoxy_glTextureStorage3DMultisampleEXT = epoxy_glTextureStorage3DMultisampleEXT_dispatch_table_thunk;
    epoxy_glTextureStorageMem1DEXT = epoxy_glTextureStorageMem1DEXT_dispatch_table_thunk;
    epoxy_glTextureStorageMem2DEXT = epoxy_glTextureStorageMem2DEXT_dispatch_table_thunk;
    epoxy_glTextureStorageMem2DMultisampleEXT = epoxy_glTextureStorageMem2DMultisampleEXT_dispatch_table_thunk;
    epoxy_glTextureStorageMem3DEXT = epoxy_glTextureStorageMem3DEXT_dispatch_table_thunk;
    epoxy_glTextureStorageMem3DMultisampleEXT = epoxy_glTextureStorageMem3DMultisampleEXT_dispatch_table_thunk;
    epoxy_glTextureStorageSparseAMD = epoxy_glTextureStorageSparseAMD_dispatch_table_thunk;
    epoxy_glTextureSubImage1D = epoxy_glTextureSubImage1D_dispatch_table_thunk;
    epoxy_glTextureSubImage1DEXT = epoxy_glTextureSubImage1DEXT_dispatch_table_thunk;
    epoxy_glTextureSubImage2D = epoxy_glTextureSubImage2D_dispatch_table_thunk;
    epoxy_glTextureSubImage2DEXT = epoxy_glTextureSubImage2DEXT_dispatch_table_thunk;
    epoxy_glTextureSubImage3D = epoxy_glTextureSubImage3D_dispatch_table_thunk;
    epoxy_glTextureSubImage3DEXT = epoxy_glTextureSubImage3DEXT_dispatch_table_thunk;
    epoxy_glTextureView = epoxy_glTextureView_dispatch_table_thunk;
    epoxy_glTextureViewEXT = epoxy_glTextureViewEXT_dispatch_table_thunk;
    epoxy_glTextureViewOES = epoxy_glTextureViewOES_dispatch_table_thunk;
    epoxy_glTrackMatrixNV = epoxy_glTrackMatrixNV_dispatch_table_thunk;
    epoxy_glTransformFeedbackAttribsNV = epoxy_glTransformFeedbackAttribsNV_dispatch_table_thunk;
    epoxy_glTransformFeedbackBufferBase = epoxy_glTransformFeedbackBufferBase_dispatch_table_thunk;
    epoxy_glTransformFeedbackBufferRange = epoxy_glTransformFeedbackBufferRange_dispatch_table_thunk;
    epoxy_glTransformFeedbackStreamAttribsNV = epoxy_glTransformFeedbackStreamAttribsNV_dispatch_table_thunk;
    epoxy_glTransformFeedbackVaryings = epoxy_glTransformFeedbackVaryings_dispatch_table_thunk;
    epoxy_glTransformFeedbackVaryingsEXT = epoxy_glTransformFeedbackVaryingsEXT_dispatch_table_thunk;
    epoxy_glTransformFeedbackVaryingsNV = epoxy_glTransformFeedbackVaryingsNV_dispatch_table_thunk;
    epoxy_glTransformPathNV = epoxy_glTransformPathNV_dispatch_table_thunk;
    epoxy_glTranslated = epoxy_glTranslated_dispatch_table_thunk;
    epoxy_glTranslatef = epoxy_glTranslatef_dispatch_table_thunk;
    epoxy_glTranslatex = epoxy_glTranslatex_dispatch_table_thunk;
    epoxy_glTranslatexOES = epoxy_glTranslatexOES_dispatch_table_thunk;
    epoxy_glUniform1d = epoxy_glUniform1d_dispatch_table_thunk;
    epoxy_glUniform1dv = epoxy_glUniform1dv_dispatch_table_thunk;
    epoxy_glUniform1f = epoxy_glUniform1f_dispatch_table_thunk;
    epoxy_glUniform1fARB = epoxy_glUniform1fARB_dispatch_table_thunk;
    epoxy_glUniform1fv = epoxy_glUniform1fv_dispatch_table_thunk;
    epoxy_glUniform1fvARB = epoxy_glUniform1fvARB_dispatch_table_thunk;
    epoxy_glUniform1i = epoxy_glUniform1i_dispatch_table_thunk;
    epoxy_glUniform1i64ARB = epoxy_glUniform1i64ARB_dispatch_table_thunk;
    epoxy_glUniform1i64NV = epoxy_glUniform1i64NV_dispatch_table_thunk;
    epoxy_glUniform1i64vARB = epoxy_glUniform1i64vARB_dispatch_table_thunk;
    epoxy_glUniform1i64vNV = epoxy_glUniform1i64vNV_dispatch_table_thunk;
    epoxy_glUniform1iARB = epoxy_glUniform1iARB_dispatch_table_thunk;
    epoxy_glUniform1iv = epoxy_glUniform1iv_dispatch_table_thunk;
    epoxy_glUniform1ivARB = epoxy_glUniform1ivARB_dispatch_table_thunk;
    epoxy_glUniform1ui = epoxy_glUniform1ui_dispatch_table_thunk;
    epoxy_glUniform1ui64ARB = epoxy_glUniform1ui64ARB_dispatch_table_thunk;
    epoxy_glUniform1ui64NV = epoxy_glUniform1ui64NV_dispatch_table_thunk;
    epoxy_glUniform1ui64vARB = epoxy_glUniform1ui64vARB_dispatch_table_thunk;
    epoxy_glUniform1ui64vNV = epoxy_glUniform1ui64vNV_dispatch_table_thunk;
    epoxy_glUniform1uiEXT = epoxy_glUniform1uiEXT_dispatch_table_thunk;
    epoxy_glUniform1uiv = epoxy_glUniform1uiv_dispatch_table_thunk;
    epoxy_glUniform1uivEXT = epoxy_glUniform1uivEXT_dispatch_table_thunk;
    epoxy_glUniform2d = epoxy_glUniform2d_dispatch_table_thunk;
    epoxy_glUniform2dv = epoxy_glUniform2dv_dispatch_table_thunk;
    epoxy_glUniform2f = epoxy_glUniform2f_dispatch_table_thunk;
    epoxy_glUniform2fARB = epoxy_glUniform2fARB_dispatch_table_thunk;
    epoxy_glUniform2fv = epoxy_glUniform2fv_dispatch_table_thunk;
    epoxy_glUniform2fvARB = epoxy_glUniform2fvARB_dispatch_table_thunk;
    epoxy_glUniform2i = epoxy_glUniform2i_dispatch_table_thunk;
    epoxy_glUniform2i64ARB = epoxy_glUniform2i64ARB_dispatch_table_thunk;
    epoxy_glUniform2i64NV = epoxy_glUniform2i64NV_dispatch_table_thunk;
    epoxy_glUniform2i64vARB = epoxy_glUniform2i64vARB_dispatch_table_thunk;
    epoxy_glUniform2i64vNV = epoxy_glUniform2i64vNV_dispatch_table_thunk;
    epoxy_glUniform2iARB = epoxy_glUniform2iARB_dispatch_table_thunk;
    epoxy_glUniform2iv = epoxy_glUniform2iv_dispatch_table_thunk;
    epoxy_glUniform2ivARB = epoxy_glUniform2ivARB_dispatch_table_thunk;
    epoxy_glUniform2ui = epoxy_glUniform2ui_dispatch_table_thunk;
    epoxy_glUniform2ui64ARB = epoxy_glUniform2ui64ARB_dispatch_table_thunk;
    epoxy_glUniform2ui64NV = epoxy_glUniform2ui64NV_dispatch_table_thunk;
    epoxy_glUniform2ui64vARB = epoxy_glUniform2ui64vARB_dispatch_table_thunk;
    epoxy_glUniform2ui64vNV = epoxy_glUniform2ui64vNV_dispatch_table_thunk;
    epoxy_glUniform2uiEXT = epoxy_glUniform2uiEXT_dispatch_table_thunk;
    epoxy_glUniform2uiv = epoxy_glUniform2uiv_dispatch_table_thunk;
    epoxy_glUniform2uivEXT = epoxy_glUniform2uivEXT_dispatch_table_thunk;
    epoxy_glUniform3d = epoxy_glUniform3d_dispatch_table_thunk;
    epoxy_glUniform3dv = epoxy_glUniform3dv_dispatch_table_thunk;
    epoxy_glUniform3f = epoxy_glUniform3f_dispatch_table_thunk;
    epoxy_glUniform3fARB = epoxy_glUniform3fARB_dispatch_table_thunk;
    epoxy_glUniform3fv = epoxy_glUniform3fv_dispatch_table_thunk;
    epoxy_glUniform3fvARB = epoxy_glUniform3fvARB_dispatch_table_thunk;
    epoxy_glUniform3i = epoxy_glUniform3i_dispatch_table_thunk;
    epoxy_glUniform3i64ARB = epoxy_glUniform3i64ARB_dispatch_table_thunk;
    epoxy_glUniform3i64NV = epoxy_glUniform3i64NV_dispatch_table_thunk;
    epoxy_glUniform3i64vARB = epoxy_glUniform3i64vARB_dispatch_table_thunk;
    epoxy_glUniform3i64vNV = epoxy_glUniform3i64vNV_dispatch_table_thunk;
    epoxy_glUniform3iARB = epoxy_glUniform3iARB_dispatch_table_thunk;
    epoxy_glUniform3iv = epoxy_glUniform3iv_dispatch_table_thunk;
    epoxy_glUniform3ivARB = epoxy_glUniform3ivARB_dispatch_table_thunk;
    epoxy_glUniform3ui = epoxy_glUniform3ui_dispatch_table_thunk;
    epoxy_glUniform3ui64ARB = epoxy_glUniform3ui64ARB_dispatch_table_thunk;
    epoxy_glUniform3ui64NV = epoxy_glUniform3ui64NV_dispatch_table_thunk;
    epoxy_glUniform3ui64vARB = epoxy_glUniform3ui64vARB_dispatch_table_thunk;
    epoxy_glUniform3ui64vNV = epoxy_glUniform3ui64vNV_dispatch_table_thunk;
    epoxy_glUniform3uiEXT = epoxy_glUniform3uiEXT_dispatch_table_thunk;
    epoxy_glUniform3uiv = epoxy_glUniform3uiv_dispatch_table_thunk;
    epoxy_glUniform3uivEXT = epoxy_glUniform3uivEXT_dispatch_table_thunk;
    epoxy_glUniform4d = epoxy_glUniform4d_dispatch_table_thunk;
    epoxy_glUniform4dv = epoxy_glUniform4dv_dispatch_table_thunk;
    epoxy_glUniform4f = epoxy_glUniform4f_dispatch_table_thunk;
    epoxy_glUniform4fARB = epoxy_glUniform4fARB_dispatch_table_thunk;
    epoxy_glUniform4fv = epoxy_glUniform4fv_dispatch_table_thunk;
    epoxy_glUniform4fvARB = epoxy_glUniform4fvARB_dispatch_table_thunk;
    epoxy_glUniform4i = epoxy_glUniform4i_dispatch_table_thunk;
    epoxy_glUniform4i64ARB = epoxy_glUniform4i64ARB_dispatch_table_thunk;
    epoxy_glUniform4i64NV = epoxy_glUniform4i64NV_dispatch_table_thunk;
    epoxy_glUniform4i64vARB = epoxy_glUniform4i64vARB_dispatch_table_thunk;
    epoxy_glUniform4i64vNV = epoxy_glUniform4i64vNV_dispatch_table_thunk;
    epoxy_glUniform4iARB = epoxy_glUniform4iARB_dispatch_table_thunk;
    epoxy_glUniform4iv = epoxy_glUniform4iv_dispatch_table_thunk;
    epoxy_glUniform4ivARB = epoxy_glUniform4ivARB_dispatch_table_thunk;
    epoxy_glUniform4ui = epoxy_glUniform4ui_dispatch_table_thunk;
    epoxy_glUniform4ui64ARB = epoxy_glUniform4ui64ARB_dispatch_table_thunk;
    epoxy_glUniform4ui64NV = epoxy_glUniform4ui64NV_dispatch_table_thunk;
    epoxy_glUniform4ui64vARB = epoxy_glUniform4ui64vARB_dispatch_table_thunk;
    epoxy_glUniform4ui64vNV = epoxy_glUniform4ui64vNV_dispatch_table_thunk;
    epoxy_glUniform4uiEXT = epoxy_glUniform4uiEXT_dispatch_table_thunk;
    epoxy_glUniform4uiv = epoxy_glUniform4uiv_dispatch_table_thunk;
    epoxy_glUniform4uivEXT = epoxy_glUniform4uivEXT_dispatch_table_thunk;
    epoxy_glUniformBlockBinding = epoxy_glUniformBlockBinding_dispatch_table_thunk;
    epoxy_glUniformBufferEXT = epoxy_glUniformBufferEXT_dispatch_table_thunk;
    epoxy_glUniformHandleui64ARB = epoxy_glUniformHandleui64ARB_dispatch_table_thunk;
    epoxy_glUniformHandleui64IMG = epoxy_glUniformHandleui64IMG_dispatch_table_thunk;
    epoxy_glUniformHandleui64NV = epoxy_glUniformHandleui64NV_dispatch_table_thunk;
    epoxy_glUniformHandleui64vARB = epoxy_glUniformHandleui64vARB_dispatch_table_thunk;
    epoxy_glUniformHandleui64vIMG = epoxy_glUniformHandleui64vIMG_dispatch_table_thunk;
    epoxy_glUniformHandleui64vNV = epoxy_glUniformHandleui64vNV_dispatch_table_thunk;
    epoxy_glUniformMatrix2dv = epoxy_glUniformMatrix2dv_dispatch_table_thunk;
    epoxy_glUniformMatrix2fv = epoxy_glUniformMatrix2fv_dispatch_table_thunk;
    epoxy_glUniformMatrix2fvARB = epoxy_glUniformMatrix2fvARB_dispatch_table_thunk;
    epoxy_glUniformMatrix2x3dv = epoxy_glUniformMatrix2x3dv_dispatch_table_thunk;
    epoxy_glUniformMatrix2x3fv = epoxy_glUniformMatrix2x3fv_dispatch_table_thunk;
    epoxy_glUniformMatrix2x3fvNV = epoxy_glUniformMatrix2x3fvNV_dispatch_table_thunk;
    epoxy_glUniformMatrix2x4dv = epoxy_glUniformMatrix2x4dv_dispatch_table_thunk;
    epoxy_glUniformMatrix2x4fv = epoxy_glUniformMatrix2x4fv_dispatch_table_thunk;
    epoxy_glUniformMatrix2x4fvNV = epoxy_glUniformMatrix2x4fvNV_dispatch_table_thunk;
    epoxy_glUniformMatrix3dv = epoxy_glUniformMatrix3dv_dispatch_table_thunk;
    epoxy_glUniformMatrix3fv = epoxy_glUniformMatrix3fv_dispatch_table_thunk;
    epoxy_glUniformMatrix3fvARB = epoxy_glUniformMatrix3fvARB_dispatch_table_thunk;
    epoxy_glUniformMatrix3x2dv = epoxy_glUniformMatrix3x2dv_dispatch_table_thunk;
    epoxy_glUniformMatrix3x2fv = epoxy_glUniformMatrix3x2fv_dispatch_table_thunk;
    epoxy_glUniformMatrix3x2fvNV = epoxy_glUniformMatrix3x2fvNV_dispatch_table_thunk;
    epoxy_glUniformMatrix3x4dv = epoxy_glUniformMatrix3x4dv_dispatch_table_thunk;
    epoxy_glUniformMatrix3x4fv = epoxy_glUniformMatrix3x4fv_dispatch_table_thunk;
    epoxy_glUniformMatrix3x4fvNV = epoxy_glUniformMatrix3x4fvNV_dispatch_table_thunk;
    epoxy_glUniformMatrix4dv = epoxy_glUniformMatrix4dv_dispatch_table_thunk;
    epoxy_glUniformMatrix4fv = epoxy_glUniformMatrix4fv_dispatch_table_thunk;
    epoxy_glUniformMatrix4fvARB = epoxy_glUniformMatrix4fvARB_dispatch_table_thunk;
    epoxy_glUniformMatrix4x2dv = epoxy_glUniformMatrix4x2dv_dispatch_table_thunk;
    epoxy_glUniformMatrix4x2fv = epoxy_glUniformMatrix4x2fv_dispatch_table_thunk;
    epoxy_glUniformMatrix4x2fvNV = epoxy_glUniformMatrix4x2fvNV_dispatch_table_thunk;
    epoxy_glUniformMatrix4x3dv = epoxy_glUniformMatrix4x3dv_dispatch_table_thunk;
    epoxy_glUniformMatrix4x3fv = epoxy_glUniformMatrix4x3fv_dispatch_table_thunk;
    epoxy_glUniformMatrix4x3fvNV = epoxy_glUniformMatrix4x3fvNV_dispatch_table_thunk;
    epoxy_glUniformSubroutinesuiv = epoxy_glUniformSubroutinesuiv_dispatch_table_thunk;
    epoxy_glUniformui64NV = epoxy_glUniformui64NV_dispatch_table_thunk;
    epoxy_glUniformui64vNV = epoxy_glUniformui64vNV_dispatch_table_thunk;
    epoxy_glUnlockArraysEXT = epoxy_glUnlockArraysEXT_dispatch_table_thunk;
    epoxy_glUnmapBuffer = epoxy_glUnmapBuffer_dispatch_table_thunk;
    epoxy_glUnmapBufferARB = epoxy_glUnmapBufferARB_dispatch_table_thunk;
    epoxy_glUnmapBufferOES = epoxy_glUnmapBufferOES_dispatch_table_thunk;
    epoxy_glUnmapNamedBuffer = epoxy_glUnmapNamedBuffer_dispatch_table_thunk;
    epoxy_glUnmapNamedBufferEXT = epoxy_glUnmapNamedBufferEXT_dispatch_table_thunk;
    epoxy_glUnmapObjectBufferATI = epoxy_glUnmapObjectBufferATI_dispatch_table_thunk;
    epoxy_glUnmapTexture2DINTEL = epoxy_glUnmapTexture2DINTEL_dispatch_table_thunk;
    epoxy_glUpdateObjectBufferATI = epoxy_glUpdateObjectBufferATI_dispatch_table_thunk;
    epoxy_glUploadGpuMaskNVX = epoxy_glUploadGpuMaskNVX_dispatch_table_thunk;
    epoxy_glUseProgram = epoxy_glUseProgram_dispatch_table_thunk;
    epoxy_glUseProgramObjectARB = epoxy_glUseProgramObjectARB_dispatch_table_thunk;
    epoxy_glUseProgramStages = epoxy_glUseProgramStages_dispatch_table_thunk;
    epoxy_glUseProgramStagesEXT = epoxy_glUseProgramStagesEXT_dispatch_table_thunk;
    epoxy_glUseShaderProgramEXT = epoxy_glUseShaderProgramEXT_dispatch_table_thunk;
    epoxy_glVDPAUFiniNV = epoxy_glVDPAUFiniNV_dispatch_table_thunk;
    epoxy_glVDPAUGetSurfaceivNV = epoxy_glVDPAUGetSurfaceivNV_dispatch_table_thunk;
    epoxy_glVDPAUInitNV = epoxy_glVDPAUInitNV_dispatch_table_thunk;
    epoxy_glVDPAUIsSurfaceNV = epoxy_glVDPAUIsSurfaceNV_dispatch_table_thunk;
    epoxy_glVDPAUMapSurfacesNV = epoxy_glVDPAUMapSurfacesNV_dispatch_table_thunk;
    epoxy_glVDPAURegisterOutputSurfaceNV = epoxy_glVDPAURegisterOutputSurfaceNV_dispatch_table_thunk;
    epoxy_glVDPAURegisterVideoSurfaceNV = epoxy_glVDPAURegisterVideoSurfaceNV_dispatch_table_thunk;
    epoxy_glVDPAURegisterVideoSurfaceWithPictureStructureNV = epoxy_glVDPAURegisterVideoSurfaceWithPictureStructureNV_dispatch_table_thunk;
    epoxy_glVDPAUSurfaceAccessNV = epoxy_glVDPAUSurfaceAccessNV_dispatch_table_thunk;
    epoxy_glVDPAUUnmapSurfacesNV = epoxy_glVDPAUUnmapSurfacesNV_dispatch_table_thunk;
    epoxy_glVDPAUUnregisterSurfaceNV = epoxy_glVDPAUUnregisterSurfaceNV_dispatch_table_thunk;
    epoxy_glValidateProgram = epoxy_glValidateProgram_dispatch_table_thunk;
    epoxy_glValidateProgramARB = epoxy_glValidateProgramARB_dispatch_table_thunk;
    epoxy_glValidateProgramPipeline = epoxy_glValidateProgramPipeline_dispatch_table_thunk;
    epoxy_glValidateProgramPipelineEXT = epoxy_glValidateProgramPipelineEXT_dispatch_table_thunk;
    epoxy_glVariantArrayObjectATI = epoxy_glVariantArrayObjectATI_dispatch_table_thunk;
    epoxy_glVariantPointerEXT = epoxy_glVariantPointerEXT_dispatch_table_thunk;
    epoxy_glVariantbvEXT = epoxy_glVariantbvEXT_dispatch_table_thunk;
    epoxy_glVariantdvEXT = epoxy_glVariantdvEXT_dispatch_table_thunk;
    epoxy_glVariantfvEXT = epoxy_glVariantfvEXT_dispatch_table_thunk;
    epoxy_glVariantivEXT = epoxy_glVariantivEXT_dispatch_table_thunk;
    epoxy_glVariantsvEXT = epoxy_glVariantsvEXT_dispatch_table_thunk;
    epoxy_glVariantubvEXT = epoxy_glVariantubvEXT_dispatch_table_thunk;
    epoxy_glVariantuivEXT = epoxy_glVariantuivEXT_dispatch_table_thunk;
    epoxy_glVariantusvEXT = epoxy_glVariantusvEXT_dispatch_table_thunk;
    epoxy_glVertex2bOES = epoxy_glVertex2bOES_dispatch_table_thunk;
    epoxy_glVertex2bvOES = epoxy_glVertex2bvOES_dispatch_table_thunk;
    epoxy_glVertex2d = epoxy_glVertex2d_dispatch_table_thunk;
    epoxy_glVertex2dv = epoxy_glVertex2dv_dispatch_table_thunk;
    epoxy_glVertex2f = epoxy_glVertex2f_dispatch_table_thunk;
    epoxy_glVertex2fv = epoxy_glVertex2fv_dispatch_table_thunk;
    epoxy_glVertex2hNV = epoxy_glVertex2hNV_dispatch_table_thunk;
    epoxy_glVertex2hvNV = epoxy_glVertex2hvNV_dispatch_table_thunk;
    epoxy_glVertex2i = epoxy_glVertex2i_dispatch_table_thunk;
    epoxy_glVertex2iv = epoxy_glVertex2iv_dispatch_table_thunk;
    epoxy_glVertex2s = epoxy_glVertex2s_dispatch_table_thunk;
    epoxy_glVertex2sv = epoxy_glVertex2sv_dispatch_table_thunk;
    epoxy_glVertex2xOES = epoxy_glVertex2xOES_dispatch_table_thunk;
    epoxy_glVertex2xvOES = epoxy_glVertex2xvOES_dispatch_table_thunk;
    epoxy_glVertex3bOES = epoxy_glVertex3bOES_dispatch_table_thunk;
    epoxy_glVertex3bvOES = epoxy_glVertex3bvOES_dispatch_table_thunk;
    epoxy_glVertex3d = epoxy_glVertex3d_dispatch_table_thunk;
    epoxy_glVertex3dv = epoxy_glVertex3dv_dispatch_table_thunk;
    epoxy_glVertex3f = epoxy_glVertex3f_dispatch_table_thunk;
    epoxy_glVertex3fv = epoxy_glVertex3fv_dispatch_table_thunk;
    epoxy_glVertex3hNV = epoxy_glVertex3hNV_dispatch_table_thunk;
    epoxy_glVertex3hvNV = epoxy_glVertex3hvNV_dispatch_table_thunk;
    epoxy_glVertex3i = epoxy_glVertex3i_dispatch_table_thunk;
    epoxy_glVertex3iv = epoxy_glVertex3iv_dispatch_table_thunk;
    epoxy_glVertex3s = epoxy_glVertex3s_dispatch_table_thunk;
    epoxy_glVertex3sv = epoxy_glVertex3sv_dispatch_table_thunk;
    epoxy_glVertex3xOES = epoxy_glVertex3xOES_dispatch_table_thunk;
    epoxy_glVertex3xvOES = epoxy_glVertex3xvOES_dispatch_table_thunk;
    epoxy_glVertex4bOES = epoxy_glVertex4bOES_dispatch_table_thunk;
    epoxy_glVertex4bvOES = epoxy_glVertex4bvOES_dispatch_table_thunk;
    epoxy_glVertex4d = epoxy_glVertex4d_dispatch_table_thunk;
    epoxy_glVertex4dv = epoxy_glVertex4dv_dispatch_table_thunk;
    epoxy_glVertex4f = epoxy_glVertex4f_dispatch_table_thunk;
    epoxy_glVertex4fv = epoxy_glVertex4fv_dispatch_table_thunk;
    epoxy_glVertex4hNV = epoxy_glVertex4hNV_dispatch_table_thunk;
    epoxy_glVertex4hvNV = epoxy_glVertex4hvNV_dispatch_table_thunk;
    epoxy_glVertex4i = epoxy_glVertex4i_dispatch_table_thunk;
    epoxy_glVertex4iv = epoxy_glVertex4iv_dispatch_table_thunk;
    epoxy_glVertex4s = epoxy_glVertex4s_dispatch_table_thunk;
    epoxy_glVertex4sv = epoxy_glVertex4sv_dispatch_table_thunk;
    epoxy_glVertex4xOES = epoxy_glVertex4xOES_dispatch_table_thunk;
    epoxy_glVertex4xvOES = epoxy_glVertex4xvOES_dispatch_table_thunk;
    epoxy_glVertexArrayAttribBinding = epoxy_glVertexArrayAttribBinding_dispatch_table_thunk;
    epoxy_glVertexArrayAttribFormat = epoxy_glVertexArrayAttribFormat_dispatch_table_thunk;
    epoxy_glVertexArrayAttribIFormat = epoxy_glVertexArrayAttribIFormat_dispatch_table_thunk;
    epoxy_glVertexArrayAttribLFormat = epoxy_glVertexArrayAttribLFormat_dispatch_table_thunk;
    epoxy_glVertexArrayBindVertexBufferEXT = epoxy_glVertexArrayBindVertexBufferEXT_dispatch_table_thunk;
    epoxy_glVertexArrayBindingDivisor = epoxy_glVertexArrayBindingDivisor_dispatch_table_thunk;
    epoxy_glVertexArrayColorOffsetEXT = epoxy_glVertexArrayColorOffsetEXT_dispatch_table_thunk;
    epoxy_glVertexArrayEdgeFlagOffsetEXT = epoxy_glVertexArrayEdgeFlagOffsetEXT_dispatch_table_thunk;
    epoxy_glVertexArrayElementBuffer = epoxy_glVertexArrayElementBuffer_dispatch_table_thunk;
    epoxy_glVertexArrayFogCoordOffsetEXT = epoxy_glVertexArrayFogCoordOffsetEXT_dispatch_table_thunk;
    epoxy_glVertexArrayIndexOffsetEXT = epoxy_glVertexArrayIndexOffsetEXT_dispatch_table_thunk;
    epoxy_glVertexArrayMultiTexCoordOffsetEXT = epoxy_glVertexArrayMultiTexCoordOffsetEXT_dispatch_table_thunk;
    epoxy_glVertexArrayNormalOffsetEXT = epoxy_glVertexArrayNormalOffsetEXT_dispatch_table_thunk;
    epoxy_glVertexArrayParameteriAPPLE = epoxy_glVertexArrayParameteriAPPLE_dispatch_table_thunk;
    epoxy_glVertexArrayRangeAPPLE = epoxy_glVertexArrayRangeAPPLE_dispatch_table_thunk;
    epoxy_glVertexArrayRangeNV = epoxy_glVertexArrayRangeNV_dispatch_table_thunk;
    epoxy_glVertexArraySecondaryColorOffsetEXT = epoxy_glVertexArraySecondaryColorOffsetEXT_dispatch_table_thunk;
    epoxy_glVertexArrayTexCoordOffsetEXT = epoxy_glVertexArrayTexCoordOffsetEXT_dispatch_table_thunk;
    epoxy_glVertexArrayVertexAttribBindingEXT = epoxy_glVertexArrayVertexAttribBindingEXT_dispatch_table_thunk;
    epoxy_glVertexArrayVertexAttribDivisorEXT = epoxy_glVertexArrayVertexAttribDivisorEXT_dispatch_table_thunk;
    epoxy_glVertexArrayVertexAttribFormatEXT = epoxy_glVertexArrayVertexAttribFormatEXT_dispatch_table_thunk;
    epoxy_glVertexArrayVertexAttribIFormatEXT = epoxy_glVertexArrayVertexAttribIFormatEXT_dispatch_table_thunk;
    epoxy_glVertexArrayVertexAttribIOffsetEXT = epoxy_glVertexArrayVertexAttribIOffsetEXT_dispatch_table_thunk;
    epoxy_glVertexArrayVertexAttribLFormatEXT = epoxy_glVertexArrayVertexAttribLFormatEXT_dispatch_table_thunk;
    epoxy_glVertexArrayVertexAttribLOffsetEXT = epoxy_glVertexArrayVertexAttribLOffsetEXT_dispatch_table_thunk;
    epoxy_glVertexArrayVertexAttribOffsetEXT = epoxy_glVertexArrayVertexAttribOffsetEXT_dispatch_table_thunk;
    epoxy_glVertexArrayVertexBindingDivisorEXT = epoxy_glVertexArrayVertexBindingDivisorEXT_dispatch_table_thunk;
    epoxy_glVertexArrayVertexBuffer = epoxy_glVertexArrayVertexBuffer_dispatch_table_thunk;
    epoxy_glVertexArrayVertexBuffers = epoxy_glVertexArrayVertexBuffers_dispatch_table_thunk;
    epoxy_glVertexArrayVertexOffsetEXT = epoxy_glVertexArrayVertexOffsetEXT_dispatch_table_thunk;
    epoxy_glVertexAttrib1d = epoxy_glVertexAttrib1d_dispatch_table_thunk;
    epoxy_glVertexAttrib1dARB = epoxy_glVertexAttrib1dARB_dispatch_table_thunk;
    epoxy_glVertexAttrib1dNV = epoxy_glVertexAttrib1dNV_dispatch_table_thunk;
    epoxy_glVertexAttrib1dv = epoxy_glVertexAttrib1dv_dispatch_table_thunk;
    epoxy_glVertexAttrib1dvARB = epoxy_glVertexAttrib1dvARB_dispatch_table_thunk;
    epoxy_glVertexAttrib1dvNV = epoxy_glVertexAttrib1dvNV_dispatch_table_thunk;
    epoxy_glVertexAttrib1f = epoxy_glVertexAttrib1f_dispatch_table_thunk;
    epoxy_glVertexAttrib1fARB = epoxy_glVertexAttrib1fARB_dispatch_table_thunk;
    epoxy_glVertexAttrib1fNV = epoxy_glVertexAttrib1fNV_dispatch_table_thunk;
    epoxy_glVertexAttrib1fv = epoxy_glVertexAttrib1fv_dispatch_table_thunk;
    epoxy_glVertexAttrib1fvARB = epoxy_glVertexAttrib1fvARB_dispatch_table_thunk;
    epoxy_glVertexAttrib1fvNV = epoxy_glVertexAttrib1fvNV_dispatch_table_thunk;
    epoxy_glVertexAttrib1hNV = epoxy_glVertexAttrib1hNV_dispatch_table_thunk;
    epoxy_glVertexAttrib1hvNV = epoxy_glVertexAttrib1hvNV_dispatch_table_thunk;
    epoxy_glVertexAttrib1s = epoxy_glVertexAttrib1s_dispatch_table_thunk;
    epoxy_glVertexAttrib1sARB = epoxy_glVertexAttrib1sARB_dispatch_table_thunk;
    epoxy_glVertexAttrib1sNV = epoxy_glVertexAttrib1sNV_dispatch_table_thunk;
    epoxy_glVertexAttrib1sv = epoxy_glVertexAttrib1sv_dispatch_table_thunk;
    epoxy_glVertexAttrib1svARB = epoxy_glVertexAttrib1svARB_dispatch_table_thunk;
    epoxy_glVertexAttrib1svNV = epoxy_glVertexAttrib1svNV_dispatch_table_thunk;
    epoxy_glVertexAttrib2d = epoxy_glVertexAttrib2d_dispatch_table_thunk;
    epoxy_glVertexAttrib2dARB = epoxy_glVertexAttrib2dARB_dispatch_table_thunk;
    epoxy_glVertexAttrib2dNV = epoxy_glVertexAttrib2dNV_dispatch_table_thunk;
    epoxy_glVertexAttrib2dv = epoxy_glVertexAttrib2dv_dispatch_table_thunk;
    epoxy_glVertexAttrib2dvARB = epoxy_glVertexAttrib2dvARB_dispatch_table_thunk;
    epoxy_glVertexAttrib2dvNV = epoxy_glVertexAttrib2dvNV_dispatch_table_thunk;
    epoxy_glVertexAttrib2f = epoxy_glVertexAttrib2f_dispatch_table_thunk;
    epoxy_glVertexAttrib2fARB = epoxy_glVertexAttrib2fARB_dispatch_table_thunk;
    epoxy_glVertexAttrib2fNV = epoxy_glVertexAttrib2fNV_dispatch_table_thunk;
    epoxy_glVertexAttrib2fv = epoxy_glVertexAttrib2fv_dispatch_table_thunk;
    epoxy_glVertexAttrib2fvARB = epoxy_glVertexAttrib2fvARB_dispatch_table_thunk;
    epoxy_glVertexAttrib2fvNV = epoxy_glVertexAttrib2fvNV_dispatch_table_thunk;
    epoxy_glVertexAttrib2hNV = epoxy_glVertexAttrib2hNV_dispatch_table_thunk;
    epoxy_glVertexAttrib2hvNV = epoxy_glVertexAttrib2hvNV_dispatch_table_thunk;
    epoxy_glVertexAttrib2s = epoxy_glVertexAttrib2s_dispatch_table_thunk;
    epoxy_glVertexAttrib2sARB = epoxy_glVertexAttrib2sARB_dispatch_table_thunk;
    epoxy_glVertexAttrib2sNV = epoxy_glVertexAttrib2sNV_dispatch_table_thunk;
    epoxy_glVertexAttrib2sv = epoxy_glVertexAttrib2sv_dispatch_table_thunk;
    epoxy_glVertexAttrib2svARB = epoxy_glVertexAttrib2svARB_dispatch_table_thunk;
    epoxy_glVertexAttrib2svNV = epoxy_glVertexAttrib2svNV_dispatch_table_thunk;
    epoxy_glVertexAttrib3d = epoxy_glVertexAttrib3d_dispatch_table_thunk;
    epoxy_glVertexAttrib3dARB = epoxy_glVertexAttrib3dARB_dispatch_table_thunk;
    epoxy_glVertexAttrib3dNV = epoxy_glVertexAttrib3dNV_dispatch_table_thunk;
    epoxy_glVertexAttrib3dv = epoxy_glVertexAttrib3dv_dispatch_table_thunk;
    epoxy_glVertexAttrib3dvARB = epoxy_glVertexAttrib3dvARB_dispatch_table_thunk;
    epoxy_glVertexAttrib3dvNV = epoxy_glVertexAttrib3dvNV_dispatch_table_thunk;
    epoxy_glVertexAttrib3f = epoxy_glVertexAttrib3f_dispatch_table_thunk;
    epoxy_glVertexAttrib3fARB = epoxy_glVertexAttrib3fARB_dispatch_table_thunk;
    epoxy_glVertexAttrib3fNV = epoxy_glVertexAttrib3fNV_dispatch_table_thunk;
    epoxy_glVertexAttrib3fv = epoxy_glVertexAttrib3fv_dispatch_table_thunk;
    epoxy_glVertexAttrib3fvARB = epoxy_glVertexAttrib3fvARB_dispatch_table_thunk;
    epoxy_glVertexAttrib3fvNV = epoxy_glVertexAttrib3fvNV_dispatch_table_thunk;
    epoxy_glVertexAttrib3hNV = epoxy_glVertexAttrib3hNV_dispatch_table_thunk;
    epoxy_glVertexAttrib3hvNV = epoxy_glVertexAttrib3hvNV_dispatch_table_thunk;
    epoxy_glVertexAttrib3s = epoxy_glVertexAttrib3s_dispatch_table_thunk;
    epoxy_glVertexAttrib3sARB = epoxy_glVertexAttrib3sARB_dispatch_table_thunk;
    epoxy_glVertexAttrib3sNV = epoxy_glVertexAttrib3sNV_dispatch_table_thunk;
    epoxy_glVertexAttrib3sv = epoxy_glVertexAttrib3sv_dispatch_table_thunk;
    epoxy_glVertexAttrib3svARB = epoxy_glVertexAttrib3svARB_dispatch_table_thunk;
    epoxy_glVertexAttrib3svNV = epoxy_glVertexAttrib3svNV_dispatch_table_thunk;
    epoxy_glVertexAttrib4Nbv = epoxy_glVertexAttrib4Nbv_dispatch_table_thunk;
    epoxy_glVertexAttrib4NbvARB = epoxy_glVertexAttrib4NbvARB_dispatch_table_thunk;
    epoxy_glVertexAttrib4Niv = epoxy_glVertexAttrib4Niv_dispatch_table_thunk;
    epoxy_glVertexAttrib4NivARB = epoxy_glVertexAttrib4NivARB_dispatch_table_thunk;
    epoxy_glVertexAttrib4Nsv = epoxy_glVertexAttrib4Nsv_dispatch_table_thunk;
    epoxy_glVertexAttrib4NsvARB = epoxy_glVertexAttrib4NsvARB_dispatch_table_thunk;
    epoxy_glVertexAttrib4Nub = epoxy_glVertexAttrib4Nub_dispatch_table_thunk;
    epoxy_glVertexAttrib4NubARB = epoxy_glVertexAttrib4NubARB_dispatch_table_thunk;
    epoxy_glVertexAttrib4Nubv = epoxy_glVertexAttrib4Nubv_dispatch_table_thunk;
    epoxy_glVertexAttrib4NubvARB = epoxy_glVertexAttrib4NubvARB_dispatch_table_thunk;
    epoxy_glVertexAttrib4Nuiv = epoxy_glVertexAttrib4Nuiv_dispatch_table_thunk;
    epoxy_glVertexAttrib4NuivARB = epoxy_glVertexAttrib4NuivARB_dispatch_table_thunk;
    epoxy_glVertexAttrib4Nusv = epoxy_glVertexAttrib4Nusv_dispatch_table_thunk;
    epoxy_glVertexAttrib4NusvARB = epoxy_glVertexAttrib4NusvARB_dispatch_table_thunk;
    epoxy_glVertexAttrib4bv = epoxy_glVertexAttrib4bv_dispatch_table_thunk;
    epoxy_glVertexAttrib4bvARB = epoxy_glVertexAttrib4bvARB_dispatch_table_thunk;
    epoxy_glVertexAttrib4d = epoxy_glVertexAttrib4d_dispatch_table_thunk;
    epoxy_glVertexAttrib4dARB = epoxy_glVertexAttrib4dARB_dispatch_table_thunk;
    epoxy_glVertexAttrib4dNV = epoxy_glVertexAttrib4dNV_dispatch_table_thunk;
    epoxy_glVertexAttrib4dv = epoxy_glVertexAttrib4dv_dispatch_table_thunk;
    epoxy_glVertexAttrib4dvARB = epoxy_glVertexAttrib4dvARB_dispatch_table_thunk;
    epoxy_glVertexAttrib4dvNV = epoxy_glVertexAttrib4dvNV_dispatch_table_thunk;
    epoxy_glVertexAttrib4f = epoxy_glVertexAttrib4f_dispatch_table_thunk;
    epoxy_glVertexAttrib4fARB = epoxy_glVertexAttrib4fARB_dispatch_table_thunk;
    epoxy_glVertexAttrib4fNV = epoxy_glVertexAttrib4fNV_dispatch_table_thunk;
    epoxy_glVertexAttrib4fv = epoxy_glVertexAttrib4fv_dispatch_table_thunk;
    epoxy_glVertexAttrib4fvARB = epoxy_glVertexAttrib4fvARB_dispatch_table_thunk;
    epoxy_glVertexAttrib4fvNV = epoxy_glVertexAttrib4fvNV_dispatch_table_thunk;
    epoxy_glVertexAttrib4hNV = epoxy_glVertexAttrib4hNV_dispatch_table_thunk;
    epoxy_glVertexAttrib4hvNV = epoxy_glVertexAttrib4hvNV_dispatch_table_thunk;
    epoxy_glVertexAttrib4iv = epoxy_glVertexAttrib4iv_dispatch_table_thunk;
    epoxy_glVertexAttrib4ivARB = epoxy_glVertexAttrib4ivARB_dispatch_table_thunk;
    epoxy_glVertexAttrib4s = epoxy_glVertexAttrib4s_dispatch_table_thunk;
    epoxy_glVertexAttrib4sARB = epoxy_glVertexAttrib4sARB_dispatch_table_thunk;
    epoxy_glVertexAttrib4sNV = epoxy_glVertexAttrib4sNV_dispatch_table_thunk;
    epoxy_glVertexAttrib4sv = epoxy_glVertexAttrib4sv_dispatch_table_thunk;
    epoxy_glVertexAttrib4svARB = epoxy_glVertexAttrib4svARB_dispatch_table_thunk;
    epoxy_glVertexAttrib4svNV = epoxy_glVertexAttrib4svNV_dispatch_table_thunk;
    epoxy_glVertexAttrib4ubNV = epoxy_glVertexAttrib4ubNV_dispatch_table_thunk;
    epoxy_glVertexAttrib4ubv = epoxy_glVertexAttrib4ubv_dispatch_table_thunk;
    epoxy_glVertexAttrib4ubvARB = epoxy_glVertexAttrib4ubvARB_dispatch_table_thunk;
    epoxy_glVertexAttrib4ubvNV = epoxy_glVertexAttrib4ubvNV_dispatch_table_thunk;
    epoxy_glVertexAttrib4uiv = epoxy_glVertexAttrib4uiv_dispatch_table_thunk;
    epoxy_glVertexAttrib4uivARB = epoxy_glVertexAttrib4uivARB_dispatch_table_thunk;
    epoxy_glVertexAttrib4usv = epoxy_glVertexAttrib4usv_dispatch_table_thunk;
    epoxy_glVertexAttrib4usvARB = epoxy_glVertexAttrib4usvARB_dispatch_table_thunk;
    epoxy_glVertexAttribArrayObjectATI = epoxy_glVertexAttribArrayObjectATI_dispatch_table_thunk;
    epoxy_glVertexAttribBinding = epoxy_glVertexAttribBinding_dispatch_table_thunk;
    epoxy_glVertexAttribDivisor = epoxy_glVertexAttribDivisor_dispatch_table_thunk;
    epoxy_glVertexAttribDivisorANGLE = epoxy_glVertexAttribDivisorANGLE_dispatch_table_thunk;
    epoxy_glVertexAttribDivisorARB = epoxy_glVertexAttribDivisorARB_dispatch_table_thunk;
    epoxy_glVertexAttribDivisorEXT = epoxy_glVertexAttribDivisorEXT_dispatch_table_thunk;
    epoxy_glVertexAttribDivisorNV = epoxy_glVertexAttribDivisorNV_dispatch_table_thunk;
    epoxy_glVertexAttribFormat = epoxy_glVertexAttribFormat_dispatch_table_thunk;
    epoxy_glVertexAttribFormatNV = epoxy_glVertexAttribFormatNV_dispatch_table_thunk;
    epoxy_glVertexAttribI1i = epoxy_glVertexAttribI1i_dispatch_table_thunk;
    epoxy_glVertexAttribI1iEXT = epoxy_glVertexAttribI1iEXT_dispatch_table_thunk;
    epoxy_glVertexAttribI1iv = epoxy_glVertexAttribI1iv_dispatch_table_thunk;
    epoxy_glVertexAttribI1ivEXT = epoxy_glVertexAttribI1ivEXT_dispatch_table_thunk;
    epoxy_glVertexAttribI1ui = epoxy_glVertexAttribI1ui_dispatch_table_thunk;
    epoxy_glVertexAttribI1uiEXT = epoxy_glVertexAttribI1uiEXT_dispatch_table_thunk;
    epoxy_glVertexAttribI1uiv = epoxy_glVertexAttribI1uiv_dispatch_table_thunk;
    epoxy_glVertexAttribI1uivEXT = epoxy_glVertexAttribI1uivEXT_dispatch_table_thunk;
    epoxy_glVertexAttribI2i = epoxy_glVertexAttribI2i_dispatch_table_thunk;
    epoxy_glVertexAttribI2iEXT = epoxy_glVertexAttribI2iEXT_dispatch_table_thunk;
    epoxy_glVertexAttribI2iv = epoxy_glVertexAttribI2iv_dispatch_table_thunk;
    epoxy_glVertexAttribI2ivEXT = epoxy_glVertexAttribI2ivEXT_dispatch_table_thunk;
    epoxy_glVertexAttribI2ui = epoxy_glVertexAttribI2ui_dispatch_table_thunk;
    epoxy_glVertexAttribI2uiEXT = epoxy_glVertexAttribI2uiEXT_dispatch_table_thunk;
    epoxy_glVertexAttribI2uiv = epoxy_glVertexAttribI2uiv_dispatch_table_thunk;
    epoxy_glVertexAttribI2uivEXT = epoxy_glVertexAttribI2uivEXT_dispatch_table_thunk;
    epoxy_glVertexAttribI3i = epoxy_glVertexAttribI3i_dispatch_table_thunk;
    epoxy_glVertexAttribI3iEXT = epoxy_glVertexAttribI3iEXT_dispatch_table_thunk;
    epoxy_glVertexAttribI3iv = epoxy_glVertexAttribI3iv_dispatch_table_thunk;
    epoxy_glVertexAttribI3ivEXT = epoxy_glVertexAttribI3ivEXT_dispatch_table_thunk;
    epoxy_glVertexAttribI3ui = epoxy_glVertexAttribI3ui_dispatch_table_thunk;
    epoxy_glVertexAttribI3uiEXT = epoxy_glVertexAttribI3uiEXT_dispatch_table_thunk;
    epoxy_glVertexAttribI3uiv = epoxy_glVertexAttribI3uiv_dispatch_table_thunk;
    epoxy_glVertexAttribI3uivEXT = epoxy_glVertexAttribI3uivEXT_dispatch_table_thunk;
    epoxy_glVertexAttribI4bv = epoxy_glVertexAttribI4bv_dispatch_table_thunk;
    epoxy_glVertexAttribI4bvEXT = epoxy_glVertexAttribI4bvEXT_dispatch_table_thunk;
    epoxy_glVertexAttribI4i = epoxy_glVertexAttribI4i_dispatch_table_thunk;
    epoxy_glVertexAttribI4iEXT = epoxy_glVertexAttribI4iEXT_dispatch_table_thunk;
    epoxy_glVertexAttribI4iv = epoxy_glVertexAttribI4iv_dispatch_table_thunk;
    epoxy_glVertexAttribI4ivEXT = epoxy_glVertexAttribI4ivEXT_dispatch_table_thunk;
    epoxy_glVertexAttribI4sv = epoxy_glVertexAttribI4sv_dispatch_table_thunk;
    epoxy_glVertexAttribI4svEXT = epoxy_glVertexAttribI4svEXT_dispatch_table_thunk;
    epoxy_glVertexAttribI4ubv = epoxy_glVertexAttribI4ubv_dispatch_table_thunk;
    epoxy_glVertexAttribI4ubvEXT = epoxy_glVertexAttribI4ubvEXT_dispatch_table_thunk;
    epoxy_glVertexAttribI4ui = epoxy_glVertexAttribI4ui_dispatch_table_thunk;
    epoxy_glVertexAttribI4uiEXT = epoxy_glVertexAttribI4uiEXT_dispatch_table_thunk;
    epoxy_glVertexAttribI4uiv = epoxy_glVertexAttribI4uiv_dispatch_table_thunk;
    epoxy_glVertexAttribI4uivEXT = epoxy_glVertexAttribI4uivEXT_dispatch_table_thunk;
    epoxy_glVertexAttribI4usv = epoxy_glVertexAttribI4usv_dispatch_table_thunk;
    epoxy_glVertexAttribI4usvEXT = epoxy_glVertexAttribI4usvEXT_dispatch_table_thunk;
    epoxy_glVertexAttribIFormat = epoxy_glVertexAttribIFormat_dispatch_table_thunk;
    epoxy_glVertexAttribIFormatNV = epoxy_glVertexAttribIFormatNV_dispatch_table_thunk;
    epoxy_glVertexAttribIPointer = epoxy_glVertexAttribIPointer_dispatch_table_thunk;
    epoxy_glVertexAttribIPointerEXT = epoxy_glVertexAttribIPointerEXT_dispatch_table_thunk;
    epoxy_glVertexAttribL1d = epoxy_glVertexAttribL1d_dispatch_table_thunk;
    epoxy_glVertexAttribL1dEXT = epoxy_glVertexAttribL1dEXT_dispatch_table_thunk;
    epoxy_glVertexAttribL1dv = epoxy_glVertexAttribL1dv_dispatch_table_thunk;
    epoxy_glVertexAttribL1dvEXT = epoxy_glVertexAttribL1dvEXT_dispatch_table_thunk;
    epoxy_glVertexAttribL1i64NV = epoxy_glVertexAttribL1i64NV_dispatch_table_thunk;
    epoxy_glVertexAttribL1i64vNV = epoxy_glVertexAttribL1i64vNV_dispatch_table_thunk;
    epoxy_glVertexAttribL1ui64ARB = epoxy_glVertexAttribL1ui64ARB_dispatch_table_thunk;
    epoxy_glVertexAttribL1ui64NV = epoxy_glVertexAttribL1ui64NV_dispatch_table_thunk;
    epoxy_glVertexAttribL1ui64vARB = epoxy_glVertexAttribL1ui64vARB_dispatch_table_thunk;
    epoxy_glVertexAttribL1ui64vNV = epoxy_glVertexAttribL1ui64vNV_dispatch_table_thunk;
    epoxy_glVertexAttribL2d = epoxy_glVertexAttribL2d_dispatch_table_thunk;
    epoxy_glVertexAttribL2dEXT = epoxy_glVertexAttribL2dEXT_dispatch_table_thunk;
    epoxy_glVertexAttribL2dv = epoxy_glVertexAttribL2dv_dispatch_table_thunk;
    epoxy_glVertexAttribL2dvEXT = epoxy_glVertexAttribL2dvEXT_dispatch_table_thunk;
    epoxy_glVertexAttribL2i64NV = epoxy_glVertexAttribL2i64NV_dispatch_table_thunk;
    epoxy_glVertexAttribL2i64vNV = epoxy_glVertexAttribL2i64vNV_dispatch_table_thunk;
    epoxy_glVertexAttribL2ui64NV = epoxy_glVertexAttribL2ui64NV_dispatch_table_thunk;
    epoxy_glVertexAttribL2ui64vNV = epoxy_glVertexAttribL2ui64vNV_dispatch_table_thunk;
    epoxy_glVertexAttribL3d = epoxy_glVertexAttribL3d_dispatch_table_thunk;
    epoxy_glVertexAttribL3dEXT = epoxy_glVertexAttribL3dEXT_dispatch_table_thunk;
    epoxy_glVertexAttribL3dv = epoxy_glVertexAttribL3dv_dispatch_table_thunk;
    epoxy_glVertexAttribL3dvEXT = epoxy_glVertexAttribL3dvEXT_dispatch_table_thunk;
    epoxy_glVertexAttribL3i64NV = epoxy_glVertexAttribL3i64NV_dispatch_table_thunk;
    epoxy_glVertexAttribL3i64vNV = epoxy_glVertexAttribL3i64vNV_dispatch_table_thunk;
    epoxy_glVertexAttribL3ui64NV = epoxy_glVertexAttribL3ui64NV_dispatch_table_thunk;
    epoxy_glVertexAttribL3ui64vNV = epoxy_glVertexAttribL3ui64vNV_dispatch_table_thunk;
    epoxy_glVertexAttribL4d = epoxy_glVertexAttribL4d_dispatch_table_thunk;
    epoxy_glVertexAttribL4dEXT = epoxy_glVertexAttribL4dEXT_dispatch_table_thunk;
    epoxy_glVertexAttribL4dv = epoxy_glVertexAttribL4dv_dispatch_table_thunk;
    epoxy_glVertexAttribL4dvEXT = epoxy_glVertexAttribL4dvEXT_dispatch_table_thunk;
    epoxy_glVertexAttribL4i64NV = epoxy_glVertexAttribL4i64NV_dispatch_table_thunk;
    epoxy_glVertexAttribL4i64vNV = epoxy_glVertexAttribL4i64vNV_dispatch_table_thunk;
    epoxy_glVertexAttribL4ui64NV = epoxy_glVertexAttribL4ui64NV_dispatch_table_thunk;
    epoxy_glVertexAttribL4ui64vNV = epoxy_glVertexAttribL4ui64vNV_dispatch_table_thunk;
    epoxy_glVertexAttribLFormat = epoxy_glVertexAttribLFormat_dispatch_table_thunk;
    epoxy_glVertexAttribLFormatNV = epoxy_glVertexAttribLFormatNV_dispatch_table_thunk;
    epoxy_glVertexAttribLPointer = epoxy_glVertexAttribLPointer_dispatch_table_thunk;
    epoxy_glVertexAttribLPointerEXT = epoxy_glVertexAttribLPointerEXT_dispatch_table_thunk;
    epoxy_glVertexAttribP1ui = epoxy_glVertexAttribP1ui_dispatch_table_thunk;
    epoxy_glVertexAttribP1uiv = epoxy_glVertexAttribP1uiv_dispatch_table_thunk;
    epoxy_glVertexAttribP2ui = epoxy_glVertexAttribP2ui_dispatch_table_thunk;
    epoxy_glVertexAttribP2uiv = epoxy_glVertexAttribP2uiv_dispatch_table_thunk;
    epoxy_glVertexAttribP3ui = epoxy_glVertexAttribP3ui_dispatch_table_thunk;
    epoxy_glVertexAttribP3uiv = epoxy_glVertexAttribP3uiv_dispatch_table_thunk;
    epoxy_glVertexAttribP4ui = epoxy_glVertexAttribP4ui_dispatch_table_thunk;
    epoxy_glVertexAttribP4uiv = epoxy_glVertexAttribP4uiv_dispatch_table_thunk;
    epoxy_glVertexAttribParameteriAMD = epoxy_glVertexAttribParameteriAMD_dispatch_table_thunk;
    epoxy_glVertexAttribPointer = epoxy_glVertexAttribPointer_dispatch_table_thunk;
    epoxy_glVertexAttribPointerARB = epoxy_glVertexAttribPointerARB_dispatch_table_thunk;
    epoxy_glVertexAttribPointerNV = epoxy_glVertexAttribPointerNV_dispatch_table_thunk;
    epoxy_glVertexAttribs1dvNV = epoxy_glVertexAttribs1dvNV_dispatch_table_thunk;
    epoxy_glVertexAttribs1fvNV = epoxy_glVertexAttribs1fvNV_dispatch_table_thunk;
    epoxy_glVertexAttribs1hvNV = epoxy_glVertexAttribs1hvNV_dispatch_table_thunk;
    epoxy_glVertexAttribs1svNV = epoxy_glVertexAttribs1svNV_dispatch_table_thunk;
    epoxy_glVertexAttribs2dvNV = epoxy_glVertexAttribs2dvNV_dispatch_table_thunk;
    epoxy_glVertexAttribs2fvNV = epoxy_glVertexAttribs2fvNV_dispatch_table_thunk;
    epoxy_glVertexAttribs2hvNV = epoxy_glVertexAttribs2hvNV_dispatch_table_thunk;
    epoxy_glVertexAttribs2svNV = epoxy_glVertexAttribs2svNV_dispatch_table_thunk;
    epoxy_glVertexAttribs3dvNV = epoxy_glVertexAttribs3dvNV_dispatch_table_thunk;
    epoxy_glVertexAttribs3fvNV = epoxy_glVertexAttribs3fvNV_dispatch_table_thunk;
    epoxy_glVertexAttribs3hvNV = epoxy_glVertexAttribs3hvNV_dispatch_table_thunk;
    epoxy_glVertexAttribs3svNV = epoxy_glVertexAttribs3svNV_dispatch_table_thunk;
    epoxy_glVertexAttribs4dvNV = epoxy_glVertexAttribs4dvNV_dispatch_table_thunk;
    epoxy_glVertexAttribs4fvNV = epoxy_glVertexAttribs4fvNV_dispatch_table_thunk;
    epoxy_glVertexAttribs4hvNV = epoxy_glVertexAttribs4hvNV_dispatch_table_thunk;
    epoxy_glVertexAttribs4svNV = epoxy_glVertexAttribs4svNV_dispatch_table_thunk;
    epoxy_glVertexAttribs4ubvNV = epoxy_glVertexAttribs4ubvNV_dispatch_table_thunk;
    epoxy_glVertexBindingDivisor = epoxy_glVertexBindingDivisor_dispatch_table_thunk;
    epoxy_glVertexBlendARB = epoxy_glVertexBlendARB_dispatch_table_thunk;
    epoxy_glVertexBlendEnvfATI = epoxy_glVertexBlendEnvfATI_dispatch_table_thunk;
    epoxy_glVertexBlendEnviATI = epoxy_glVertexBlendEnviATI_dispatch_table_thunk;
    epoxy_glVertexFormatNV = epoxy_glVertexFormatNV_dispatch_table_thunk;
    epoxy_glVertexP2ui = epoxy_glVertexP2ui_dispatch_table_thunk;
    epoxy_glVertexP2uiv = epoxy_glVertexP2uiv_dispatch_table_thunk;
    epoxy_glVertexP3ui = epoxy_glVertexP3ui_dispatch_table_thunk;
    epoxy_glVertexP3uiv = epoxy_glVertexP3uiv_dispatch_table_thunk;
    epoxy_glVertexP4ui = epoxy_glVertexP4ui_dispatch_table_thunk;
    epoxy_glVertexP4uiv = epoxy_glVertexP4uiv_dispatch_table_thunk;
    epoxy_glVertexPointer = epoxy_glVertexPointer_dispatch_table_thunk;
    epoxy_glVertexPointerEXT = epoxy_glVertexPointerEXT_dispatch_table_thunk;
    epoxy_glVertexPointerListIBM = epoxy_glVertexPointerListIBM_dispatch_table_thunk;
    epoxy_glVertexPointervINTEL = epoxy_glVertexPointervINTEL_dispatch_table_thunk;
    epoxy_glVertexStream1dATI = epoxy_glVertexStream1dATI_dispatch_table_thunk;
    epoxy_glVertexStream1dvATI = epoxy_glVertexStream1dvATI_dispatch_table_thunk;
    epoxy_glVertexStream1fATI = epoxy_glVertexStream1fATI_dispatch_table_thunk;
    epoxy_glVertexStream1fvATI = epoxy_glVertexStream1fvATI_dispatch_table_thunk;
    epoxy_glVertexStream1iATI = epoxy_glVertexStream1iATI_dispatch_table_thunk;
    epoxy_glVertexStream1ivATI = epoxy_glVertexStream1ivATI_dispatch_table_thunk;
    epoxy_glVertexStream1sATI = epoxy_glVertexStream1sATI_dispatch_table_thunk;
    epoxy_glVertexStream1svATI = epoxy_glVertexStream1svATI_dispatch_table_thunk;
    epoxy_glVertexStream2dATI = epoxy_glVertexStream2dATI_dispatch_table_thunk;
    epoxy_glVertexStream2dvATI = epoxy_glVertexStream2dvATI_dispatch_table_thunk;
    epoxy_glVertexStream2fATI = epoxy_glVertexStream2fATI_dispatch_table_thunk;
    epoxy_glVertexStream2fvATI = epoxy_glVertexStream2fvATI_dispatch_table_thunk;
    epoxy_glVertexStream2iATI = epoxy_glVertexStream2iATI_dispatch_table_thunk;
    epoxy_glVertexStream2ivATI = epoxy_glVertexStream2ivATI_dispatch_table_thunk;
    epoxy_glVertexStream2sATI = epoxy_glVertexStream2sATI_dispatch_table_thunk;
    epoxy_glVertexStream2svATI = epoxy_glVertexStream2svATI_dispatch_table_thunk;
    epoxy_glVertexStream3dATI = epoxy_glVertexStream3dATI_dispatch_table_thunk;
    epoxy_glVertexStream3dvATI = epoxy_glVertexStream3dvATI_dispatch_table_thunk;
    epoxy_glVertexStream3fATI = epoxy_glVertexStream3fATI_dispatch_table_thunk;
    epoxy_glVertexStream3fvATI = epoxy_glVertexStream3fvATI_dispatch_table_thunk;
    epoxy_glVertexStream3iATI = epoxy_glVertexStream3iATI_dispatch_table_thunk;
    epoxy_glVertexStream3ivATI = epoxy_glVertexStream3ivATI_dispatch_table_thunk;
    epoxy_glVertexStream3sATI = epoxy_glVertexStream3sATI_dispatch_table_thunk;
    epoxy_glVertexStream3svATI = epoxy_glVertexStream3svATI_dispatch_table_thunk;
    epoxy_glVertexStream4dATI = epoxy_glVertexStream4dATI_dispatch_table_thunk;
    epoxy_glVertexStream4dvATI = epoxy_glVertexStream4dvATI_dispatch_table_thunk;
    epoxy_glVertexStream4fATI = epoxy_glVertexStream4fATI_dispatch_table_thunk;
    epoxy_glVertexStream4fvATI = epoxy_glVertexStream4fvATI_dispatch_table_thunk;
    epoxy_glVertexStream4iATI = epoxy_glVertexStream4iATI_dispatch_table_thunk;
    epoxy_glVertexStream4ivATI = epoxy_glVertexStream4ivATI_dispatch_table_thunk;
    epoxy_glVertexStream4sATI = epoxy_glVertexStream4sATI_dispatch_table_thunk;
    epoxy_glVertexStream4svATI = epoxy_glVertexStream4svATI_dispatch_table_thunk;
    epoxy_glVertexWeightPointerEXT = epoxy_glVertexWeightPointerEXT_dispatch_table_thunk;
    epoxy_glVertexWeightfEXT = epoxy_glVertexWeightfEXT_dispatch_table_thunk;
    epoxy_glVertexWeightfvEXT = epoxy_glVertexWeightfvEXT_dispatch_table_thunk;
    epoxy_glVertexWeighthNV = epoxy_glVertexWeighthNV_dispatch_table_thunk;
    epoxy_glVertexWeighthvNV = epoxy_glVertexWeighthvNV_dispatch_table_thunk;
    epoxy_glVideoCaptureNV = epoxy_glVideoCaptureNV_dispatch_table_thunk;
    epoxy_glVideoCaptureStreamParameterdvNV = epoxy_glVideoCaptureStreamParameterdvNV_dispatch_table_thunk;
    epoxy_glVideoCaptureStreamParameterfvNV = epoxy_glVideoCaptureStreamParameterfvNV_dispatch_table_thunk;
    epoxy_glVideoCaptureStreamParameterivNV = epoxy_glVideoCaptureStreamParameterivNV_dispatch_table_thunk;
    epoxy_glViewport = epoxy_glViewport_dispatch_table_thunk;
    epoxy_glViewportArrayv = epoxy_glViewportArrayv_dispatch_table_thunk;
    epoxy_glViewportArrayvNV = epoxy_glViewportArrayvNV_dispatch_table_thunk;
    epoxy_glViewportArrayvOES = epoxy_glViewportArrayvOES_dispatch_table_thunk;
    epoxy_glViewportIndexedf = epoxy_glViewportIndexedf_dispatch_table_thunk;
    epoxy_glViewportIndexedfNV = epoxy_glViewportIndexedfNV_dispatch_table_thunk;
    epoxy_glViewportIndexedfOES = epoxy_glViewportIndexedfOES_dispatch_table_thunk;
    epoxy_glViewportIndexedfv = epoxy_glViewportIndexedfv_dispatch_table_thunk;
    epoxy_glViewportIndexedfvNV = epoxy_glViewportIndexedfvNV_dispatch_table_thunk;
    epoxy_glViewportIndexedfvOES = epoxy_glViewportIndexedfvOES_dispatch_table_thunk;
    epoxy_glViewportPositionWScaleNV = epoxy_glViewportPositionWScaleNV_dispatch_table_thunk;
    epoxy_glViewportSwizzleNV = epoxy_glViewportSwizzleNV_dispatch_table_thunk;
    epoxy_glWaitSemaphoreEXT = epoxy_glWaitSemaphoreEXT_dispatch_table_thunk;
    epoxy_glWaitSemaphoreui64NVX = epoxy_glWaitSemaphoreui64NVX_dispatch_table_thunk;
    epoxy_glWaitSync = epoxy_glWaitSync_dispatch_table_thunk;
    epoxy_glWaitSyncAPPLE = epoxy_glWaitSyncAPPLE_dispatch_table_thunk;
    epoxy_glWaitVkSemaphoreNV = epoxy_glWaitVkSemaphoreNV_dispatch_table_thunk;
    epoxy_glWeightPathsNV = epoxy_glWeightPathsNV_dispatch_table_thunk;
    epoxy_glWeightPointerARB = epoxy_glWeightPointerARB_dispatch_table_thunk;
    epoxy_glWeightPointerOES = epoxy_glWeightPointerOES_dispatch_table_thunk;
    epoxy_glWeightbvARB = epoxy_glWeightbvARB_dispatch_table_thunk;
    epoxy_glWeightdvARB = epoxy_glWeightdvARB_dispatch_table_thunk;
    epoxy_glWeightfvARB = epoxy_glWeightfvARB_dispatch_table_thunk;
    epoxy_glWeightivARB = epoxy_glWeightivARB_dispatch_table_thunk;
    epoxy_glWeightsvARB = epoxy_glWeightsvARB_dispatch_table_thunk;
    epoxy_glWeightubvARB = epoxy_glWeightubvARB_dispatch_table_thunk;
    epoxy_glWeightuivARB = epoxy_glWeightuivARB_dispatch_table_thunk;
    epoxy_glWeightusvARB = epoxy_glWeightusvARB_dispatch_table_thunk;
    epoxy_glWindowPos2d = epoxy_glWindowPos2d_dispatch_table_thunk;
    epoxy_glWindowPos2dARB = epoxy_glWindowPos2dARB_dispatch_table_thunk;
    epoxy_glWindowPos2dMESA = epoxy_glWindowPos2dMESA_dispatch_table_thunk;
    epoxy_glWindowPos2dv = epoxy_glWindowPos2dv_dispatch_table_thunk;
    epoxy_glWindowPos2dvARB = epoxy_glWindowPos2dvARB_dispatch_table_thunk;
    epoxy_glWindowPos2dvMESA = epoxy_glWindowPos2dvMESA_dispatch_table_thunk;
    epoxy_glWindowPos2f = epoxy_glWindowPos2f_dispatch_table_thunk;
    epoxy_glWindowPos2fARB = epoxy_glWindowPos2fARB_dispatch_table_thunk;
    epoxy_glWindowPos2fMESA = epoxy_glWindowPos2fMESA_dispatch_table_thunk;
    epoxy_glWindowPos2fv = epoxy_glWindowPos2fv_dispatch_table_thunk;
    epoxy_glWindowPos2fvARB = epoxy_glWindowPos2fvARB_dispatch_table_thunk;
    epoxy_glWindowPos2fvMESA = epoxy_glWindowPos2fvMESA_dispatch_table_thunk;
    epoxy_glWindowPos2i = epoxy_glWindowPos2i_dispatch_table_thunk;
    epoxy_glWindowPos2iARB = epoxy_glWindowPos2iARB_dispatch_table_thunk;
    epoxy_glWindowPos2iMESA = epoxy_glWindowPos2iMESA_dispatch_table_thunk;
    epoxy_glWindowPos2iv = epoxy_glWindowPos2iv_dispatch_table_thunk;
    epoxy_glWindowPos2ivARB = epoxy_glWindowPos2ivARB_dispatch_table_thunk;
    epoxy_glWindowPos2ivMESA = epoxy_glWindowPos2ivMESA_dispatch_table_thunk;
    epoxy_glWindowPos2s = epoxy_glWindowPos2s_dispatch_table_thunk;
    epoxy_glWindowPos2sARB = epoxy_glWindowPos2sARB_dispatch_table_thunk;
    epoxy_glWindowPos2sMESA = epoxy_glWindowPos2sMESA_dispatch_table_thunk;
    epoxy_glWindowPos2sv = epoxy_glWindowPos2sv_dispatch_table_thunk;
    epoxy_glWindowPos2svARB = epoxy_glWindowPos2svARB_dispatch_table_thunk;
    epoxy_glWindowPos2svMESA = epoxy_glWindowPos2svMESA_dispatch_table_thunk;
    epoxy_glWindowPos3d = epoxy_glWindowPos3d_dispatch_table_thunk;
    epoxy_glWindowPos3dARB = epoxy_glWindowPos3dARB_dispatch_table_thunk;
    epoxy_glWindowPos3dMESA = epoxy_glWindowPos3dMESA_dispatch_table_thunk;
    epoxy_glWindowPos3dv = epoxy_glWindowPos3dv_dispatch_table_thunk;
    epoxy_glWindowPos3dvARB = epoxy_glWindowPos3dvARB_dispatch_table_thunk;
    epoxy_glWindowPos3dvMESA = epoxy_glWindowPos3dvMESA_dispatch_table_thunk;
    epoxy_glWindowPos3f = epoxy_glWindowPos3f_dispatch_table_thunk;
    epoxy_glWindowPos3fARB = epoxy_glWindowPos3fARB_dispatch_table_thunk;
    epoxy_glWindowPos3fMESA = epoxy_glWindowPos3fMESA_dispatch_table_thunk;
    epoxy_glWindowPos3fv = epoxy_glWindowPos3fv_dispatch_table_thunk;
    epoxy_glWindowPos3fvARB = epoxy_glWindowPos3fvARB_dispatch_table_thunk;
    epoxy_glWindowPos3fvMESA = epoxy_glWindowPos3fvMESA_dispatch_table_thunk;
    epoxy_glWindowPos3i = epoxy_glWindowPos3i_dispatch_table_thunk;
    epoxy_glWindowPos3iARB = epoxy_glWindowPos3iARB_dispatch_table_thunk;
    epoxy_glWindowPos3iMESA = epoxy_glWindowPos3iMESA_dispatch_table_thunk;
    epoxy_glWindowPos3iv = epoxy_glWindowPos3iv_dispatch_table_thunk;
    epoxy_glWindowPos3ivARB = epoxy_glWindowPos3ivARB_dispatch_table_thunk;
    epoxy_glWindowPos3ivMESA = epoxy_glWindowPos3ivMESA_dispatch_table_thunk;
    epoxy_glWindowPos3s = epoxy_glWindowPos3s_dispatch_table_thunk;
    epoxy_glWindowPos3sARB = epoxy_glWindowPos3sARB_dispatch_table_thunk;
    epoxy_glWindowPos3sMESA = epoxy_glWindowPos3sMESA_dispatch_table_thunk;
    epoxy_glWindowPos3sv = epoxy_glWindowPos3sv_dispatch_table_thunk;
    epoxy_glWindowPos3svARB = epoxy_glWindowPos3svARB_dispatch_table_thunk;
    epoxy_glWindowPos3svMESA = epoxy_glWindowPos3svMESA_dispatch_table_thunk;
    epoxy_glWindowPos4dMESA = epoxy_glWindowPos4dMESA_dispatch_table_thunk;
    epoxy_glWindowPos4dvMESA = epoxy_glWindowPos4dvMESA_dispatch_table_thunk;
    epoxy_glWindowPos4fMESA = epoxy_glWindowPos4fMESA_dispatch_table_thunk;
    epoxy_glWindowPos4fvMESA = epoxy_glWindowPos4fvMESA_dispatch_table_thunk;
    epoxy_glWindowPos4iMESA = epoxy_glWindowPos4iMESA_dispatch_table_thunk;
    epoxy_glWindowPos4ivMESA = epoxy_glWindowPos4ivMESA_dispatch_table_thunk;
    epoxy_glWindowPos4sMESA = epoxy_glWindowPos4sMESA_dispatch_table_thunk;
    epoxy_glWindowPos4svMESA = epoxy_glWindowPos4svMESA_dispatch_table_thunk;
    epoxy_glWindowRectanglesEXT = epoxy_glWindowRectanglesEXT_dispatch_table_thunk;
    epoxy_glWriteMaskEXT = epoxy_glWriteMaskEXT_dispatch_table_thunk;
}

#endif /* !USING_DISPATCH_TABLE */
PFNGLACCUMPROC epoxy_glAccum = epoxy_glAccum_global_rewrite_ptr;

PFNGLACCUMXOESPROC epoxy_glAccumxOES = epoxy_glAccumxOES_global_rewrite_ptr;

PFNGLACQUIREKEYEDMUTEXWIN32EXTPROC epoxy_glAcquireKeyedMutexWin32EXT = epoxy_glAcquireKeyedMutexWin32EXT_global_rewrite_ptr;

PFNGLACTIVEPROGRAMEXTPROC epoxy_glActiveProgramEXT = epoxy_glActiveProgramEXT_global_rewrite_ptr;

PFNGLACTIVESHADERPROGRAMPROC epoxy_glActiveShaderProgram = epoxy_glActiveShaderProgram_global_rewrite_ptr;

PFNGLACTIVESHADERPROGRAMEXTPROC epoxy_glActiveShaderProgramEXT = epoxy_glActiveShaderProgramEXT_global_rewrite_ptr;

PFNGLACTIVESTENCILFACEEXTPROC epoxy_glActiveStencilFaceEXT = epoxy_glActiveStencilFaceEXT_global_rewrite_ptr;

PFNGLACTIVETEXTUREPROC epoxy_glActiveTexture = epoxy_glActiveTexture_global_rewrite_ptr;

PFNGLACTIVETEXTUREARBPROC epoxy_glActiveTextureARB = epoxy_glActiveTextureARB_global_rewrite_ptr;

PFNGLACTIVEVARYINGNVPROC epoxy_glActiveVaryingNV = epoxy_glActiveVaryingNV_global_rewrite_ptr;

PFNGLALPHAFRAGMENTOP1ATIPROC epoxy_glAlphaFragmentOp1ATI = epoxy_glAlphaFragmentOp1ATI_global_rewrite_ptr;

PFNGLALPHAFRAGMENTOP2ATIPROC epoxy_glAlphaFragmentOp2ATI = epoxy_glAlphaFragmentOp2ATI_global_rewrite_ptr;

PFNGLALPHAFRAGMENTOP3ATIPROC epoxy_glAlphaFragmentOp3ATI = epoxy_glAlphaFragmentOp3ATI_global_rewrite_ptr;

PFNGLALPHAFUNCPROC epoxy_glAlphaFunc = epoxy_glAlphaFunc_global_rewrite_ptr;

PFNGLALPHAFUNCQCOMPROC epoxy_glAlphaFuncQCOM = epoxy_glAlphaFuncQCOM_global_rewrite_ptr;

PFNGLALPHAFUNCXPROC epoxy_glAlphaFuncx = epoxy_glAlphaFuncx_global_rewrite_ptr;

PFNGLALPHAFUNCXOESPROC epoxy_glAlphaFuncxOES = epoxy_glAlphaFuncxOES_global_rewrite_ptr;

PFNGLALPHATOCOVERAGEDITHERCONTROLNVPROC epoxy_glAlphaToCoverageDitherControlNV = epoxy_glAlphaToCoverageDitherControlNV_global_rewrite_ptr;

PFNGLAPPLYFRAMEBUFFERATTACHMENTCMAAINTELPROC epoxy_glApplyFramebufferAttachmentCMAAINTEL = epoxy_glApplyFramebufferAttachmentCMAAINTEL_global_rewrite_ptr;

PFNGLAPPLYTEXTUREEXTPROC epoxy_glApplyTextureEXT = epoxy_glApplyTextureEXT_global_rewrite_ptr;

PFNGLAREPROGRAMSRESIDENTNVPROC epoxy_glAreProgramsResidentNV = epoxy_glAreProgramsResidentNV_global_rewrite_ptr;

PFNGLARETEXTURESRESIDENTPROC epoxy_glAreTexturesResident = epoxy_glAreTexturesResident_global_rewrite_ptr;

PFNGLARETEXTURESRESIDENTEXTPROC epoxy_glAreTexturesResidentEXT = epoxy_glAreTexturesResidentEXT_global_rewrite_ptr;

PFNGLARRAYELEMENTPROC epoxy_glArrayElement = epoxy_glArrayElement_global_rewrite_ptr;

PFNGLARRAYELEMENTEXTPROC epoxy_glArrayElementEXT = epoxy_glArrayElementEXT_global_rewrite_ptr;

PFNGLARRAYOBJECTATIPROC epoxy_glArrayObjectATI = epoxy_glArrayObjectATI_global_rewrite_ptr;

PFNGLASYNCCOPYBUFFERSUBDATANVXPROC epoxy_glAsyncCopyBufferSubDataNVX = epoxy_glAsyncCopyBufferSubDataNVX_global_rewrite_ptr;

PFNGLASYNCCOPYIMAGESUBDATANVXPROC epoxy_glAsyncCopyImageSubDataNVX = epoxy_glAsyncCopyImageSubDataNVX_global_rewrite_ptr;

PFNGLASYNCMARKERSGIXPROC epoxy_glAsyncMarkerSGIX = epoxy_glAsyncMarkerSGIX_global_rewrite_ptr;

PFNGLATTACHOBJECTARBPROC epoxy_glAttachObjectARB = epoxy_glAttachObjectARB_global_rewrite_ptr;

PFNGLATTACHSHADERPROC epoxy_glAttachShader = epoxy_glAttachShader_global_rewrite_ptr;

PFNGLBEGINPROC epoxy_glBegin_unwrapped = epoxy_glBegin_unwrapped_global_rewrite_ptr;

PFNGLBEGINCONDITIONALRENDERPROC epoxy_glBeginConditionalRender = epoxy_glBeginConditionalRender_global_rewrite_ptr;

PFNGLBEGINCONDITIONALRENDERNVPROC epoxy_glBeginConditionalRenderNV = epoxy_glBeginConditionalRenderNV_global_rewrite_ptr;

PFNGLBEGINCONDITIONALRENDERNVXPROC epoxy_glBeginConditionalRenderNVX = epoxy_glBeginConditionalRenderNVX_global_rewrite_ptr;

PFNGLBEGINFRAGMENTSHADERATIPROC epoxy_glBeginFragmentShaderATI = epoxy_glBeginFragmentShaderATI_global_rewrite_ptr;

PFNGLBEGINOCCLUSIONQUERYNVPROC epoxy_glBeginOcclusionQueryNV = epoxy_glBeginOcclusionQueryNV_global_rewrite_ptr;

PFNGLBEGINPERFMONITORAMDPROC epoxy_glBeginPerfMonitorAMD = epoxy_glBeginPerfMonitorAMD_global_rewrite_ptr;

PFNGLBEGINPERFQUERYINTELPROC epoxy_glBeginPerfQueryINTEL = epoxy_glBeginPerfQueryINTEL_global_rewrite_ptr;

PFNGLBEGINQUERYPROC epoxy_glBeginQuery = epoxy_glBeginQuery_global_rewrite_ptr;

PFNGLBEGINQUERYARBPROC epoxy_glBeginQueryARB = epoxy_glBeginQueryARB_global_rewrite_ptr;

PFNGLBEGINQUERYEXTPROC epoxy_glBeginQueryEXT = epoxy_glBeginQueryEXT_global_rewrite_ptr;

PFNGLBEGINQUERYINDEXEDPROC epoxy_glBeginQueryIndexed = epoxy_glBeginQueryIndexed_global_rewrite_ptr;

PFNGLBEGINTRANSFORMFEEDBACKPROC epoxy_glBeginTransformFeedback = epoxy_glBeginTransformFeedback_global_rewrite_ptr;

PFNGLBEGINTRANSFORMFEEDBACKEXTPROC epoxy_glBeginTransformFeedbackEXT = epoxy_glBeginTransformFeedbackEXT_global_rewrite_ptr;

PFNGLBEGINTRANSFORMFEEDBACKNVPROC epoxy_glBeginTransformFeedbackNV = epoxy_glBeginTransformFeedbackNV_global_rewrite_ptr;

PFNGLBEGINVERTEXSHADEREXTPROC epoxy_glBeginVertexShaderEXT = epoxy_glBeginVertexShaderEXT_global_rewrite_ptr;

PFNGLBEGINVIDEOCAPTURENVPROC epoxy_glBeginVideoCaptureNV = epoxy_glBeginVideoCaptureNV_global_rewrite_ptr;

PFNGLBINDATTRIBLOCATIONPROC epoxy_glBindAttribLocation = epoxy_glBindAttribLocation_global_rewrite_ptr;

PFNGLBINDATTRIBLOCATIONARBPROC epoxy_glBindAttribLocationARB = epoxy_glBindAttribLocationARB_global_rewrite_ptr;

PFNGLBINDBUFFERPROC epoxy_glBindBuffer = epoxy_glBindBuffer_global_rewrite_ptr;

PFNGLBINDBUFFERARBPROC epoxy_glBindBufferARB = epoxy_glBindBufferARB_global_rewrite_ptr;

PFNGLBINDBUFFERBASEPROC epoxy_glBindBufferBase = epoxy_glBindBufferBase_global_rewrite_ptr;

PFNGLBINDBUFFERBASEEXTPROC epoxy_glBindBufferBaseEXT = epoxy_glBindBufferBaseEXT_global_rewrite_ptr;

PFNGLBINDBUFFERBASENVPROC epoxy_glBindBufferBaseNV = epoxy_glBindBufferBaseNV_global_rewrite_ptr;

PFNGLBINDBUFFEROFFSETEXTPROC epoxy_glBindBufferOffsetEXT = epoxy_glBindBufferOffsetEXT_global_rewrite_ptr;

PFNGLBINDBUFFEROFFSETNVPROC epoxy_glBindBufferOffsetNV = epoxy_glBindBufferOffsetNV_global_rewrite_ptr;

PFNGLBINDBUFFERRANGEPROC epoxy_glBindBufferRange = epoxy_glBindBufferRange_global_rewrite_ptr;

PFNGLBINDBUFFERRANGEEXTPROC epoxy_glBindBufferRangeEXT = epoxy_glBindBufferRangeEXT_global_rewrite_ptr;

PFNGLBINDBUFFERRANGENVPROC epoxy_glBindBufferRangeNV = epoxy_glBindBufferRangeNV_global_rewrite_ptr;

PFNGLBINDBUFFERSBASEPROC epoxy_glBindBuffersBase = epoxy_glBindBuffersBase_global_rewrite_ptr;

PFNGLBINDBUFFERSRANGEPROC epoxy_glBindBuffersRange = epoxy_glBindBuffersRange_global_rewrite_ptr;

PFNGLBINDFRAGDATALOCATIONPROC epoxy_glBindFragDataLocation = epoxy_glBindFragDataLocation_global_rewrite_ptr;

PFNGLBINDFRAGDATALOCATIONEXTPROC epoxy_glBindFragDataLocationEXT = epoxy_glBindFragDataLocationEXT_global_rewrite_ptr;

PFNGLBINDFRAGDATALOCATIONINDEXEDPROC epoxy_glBindFragDataLocationIndexed = epoxy_glBindFragDataLocationIndexed_global_rewrite_ptr;

PFNGLBINDFRAGDATALOCATIONINDEXEDEXTPROC epoxy_glBindFragDataLocationIndexedEXT = epoxy_glBindFragDataLocationIndexedEXT_global_rewrite_ptr;

PFNGLBINDFRAGMENTSHADERATIPROC epoxy_glBindFragmentShaderATI = epoxy_glBindFragmentShaderATI_global_rewrite_ptr;

PFNGLBINDFRAMEBUFFERPROC epoxy_glBindFramebuffer = epoxy_glBindFramebuffer_global_rewrite_ptr;

PFNGLBINDFRAMEBUFFEREXTPROC epoxy_glBindFramebufferEXT = epoxy_glBindFramebufferEXT_global_rewrite_ptr;

PFNGLBINDFRAMEBUFFEROESPROC epoxy_glBindFramebufferOES = epoxy_glBindFramebufferOES_global_rewrite_ptr;

PFNGLBINDIMAGETEXTUREPROC epoxy_glBindImageTexture = epoxy_glBindImageTexture_global_rewrite_ptr;

PFNGLBINDIMAGETEXTUREEXTPROC epoxy_glBindImageTextureEXT = epoxy_glBindImageTextureEXT_global_rewrite_ptr;

PFNGLBINDIMAGETEXTURESPROC epoxy_glBindImageTextures = epoxy_glBindImageTextures_global_rewrite_ptr;

PFNGLBINDLIGHTPARAMETEREXTPROC epoxy_glBindLightParameterEXT = epoxy_glBindLightParameterEXT_global_rewrite_ptr;

PFNGLBINDMATERIALPARAMETEREXTPROC epoxy_glBindMaterialParameterEXT = epoxy_glBindMaterialParameterEXT_global_rewrite_ptr;

PFNGLBINDMULTITEXTUREEXTPROC epoxy_glBindMultiTextureEXT = epoxy_glBindMultiTextureEXT_global_rewrite_ptr;

PFNGLBINDPARAMETEREXTPROC epoxy_glBindParameterEXT = epoxy_glBindParameterEXT_global_rewrite_ptr;

PFNGLBINDPROGRAMARBPROC epoxy_glBindProgramARB = epoxy_glBindProgramARB_global_rewrite_ptr;

PFNGLBINDPROGRAMNVPROC epoxy_glBindProgramNV = epoxy_glBindProgramNV_global_rewrite_ptr;

PFNGLBINDPROGRAMPIPELINEPROC epoxy_glBindProgramPipeline = epoxy_glBindProgramPipeline_global_rewrite_ptr;

PFNGLBINDPROGRAMPIPELINEEXTPROC epoxy_glBindProgramPipelineEXT = epoxy_glBindProgramPipelineEXT_global_rewrite_ptr;

PFNGLBINDRENDERBUFFERPROC epoxy_glBindRenderbuffer = epoxy_glBindRenderbuffer_global_rewrite_ptr;

PFNGLBINDRENDERBUFFEREXTPROC epoxy_glBindRenderbufferEXT = epoxy_glBindRenderbufferEXT_global_rewrite_ptr;

PFNGLBINDRENDERBUFFEROESPROC epoxy_glBindRenderbufferOES = epoxy_glBindRenderbufferOES_global_rewrite_ptr;

PFNGLBINDSAMPLERPROC epoxy_glBindSampler = epoxy_glBindSampler_global_rewrite_ptr;

PFNGLBINDSAMPLERSPROC epoxy_glBindSamplers = epoxy_glBindSamplers_global_rewrite_ptr;

PFNGLBINDSHADINGRATEIMAGENVPROC epoxy_glBindShadingRateImageNV = epoxy_glBindShadingRateImageNV_global_rewrite_ptr;

PFNGLBINDTEXGENPARAMETEREXTPROC epoxy_glBindTexGenParameterEXT = epoxy_glBindTexGenParameterEXT_global_rewrite_ptr;

PFNGLBINDTEXTUREPROC epoxy_glBindTexture = epoxy_glBindTexture_global_rewrite_ptr;

PFNGLBINDTEXTUREEXTPROC epoxy_glBindTextureEXT = epoxy_glBindTextureEXT_global_rewrite_ptr;

PFNGLBINDTEXTUREUNITPROC epoxy_glBindTextureUnit = epoxy_glBindTextureUnit_global_rewrite_ptr;

PFNGLBINDTEXTUREUNITPARAMETEREXTPROC epoxy_glBindTextureUnitParameterEXT = epoxy_glBindTextureUnitParameterEXT_global_rewrite_ptr;

PFNGLBINDTEXTURESPROC epoxy_glBindTextures = epoxy_glBindTextures_global_rewrite_ptr;

PFNGLBINDTRANSFORMFEEDBACKPROC epoxy_glBindTransformFeedback = epoxy_glBindTransformFeedback_global_rewrite_ptr;

PFNGLBINDTRANSFORMFEEDBACKNVPROC epoxy_glBindTransformFeedbackNV = epoxy_glBindTransformFeedbackNV_global_rewrite_ptr;

PFNGLBINDVERTEXARRAYPROC epoxy_glBindVertexArray = epoxy_glBindVertexArray_global_rewrite_ptr;

PFNGLBINDVERTEXARRAYAPPLEPROC epoxy_glBindVertexArrayAPPLE = epoxy_glBindVertexArrayAPPLE_global_rewrite_ptr;

PFNGLBINDVERTEXARRAYOESPROC epoxy_glBindVertexArrayOES = epoxy_glBindVertexArrayOES_global_rewrite_ptr;

PFNGLBINDVERTEXBUFFERPROC epoxy_glBindVertexBuffer = epoxy_glBindVertexBuffer_global_rewrite_ptr;

PFNGLBINDVERTEXBUFFERSPROC epoxy_glBindVertexBuffers = epoxy_glBindVertexBuffers_global_rewrite_ptr;

PFNGLBINDVERTEXSHADEREXTPROC epoxy_glBindVertexShaderEXT = epoxy_glBindVertexShaderEXT_global_rewrite_ptr;

PFNGLBINDVIDEOCAPTURESTREAMBUFFERNVPROC epoxy_glBindVideoCaptureStreamBufferNV = epoxy_glBindVideoCaptureStreamBufferNV_global_rewrite_ptr;

PFNGLBINDVIDEOCAPTURESTREAMTEXTURENVPROC epoxy_glBindVideoCaptureStreamTextureNV = epoxy_glBindVideoCaptureStreamTextureNV_global_rewrite_ptr;

PFNGLBINORMAL3BEXTPROC epoxy_glBinormal3bEXT = epoxy_glBinormal3bEXT_global_rewrite_ptr;

PFNGLBINORMAL3BVEXTPROC epoxy_glBinormal3bvEXT = epoxy_glBinormal3bvEXT_global_rewrite_ptr;

PFNGLBINORMAL3DEXTPROC epoxy_glBinormal3dEXT = epoxy_glBinormal3dEXT_global_rewrite_ptr;

PFNGLBINORMAL3DVEXTPROC epoxy_glBinormal3dvEXT = epoxy_glBinormal3dvEXT_global_rewrite_ptr;

PFNGLBINORMAL3FEXTPROC epoxy_glBinormal3fEXT = epoxy_glBinormal3fEXT_global_rewrite_ptr;

PFNGLBINORMAL3FVEXTPROC epoxy_glBinormal3fvEXT = epoxy_glBinormal3fvEXT_global_rewrite_ptr;

PFNGLBINORMAL3IEXTPROC epoxy_glBinormal3iEXT = epoxy_glBinormal3iEXT_global_rewrite_ptr;

PFNGLBINORMAL3IVEXTPROC epoxy_glBinormal3ivEXT = epoxy_glBinormal3ivEXT_global_rewrite_ptr;

PFNGLBINORMAL3SEXTPROC epoxy_glBinormal3sEXT = epoxy_glBinormal3sEXT_global_rewrite_ptr;

PFNGLBINORMAL3SVEXTPROC epoxy_glBinormal3svEXT = epoxy_glBinormal3svEXT_global_rewrite_ptr;

PFNGLBINORMALPOINTEREXTPROC epoxy_glBinormalPointerEXT = epoxy_glBinormalPointerEXT_global_rewrite_ptr;

PFNGLBITMAPPROC epoxy_glBitmap = epoxy_glBitmap_global_rewrite_ptr;

PFNGLBITMAPXOESPROC epoxy_glBitmapxOES = epoxy_glBitmapxOES_global_rewrite_ptr;

PFNGLBLENDBARRIERPROC epoxy_glBlendBarrier = epoxy_glBlendBarrier_global_rewrite_ptr;

PFNGLBLENDBARRIERKHRPROC epoxy_glBlendBarrierKHR = epoxy_glBlendBarrierKHR_global_rewrite_ptr;

PFNGLBLENDBARRIERNVPROC epoxy_glBlendBarrierNV = epoxy_glBlendBarrierNV_global_rewrite_ptr;

PFNGLBLENDCOLORPROC epoxy_glBlendColor = epoxy_glBlendColor_global_rewrite_ptr;

PFNGLBLENDCOLOREXTPROC epoxy_glBlendColorEXT = epoxy_glBlendColorEXT_global_rewrite_ptr;

PFNGLBLENDCOLORXOESPROC epoxy_glBlendColorxOES = epoxy_glBlendColorxOES_global_rewrite_ptr;

PFNGLBLENDEQUATIONPROC epoxy_glBlendEquation = epoxy_glBlendEquation_global_rewrite_ptr;

PFNGLBLENDEQUATIONEXTPROC epoxy_glBlendEquationEXT = epoxy_glBlendEquationEXT_global_rewrite_ptr;

PFNGLBLENDEQUATIONINDEXEDAMDPROC epoxy_glBlendEquationIndexedAMD = epoxy_glBlendEquationIndexedAMD_global_rewrite_ptr;

PFNGLBLENDEQUATIONOESPROC epoxy_glBlendEquationOES = epoxy_glBlendEquationOES_global_rewrite_ptr;

PFNGLBLENDEQUATIONSEPARATEPROC epoxy_glBlendEquationSeparate = epoxy_glBlendEquationSeparate_global_rewrite_ptr;

PFNGLBLENDEQUATIONSEPARATEEXTPROC epoxy_glBlendEquationSeparateEXT = epoxy_glBlendEquationSeparateEXT_global_rewrite_ptr;

PFNGLBLENDEQUATIONSEPARATEINDEXEDAMDPROC epoxy_glBlendEquationSeparateIndexedAMD = epoxy_glBlendEquationSeparateIndexedAMD_global_rewrite_ptr;

PFNGLBLENDEQUATIONSEPARATEOESPROC epoxy_glBlendEquationSeparateOES = epoxy_glBlendEquationSeparateOES_global_rewrite_ptr;

PFNGLBLENDEQUATIONSEPARATEIPROC epoxy_glBlendEquationSeparatei = epoxy_glBlendEquationSeparatei_global_rewrite_ptr;

PFNGLBLENDEQUATIONSEPARATEIARBPROC epoxy_glBlendEquationSeparateiARB = epoxy_glBlendEquationSeparateiARB_global_rewrite_ptr;

PFNGLBLENDEQUATIONSEPARATEIEXTPROC epoxy_glBlendEquationSeparateiEXT = epoxy_glBlendEquationSeparateiEXT_global_rewrite_ptr;

PFNGLBLENDEQUATIONSEPARATEIOESPROC epoxy_glBlendEquationSeparateiOES = epoxy_glBlendEquationSeparateiOES_global_rewrite_ptr;

PFNGLBLENDEQUATIONIPROC epoxy_glBlendEquationi = epoxy_glBlendEquationi_global_rewrite_ptr;

PFNGLBLENDEQUATIONIARBPROC epoxy_glBlendEquationiARB = epoxy_glBlendEquationiARB_global_rewrite_ptr;

PFNGLBLENDEQUATIONIEXTPROC epoxy_glBlendEquationiEXT = epoxy_glBlendEquationiEXT_global_rewrite_ptr;

PFNGLBLENDEQUATIONIOESPROC epoxy_glBlendEquationiOES = epoxy_glBlendEquationiOES_global_rewrite_ptr;

PFNGLBLENDFUNCPROC epoxy_glBlendFunc = epoxy_glBlendFunc_global_rewrite_ptr;

PFNGLBLENDFUNCINDEXEDAMDPROC epoxy_glBlendFuncIndexedAMD = epoxy_glBlendFuncIndexedAMD_global_rewrite_ptr;

PFNGLBLENDFUNCSEPARATEPROC epoxy_glBlendFuncSeparate = epoxy_glBlendFuncSeparate_global_rewrite_ptr;

PFNGLBLENDFUNCSEPARATEEXTPROC epoxy_glBlendFuncSeparateEXT = epoxy_glBlendFuncSeparateEXT_global_rewrite_ptr;

PFNGLBLENDFUNCSEPARATEINGRPROC epoxy_glBlendFuncSeparateINGR = epoxy_glBlendFuncSeparateINGR_global_rewrite_ptr;

PFNGLBLENDFUNCSEPARATEINDEXEDAMDPROC epoxy_glBlendFuncSeparateIndexedAMD = epoxy_glBlendFuncSeparateIndexedAMD_global_rewrite_ptr;

PFNGLBLENDFUNCSEPARATEOESPROC epoxy_glBlendFuncSeparateOES = epoxy_glBlendFuncSeparateOES_global_rewrite_ptr;

PFNGLBLENDFUNCSEPARATEIPROC epoxy_glBlendFuncSeparatei = epoxy_glBlendFuncSeparatei_global_rewrite_ptr;

PFNGLBLENDFUNCSEPARATEIARBPROC epoxy_glBlendFuncSeparateiARB = epoxy_glBlendFuncSeparateiARB_global_rewrite_ptr;

PFNGLBLENDFUNCSEPARATEIEXTPROC epoxy_glBlendFuncSeparateiEXT = epoxy_glBlendFuncSeparateiEXT_global_rewrite_ptr;

PFNGLBLENDFUNCSEPARATEIOESPROC epoxy_glBlendFuncSeparateiOES = epoxy_glBlendFuncSeparateiOES_global_rewrite_ptr;

PFNGLBLENDFUNCIPROC epoxy_glBlendFunci = epoxy_glBlendFunci_global_rewrite_ptr;

PFNGLBLENDFUNCIARBPROC epoxy_glBlendFunciARB = epoxy_glBlendFunciARB_global_rewrite_ptr;

PFNGLBLENDFUNCIEXTPROC epoxy_glBlendFunciEXT = epoxy_glBlendFunciEXT_global_rewrite_ptr;

PFNGLBLENDFUNCIOESPROC epoxy_glBlendFunciOES = epoxy_glBlendFunciOES_global_rewrite_ptr;

PFNGLBLENDPARAMETERINVPROC epoxy_glBlendParameteriNV = epoxy_glBlendParameteriNV_global_rewrite_ptr;

PFNGLBLITFRAMEBUFFERPROC epoxy_glBlitFramebuffer = epoxy_glBlitFramebuffer_global_rewrite_ptr;

PFNGLBLITFRAMEBUFFERANGLEPROC epoxy_glBlitFramebufferANGLE = epoxy_glBlitFramebufferANGLE_global_rewrite_ptr;

PFNGLBLITFRAMEBUFFEREXTPROC epoxy_glBlitFramebufferEXT = epoxy_glBlitFramebufferEXT_global_rewrite_ptr;

PFNGLBLITFRAMEBUFFERNVPROC epoxy_glBlitFramebufferNV = epoxy_glBlitFramebufferNV_global_rewrite_ptr;

PFNGLBLITNAMEDFRAMEBUFFERPROC epoxy_glBlitNamedFramebuffer = epoxy_glBlitNamedFramebuffer_global_rewrite_ptr;

PFNGLBUFFERADDRESSRANGENVPROC epoxy_glBufferAddressRangeNV = epoxy_glBufferAddressRangeNV_global_rewrite_ptr;

PFNGLBUFFERATTACHMEMORYNVPROC epoxy_glBufferAttachMemoryNV = epoxy_glBufferAttachMemoryNV_global_rewrite_ptr;

PFNGLBUFFERDATAPROC epoxy_glBufferData = epoxy_glBufferData_global_rewrite_ptr;

PFNGLBUFFERDATAARBPROC epoxy_glBufferDataARB = epoxy_glBufferDataARB_global_rewrite_ptr;

PFNGLBUFFERPAGECOMMITMENTARBPROC epoxy_glBufferPageCommitmentARB = epoxy_glBufferPageCommitmentARB_global_rewrite_ptr;

PFNGLBUFFERPARAMETERIAPPLEPROC epoxy_glBufferParameteriAPPLE = epoxy_glBufferParameteriAPPLE_global_rewrite_ptr;

PFNGLBUFFERSTORAGEPROC epoxy_glBufferStorage = epoxy_glBufferStorage_global_rewrite_ptr;

PFNGLBUFFERSTORAGEEXTPROC epoxy_glBufferStorageEXT = epoxy_glBufferStorageEXT_global_rewrite_ptr;

PFNGLBUFFERSTORAGEEXTERNALEXTPROC epoxy_glBufferStorageExternalEXT = epoxy_glBufferStorageExternalEXT_global_rewrite_ptr;

PFNGLBUFFERSTORAGEMEMEXTPROC epoxy_glBufferStorageMemEXT = epoxy_glBufferStorageMemEXT_global_rewrite_ptr;

PFNGLBUFFERSUBDATAPROC epoxy_glBufferSubData = epoxy_glBufferSubData_global_rewrite_ptr;

PFNGLBUFFERSUBDATAARBPROC epoxy_glBufferSubDataARB = epoxy_glBufferSubDataARB_global_rewrite_ptr;

PFNGLCALLCOMMANDLISTNVPROC epoxy_glCallCommandListNV = epoxy_glCallCommandListNV_global_rewrite_ptr;

PFNGLCALLLISTPROC epoxy_glCallList = epoxy_glCallList_global_rewrite_ptr;

PFNGLCALLLISTSPROC epoxy_glCallLists = epoxy_glCallLists_global_rewrite_ptr;

PFNGLCHECKFRAMEBUFFERSTATUSPROC epoxy_glCheckFramebufferStatus = epoxy_glCheckFramebufferStatus_global_rewrite_ptr;

PFNGLCHECKFRAMEBUFFERSTATUSEXTPROC epoxy_glCheckFramebufferStatusEXT = epoxy_glCheckFramebufferStatusEXT_global_rewrite_ptr;

PFNGLCHECKFRAMEBUFFERSTATUSOESPROC epoxy_glCheckFramebufferStatusOES = epoxy_glCheckFramebufferStatusOES_global_rewrite_ptr;

PFNGLCHECKNAMEDFRAMEBUFFERSTATUSPROC epoxy_glCheckNamedFramebufferStatus = epoxy_glCheckNamedFramebufferStatus_global_rewrite_ptr;

PFNGLCHECKNAMEDFRAMEBUFFERSTATUSEXTPROC epoxy_glCheckNamedFramebufferStatusEXT = epoxy_glCheckNamedFramebufferStatusEXT_global_rewrite_ptr;

PFNGLCLAMPCOLORPROC epoxy_glClampColor = epoxy_glClampColor_global_rewrite_ptr;

PFNGLCLAMPCOLORARBPROC epoxy_glClampColorARB = epoxy_glClampColorARB_global_rewrite_ptr;

PFNGLCLEARPROC epoxy_glClear = epoxy_glClear_global_rewrite_ptr;

PFNGLCLEARACCUMPROC epoxy_glClearAccum = epoxy_glClearAccum_global_rewrite_ptr;

PFNGLCLEARACCUMXOESPROC epoxy_glClearAccumxOES = epoxy_glClearAccumxOES_global_rewrite_ptr;

PFNGLCLEARBUFFERDATAPROC epoxy_glClearBufferData = epoxy_glClearBufferData_global_rewrite_ptr;

PFNGLCLEARBUFFERSUBDATAPROC epoxy_glClearBufferSubData = epoxy_glClearBufferSubData_global_rewrite_ptr;

PFNGLCLEARBUFFERFIPROC epoxy_glClearBufferfi = epoxy_glClearBufferfi_global_rewrite_ptr;

PFNGLCLEARBUFFERFVPROC epoxy_glClearBufferfv = epoxy_glClearBufferfv_global_rewrite_ptr;

PFNGLCLEARBUFFERIVPROC epoxy_glClearBufferiv = epoxy_glClearBufferiv_global_rewrite_ptr;

PFNGLCLEARBUFFERUIVPROC epoxy_glClearBufferuiv = epoxy_glClearBufferuiv_global_rewrite_ptr;

PFNGLCLEARCOLORPROC epoxy_glClearColor = epoxy_glClearColor_global_rewrite_ptr;

PFNGLCLEARCOLORIIEXTPROC epoxy_glClearColorIiEXT = epoxy_glClearColorIiEXT_global_rewrite_ptr;

PFNGLCLEARCOLORIUIEXTPROC epoxy_glClearColorIuiEXT = epoxy_glClearColorIuiEXT_global_rewrite_ptr;

PFNGLCLEARCOLORXPROC epoxy_glClearColorx = epoxy_glClearColorx_global_rewrite_ptr;

PFNGLCLEARCOLORXOESPROC epoxy_glClearColorxOES = epoxy_glClearColorxOES_global_rewrite_ptr;

PFNGLCLEARDEPTHPROC epoxy_glClearDepth = epoxy_glClearDepth_global_rewrite_ptr;

PFNGLCLEARDEPTHDNVPROC epoxy_glClearDepthdNV = epoxy_glClearDepthdNV_global_rewrite_ptr;

PFNGLCLEARDEPTHFPROC epoxy_glClearDepthf = epoxy_glClearDepthf_global_rewrite_ptr;

PFNGLCLEARDEPTHFOESPROC epoxy_glClearDepthfOES = epoxy_glClearDepthfOES_global_rewrite_ptr;

PFNGLCLEARDEPTHXPROC epoxy_glClearDepthx = epoxy_glClearDepthx_global_rewrite_ptr;

PFNGLCLEARDEPTHXOESPROC epoxy_glClearDepthxOES = epoxy_glClearDepthxOES_global_rewrite_ptr;

PFNGLCLEARINDEXPROC epoxy_glClearIndex = epoxy_glClearIndex_global_rewrite_ptr;

PFNGLCLEARNAMEDBUFFERDATAPROC epoxy_glClearNamedBufferData = epoxy_glClearNamedBufferData_global_rewrite_ptr;

PFNGLCLEARNAMEDBUFFERDATAEXTPROC epoxy_glClearNamedBufferDataEXT = epoxy_glClearNamedBufferDataEXT_global_rewrite_ptr;

PFNGLCLEARNAMEDBUFFERSUBDATAPROC epoxy_glClearNamedBufferSubData = epoxy_glClearNamedBufferSubData_global_rewrite_ptr;

PFNGLCLEARNAMEDBUFFERSUBDATAEXTPROC epoxy_glClearNamedBufferSubDataEXT = epoxy_glClearNamedBufferSubDataEXT_global_rewrite_ptr;

PFNGLCLEARNAMEDFRAMEBUFFERFIPROC epoxy_glClearNamedFramebufferfi = epoxy_glClearNamedFramebufferfi_global_rewrite_ptr;

PFNGLCLEARNAMEDFRAMEBUFFERFVPROC epoxy_glClearNamedFramebufferfv = epoxy_glClearNamedFramebufferfv_global_rewrite_ptr;

PFNGLCLEARNAMEDFRAMEBUFFERIVPROC epoxy_glClearNamedFramebufferiv = epoxy_glClearNamedFramebufferiv_global_rewrite_ptr;

PFNGLCLEARNAMEDFRAMEBUFFERUIVPROC epoxy_glClearNamedFramebufferuiv = epoxy_glClearNamedFramebufferuiv_global_rewrite_ptr;

PFNGLCLEARPIXELLOCALSTORAGEUIEXTPROC epoxy_glClearPixelLocalStorageuiEXT = epoxy_glClearPixelLocalStorageuiEXT_global_rewrite_ptr;

PFNGLCLEARSTENCILPROC epoxy_glClearStencil = epoxy_glClearStencil_global_rewrite_ptr;

PFNGLCLEARTEXIMAGEPROC epoxy_glClearTexImage = epoxy_glClearTexImage_global_rewrite_ptr;

PFNGLCLEARTEXIMAGEEXTPROC epoxy_glClearTexImageEXT = epoxy_glClearTexImageEXT_global_rewrite_ptr;

PFNGLCLEARTEXSUBIMAGEPROC epoxy_glClearTexSubImage = epoxy_glClearTexSubImage_global_rewrite_ptr;

PFNGLCLEARTEXSUBIMAGEEXTPROC epoxy_glClearTexSubImageEXT = epoxy_glClearTexSubImageEXT_global_rewrite_ptr;

PFNGLCLIENTACTIVETEXTUREPROC epoxy_glClientActiveTexture = epoxy_glClientActiveTexture_global_rewrite_ptr;

PFNGLCLIENTACTIVETEXTUREARBPROC epoxy_glClientActiveTextureARB = epoxy_glClientActiveTextureARB_global_rewrite_ptr;

PFNGLCLIENTACTIVEVERTEXSTREAMATIPROC epoxy_glClientActiveVertexStreamATI = epoxy_glClientActiveVertexStreamATI_global_rewrite_ptr;

PFNGLCLIENTATTRIBDEFAULTEXTPROC epoxy_glClientAttribDefaultEXT = epoxy_glClientAttribDefaultEXT_global_rewrite_ptr;

PFNGLCLIENTWAITSEMAPHOREUI64NVXPROC epoxy_glClientWaitSemaphoreui64NVX = epoxy_glClientWaitSemaphoreui64NVX_global_rewrite_ptr;

PFNGLCLIENTWAITSYNCPROC epoxy_glClientWaitSync = epoxy_glClientWaitSync_global_rewrite_ptr;

PFNGLCLIENTWAITSYNCAPPLEPROC epoxy_glClientWaitSyncAPPLE = epoxy_glClientWaitSyncAPPLE_global_rewrite_ptr;

PFNGLCLIPCONTROLPROC epoxy_glClipControl = epoxy_glClipControl_global_rewrite_ptr;

PFNGLCLIPCONTROLEXTPROC epoxy_glClipControlEXT = epoxy_glClipControlEXT_global_rewrite_ptr;

PFNGLCLIPPLANEPROC epoxy_glClipPlane = epoxy_glClipPlane_global_rewrite_ptr;

PFNGLCLIPPLANEFPROC epoxy_glClipPlanef = epoxy_glClipPlanef_global_rewrite_ptr;

PFNGLCLIPPLANEFIMGPROC epoxy_glClipPlanefIMG = epoxy_glClipPlanefIMG_global_rewrite_ptr;

PFNGLCLIPPLANEFOESPROC epoxy_glClipPlanefOES = epoxy_glClipPlanefOES_global_rewrite_ptr;

PFNGLCLIPPLANEXPROC epoxy_glClipPlanex = epoxy_glClipPlanex_global_rewrite_ptr;

PFNGLCLIPPLANEXIMGPROC epoxy_glClipPlanexIMG = epoxy_glClipPlanexIMG_global_rewrite_ptr;

PFNGLCLIPPLANEXOESPROC epoxy_glClipPlanexOES = epoxy_glClipPlanexOES_global_rewrite_ptr;

PFNGLCOLOR3BPROC epoxy_glColor3b = epoxy_glColor3b_global_rewrite_ptr;

PFNGLCOLOR3BVPROC epoxy_glColor3bv = epoxy_glColor3bv_global_rewrite_ptr;

PFNGLCOLOR3DPROC epoxy_glColor3d = epoxy_glColor3d_global_rewrite_ptr;

PFNGLCOLOR3DVPROC epoxy_glColor3dv = epoxy_glColor3dv_global_rewrite_ptr;

PFNGLCOLOR3FPROC epoxy_glColor3f = epoxy_glColor3f_global_rewrite_ptr;

PFNGLCOLOR3FVERTEX3FSUNPROC epoxy_glColor3fVertex3fSUN = epoxy_glColor3fVertex3fSUN_global_rewrite_ptr;

PFNGLCOLOR3FVERTEX3FVSUNPROC epoxy_glColor3fVertex3fvSUN = epoxy_glColor3fVertex3fvSUN_global_rewrite_ptr;

PFNGLCOLOR3FVPROC epoxy_glColor3fv = epoxy_glColor3fv_global_rewrite_ptr;

PFNGLCOLOR3HNVPROC epoxy_glColor3hNV = epoxy_glColor3hNV_global_rewrite_ptr;

PFNGLCOLOR3HVNVPROC epoxy_glColor3hvNV = epoxy_glColor3hvNV_global_rewrite_ptr;

PFNGLCOLOR3IPROC epoxy_glColor3i = epoxy_glColor3i_global_rewrite_ptr;

PFNGLCOLOR3IVPROC epoxy_glColor3iv = epoxy_glColor3iv_global_rewrite_ptr;

PFNGLCOLOR3SPROC epoxy_glColor3s = epoxy_glColor3s_global_rewrite_ptr;

PFNGLCOLOR3SVPROC epoxy_glColor3sv = epoxy_glColor3sv_global_rewrite_ptr;

PFNGLCOLOR3UBPROC epoxy_glColor3ub = epoxy_glColor3ub_global_rewrite_ptr;

PFNGLCOLOR3UBVPROC epoxy_glColor3ubv = epoxy_glColor3ubv_global_rewrite_ptr;

PFNGLCOLOR3UIPROC epoxy_glColor3ui = epoxy_glColor3ui_global_rewrite_ptr;

PFNGLCOLOR3UIVPROC epoxy_glColor3uiv = epoxy_glColor3uiv_global_rewrite_ptr;

PFNGLCOLOR3USPROC epoxy_glColor3us = epoxy_glColor3us_global_rewrite_ptr;

PFNGLCOLOR3USVPROC epoxy_glColor3usv = epoxy_glColor3usv_global_rewrite_ptr;

PFNGLCOLOR3XOESPROC epoxy_glColor3xOES = epoxy_glColor3xOES_global_rewrite_ptr;

PFNGLCOLOR3XVOESPROC epoxy_glColor3xvOES = epoxy_glColor3xvOES_global_rewrite_ptr;

PFNGLCOLOR4BPROC epoxy_glColor4b = epoxy_glColor4b_global_rewrite_ptr;

PFNGLCOLOR4BVPROC epoxy_glColor4bv = epoxy_glColor4bv_global_rewrite_ptr;

PFNGLCOLOR4DPROC epoxy_glColor4d = epoxy_glColor4d_global_rewrite_ptr;

PFNGLCOLOR4DVPROC epoxy_glColor4dv = epoxy_glColor4dv_global_rewrite_ptr;

PFNGLCOLOR4FPROC epoxy_glColor4f = epoxy_glColor4f_global_rewrite_ptr;

PFNGLCOLOR4FNORMAL3FVERTEX3FSUNPROC epoxy_glColor4fNormal3fVertex3fSUN = epoxy_glColor4fNormal3fVertex3fSUN_global_rewrite_ptr;

PFNGLCOLOR4FNORMAL3FVERTEX3FVSUNPROC epoxy_glColor4fNormal3fVertex3fvSUN = epoxy_glColor4fNormal3fVertex3fvSUN_global_rewrite_ptr;

PFNGLCOLOR4FVPROC epoxy_glColor4fv = epoxy_glColor4fv_global_rewrite_ptr;

PFNGLCOLOR4HNVPROC epoxy_glColor4hNV = epoxy_glColor4hNV_global_rewrite_ptr;

PFNGLCOLOR4HVNVPROC epoxy_glColor4hvNV = epoxy_glColor4hvNV_global_rewrite_ptr;

PFNGLCOLOR4IPROC epoxy_glColor4i = epoxy_glColor4i_global_rewrite_ptr;

PFNGLCOLOR4IVPROC epoxy_glColor4iv = epoxy_glColor4iv_global_rewrite_ptr;

PFNGLCOLOR4SPROC epoxy_glColor4s = epoxy_glColor4s_global_rewrite_ptr;

PFNGLCOLOR4SVPROC epoxy_glColor4sv = epoxy_glColor4sv_global_rewrite_ptr;

PFNGLCOLOR4UBPROC epoxy_glColor4ub = epoxy_glColor4ub_global_rewrite_ptr;

PFNGLCOLOR4UBVERTEX2FSUNPROC epoxy_glColor4ubVertex2fSUN = epoxy_glColor4ubVertex2fSUN_global_rewrite_ptr;

PFNGLCOLOR4UBVERTEX2FVSUNPROC epoxy_glColor4ubVertex2fvSUN = epoxy_glColor4ubVertex2fvSUN_global_rewrite_ptr;

PFNGLCOLOR4UBVERTEX3FSUNPROC epoxy_glColor4ubVertex3fSUN = epoxy_glColor4ubVertex3fSUN_global_rewrite_ptr;

PFNGLCOLOR4UBVERTEX3FVSUNPROC epoxy_glColor4ubVertex3fvSUN = epoxy_glColor4ubVertex3fvSUN_global_rewrite_ptr;

PFNGLCOLOR4UBVPROC epoxy_glColor4ubv = epoxy_glColor4ubv_global_rewrite_ptr;

PFNGLCOLOR4UIPROC epoxy_glColor4ui = epoxy_glColor4ui_global_rewrite_ptr;

PFNGLCOLOR4UIVPROC epoxy_glColor4uiv = epoxy_glColor4uiv_global_rewrite_ptr;

PFNGLCOLOR4USPROC epoxy_glColor4us = epoxy_glColor4us_global_rewrite_ptr;

PFNGLCOLOR4USVPROC epoxy_glColor4usv = epoxy_glColor4usv_global_rewrite_ptr;

PFNGLCOLOR4XPROC epoxy_glColor4x = epoxy_glColor4x_global_rewrite_ptr;

PFNGLCOLOR4XOESPROC epoxy_glColor4xOES = epoxy_glColor4xOES_global_rewrite_ptr;

PFNGLCOLOR4XVOESPROC epoxy_glColor4xvOES = epoxy_glColor4xvOES_global_rewrite_ptr;

PFNGLCOLORFORMATNVPROC epoxy_glColorFormatNV = epoxy_glColorFormatNV_global_rewrite_ptr;

PFNGLCOLORFRAGMENTOP1ATIPROC epoxy_glColorFragmentOp1ATI = epoxy_glColorFragmentOp1ATI_global_rewrite_ptr;

PFNGLCOLORFRAGMENTOP2ATIPROC epoxy_glColorFragmentOp2ATI = epoxy_glColorFragmentOp2ATI_global_rewrite_ptr;

PFNGLCOLORFRAGMENTOP3ATIPROC epoxy_glColorFragmentOp3ATI = epoxy_glColorFragmentOp3ATI_global_rewrite_ptr;

PFNGLCOLORMASKPROC epoxy_glColorMask = epoxy_glColorMask_global_rewrite_ptr;

PFNGLCOLORMASKINDEXEDEXTPROC epoxy_glColorMaskIndexedEXT = epoxy_glColorMaskIndexedEXT_global_rewrite_ptr;

PFNGLCOLORMASKIPROC epoxy_glColorMaski = epoxy_glColorMaski_global_rewrite_ptr;

PFNGLCOLORMASKIEXTPROC epoxy_glColorMaskiEXT = epoxy_glColorMaskiEXT_global_rewrite_ptr;

PFNGLCOLORMASKIOESPROC epoxy_glColorMaskiOES = epoxy_glColorMaskiOES_global_rewrite_ptr;

PFNGLCOLORMATERIALPROC epoxy_glColorMaterial = epoxy_glColorMaterial_global_rewrite_ptr;

PFNGLCOLORP3UIPROC epoxy_glColorP3ui = epoxy_glColorP3ui_global_rewrite_ptr;

PFNGLCOLORP3UIVPROC epoxy_glColorP3uiv = epoxy_glColorP3uiv_global_rewrite_ptr;

PFNGLCOLORP4UIPROC epoxy_glColorP4ui = epoxy_glColorP4ui_global_rewrite_ptr;

PFNGLCOLORP4UIVPROC epoxy_glColorP4uiv = epoxy_glColorP4uiv_global_rewrite_ptr;

PFNGLCOLORPOINTERPROC epoxy_glColorPointer = epoxy_glColorPointer_global_rewrite_ptr;

PFNGLCOLORPOINTEREXTPROC epoxy_glColorPointerEXT = epoxy_glColorPointerEXT_global_rewrite_ptr;

PFNGLCOLORPOINTERLISTIBMPROC epoxy_glColorPointerListIBM = epoxy_glColorPointerListIBM_global_rewrite_ptr;

PFNGLCOLORPOINTERVINTELPROC epoxy_glColorPointervINTEL = epoxy_glColorPointervINTEL_global_rewrite_ptr;

PFNGLCOLORSUBTABLEPROC epoxy_glColorSubTable = epoxy_glColorSubTable_global_rewrite_ptr;

PFNGLCOLORSUBTABLEEXTPROC epoxy_glColorSubTableEXT = epoxy_glColorSubTableEXT_global_rewrite_ptr;

PFNGLCOLORTABLEPROC epoxy_glColorTable = epoxy_glColorTable_global_rewrite_ptr;

PFNGLCOLORTABLEEXTPROC epoxy_glColorTableEXT = epoxy_glColorTableEXT_global_rewrite_ptr;

PFNGLCOLORTABLEPARAMETERFVPROC epoxy_glColorTableParameterfv = epoxy_glColorTableParameterfv_global_rewrite_ptr;

PFNGLCOLORTABLEPARAMETERFVSGIPROC epoxy_glColorTableParameterfvSGI = epoxy_glColorTableParameterfvSGI_global_rewrite_ptr;

PFNGLCOLORTABLEPARAMETERIVPROC epoxy_glColorTableParameteriv = epoxy_glColorTableParameteriv_global_rewrite_ptr;

PFNGLCOLORTABLEPARAMETERIVSGIPROC epoxy_glColorTableParameterivSGI = epoxy_glColorTableParameterivSGI_global_rewrite_ptr;

PFNGLCOLORTABLESGIPROC epoxy_glColorTableSGI = epoxy_glColorTableSGI_global_rewrite_ptr;

PFNGLCOMBINERINPUTNVPROC epoxy_glCombinerInputNV = epoxy_glCombinerInputNV_global_rewrite_ptr;

PFNGLCOMBINEROUTPUTNVPROC epoxy_glCombinerOutputNV = epoxy_glCombinerOutputNV_global_rewrite_ptr;

PFNGLCOMBINERPARAMETERFNVPROC epoxy_glCombinerParameterfNV = epoxy_glCombinerParameterfNV_global_rewrite_ptr;

PFNGLCOMBINERPARAMETERFVNVPROC epoxy_glCombinerParameterfvNV = epoxy_glCombinerParameterfvNV_global_rewrite_ptr;

PFNGLCOMBINERPARAMETERINVPROC epoxy_glCombinerParameteriNV = epoxy_glCombinerParameteriNV_global_rewrite_ptr;

PFNGLCOMBINERPARAMETERIVNVPROC epoxy_glCombinerParameterivNV = epoxy_glCombinerParameterivNV_global_rewrite_ptr;

PFNGLCOMBINERSTAGEPARAMETERFVNVPROC epoxy_glCombinerStageParameterfvNV = epoxy_glCombinerStageParameterfvNV_global_rewrite_ptr;

PFNGLCOMMANDLISTSEGMENTSNVPROC epoxy_glCommandListSegmentsNV = epoxy_glCommandListSegmentsNV_global_rewrite_ptr;

PFNGLCOMPILECOMMANDLISTNVPROC epoxy_glCompileCommandListNV = epoxy_glCompileCommandListNV_global_rewrite_ptr;

PFNGLCOMPILESHADERPROC epoxy_glCompileShader = epoxy_glCompileShader_global_rewrite_ptr;

PFNGLCOMPILESHADERARBPROC epoxy_glCompileShaderARB = epoxy_glCompileShaderARB_global_rewrite_ptr;

PFNGLCOMPILESHADERINCLUDEARBPROC epoxy_glCompileShaderIncludeARB = epoxy_glCompileShaderIncludeARB_global_rewrite_ptr;

PFNGLCOMPRESSEDMULTITEXIMAGE1DEXTPROC epoxy_glCompressedMultiTexImage1DEXT = epoxy_glCompressedMultiTexImage1DEXT_global_rewrite_ptr;

PFNGLCOMPRESSEDMULTITEXIMAGE2DEXTPROC epoxy_glCompressedMultiTexImage2DEXT = epoxy_glCompressedMultiTexImage2DEXT_global_rewrite_ptr;

PFNGLCOMPRESSEDMULTITEXIMAGE3DEXTPROC epoxy_glCompressedMultiTexImage3DEXT = epoxy_glCompressedMultiTexImage3DEXT_global_rewrite_ptr;

PFNGLCOMPRESSEDMULTITEXSUBIMAGE1DEXTPROC epoxy_glCompressedMultiTexSubImage1DEXT = epoxy_glCompressedMultiTexSubImage1DEXT_global_rewrite_ptr;

PFNGLCOMPRESSEDMULTITEXSUBIMAGE2DEXTPROC epoxy_glCompressedMultiTexSubImage2DEXT = epoxy_glCompressedMultiTexSubImage2DEXT_global_rewrite_ptr;

PFNGLCOMPRESSEDMULTITEXSUBIMAGE3DEXTPROC epoxy_glCompressedMultiTexSubImage3DEXT = epoxy_glCompressedMultiTexSubImage3DEXT_global_rewrite_ptr;

PFNGLCOMPRESSEDTEXIMAGE1DPROC epoxy_glCompressedTexImage1D = epoxy_glCompressedTexImage1D_global_rewrite_ptr;

PFNGLCOMPRESSEDTEXIMAGE1DARBPROC epoxy_glCompressedTexImage1DARB = epoxy_glCompressedTexImage1DARB_global_rewrite_ptr;

PFNGLCOMPRESSEDTEXIMAGE2DPROC epoxy_glCompressedTexImage2D = epoxy_glCompressedTexImage2D_global_rewrite_ptr;

PFNGLCOMPRESSEDTEXIMAGE2DARBPROC epoxy_glCompressedTexImage2DARB = epoxy_glCompressedTexImage2DARB_global_rewrite_ptr;

PFNGLCOMPRESSEDTEXIMAGE3DPROC epoxy_glCompressedTexImage3D = epoxy_glCompressedTexImage3D_global_rewrite_ptr;

PFNGLCOMPRESSEDTEXIMAGE3DARBPROC epoxy_glCompressedTexImage3DARB = epoxy_glCompressedTexImage3DARB_global_rewrite_ptr;

PFNGLCOMPRESSEDTEXIMAGE3DOESPROC epoxy_glCompressedTexImage3DOES = epoxy_glCompressedTexImage3DOES_global_rewrite_ptr;

PFNGLCOMPRESSEDTEXSUBIMAGE1DPROC epoxy_glCompressedTexSubImage1D = epoxy_glCompressedTexSubImage1D_global_rewrite_ptr;

PFNGLCOMPRESSEDTEXSUBIMAGE1DARBPROC epoxy_glCompressedTexSubImage1DARB = epoxy_glCompressedTexSubImage1DARB_global_rewrite_ptr;

PFNGLCOMPRESSEDTEXSUBIMAGE2DPROC epoxy_glCompressedTexSubImage2D = epoxy_glCompressedTexSubImage2D_global_rewrite_ptr;

PFNGLCOMPRESSEDTEXSUBIMAGE2DARBPROC epoxy_glCompressedTexSubImage2DARB = epoxy_glCompressedTexSubImage2DARB_global_rewrite_ptr;

PFNGLCOMPRESSEDTEXSUBIMAGE3DPROC epoxy_glCompressedTexSubImage3D = epoxy_glCompressedTexSubImage3D_global_rewrite_ptr;

PFNGLCOMPRESSEDTEXSUBIMAGE3DARBPROC epoxy_glCompressedTexSubImage3DARB = epoxy_glCompressedTexSubImage3DARB_global_rewrite_ptr;

PFNGLCOMPRESSEDTEXSUBIMAGE3DOESPROC epoxy_glCompressedTexSubImage3DOES = epoxy_glCompressedTexSubImage3DOES_global_rewrite_ptr;

PFNGLCOMPRESSEDTEXTUREIMAGE1DEXTPROC epoxy_glCompressedTextureImage1DEXT = epoxy_glCompressedTextureImage1DEXT_global_rewrite_ptr;

PFNGLCOMPRESSEDTEXTUREIMAGE2DEXTPROC epoxy_glCompressedTextureImage2DEXT = epoxy_glCompressedTextureImage2DEXT_global_rewrite_ptr;

PFNGLCOMPRESSEDTEXTUREIMAGE3DEXTPROC epoxy_glCompressedTextureImage3DEXT = epoxy_glCompressedTextureImage3DEXT_global_rewrite_ptr;

PFNGLCOMPRESSEDTEXTURESUBIMAGE1DPROC epoxy_glCompressedTextureSubImage1D = epoxy_glCompressedTextureSubImage1D_global_rewrite_ptr;

PFNGLCOMPRESSEDTEXTURESUBIMAGE1DEXTPROC epoxy_glCompressedTextureSubImage1DEXT = epoxy_glCompressedTextureSubImage1DEXT_global_rewrite_ptr;

PFNGLCOMPRESSEDTEXTURESUBIMAGE2DPROC epoxy_glCompressedTextureSubImage2D = epoxy_glCompressedTextureSubImage2D_global_rewrite_ptr;

PFNGLCOMPRESSEDTEXTURESUBIMAGE2DEXTPROC epoxy_glCompressedTextureSubImage2DEXT = epoxy_glCompressedTextureSubImage2DEXT_global_rewrite_ptr;

PFNGLCOMPRESSEDTEXTURESUBIMAGE3DPROC epoxy_glCompressedTextureSubImage3D = epoxy_glCompressedTextureSubImage3D_global_rewrite_ptr;

PFNGLCOMPRESSEDTEXTURESUBIMAGE3DEXTPROC epoxy_glCompressedTextureSubImage3DEXT = epoxy_glCompressedTextureSubImage3DEXT_global_rewrite_ptr;

PFNGLCONSERVATIVERASTERPARAMETERFNVPROC epoxy_glConservativeRasterParameterfNV = epoxy_glConservativeRasterParameterfNV_global_rewrite_ptr;

PFNGLCONSERVATIVERASTERPARAMETERINVPROC epoxy_glConservativeRasterParameteriNV = epoxy_glConservativeRasterParameteriNV_global_rewrite_ptr;

PFNGLCONVOLUTIONFILTER1DPROC epoxy_glConvolutionFilter1D = epoxy_glConvolutionFilter1D_global_rewrite_ptr;

PFNGLCONVOLUTIONFILTER1DEXTPROC epoxy_glConvolutionFilter1DEXT = epoxy_glConvolutionFilter1DEXT_global_rewrite_ptr;

PFNGLCONVOLUTIONFILTER2DPROC epoxy_glConvolutionFilter2D = epoxy_glConvolutionFilter2D_global_rewrite_ptr;

PFNGLCONVOLUTIONFILTER2DEXTPROC epoxy_glConvolutionFilter2DEXT = epoxy_glConvolutionFilter2DEXT_global_rewrite_ptr;

PFNGLCONVOLUTIONPARAMETERFPROC epoxy_glConvolutionParameterf = epoxy_glConvolutionParameterf_global_rewrite_ptr;

PFNGLCONVOLUTIONPARAMETERFEXTPROC epoxy_glConvolutionParameterfEXT = epoxy_glConvolutionParameterfEXT_global_rewrite_ptr;

PFNGLCONVOLUTIONPARAMETERFVPROC epoxy_glConvolutionParameterfv = epoxy_glConvolutionParameterfv_global_rewrite_ptr;

PFNGLCONVOLUTIONPARAMETERFVEXTPROC epoxy_glConvolutionParameterfvEXT = epoxy_glConvolutionParameterfvEXT_global_rewrite_ptr;

PFNGLCONVOLUTIONPARAMETERIPROC epoxy_glConvolutionParameteri = epoxy_glConvolutionParameteri_global_rewrite_ptr;

PFNGLCONVOLUTIONPARAMETERIEXTPROC epoxy_glConvolutionParameteriEXT = epoxy_glConvolutionParameteriEXT_global_rewrite_ptr;

PFNGLCONVOLUTIONPARAMETERIVPROC epoxy_glConvolutionParameteriv = epoxy_glConvolutionParameteriv_global_rewrite_ptr;

PFNGLCONVOLUTIONPARAMETERIVEXTPROC epoxy_glConvolutionParameterivEXT = epoxy_glConvolutionParameterivEXT_global_rewrite_ptr;

PFNGLCONVOLUTIONPARAMETERXOESPROC epoxy_glConvolutionParameterxOES = epoxy_glConvolutionParameterxOES_global_rewrite_ptr;

PFNGLCONVOLUTIONPARAMETERXVOESPROC epoxy_glConvolutionParameterxvOES = epoxy_glConvolutionParameterxvOES_global_rewrite_ptr;

PFNGLCOPYBUFFERSUBDATAPROC epoxy_glCopyBufferSubData = epoxy_glCopyBufferSubData_global_rewrite_ptr;

PFNGLCOPYBUFFERSUBDATANVPROC epoxy_glCopyBufferSubDataNV = epoxy_glCopyBufferSubDataNV_global_rewrite_ptr;

PFNGLCOPYCOLORSUBTABLEPROC epoxy_glCopyColorSubTable = epoxy_glCopyColorSubTable_global_rewrite_ptr;

PFNGLCOPYCOLORSUBTABLEEXTPROC epoxy_glCopyColorSubTableEXT = epoxy_glCopyColorSubTableEXT_global_rewrite_ptr;

PFNGLCOPYCOLORTABLEPROC epoxy_glCopyColorTable = epoxy_glCopyColorTable_global_rewrite_ptr;

PFNGLCOPYCOLORTABLESGIPROC epoxy_glCopyColorTableSGI = epoxy_glCopyColorTableSGI_global_rewrite_ptr;

PFNGLCOPYCONVOLUTIONFILTER1DPROC epoxy_glCopyConvolutionFilter1D = epoxy_glCopyConvolutionFilter1D_global_rewrite_ptr;

PFNGLCOPYCONVOLUTIONFILTER1DEXTPROC epoxy_glCopyConvolutionFilter1DEXT = epoxy_glCopyConvolutionFilter1DEXT_global_rewrite_ptr;

PFNGLCOPYCONVOLUTIONFILTER2DPROC epoxy_glCopyConvolutionFilter2D = epoxy_glCopyConvolutionFilter2D_global_rewrite_ptr;

PFNGLCOPYCONVOLUTIONFILTER2DEXTPROC epoxy_glCopyConvolutionFilter2DEXT = epoxy_glCopyConvolutionFilter2DEXT_global_rewrite_ptr;

PFNGLCOPYIMAGESUBDATAPROC epoxy_glCopyImageSubData = epoxy_glCopyImageSubData_global_rewrite_ptr;

PFNGLCOPYIMAGESUBDATAEXTPROC epoxy_glCopyImageSubDataEXT = epoxy_glCopyImageSubDataEXT_global_rewrite_ptr;

PFNGLCOPYIMAGESUBDATANVPROC epoxy_glCopyImageSubDataNV = epoxy_glCopyImageSubDataNV_global_rewrite_ptr;

PFNGLCOPYIMAGESUBDATAOESPROC epoxy_glCopyImageSubDataOES = epoxy_glCopyImageSubDataOES_global_rewrite_ptr;

PFNGLCOPYMULTITEXIMAGE1DEXTPROC epoxy_glCopyMultiTexImage1DEXT = epoxy_glCopyMultiTexImage1DEXT_global_rewrite_ptr;

PFNGLCOPYMULTITEXIMAGE2DEXTPROC epoxy_glCopyMultiTexImage2DEXT = epoxy_glCopyMultiTexImage2DEXT_global_rewrite_ptr;

PFNGLCOPYMULTITEXSUBIMAGE1DEXTPROC epoxy_glCopyMultiTexSubImage1DEXT = epoxy_glCopyMultiTexSubImage1DEXT_global_rewrite_ptr;

PFNGLCOPYMULTITEXSUBIMAGE2DEXTPROC epoxy_glCopyMultiTexSubImage2DEXT = epoxy_glCopyMultiTexSubImage2DEXT_global_rewrite_ptr;

PFNGLCOPYMULTITEXSUBIMAGE3DEXTPROC epoxy_glCopyMultiTexSubImage3DEXT = epoxy_glCopyMultiTexSubImage3DEXT_global_rewrite_ptr;

PFNGLCOPYNAMEDBUFFERSUBDATAPROC epoxy_glCopyNamedBufferSubData = epoxy_glCopyNamedBufferSubData_global_rewrite_ptr;

PFNGLCOPYPATHNVPROC epoxy_glCopyPathNV = epoxy_glCopyPathNV_global_rewrite_ptr;

PFNGLCOPYPIXELSPROC epoxy_glCopyPixels = epoxy_glCopyPixels_global_rewrite_ptr;

PFNGLCOPYTEXIMAGE1DPROC epoxy_glCopyTexImage1D = epoxy_glCopyTexImage1D_global_rewrite_ptr;

PFNGLCOPYTEXIMAGE1DEXTPROC epoxy_glCopyTexImage1DEXT = epoxy_glCopyTexImage1DEXT_global_rewrite_ptr;

PFNGLCOPYTEXIMAGE2DPROC epoxy_glCopyTexImage2D = epoxy_glCopyTexImage2D_global_rewrite_ptr;

PFNGLCOPYTEXIMAGE2DEXTPROC epoxy_glCopyTexImage2DEXT = epoxy_glCopyTexImage2DEXT_global_rewrite_ptr;

PFNGLCOPYTEXSUBIMAGE1DPROC epoxy_glCopyTexSubImage1D = epoxy_glCopyTexSubImage1D_global_rewrite_ptr;

PFNGLCOPYTEXSUBIMAGE1DEXTPROC epoxy_glCopyTexSubImage1DEXT = epoxy_glCopyTexSubImage1DEXT_global_rewrite_ptr;

PFNGLCOPYTEXSUBIMAGE2DPROC epoxy_glCopyTexSubImage2D = epoxy_glCopyTexSubImage2D_global_rewrite_ptr;

PFNGLCOPYTEXSUBIMAGE2DEXTPROC epoxy_glCopyTexSubImage2DEXT = epoxy_glCopyTexSubImage2DEXT_global_rewrite_ptr;

PFNGLCOPYTEXSUBIMAGE3DPROC epoxy_glCopyTexSubImage3D = epoxy_glCopyTexSubImage3D_global_rewrite_ptr;

PFNGLCOPYTEXSUBIMAGE3DEXTPROC epoxy_glCopyTexSubImage3DEXT = epoxy_glCopyTexSubImage3DEXT_global_rewrite_ptr;

PFNGLCOPYTEXSUBIMAGE3DOESPROC epoxy_glCopyTexSubImage3DOES = epoxy_glCopyTexSubImage3DOES_global_rewrite_ptr;

PFNGLCOPYTEXTUREIMAGE1DEXTPROC epoxy_glCopyTextureImage1DEXT = epoxy_glCopyTextureImage1DEXT_global_rewrite_ptr;

PFNGLCOPYTEXTUREIMAGE2DEXTPROC epoxy_glCopyTextureImage2DEXT = epoxy_glCopyTextureImage2DEXT_global_rewrite_ptr;

PFNGLCOPYTEXTURELEVELSAPPLEPROC epoxy_glCopyTextureLevelsAPPLE = epoxy_glCopyTextureLevelsAPPLE_global_rewrite_ptr;

PFNGLCOPYTEXTURESUBIMAGE1DPROC epoxy_glCopyTextureSubImage1D = epoxy_glCopyTextureSubImage1D_global_rewrite_ptr;

PFNGLCOPYTEXTURESUBIMAGE1DEXTPROC epoxy_glCopyTextureSubImage1DEXT = epoxy_glCopyTextureSubImage1DEXT_global_rewrite_ptr;

PFNGLCOPYTEXTURESUBIMAGE2DPROC epoxy_glCopyTextureSubImage2D = epoxy_glCopyTextureSubImage2D_global_rewrite_ptr;

PFNGLCOPYTEXTURESUBIMAGE2DEXTPROC epoxy_glCopyTextureSubImage2DEXT = epoxy_glCopyTextureSubImage2DEXT_global_rewrite_ptr;

PFNGLCOPYTEXTURESUBIMAGE3DPROC epoxy_glCopyTextureSubImage3D = epoxy_glCopyTextureSubImage3D_global_rewrite_ptr;

PFNGLCOPYTEXTURESUBIMAGE3DEXTPROC epoxy_glCopyTextureSubImage3DEXT = epoxy_glCopyTextureSubImage3DEXT_global_rewrite_ptr;

PFNGLCOVERFILLPATHINSTANCEDNVPROC epoxy_glCoverFillPathInstancedNV = epoxy_glCoverFillPathInstancedNV_global_rewrite_ptr;

PFNGLCOVERFILLPATHNVPROC epoxy_glCoverFillPathNV = epoxy_glCoverFillPathNV_global_rewrite_ptr;

PFNGLCOVERSTROKEPATHINSTANCEDNVPROC epoxy_glCoverStrokePathInstancedNV = epoxy_glCoverStrokePathInstancedNV_global_rewrite_ptr;

PFNGLCOVERSTROKEPATHNVPROC epoxy_glCoverStrokePathNV = epoxy_glCoverStrokePathNV_global_rewrite_ptr;

PFNGLCOVERAGEMASKNVPROC epoxy_glCoverageMaskNV = epoxy_glCoverageMaskNV_global_rewrite_ptr;

PFNGLCOVERAGEMODULATIONNVPROC epoxy_glCoverageModulationNV = epoxy_glCoverageModulationNV_global_rewrite_ptr;

PFNGLCOVERAGEMODULATIONTABLENVPROC epoxy_glCoverageModulationTableNV = epoxy_glCoverageModulationTableNV_global_rewrite_ptr;

PFNGLCOVERAGEOPERATIONNVPROC epoxy_glCoverageOperationNV = epoxy_glCoverageOperationNV_global_rewrite_ptr;

PFNGLCREATEBUFFERSPROC epoxy_glCreateBuffers = epoxy_glCreateBuffers_global_rewrite_ptr;

PFNGLCREATECOMMANDLISTSNVPROC epoxy_glCreateCommandListsNV = epoxy_glCreateCommandListsNV_global_rewrite_ptr;

PFNGLCREATEFRAMEBUFFERSPROC epoxy_glCreateFramebuffers = epoxy_glCreateFramebuffers_global_rewrite_ptr;

PFNGLCREATEMEMORYOBJECTSEXTPROC epoxy_glCreateMemoryObjectsEXT = epoxy_glCreateMemoryObjectsEXT_global_rewrite_ptr;

PFNGLCREATEPERFQUERYINTELPROC epoxy_glCreatePerfQueryINTEL = epoxy_glCreatePerfQueryINTEL_global_rewrite_ptr;

PFNGLCREATEPROGRAMPROC epoxy_glCreateProgram = epoxy_glCreateProgram_global_rewrite_ptr;

PFNGLCREATEPROGRAMOBJECTARBPROC epoxy_glCreateProgramObjectARB = epoxy_glCreateProgramObjectARB_global_rewrite_ptr;

PFNGLCREATEPROGRAMPIPELINESPROC epoxy_glCreateProgramPipelines = epoxy_glCreateProgramPipelines_global_rewrite_ptr;

PFNGLCREATEPROGRESSFENCENVXPROC epoxy_glCreateProgressFenceNVX = epoxy_glCreateProgressFenceNVX_global_rewrite_ptr;

PFNGLCREATEQUERIESPROC epoxy_glCreateQueries = epoxy_glCreateQueries_global_rewrite_ptr;

PFNGLCREATERENDERBUFFERSPROC epoxy_glCreateRenderbuffers = epoxy_glCreateRenderbuffers_global_rewrite_ptr;

PFNGLCREATESAMPLERSPROC epoxy_glCreateSamplers = epoxy_glCreateSamplers_global_rewrite_ptr;

PFNGLCREATESHADERPROC epoxy_glCreateShader = epoxy_glCreateShader_global_rewrite_ptr;

PFNGLCREATESHADEROBJECTARBPROC epoxy_glCreateShaderObjectARB = epoxy_glCreateShaderObjectARB_global_rewrite_ptr;

PFNGLCREATESHADERPROGRAMEXTPROC epoxy_glCreateShaderProgramEXT = epoxy_glCreateShaderProgramEXT_global_rewrite_ptr;

PFNGLCREATESHADERPROGRAMVPROC epoxy_glCreateShaderProgramv = epoxy_glCreateShaderProgramv_global_rewrite_ptr;

PFNGLCREATESHADERPROGRAMVEXTPROC epoxy_glCreateShaderProgramvEXT = epoxy_glCreateShaderProgramvEXT_global_rewrite_ptr;

PFNGLCREATESTATESNVPROC epoxy_glCreateStatesNV = epoxy_glCreateStatesNV_global_rewrite_ptr;

PFNGLCREATESYNCFROMCLEVENTARBPROC epoxy_glCreateSyncFromCLeventARB = epoxy_glCreateSyncFromCLeventARB_global_rewrite_ptr;

PFNGLCREATETEXTURESPROC epoxy_glCreateTextures = epoxy_glCreateTextures_global_rewrite_ptr;

PFNGLCREATETRANSFORMFEEDBACKSPROC epoxy_glCreateTransformFeedbacks = epoxy_glCreateTransformFeedbacks_global_rewrite_ptr;

PFNGLCREATEVERTEXARRAYSPROC epoxy_glCreateVertexArrays = epoxy_glCreateVertexArrays_global_rewrite_ptr;

PFNGLCULLFACEPROC epoxy_glCullFace = epoxy_glCullFace_global_rewrite_ptr;

PFNGLCULLPARAMETERDVEXTPROC epoxy_glCullParameterdvEXT = epoxy_glCullParameterdvEXT_global_rewrite_ptr;

PFNGLCULLPARAMETERFVEXTPROC epoxy_glCullParameterfvEXT = epoxy_glCullParameterfvEXT_global_rewrite_ptr;

PFNGLCURRENTPALETTEMATRIXARBPROC epoxy_glCurrentPaletteMatrixARB = epoxy_glCurrentPaletteMatrixARB_global_rewrite_ptr;

PFNGLCURRENTPALETTEMATRIXOESPROC epoxy_glCurrentPaletteMatrixOES = epoxy_glCurrentPaletteMatrixOES_global_rewrite_ptr;

PFNGLDEBUGMESSAGECALLBACKPROC epoxy_glDebugMessageCallback = epoxy_glDebugMessageCallback_global_rewrite_ptr;

PFNGLDEBUGMESSAGECALLBACKAMDPROC epoxy_glDebugMessageCallbackAMD = epoxy_glDebugMessageCallbackAMD_global_rewrite_ptr;

PFNGLDEBUGMESSAGECALLBACKARBPROC epoxy_glDebugMessageCallbackARB = epoxy_glDebugMessageCallbackARB_global_rewrite_ptr;

PFNGLDEBUGMESSAGECALLBACKKHRPROC epoxy_glDebugMessageCallbackKHR = epoxy_glDebugMessageCallbackKHR_global_rewrite_ptr;

PFNGLDEBUGMESSAGECONTROLPROC epoxy_glDebugMessageControl = epoxy_glDebugMessageControl_global_rewrite_ptr;

PFNGLDEBUGMESSAGECONTROLARBPROC epoxy_glDebugMessageControlARB = epoxy_glDebugMessageControlARB_global_rewrite_ptr;

PFNGLDEBUGMESSAGECONTROLKHRPROC epoxy_glDebugMessageControlKHR = epoxy_glDebugMessageControlKHR_global_rewrite_ptr;

PFNGLDEBUGMESSAGEENABLEAMDPROC epoxy_glDebugMessageEnableAMD = epoxy_glDebugMessageEnableAMD_global_rewrite_ptr;

PFNGLDEBUGMESSAGEINSERTPROC epoxy_glDebugMessageInsert = epoxy_glDebugMessageInsert_global_rewrite_ptr;

PFNGLDEBUGMESSAGEINSERTAMDPROC epoxy_glDebugMessageInsertAMD = epoxy_glDebugMessageInsertAMD_global_rewrite_ptr;

PFNGLDEBUGMESSAGEINSERTARBPROC epoxy_glDebugMessageInsertARB = epoxy_glDebugMessageInsertARB_global_rewrite_ptr;

PFNGLDEBUGMESSAGEINSERTKHRPROC epoxy_glDebugMessageInsertKHR = epoxy_glDebugMessageInsertKHR_global_rewrite_ptr;

PFNGLDEFORMSGIXPROC epoxy_glDeformSGIX = epoxy_glDeformSGIX_global_rewrite_ptr;

PFNGLDEFORMATIONMAP3DSGIXPROC epoxy_glDeformationMap3dSGIX = epoxy_glDeformationMap3dSGIX_global_rewrite_ptr;

PFNGLDEFORMATIONMAP3FSGIXPROC epoxy_glDeformationMap3fSGIX = epoxy_glDeformationMap3fSGIX_global_rewrite_ptr;

PFNGLDELETEASYNCMARKERSSGIXPROC epoxy_glDeleteAsyncMarkersSGIX = epoxy_glDeleteAsyncMarkersSGIX_global_rewrite_ptr;

PFNGLDELETEBUFFERSPROC epoxy_glDeleteBuffers = epoxy_glDeleteBuffers_global_rewrite_ptr;

PFNGLDELETEBUFFERSARBPROC epoxy_glDeleteBuffersARB = epoxy_glDeleteBuffersARB_global_rewrite_ptr;

PFNGLDELETECOMMANDLISTSNVPROC epoxy_glDeleteCommandListsNV = epoxy_glDeleteCommandListsNV_global_rewrite_ptr;

PFNGLDELETEFENCESAPPLEPROC epoxy_glDeleteFencesAPPLE = epoxy_glDeleteFencesAPPLE_global_rewrite_ptr;

PFNGLDELETEFENCESNVPROC epoxy_glDeleteFencesNV = epoxy_glDeleteFencesNV_global_rewrite_ptr;

PFNGLDELETEFRAGMENTSHADERATIPROC epoxy_glDeleteFragmentShaderATI = epoxy_glDeleteFragmentShaderATI_global_rewrite_ptr;

PFNGLDELETEFRAMEBUFFERSPROC epoxy_glDeleteFramebuffers = epoxy_glDeleteFramebuffers_global_rewrite_ptr;

PFNGLDELETEFRAMEBUFFERSEXTPROC epoxy_glDeleteFramebuffersEXT = epoxy_glDeleteFramebuffersEXT_global_rewrite_ptr;

PFNGLDELETEFRAMEBUFFERSOESPROC epoxy_glDeleteFramebuffersOES = epoxy_glDeleteFramebuffersOES_global_rewrite_ptr;

PFNGLDELETELISTSPROC epoxy_glDeleteLists = epoxy_glDeleteLists_global_rewrite_ptr;

PFNGLDELETEMEMORYOBJECTSEXTPROC epoxy_glDeleteMemoryObjectsEXT = epoxy_glDeleteMemoryObjectsEXT_global_rewrite_ptr;

PFNGLDELETENAMEDSTRINGARBPROC epoxy_glDeleteNamedStringARB = epoxy_glDeleteNamedStringARB_global_rewrite_ptr;

PFNGLDELETENAMESAMDPROC epoxy_glDeleteNamesAMD = epoxy_glDeleteNamesAMD_global_rewrite_ptr;

PFNGLDELETEOBJECTARBPROC epoxy_glDeleteObjectARB = epoxy_glDeleteObjectARB_global_rewrite_ptr;

PFNGLDELETEOCCLUSIONQUERIESNVPROC epoxy_glDeleteOcclusionQueriesNV = epoxy_glDeleteOcclusionQueriesNV_global_rewrite_ptr;

PFNGLDELETEPATHSNVPROC epoxy_glDeletePathsNV = epoxy_glDeletePathsNV_global_rewrite_ptr;

PFNGLDELETEPERFMONITORSAMDPROC epoxy_glDeletePerfMonitorsAMD = epoxy_glDeletePerfMonitorsAMD_global_rewrite_ptr;

PFNGLDELETEPERFQUERYINTELPROC epoxy_glDeletePerfQueryINTEL = epoxy_glDeletePerfQueryINTEL_global_rewrite_ptr;

PFNGLDELETEPROGRAMPROC epoxy_glDeleteProgram = epoxy_glDeleteProgram_global_rewrite_ptr;

PFNGLDELETEPROGRAMPIPELINESPROC epoxy_glDeleteProgramPipelines = epoxy_glDeleteProgramPipelines_global_rewrite_ptr;

PFNGLDELETEPROGRAMPIPELINESEXTPROC epoxy_glDeleteProgramPipelinesEXT = epoxy_glDeleteProgramPipelinesEXT_global_rewrite_ptr;

PFNGLDELETEPROGRAMSARBPROC epoxy_glDeleteProgramsARB = epoxy_glDeleteProgramsARB_global_rewrite_ptr;

PFNGLDELETEPROGRAMSNVPROC epoxy_glDeleteProgramsNV = epoxy_glDeleteProgramsNV_global_rewrite_ptr;

PFNGLDELETEQUERIESPROC epoxy_glDeleteQueries = epoxy_glDeleteQueries_global_rewrite_ptr;

PFNGLDELETEQUERIESARBPROC epoxy_glDeleteQueriesARB = epoxy_glDeleteQueriesARB_global_rewrite_ptr;

PFNGLDELETEQUERIESEXTPROC epoxy_glDeleteQueriesEXT = epoxy_glDeleteQueriesEXT_global_rewrite_ptr;

PFNGLDELETEQUERYRESOURCETAGNVPROC epoxy_glDeleteQueryResourceTagNV = epoxy_glDeleteQueryResourceTagNV_global_rewrite_ptr;

PFNGLDELETERENDERBUFFERSPROC epoxy_glDeleteRenderbuffers = epoxy_glDeleteRenderbuffers_global_rewrite_ptr;

PFNGLDELETERENDERBUFFERSEXTPROC epoxy_glDeleteRenderbuffersEXT = epoxy_glDeleteRenderbuffersEXT_global_rewrite_ptr;

PFNGLDELETERENDERBUFFERSOESPROC epoxy_glDeleteRenderbuffersOES = epoxy_glDeleteRenderbuffersOES_global_rewrite_ptr;

PFNGLDELETESAMPLERSPROC epoxy_glDeleteSamplers = epoxy_glDeleteSamplers_global_rewrite_ptr;

PFNGLDELETESEMAPHORESEXTPROC epoxy_glDeleteSemaphoresEXT = epoxy_glDeleteSemaphoresEXT_global_rewrite_ptr;

PFNGLDELETESHADERPROC epoxy_glDeleteShader = epoxy_glDeleteShader_global_rewrite_ptr;

PFNGLDELETESTATESNVPROC epoxy_glDeleteStatesNV = epoxy_glDeleteStatesNV_global_rewrite_ptr;

PFNGLDELETESYNCPROC epoxy_glDeleteSync = epoxy_glDeleteSync_global_rewrite_ptr;

PFNGLDELETESYNCAPPLEPROC epoxy_glDeleteSyncAPPLE = epoxy_glDeleteSyncAPPLE_global_rewrite_ptr;

PFNGLDELETETEXTURESPROC epoxy_glDeleteTextures = epoxy_glDeleteTextures_global_rewrite_ptr;

PFNGLDELETETEXTURESEXTPROC epoxy_glDeleteTexturesEXT = epoxy_glDeleteTexturesEXT_global_rewrite_ptr;

PFNGLDELETETRANSFORMFEEDBACKSPROC epoxy_glDeleteTransformFeedbacks = epoxy_glDeleteTransformFeedbacks_global_rewrite_ptr;

PFNGLDELETETRANSFORMFEEDBACKSNVPROC epoxy_glDeleteTransformFeedbacksNV = epoxy_glDeleteTransformFeedbacksNV_global_rewrite_ptr;

PFNGLDELETEVERTEXARRAYSPROC epoxy_glDeleteVertexArrays = epoxy_glDeleteVertexArrays_global_rewrite_ptr;

PFNGLDELETEVERTEXARRAYSAPPLEPROC epoxy_glDeleteVertexArraysAPPLE = epoxy_glDeleteVertexArraysAPPLE_global_rewrite_ptr;

PFNGLDELETEVERTEXARRAYSOESPROC epoxy_glDeleteVertexArraysOES = epoxy_glDeleteVertexArraysOES_global_rewrite_ptr;

PFNGLDELETEVERTEXSHADEREXTPROC epoxy_glDeleteVertexShaderEXT = epoxy_glDeleteVertexShaderEXT_global_rewrite_ptr;

PFNGLDEPTHBOUNDSEXTPROC epoxy_glDepthBoundsEXT = epoxy_glDepthBoundsEXT_global_rewrite_ptr;

PFNGLDEPTHBOUNDSDNVPROC epoxy_glDepthBoundsdNV = epoxy_glDepthBoundsdNV_global_rewrite_ptr;

PFNGLDEPTHFUNCPROC epoxy_glDepthFunc = epoxy_glDepthFunc_global_rewrite_ptr;

PFNGLDEPTHMASKPROC epoxy_glDepthMask = epoxy_glDepthMask_global_rewrite_ptr;

PFNGLDEPTHRANGEPROC epoxy_glDepthRange = epoxy_glDepthRange_global_rewrite_ptr;

PFNGLDEPTHRANGEARRAYFVNVPROC epoxy_glDepthRangeArrayfvNV = epoxy_glDepthRangeArrayfvNV_global_rewrite_ptr;

PFNGLDEPTHRANGEARRAYFVOESPROC epoxy_glDepthRangeArrayfvOES = epoxy_glDepthRangeArrayfvOES_global_rewrite_ptr;

PFNGLDEPTHRANGEARRAYVPROC epoxy_glDepthRangeArrayv = epoxy_glDepthRangeArrayv_global_rewrite_ptr;

PFNGLDEPTHRANGEINDEXEDPROC epoxy_glDepthRangeIndexed = epoxy_glDepthRangeIndexed_global_rewrite_ptr;

PFNGLDEPTHRANGEINDEXEDFNVPROC epoxy_glDepthRangeIndexedfNV = epoxy_glDepthRangeIndexedfNV_global_rewrite_ptr;

PFNGLDEPTHRANGEINDEXEDFOESPROC epoxy_glDepthRangeIndexedfOES = epoxy_glDepthRangeIndexedfOES_global_rewrite_ptr;

PFNGLDEPTHRANGEDNVPROC epoxy_glDepthRangedNV = epoxy_glDepthRangedNV_global_rewrite_ptr;

PFNGLDEPTHRANGEFPROC epoxy_glDepthRangef = epoxy_glDepthRangef_global_rewrite_ptr;

PFNGLDEPTHRANGEFOESPROC epoxy_glDepthRangefOES = epoxy_glDepthRangefOES_global_rewrite_ptr;

PFNGLDEPTHRANGEXPROC epoxy_glDepthRangex = epoxy_glDepthRangex_global_rewrite_ptr;

PFNGLDEPTHRANGEXOESPROC epoxy_glDepthRangexOES = epoxy_glDepthRangexOES_global_rewrite_ptr;

PFNGLDETACHOBJECTARBPROC epoxy_glDetachObjectARB = epoxy_glDetachObjectARB_global_rewrite_ptr;

PFNGLDETACHSHADERPROC epoxy_glDetachShader = epoxy_glDetachShader_global_rewrite_ptr;

PFNGLDETAILTEXFUNCSGISPROC epoxy_glDetailTexFuncSGIS = epoxy_glDetailTexFuncSGIS_global_rewrite_ptr;

PFNGLDISABLEPROC epoxy_glDisable = epoxy_glDisable_global_rewrite_ptr;

PFNGLDISABLECLIENTSTATEPROC epoxy_glDisableClientState = epoxy_glDisableClientState_global_rewrite_ptr;

PFNGLDISABLECLIENTSTATEINDEXEDEXTPROC epoxy_glDisableClientStateIndexedEXT = epoxy_glDisableClientStateIndexedEXT_global_rewrite_ptr;

PFNGLDISABLECLIENTSTATEIEXTPROC epoxy_glDisableClientStateiEXT = epoxy_glDisableClientStateiEXT_global_rewrite_ptr;

PFNGLDISABLEDRIVERCONTROLQCOMPROC epoxy_glDisableDriverControlQCOM = epoxy_glDisableDriverControlQCOM_global_rewrite_ptr;

PFNGLDISABLEINDEXEDEXTPROC epoxy_glDisableIndexedEXT = epoxy_glDisableIndexedEXT_global_rewrite_ptr;

PFNGLDISABLEVARIANTCLIENTSTATEEXTPROC epoxy_glDisableVariantClientStateEXT = epoxy_glDisableVariantClientStateEXT_global_rewrite_ptr;

PFNGLDISABLEVERTEXARRAYATTRIBPROC epoxy_glDisableVertexArrayAttrib = epoxy_glDisableVertexArrayAttrib_global_rewrite_ptr;

PFNGLDISABLEVERTEXARRAYATTRIBEXTPROC epoxy_glDisableVertexArrayAttribEXT = epoxy_glDisableVertexArrayAttribEXT_global_rewrite_ptr;

PFNGLDISABLEVERTEXARRAYEXTPROC epoxy_glDisableVertexArrayEXT = epoxy_glDisableVertexArrayEXT_global_rewrite_ptr;

PFNGLDISABLEVERTEXATTRIBAPPLEPROC epoxy_glDisableVertexAttribAPPLE = epoxy_glDisableVertexAttribAPPLE_global_rewrite_ptr;

PFNGLDISABLEVERTEXATTRIBARRAYPROC epoxy_glDisableVertexAttribArray = epoxy_glDisableVertexAttribArray_global_rewrite_ptr;

PFNGLDISABLEVERTEXATTRIBARRAYARBPROC epoxy_glDisableVertexAttribArrayARB = epoxy_glDisableVertexAttribArrayARB_global_rewrite_ptr;

PFNGLDISABLEIPROC epoxy_glDisablei = epoxy_glDisablei_global_rewrite_ptr;

PFNGLDISABLEIEXTPROC epoxy_glDisableiEXT = epoxy_glDisableiEXT_global_rewrite_ptr;

PFNGLDISABLEINVPROC epoxy_glDisableiNV = epoxy_glDisableiNV_global_rewrite_ptr;

PFNGLDISABLEIOESPROC epoxy_glDisableiOES = epoxy_glDisableiOES_global_rewrite_ptr;

PFNGLDISCARDFRAMEBUFFEREXTPROC epoxy_glDiscardFramebufferEXT = epoxy_glDiscardFramebufferEXT_global_rewrite_ptr;

PFNGLDISPATCHCOMPUTEPROC epoxy_glDispatchCompute = epoxy_glDispatchCompute_global_rewrite_ptr;

PFNGLDISPATCHCOMPUTEGROUPSIZEARBPROC epoxy_glDispatchComputeGroupSizeARB = epoxy_glDispatchComputeGroupSizeARB_global_rewrite_ptr;

PFNGLDISPATCHCOMPUTEINDIRECTPROC epoxy_glDispatchComputeIndirect = epoxy_glDispatchComputeIndirect_global_rewrite_ptr;

PFNGLDRAWARRAYSPROC epoxy_glDrawArrays = epoxy_glDrawArrays_global_rewrite_ptr;

PFNGLDRAWARRAYSEXTPROC epoxy_glDrawArraysEXT = epoxy_glDrawArraysEXT_global_rewrite_ptr;

PFNGLDRAWARRAYSINDIRECTPROC epoxy_glDrawArraysIndirect = epoxy_glDrawArraysIndirect_global_rewrite_ptr;

PFNGLDRAWARRAYSINSTANCEDPROC epoxy_glDrawArraysInstanced = epoxy_glDrawArraysInstanced_global_rewrite_ptr;

PFNGLDRAWARRAYSINSTANCEDANGLEPROC epoxy_glDrawArraysInstancedANGLE = epoxy_glDrawArraysInstancedANGLE_global_rewrite_ptr;

PFNGLDRAWARRAYSINSTANCEDARBPROC epoxy_glDrawArraysInstancedARB = epoxy_glDrawArraysInstancedARB_global_rewrite_ptr;

PFNGLDRAWARRAYSINSTANCEDBASEINSTANCEPROC epoxy_glDrawArraysInstancedBaseInstance = epoxy_glDrawArraysInstancedBaseInstance_global_rewrite_ptr;

PFNGLDRAWARRAYSINSTANCEDBASEINSTANCEEXTPROC epoxy_glDrawArraysInstancedBaseInstanceEXT = epoxy_glDrawArraysInstancedBaseInstanceEXT_global_rewrite_ptr;

PFNGLDRAWARRAYSINSTANCEDEXTPROC epoxy_glDrawArraysInstancedEXT = epoxy_glDrawArraysInstancedEXT_global_rewrite_ptr;

PFNGLDRAWARRAYSINSTANCEDNVPROC epoxy_glDrawArraysInstancedNV = epoxy_glDrawArraysInstancedNV_global_rewrite_ptr;

PFNGLDRAWBUFFERPROC epoxy_glDrawBuffer = epoxy_glDrawBuffer_global_rewrite_ptr;

PFNGLDRAWBUFFERSPROC epoxy_glDrawBuffers = epoxy_glDrawBuffers_global_rewrite_ptr;

PFNGLDRAWBUFFERSARBPROC epoxy_glDrawBuffersARB = epoxy_glDrawBuffersARB_global_rewrite_ptr;

PFNGLDRAWBUFFERSATIPROC epoxy_glDrawBuffersATI = epoxy_glDrawBuffersATI_global_rewrite_ptr;

PFNGLDRAWBUFFERSEXTPROC epoxy_glDrawBuffersEXT = epoxy_glDrawBuffersEXT_global_rewrite_ptr;

PFNGLDRAWBUFFERSINDEXEDEXTPROC epoxy_glDrawBuffersIndexedEXT = epoxy_glDrawBuffersIndexedEXT_global_rewrite_ptr;

PFNGLDRAWBUFFERSNVPROC epoxy_glDrawBuffersNV = epoxy_glDrawBuffersNV_global_rewrite_ptr;

PFNGLDRAWCOMMANDSADDRESSNVPROC epoxy_glDrawCommandsAddressNV = epoxy_glDrawCommandsAddressNV_global_rewrite_ptr;

PFNGLDRAWCOMMANDSNVPROC epoxy_glDrawCommandsNV = epoxy_glDrawCommandsNV_global_rewrite_ptr;

PFNGLDRAWCOMMANDSSTATESADDRESSNVPROC epoxy_glDrawCommandsStatesAddressNV = epoxy_glDrawCommandsStatesAddressNV_global_rewrite_ptr;

PFNGLDRAWCOMMANDSSTATESNVPROC epoxy_glDrawCommandsStatesNV = epoxy_glDrawCommandsStatesNV_global_rewrite_ptr;

PFNGLDRAWELEMENTARRAYAPPLEPROC epoxy_glDrawElementArrayAPPLE = epoxy_glDrawElementArrayAPPLE_global_rewrite_ptr;

PFNGLDRAWELEMENTARRAYATIPROC epoxy_glDrawElementArrayATI = epoxy_glDrawElementArrayATI_global_rewrite_ptr;

PFNGLDRAWELEMENTSPROC epoxy_glDrawElements = epoxy_glDrawElements_global_rewrite_ptr;

PFNGLDRAWELEMENTSBASEVERTEXPROC epoxy_glDrawElementsBaseVertex = epoxy_glDrawElementsBaseVertex_global_rewrite_ptr;

PFNGLDRAWELEMENTSBASEVERTEXEXTPROC epoxy_glDrawElementsBaseVertexEXT = epoxy_glDrawElementsBaseVertexEXT_global_rewrite_ptr;

PFNGLDRAWELEMENTSBASEVERTEXOESPROC epoxy_glDrawElementsBaseVertexOES = epoxy_glDrawElementsBaseVertexOES_global_rewrite_ptr;

PFNGLDRAWELEMENTSINDIRECTPROC epoxy_glDrawElementsIndirect = epoxy_glDrawElementsIndirect_global_rewrite_ptr;

PFNGLDRAWELEMENTSINSTANCEDPROC epoxy_glDrawElementsInstanced = epoxy_glDrawElementsInstanced_global_rewrite_ptr;

PFNGLDRAWELEMENTSINSTANCEDANGLEPROC epoxy_glDrawElementsInstancedANGLE = epoxy_glDrawElementsInstancedANGLE_global_rewrite_ptr;

PFNGLDRAWELEMENTSINSTANCEDARBPROC epoxy_glDrawElementsInstancedARB = epoxy_glDrawElementsInstancedARB_global_rewrite_ptr;

PFNGLDRAWELEMENTSINSTANCEDBASEINSTANCEPROC epoxy_glDrawElementsInstancedBaseInstance = epoxy_glDrawElementsInstancedBaseInstance_global_rewrite_ptr;

PFNGLDRAWELEMENTSINSTANCEDBASEINSTANCEEXTPROC epoxy_glDrawElementsInstancedBaseInstanceEXT = epoxy_glDrawElementsInstancedBaseInstanceEXT_global_rewrite_ptr;

PFNGLDRAWELEMENTSINSTANCEDBASEVERTEXPROC epoxy_glDrawElementsInstancedBaseVertex = epoxy_glDrawElementsInstancedBaseVertex_global_rewrite_ptr;

PFNGLDRAWELEMENTSINSTANCEDBASEVERTEXBASEINSTANCEPROC epoxy_glDrawElementsInstancedBaseVertexBaseInstance = epoxy_glDrawElementsInstancedBaseVertexBaseInstance_global_rewrite_ptr;

PFNGLDRAWELEMENTSINSTANCEDBASEVERTEXBASEINSTANCEEXTPROC epoxy_glDrawElementsInstancedBaseVertexBaseInstanceEXT = epoxy_glDrawElementsInstancedBaseVertexBaseInstanceEXT_global_rewrite_ptr;

PFNGLDRAWELEMENTSINSTANCEDBASEVERTEXEXTPROC epoxy_glDrawElementsInstancedBaseVertexEXT = epoxy_glDrawElementsInstancedBaseVertexEXT_global_rewrite_ptr;

PFNGLDRAWELEMENTSINSTANCEDBASEVERTEXOESPROC epoxy_glDrawElementsInstancedBaseVertexOES = epoxy_glDrawElementsInstancedBaseVertexOES_global_rewrite_ptr;

PFNGLDRAWELEMENTSINSTANCEDEXTPROC epoxy_glDrawElementsInstancedEXT = epoxy_glDrawElementsInstancedEXT_global_rewrite_ptr;

PFNGLDRAWELEMENTSINSTANCEDNVPROC epoxy_glDrawElementsInstancedNV = epoxy_glDrawElementsInstancedNV_global_rewrite_ptr;

PFNGLDRAWMESHARRAYSSUNPROC epoxy_glDrawMeshArraysSUN = epoxy_glDrawMeshArraysSUN_global_rewrite_ptr;

PFNGLDRAWMESHTASKSINDIRECTNVPROC epoxy_glDrawMeshTasksIndirectNV = epoxy_glDrawMeshTasksIndirectNV_global_rewrite_ptr;

PFNGLDRAWMESHTASKSNVPROC epoxy_glDrawMeshTasksNV = epoxy_glDrawMeshTasksNV_global_rewrite_ptr;

PFNGLDRAWPIXELSPROC epoxy_glDrawPixels = epoxy_glDrawPixels_global_rewrite_ptr;

PFNGLDRAWRANGEELEMENTARRAYAPPLEPROC epoxy_glDrawRangeElementArrayAPPLE = epoxy_glDrawRangeElementArrayAPPLE_global_rewrite_ptr;

PFNGLDRAWRANGEELEMENTARRAYATIPROC epoxy_glDrawRangeElementArrayATI = epoxy_glDrawRangeElementArrayATI_global_rewrite_ptr;

PFNGLDRAWRANGEELEMENTSPROC epoxy_glDrawRangeElements = epoxy_glDrawRangeElements_global_rewrite_ptr;

PFNGLDRAWRANGEELEMENTSBASEVERTEXPROC epoxy_glDrawRangeElementsBaseVertex = epoxy_glDrawRangeElementsBaseVertex_global_rewrite_ptr;

PFNGLDRAWRANGEELEMENTSBASEVERTEXEXTPROC epoxy_glDrawRangeElementsBaseVertexEXT = epoxy_glDrawRangeElementsBaseVertexEXT_global_rewrite_ptr;

PFNGLDRAWRANGEELEMENTSBASEVERTEXOESPROC epoxy_glDrawRangeElementsBaseVertexOES = epoxy_glDrawRangeElementsBaseVertexOES_global_rewrite_ptr;

PFNGLDRAWRANGEELEMENTSEXTPROC epoxy_glDrawRangeElementsEXT = epoxy_glDrawRangeElementsEXT_global_rewrite_ptr;

PFNGLDRAWTEXFOESPROC epoxy_glDrawTexfOES = epoxy_glDrawTexfOES_global_rewrite_ptr;

PFNGLDRAWTEXFVOESPROC epoxy_glDrawTexfvOES = epoxy_glDrawTexfvOES_global_rewrite_ptr;

PFNGLDRAWTEXIOESPROC epoxy_glDrawTexiOES = epoxy_glDrawTexiOES_global_rewrite_ptr;

PFNGLDRAWTEXIVOESPROC epoxy_glDrawTexivOES = epoxy_glDrawTexivOES_global_rewrite_ptr;

PFNGLDRAWTEXSOESPROC epoxy_glDrawTexsOES = epoxy_glDrawTexsOES_global_rewrite_ptr;

PFNGLDRAWTEXSVOESPROC epoxy_glDrawTexsvOES = epoxy_glDrawTexsvOES_global_rewrite_ptr;

PFNGLDRAWTEXTURENVPROC epoxy_glDrawTextureNV = epoxy_glDrawTextureNV_global_rewrite_ptr;

PFNGLDRAWTEXXOESPROC epoxy_glDrawTexxOES = epoxy_glDrawTexxOES_global_rewrite_ptr;

PFNGLDRAWTEXXVOESPROC epoxy_glDrawTexxvOES = epoxy_glDrawTexxvOES_global_rewrite_ptr;

PFNGLDRAWTRANSFORMFEEDBACKPROC epoxy_glDrawTransformFeedback = epoxy_glDrawTransformFeedback_global_rewrite_ptr;

PFNGLDRAWTRANSFORMFEEDBACKEXTPROC epoxy_glDrawTransformFeedbackEXT = epoxy_glDrawTransformFeedbackEXT_global_rewrite_ptr;

PFNGLDRAWTRANSFORMFEEDBACKINSTANCEDPROC epoxy_glDrawTransformFeedbackInstanced = epoxy_glDrawTransformFeedbackInstanced_global_rewrite_ptr;

PFNGLDRAWTRANSFORMFEEDBACKINSTANCEDEXTPROC epoxy_glDrawTransformFeedbackInstancedEXT = epoxy_glDrawTransformFeedbackInstancedEXT_global_rewrite_ptr;

PFNGLDRAWTRANSFORMFEEDBACKNVPROC epoxy_glDrawTransformFeedbackNV = epoxy_glDrawTransformFeedbackNV_global_rewrite_ptr;

PFNGLDRAWTRANSFORMFEEDBACKSTREAMPROC epoxy_glDrawTransformFeedbackStream = epoxy_glDrawTransformFeedbackStream_global_rewrite_ptr;

PFNGLDRAWTRANSFORMFEEDBACKSTREAMINSTANCEDPROC epoxy_glDrawTransformFeedbackStreamInstanced = epoxy_glDrawTransformFeedbackStreamInstanced_global_rewrite_ptr;

PFNGLDRAWVKIMAGENVPROC epoxy_glDrawVkImageNV = epoxy_glDrawVkImageNV_global_rewrite_ptr;

PFNGLEGLIMAGETARGETRENDERBUFFERSTORAGEOESPROC epoxy_glEGLImageTargetRenderbufferStorageOES = epoxy_glEGLImageTargetRenderbufferStorageOES_global_rewrite_ptr;

PFNGLEGLIMAGETARGETTEXSTORAGEEXTPROC epoxy_glEGLImageTargetTexStorageEXT = epoxy_glEGLImageTargetTexStorageEXT_global_rewrite_ptr;

PFNGLEGLIMAGETARGETTEXTURE2DOESPROC epoxy_glEGLImageTargetTexture2DOES = epoxy_glEGLImageTargetTexture2DOES_global_rewrite_ptr;

PFNGLEGLIMAGETARGETTEXTURESTORAGEEXTPROC epoxy_glEGLImageTargetTextureStorageEXT = epoxy_glEGLImageTargetTextureStorageEXT_global_rewrite_ptr;

PFNGLEDGEFLAGPROC epoxy_glEdgeFlag = epoxy_glEdgeFlag_global_rewrite_ptr;

PFNGLEDGEFLAGFORMATNVPROC epoxy_glEdgeFlagFormatNV = epoxy_glEdgeFlagFormatNV_global_rewrite_ptr;

PFNGLEDGEFLAGPOINTERPROC epoxy_glEdgeFlagPointer = epoxy_glEdgeFlagPointer_global_rewrite_ptr;

PFNGLEDGEFLAGPOINTEREXTPROC epoxy_glEdgeFlagPointerEXT = epoxy_glEdgeFlagPointerEXT_global_rewrite_ptr;

PFNGLEDGEFLAGPOINTERLISTIBMPROC epoxy_glEdgeFlagPointerListIBM = epoxy_glEdgeFlagPointerListIBM_global_rewrite_ptr;

PFNGLEDGEFLAGVPROC epoxy_glEdgeFlagv = epoxy_glEdgeFlagv_global_rewrite_ptr;

PFNGLELEMENTPOINTERAPPLEPROC epoxy_glElementPointerAPPLE = epoxy_glElementPointerAPPLE_global_rewrite_ptr;

PFNGLELEMENTPOINTERATIPROC epoxy_glElementPointerATI = epoxy_glElementPointerATI_global_rewrite_ptr;

PFNGLENABLEPROC epoxy_glEnable = epoxy_glEnable_global_rewrite_ptr;

PFNGLENABLECLIENTSTATEPROC epoxy_glEnableClientState = epoxy_glEnableClientState_global_rewrite_ptr;

PFNGLENABLECLIENTSTATEINDEXEDEXTPROC epoxy_glEnableClientStateIndexedEXT = epoxy_glEnableClientStateIndexedEXT_global_rewrite_ptr;

PFNGLENABLECLIENTSTATEIEXTPROC epoxy_glEnableClientStateiEXT = epoxy_glEnableClientStateiEXT_global_rewrite_ptr;

PFNGLENABLEDRIVERCONTROLQCOMPROC epoxy_glEnableDriverControlQCOM = epoxy_glEnableDriverControlQCOM_global_rewrite_ptr;

PFNGLENABLEINDEXEDEXTPROC epoxy_glEnableIndexedEXT = epoxy_glEnableIndexedEXT_global_rewrite_ptr;

PFNGLENABLEVARIANTCLIENTSTATEEXTPROC epoxy_glEnableVariantClientStateEXT = epoxy_glEnableVariantClientStateEXT_global_rewrite_ptr;

PFNGLENABLEVERTEXARRAYATTRIBPROC epoxy_glEnableVertexArrayAttrib = epoxy_glEnableVertexArrayAttrib_global_rewrite_ptr;

PFNGLENABLEVERTEXARRAYATTRIBEXTPROC epoxy_glEnableVertexArrayAttribEXT = epoxy_glEnableVertexArrayAttribEXT_global_rewrite_ptr;

PFNGLENABLEVERTEXARRAYEXTPROC epoxy_glEnableVertexArrayEXT = epoxy_glEnableVertexArrayEXT_global_rewrite_ptr;

PFNGLENABLEVERTEXATTRIBAPPLEPROC epoxy_glEnableVertexAttribAPPLE = epoxy_glEnableVertexAttribAPPLE_global_rewrite_ptr;

PFNGLENABLEVERTEXATTRIBARRAYPROC epoxy_glEnableVertexAttribArray = epoxy_glEnableVertexAttribArray_global_rewrite_ptr;

PFNGLENABLEVERTEXATTRIBARRAYARBPROC epoxy_glEnableVertexAttribArrayARB = epoxy_glEnableVertexAttribArrayARB_global_rewrite_ptr;

PFNGLENABLEIPROC epoxy_glEnablei = epoxy_glEnablei_global_rewrite_ptr;

PFNGLENABLEIEXTPROC epoxy_glEnableiEXT = epoxy_glEnableiEXT_global_rewrite_ptr;

PFNGLENABLEINVPROC epoxy_glEnableiNV = epoxy_glEnableiNV_global_rewrite_ptr;

PFNGLENABLEIOESPROC epoxy_glEnableiOES = epoxy_glEnableiOES_global_rewrite_ptr;

PFNGLENDPROC epoxy_glEnd_unwrapped = epoxy_glEnd_unwrapped_global_rewrite_ptr;

PFNGLENDCONDITIONALRENDERPROC epoxy_glEndConditionalRender = epoxy_glEndConditionalRender_global_rewrite_ptr;

PFNGLENDCONDITIONALRENDERNVPROC epoxy_glEndConditionalRenderNV = epoxy_glEndConditionalRenderNV_global_rewrite_ptr;

PFNGLENDCONDITIONALRENDERNVXPROC epoxy_glEndConditionalRenderNVX = epoxy_glEndConditionalRenderNVX_global_rewrite_ptr;

PFNGLENDFRAGMENTSHADERATIPROC epoxy_glEndFragmentShaderATI = epoxy_glEndFragmentShaderATI_global_rewrite_ptr;

PFNGLENDLISTPROC epoxy_glEndList = epoxy_glEndList_global_rewrite_ptr;

PFNGLENDOCCLUSIONQUERYNVPROC epoxy_glEndOcclusionQueryNV = epoxy_glEndOcclusionQueryNV_global_rewrite_ptr;

PFNGLENDPERFMONITORAMDPROC epoxy_glEndPerfMonitorAMD = epoxy_glEndPerfMonitorAMD_global_rewrite_ptr;

PFNGLENDPERFQUERYINTELPROC epoxy_glEndPerfQueryINTEL = epoxy_glEndPerfQueryINTEL_global_rewrite_ptr;

PFNGLENDQUERYPROC epoxy_glEndQuery = epoxy_glEndQuery_global_rewrite_ptr;

PFNGLENDQUERYARBPROC epoxy_glEndQueryARB = epoxy_glEndQueryARB_global_rewrite_ptr;

PFNGLENDQUERYEXTPROC epoxy_glEndQueryEXT = epoxy_glEndQueryEXT_global_rewrite_ptr;

PFNGLENDQUERYINDEXEDPROC epoxy_glEndQueryIndexed = epoxy_glEndQueryIndexed_global_rewrite_ptr;

PFNGLENDTILINGQCOMPROC epoxy_glEndTilingQCOM = epoxy_glEndTilingQCOM_global_rewrite_ptr;

PFNGLENDTRANSFORMFEEDBACKPROC epoxy_glEndTransformFeedback = epoxy_glEndTransformFeedback_global_rewrite_ptr;

PFNGLENDTRANSFORMFEEDBACKEXTPROC epoxy_glEndTransformFeedbackEXT = epoxy_glEndTransformFeedbackEXT_global_rewrite_ptr;

PFNGLENDTRANSFORMFEEDBACKNVPROC epoxy_glEndTransformFeedbackNV = epoxy_glEndTransformFeedbackNV_global_rewrite_ptr;

PFNGLENDVERTEXSHADEREXTPROC epoxy_glEndVertexShaderEXT = epoxy_glEndVertexShaderEXT_global_rewrite_ptr;

PFNGLENDVIDEOCAPTURENVPROC epoxy_glEndVideoCaptureNV = epoxy_glEndVideoCaptureNV_global_rewrite_ptr;

PFNGLEVALCOORD1DPROC epoxy_glEvalCoord1d = epoxy_glEvalCoord1d_global_rewrite_ptr;

PFNGLEVALCOORD1DVPROC epoxy_glEvalCoord1dv = epoxy_glEvalCoord1dv_global_rewrite_ptr;

PFNGLEVALCOORD1FPROC epoxy_glEvalCoord1f = epoxy_glEvalCoord1f_global_rewrite_ptr;

PFNGLEVALCOORD1FVPROC epoxy_glEvalCoord1fv = epoxy_glEvalCoord1fv_global_rewrite_ptr;

PFNGLEVALCOORD1XOESPROC epoxy_glEvalCoord1xOES = epoxy_glEvalCoord1xOES_global_rewrite_ptr;

PFNGLEVALCOORD1XVOESPROC epoxy_glEvalCoord1xvOES = epoxy_glEvalCoord1xvOES_global_rewrite_ptr;

PFNGLEVALCOORD2DPROC epoxy_glEvalCoord2d = epoxy_glEvalCoord2d_global_rewrite_ptr;

PFNGLEVALCOORD2DVPROC epoxy_glEvalCoord2dv = epoxy_glEvalCoord2dv_global_rewrite_ptr;

PFNGLEVALCOORD2FPROC epoxy_glEvalCoord2f = epoxy_glEvalCoord2f_global_rewrite_ptr;

PFNGLEVALCOORD2FVPROC epoxy_glEvalCoord2fv = epoxy_glEvalCoord2fv_global_rewrite_ptr;

PFNGLEVALCOORD2XOESPROC epoxy_glEvalCoord2xOES = epoxy_glEvalCoord2xOES_global_rewrite_ptr;

PFNGLEVALCOORD2XVOESPROC epoxy_glEvalCoord2xvOES = epoxy_glEvalCoord2xvOES_global_rewrite_ptr;

PFNGLEVALMAPSNVPROC epoxy_glEvalMapsNV = epoxy_glEvalMapsNV_global_rewrite_ptr;

PFNGLEVALMESH1PROC epoxy_glEvalMesh1 = epoxy_glEvalMesh1_global_rewrite_ptr;

PFNGLEVALMESH2PROC epoxy_glEvalMesh2 = epoxy_glEvalMesh2_global_rewrite_ptr;

PFNGLEVALPOINT1PROC epoxy_glEvalPoint1 = epoxy_glEvalPoint1_global_rewrite_ptr;

PFNGLEVALPOINT2PROC epoxy_glEvalPoint2 = epoxy_glEvalPoint2_global_rewrite_ptr;

PFNGLEVALUATEDEPTHVALUESARBPROC epoxy_glEvaluateDepthValuesARB = epoxy_glEvaluateDepthValuesARB_global_rewrite_ptr;

PFNGLEXECUTEPROGRAMNVPROC epoxy_glExecuteProgramNV = epoxy_glExecuteProgramNV_global_rewrite_ptr;

PFNGLEXTGETBUFFERPOINTERVQCOMPROC epoxy_glExtGetBufferPointervQCOM = epoxy_glExtGetBufferPointervQCOM_global_rewrite_ptr;

PFNGLEXTGETBUFFERSQCOMPROC epoxy_glExtGetBuffersQCOM = epoxy_glExtGetBuffersQCOM_global_rewrite_ptr;

PFNGLEXTGETFRAMEBUFFERSQCOMPROC epoxy_glExtGetFramebuffersQCOM = epoxy_glExtGetFramebuffersQCOM_global_rewrite_ptr;

PFNGLEXTGETPROGRAMBINARYSOURCEQCOMPROC epoxy_glExtGetProgramBinarySourceQCOM = epoxy_glExtGetProgramBinarySourceQCOM_global_rewrite_ptr;

PFNGLEXTGETPROGRAMSQCOMPROC epoxy_glExtGetProgramsQCOM = epoxy_glExtGetProgramsQCOM_global_rewrite_ptr;

PFNGLEXTGETRENDERBUFFERSQCOMPROC epoxy_glExtGetRenderbuffersQCOM = epoxy_glExtGetRenderbuffersQCOM_global_rewrite_ptr;

PFNGLEXTGETSHADERSQCOMPROC epoxy_glExtGetShadersQCOM = epoxy_glExtGetShadersQCOM_global_rewrite_ptr;

PFNGLEXTGETTEXLEVELPARAMETERIVQCOMPROC epoxy_glExtGetTexLevelParameterivQCOM = epoxy_glExtGetTexLevelParameterivQCOM_global_rewrite_ptr;

PFNGLEXTGETTEXSUBIMAGEQCOMPROC epoxy_glExtGetTexSubImageQCOM = epoxy_glExtGetTexSubImageQCOM_global_rewrite_ptr;

PFNGLEXTGETTEXTURESQCOMPROC epoxy_glExtGetTexturesQCOM = epoxy_glExtGetTexturesQCOM_global_rewrite_ptr;

PFNGLEXTISPROGRAMBINARYQCOMPROC epoxy_glExtIsProgramBinaryQCOM = epoxy_glExtIsProgramBinaryQCOM_global_rewrite_ptr;

PFNGLEXTTEXOBJECTSTATEOVERRIDEIQCOMPROC epoxy_glExtTexObjectStateOverrideiQCOM = epoxy_glExtTexObjectStateOverrideiQCOM_global_rewrite_ptr;

PFNGLEXTRACTCOMPONENTEXTPROC epoxy_glExtractComponentEXT = epoxy_glExtractComponentEXT_global_rewrite_ptr;

PFNGLFEEDBACKBUFFERPROC epoxy_glFeedbackBuffer = epoxy_glFeedbackBuffer_global_rewrite_ptr;

PFNGLFEEDBACKBUFFERXOESPROC epoxy_glFeedbackBufferxOES = epoxy_glFeedbackBufferxOES_global_rewrite_ptr;

PFNGLFENCESYNCPROC epoxy_glFenceSync = epoxy_glFenceSync_global_rewrite_ptr;

PFNGLFENCESYNCAPPLEPROC epoxy_glFenceSyncAPPLE = epoxy_glFenceSyncAPPLE_global_rewrite_ptr;

PFNGLFINALCOMBINERINPUTNVPROC epoxy_glFinalCombinerInputNV = epoxy_glFinalCombinerInputNV_global_rewrite_ptr;

PFNGLFINISHPROC epoxy_glFinish = epoxy_glFinish_global_rewrite_ptr;

PFNGLFINISHASYNCSGIXPROC epoxy_glFinishAsyncSGIX = epoxy_glFinishAsyncSGIX_global_rewrite_ptr;

PFNGLFINISHFENCEAPPLEPROC epoxy_glFinishFenceAPPLE = epoxy_glFinishFenceAPPLE_global_rewrite_ptr;

PFNGLFINISHFENCENVPROC epoxy_glFinishFenceNV = epoxy_glFinishFenceNV_global_rewrite_ptr;

PFNGLFINISHOBJECTAPPLEPROC epoxy_glFinishObjectAPPLE = epoxy_glFinishObjectAPPLE_global_rewrite_ptr;

PFNGLFINISHTEXTURESUNXPROC epoxy_glFinishTextureSUNX = epoxy_glFinishTextureSUNX_global_rewrite_ptr;

PFNGLFLUSHPROC epoxy_glFlush = epoxy_glFlush_global_rewrite_ptr;

PFNGLFLUSHMAPPEDBUFFERRANGEPROC epoxy_glFlushMappedBufferRange = epoxy_glFlushMappedBufferRange_global_rewrite_ptr;

PFNGLFLUSHMAPPEDBUFFERRANGEAPPLEPROC epoxy_glFlushMappedBufferRangeAPPLE = epoxy_glFlushMappedBufferRangeAPPLE_global_rewrite_ptr;

PFNGLFLUSHMAPPEDBUFFERRANGEEXTPROC epoxy_glFlushMappedBufferRangeEXT = epoxy_glFlushMappedBufferRangeEXT_global_rewrite_ptr;

PFNGLFLUSHMAPPEDNAMEDBUFFERRANGEPROC epoxy_glFlushMappedNamedBufferRange = epoxy_glFlushMappedNamedBufferRange_global_rewrite_ptr;

PFNGLFLUSHMAPPEDNAMEDBUFFERRANGEEXTPROC epoxy_glFlushMappedNamedBufferRangeEXT = epoxy_glFlushMappedNamedBufferRangeEXT_global_rewrite_ptr;

PFNGLFLUSHPIXELDATARANGENVPROC epoxy_glFlushPixelDataRangeNV = epoxy_glFlushPixelDataRangeNV_global_rewrite_ptr;

PFNGLFLUSHRASTERSGIXPROC epoxy_glFlushRasterSGIX = epoxy_glFlushRasterSGIX_global_rewrite_ptr;

PFNGLFLUSHSTATICDATAIBMPROC epoxy_glFlushStaticDataIBM = epoxy_glFlushStaticDataIBM_global_rewrite_ptr;

PFNGLFLUSHVERTEXARRAYRANGEAPPLEPROC epoxy_glFlushVertexArrayRangeAPPLE = epoxy_glFlushVertexArrayRangeAPPLE_global_rewrite_ptr;

PFNGLFLUSHVERTEXARRAYRANGENVPROC epoxy_glFlushVertexArrayRangeNV = epoxy_glFlushVertexArrayRangeNV_global_rewrite_ptr;

PFNGLFOGCOORDFORMATNVPROC epoxy_glFogCoordFormatNV = epoxy_glFogCoordFormatNV_global_rewrite_ptr;

PFNGLFOGCOORDPOINTERPROC epoxy_glFogCoordPointer = epoxy_glFogCoordPointer_global_rewrite_ptr;

PFNGLFOGCOORDPOINTEREXTPROC epoxy_glFogCoordPointerEXT = epoxy_glFogCoordPointerEXT_global_rewrite_ptr;

PFNGLFOGCOORDPOINTERLISTIBMPROC epoxy_glFogCoordPointerListIBM = epoxy_glFogCoordPointerListIBM_global_rewrite_ptr;

PFNGLFOGCOORDDPROC epoxy_glFogCoordd = epoxy_glFogCoordd_global_rewrite_ptr;

PFNGLFOGCOORDDEXTPROC epoxy_glFogCoorddEXT = epoxy_glFogCoorddEXT_global_rewrite_ptr;

PFNGLFOGCOORDDVPROC epoxy_glFogCoorddv = epoxy_glFogCoorddv_global_rewrite_ptr;

PFNGLFOGCOORDDVEXTPROC epoxy_glFogCoorddvEXT = epoxy_glFogCoorddvEXT_global_rewrite_ptr;

PFNGLFOGCOORDFPROC epoxy_glFogCoordf = epoxy_glFogCoordf_global_rewrite_ptr;

PFNGLFOGCOORDFEXTPROC epoxy_glFogCoordfEXT = epoxy_glFogCoordfEXT_global_rewrite_ptr;

PFNGLFOGCOORDFVPROC epoxy_glFogCoordfv = epoxy_glFogCoordfv_global_rewrite_ptr;

PFNGLFOGCOORDFVEXTPROC epoxy_glFogCoordfvEXT = epoxy_glFogCoordfvEXT_global_rewrite_ptr;

PFNGLFOGCOORDHNVPROC epoxy_glFogCoordhNV = epoxy_glFogCoordhNV_global_rewrite_ptr;

PFNGLFOGCOORDHVNVPROC epoxy_glFogCoordhvNV = epoxy_glFogCoordhvNV_global_rewrite_ptr;

PFNGLFOGFUNCSGISPROC epoxy_glFogFuncSGIS = epoxy_glFogFuncSGIS_global_rewrite_ptr;

PFNGLFOGFPROC epoxy_glFogf = epoxy_glFogf_global_rewrite_ptr;

PFNGLFOGFVPROC epoxy_glFogfv = epoxy_glFogfv_global_rewrite_ptr;

PFNGLFOGIPROC epoxy_glFogi = epoxy_glFogi_global_rewrite_ptr;

PFNGLFOGIVPROC epoxy_glFogiv = epoxy_glFogiv_global_rewrite_ptr;

PFNGLFOGXPROC epoxy_glFogx = epoxy_glFogx_global_rewrite_ptr;

PFNGLFOGXOESPROC epoxy_glFogxOES = epoxy_glFogxOES_global_rewrite_ptr;

PFNGLFOGXVPROC epoxy_glFogxv = epoxy_glFogxv_global_rewrite_ptr;

PFNGLFOGXVOESPROC epoxy_glFogxvOES = epoxy_glFogxvOES_global_rewrite_ptr;

PFNGLFRAGMENTCOLORMATERIALSGIXPROC epoxy_glFragmentColorMaterialSGIX = epoxy_glFragmentColorMaterialSGIX_global_rewrite_ptr;

PFNGLFRAGMENTCOVERAGECOLORNVPROC epoxy_glFragmentCoverageColorNV = epoxy_glFragmentCoverageColorNV_global_rewrite_ptr;

PFNGLFRAGMENTLIGHTMODELFSGIXPROC epoxy_glFragmentLightModelfSGIX = epoxy_glFragmentLightModelfSGIX_global_rewrite_ptr;

PFNGLFRAGMENTLIGHTMODELFVSGIXPROC epoxy_glFragmentLightModelfvSGIX = epoxy_glFragmentLightModelfvSGIX_global_rewrite_ptr;

PFNGLFRAGMENTLIGHTMODELISGIXPROC epoxy_glFragmentLightModeliSGIX = epoxy_glFragmentLightModeliSGIX_global_rewrite_ptr;

PFNGLFRAGMENTLIGHTMODELIVSGIXPROC epoxy_glFragmentLightModelivSGIX = epoxy_glFragmentLightModelivSGIX_global_rewrite_ptr;

PFNGLFRAGMENTLIGHTFSGIXPROC epoxy_glFragmentLightfSGIX = epoxy_glFragmentLightfSGIX_global_rewrite_ptr;

PFNGLFRAGMENTLIGHTFVSGIXPROC epoxy_glFragmentLightfvSGIX = epoxy_glFragmentLightfvSGIX_global_rewrite_ptr;

PFNGLFRAGMENTLIGHTISGIXPROC epoxy_glFragmentLightiSGIX = epoxy_glFragmentLightiSGIX_global_rewrite_ptr;

PFNGLFRAGMENTLIGHTIVSGIXPROC epoxy_glFragmentLightivSGIX = epoxy_glFragmentLightivSGIX_global_rewrite_ptr;

PFNGLFRAGMENTMATERIALFSGIXPROC epoxy_glFragmentMaterialfSGIX = epoxy_glFragmentMaterialfSGIX_global_rewrite_ptr;

PFNGLFRAGMENTMATERIALFVSGIXPROC epoxy_glFragmentMaterialfvSGIX = epoxy_glFragmentMaterialfvSGIX_global_rewrite_ptr;

PFNGLFRAGMENTMATERIALISGIXPROC epoxy_glFragmentMaterialiSGIX = epoxy_glFragmentMaterialiSGIX_global_rewrite_ptr;

PFNGLFRAGMENTMATERIALIVSGIXPROC epoxy_glFragmentMaterialivSGIX = epoxy_glFragmentMaterialivSGIX_global_rewrite_ptr;

PFNGLFRAMETERMINATORGREMEDYPROC epoxy_glFrameTerminatorGREMEDY = epoxy_glFrameTerminatorGREMEDY_global_rewrite_ptr;

PFNGLFRAMEZOOMSGIXPROC epoxy_glFrameZoomSGIX = epoxy_glFrameZoomSGIX_global_rewrite_ptr;

PFNGLFRAMEBUFFERDRAWBUFFEREXTPROC epoxy_glFramebufferDrawBufferEXT = epoxy_glFramebufferDrawBufferEXT_global_rewrite_ptr;

PFNGLFRAMEBUFFERDRAWBUFFERSEXTPROC epoxy_glFramebufferDrawBuffersEXT = epoxy_glFramebufferDrawBuffersEXT_global_rewrite_ptr;

PFNGLFRAMEBUFFERFETCHBARRIEREXTPROC epoxy_glFramebufferFetchBarrierEXT = epoxy_glFramebufferFetchBarrierEXT_global_rewrite_ptr;

PFNGLFRAMEBUFFERFETCHBARRIERQCOMPROC epoxy_glFramebufferFetchBarrierQCOM = epoxy_glFramebufferFetchBarrierQCOM_global_rewrite_ptr;

PFNGLFRAMEBUFFERFOVEATIONCONFIGQCOMPROC epoxy_glFramebufferFoveationConfigQCOM = epoxy_glFramebufferFoveationConfigQCOM_global_rewrite_ptr;

PFNGLFRAMEBUFFERFOVEATIONPARAMETERSQCOMPROC epoxy_glFramebufferFoveationParametersQCOM = epoxy_glFramebufferFoveationParametersQCOM_global_rewrite_ptr;

PFNGLFRAMEBUFFERPARAMETERIPROC epoxy_glFramebufferParameteri = epoxy_glFramebufferParameteri_global_rewrite_ptr;

PFNGLFRAMEBUFFERPARAMETERIMESAPROC epoxy_glFramebufferParameteriMESA = epoxy_glFramebufferParameteriMESA_global_rewrite_ptr;

PFNGLFRAMEBUFFERPIXELLOCALSTORAGESIZEEXTPROC epoxy_glFramebufferPixelLocalStorageSizeEXT = epoxy_glFramebufferPixelLocalStorageSizeEXT_global_rewrite_ptr;

PFNGLFRAMEBUFFERREADBUFFEREXTPROC epoxy_glFramebufferReadBufferEXT = epoxy_glFramebufferReadBufferEXT_global_rewrite_ptr;

PFNGLFRAMEBUFFERRENDERBUFFERPROC epoxy_glFramebufferRenderbuffer = epoxy_glFramebufferRenderbuffer_global_rewrite_ptr;

PFNGLFRAMEBUFFERRENDERBUFFEREXTPROC epoxy_glFramebufferRenderbufferEXT = epoxy_glFramebufferRenderbufferEXT_global_rewrite_ptr;

PFNGLFRAMEBUFFERRENDERBUFFEROESPROC epoxy_glFramebufferRenderbufferOES = epoxy_glFramebufferRenderbufferOES_global_rewrite_ptr;

PFNGLFRAMEBUFFERSAMPLELOCATIONSFVARBPROC epoxy_glFramebufferSampleLocationsfvARB = epoxy_glFramebufferSampleLocationsfvARB_global_rewrite_ptr;

PFNGLFRAMEBUFFERSAMPLELOCATIONSFVNVPROC epoxy_glFramebufferSampleLocationsfvNV = epoxy_glFramebufferSampleLocationsfvNV_global_rewrite_ptr;

PFNGLFRAMEBUFFERSAMPLEPOSITIONSFVAMDPROC epoxy_glFramebufferSamplePositionsfvAMD = epoxy_glFramebufferSamplePositionsfvAMD_global_rewrite_ptr;

PFNGLFRAMEBUFFERTEXTUREPROC epoxy_glFramebufferTexture = epoxy_glFramebufferTexture_global_rewrite_ptr;

PFNGLFRAMEBUFFERTEXTURE1DPROC epoxy_glFramebufferTexture1D = epoxy_glFramebufferTexture1D_global_rewrite_ptr;

PFNGLFRAMEBUFFERTEXTURE1DEXTPROC epoxy_glFramebufferTexture1DEXT = epoxy_glFramebufferTexture1DEXT_global_rewrite_ptr;

PFNGLFRAMEBUFFERTEXTURE2DPROC epoxy_glFramebufferTexture2D = epoxy_glFramebufferTexture2D_global_rewrite_ptr;

PFNGLFRAMEBUFFERTEXTURE2DDOWNSAMPLEIMGPROC epoxy_glFramebufferTexture2DDownsampleIMG = epoxy_glFramebufferTexture2DDownsampleIMG_global_rewrite_ptr;

PFNGLFRAMEBUFFERTEXTURE2DEXTPROC epoxy_glFramebufferTexture2DEXT = epoxy_glFramebufferTexture2DEXT_global_rewrite_ptr;

PFNGLFRAMEBUFFERTEXTURE2DMULTISAMPLEEXTPROC epoxy_glFramebufferTexture2DMultisampleEXT = epoxy_glFramebufferTexture2DMultisampleEXT_global_rewrite_ptr;

PFNGLFRAMEBUFFERTEXTURE2DMULTISAMPLEIMGPROC epoxy_glFramebufferTexture2DMultisampleIMG = epoxy_glFramebufferTexture2DMultisampleIMG_global_rewrite_ptr;

PFNGLFRAMEBUFFERTEXTURE2DOESPROC epoxy_glFramebufferTexture2DOES = epoxy_glFramebufferTexture2DOES_global_rewrite_ptr;

PFNGLFRAMEBUFFERTEXTURE3DPROC epoxy_glFramebufferTexture3D = epoxy_glFramebufferTexture3D_global_rewrite_ptr;

PFNGLFRAMEBUFFERTEXTURE3DEXTPROC epoxy_glFramebufferTexture3DEXT = epoxy_glFramebufferTexture3DEXT_global_rewrite_ptr;

PFNGLFRAMEBUFFERTEXTURE3DOESPROC epoxy_glFramebufferTexture3DOES = epoxy_glFramebufferTexture3DOES_global_rewrite_ptr;

PFNGLFRAMEBUFFERTEXTUREARBPROC epoxy_glFramebufferTextureARB = epoxy_glFramebufferTextureARB_global_rewrite_ptr;

PFNGLFRAMEBUFFERTEXTUREEXTPROC epoxy_glFramebufferTextureEXT = epoxy_glFramebufferTextureEXT_global_rewrite_ptr;

PFNGLFRAMEBUFFERTEXTUREFACEARBPROC epoxy_glFramebufferTextureFaceARB = epoxy_glFramebufferTextureFaceARB_global_rewrite_ptr;

PFNGLFRAMEBUFFERTEXTUREFACEEXTPROC epoxy_glFramebufferTextureFaceEXT = epoxy_glFramebufferTextureFaceEXT_global_rewrite_ptr;

PFNGLFRAMEBUFFERTEXTURELAYERPROC epoxy_glFramebufferTextureLayer = epoxy_glFramebufferTextureLayer_global_rewrite_ptr;

PFNGLFRAMEBUFFERTEXTURELAYERARBPROC epoxy_glFramebufferTextureLayerARB = epoxy_glFramebufferTextureLayerARB_global_rewrite_ptr;

PFNGLFRAMEBUFFERTEXTURELAYERDOWNSAMPLEIMGPROC epoxy_glFramebufferTextureLayerDownsampleIMG = epoxy_glFramebufferTextureLayerDownsampleIMG_global_rewrite_ptr;

PFNGLFRAMEBUFFERTEXTURELAYEREXTPROC epoxy_glFramebufferTextureLayerEXT = epoxy_glFramebufferTextureLayerEXT_global_rewrite_ptr;

PFNGLFRAMEBUFFERTEXTUREMULTISAMPLEMULTIVIEWOVRPROC epoxy_glFramebufferTextureMultisampleMultiviewOVR = epoxy_glFramebufferTextureMultisampleMultiviewOVR_global_rewrite_ptr;

PFNGLFRAMEBUFFERTEXTUREMULTIVIEWOVRPROC epoxy_glFramebufferTextureMultiviewOVR = epoxy_glFramebufferTextureMultiviewOVR_global_rewrite_ptr;

PFNGLFRAMEBUFFERTEXTUREOESPROC epoxy_glFramebufferTextureOES = epoxy_glFramebufferTextureOES_global_rewrite_ptr;

PFNGLFREEOBJECTBUFFERATIPROC epoxy_glFreeObjectBufferATI = epoxy_glFreeObjectBufferATI_global_rewrite_ptr;

PFNGLFRONTFACEPROC epoxy_glFrontFace = epoxy_glFrontFace_global_rewrite_ptr;

PFNGLFRUSTUMPROC epoxy_glFrustum = epoxy_glFrustum_global_rewrite_ptr;

PFNGLFRUSTUMFPROC epoxy_glFrustumf = epoxy_glFrustumf_global_rewrite_ptr;

PFNGLFRUSTUMFOESPROC epoxy_glFrustumfOES = epoxy_glFrustumfOES_global_rewrite_ptr;

PFNGLFRUSTUMXPROC epoxy_glFrustumx = epoxy_glFrustumx_global_rewrite_ptr;

PFNGLFRUSTUMXOESPROC epoxy_glFrustumxOES = epoxy_glFrustumxOES_global_rewrite_ptr;

PFNGLGENASYNCMARKERSSGIXPROC epoxy_glGenAsyncMarkersSGIX = epoxy_glGenAsyncMarkersSGIX_global_rewrite_ptr;

PFNGLGENBUFFERSPROC epoxy_glGenBuffers = epoxy_glGenBuffers_global_rewrite_ptr;

PFNGLGENBUFFERSARBPROC epoxy_glGenBuffersARB = epoxy_glGenBuffersARB_global_rewrite_ptr;

PFNGLGENFENCESAPPLEPROC epoxy_glGenFencesAPPLE = epoxy_glGenFencesAPPLE_global_rewrite_ptr;

PFNGLGENFENCESNVPROC epoxy_glGenFencesNV = epoxy_glGenFencesNV_global_rewrite_ptr;

PFNGLGENFRAGMENTSHADERSATIPROC epoxy_glGenFragmentShadersATI = epoxy_glGenFragmentShadersATI_global_rewrite_ptr;

PFNGLGENFRAMEBUFFERSPROC epoxy_glGenFramebuffers = epoxy_glGenFramebuffers_global_rewrite_ptr;

PFNGLGENFRAMEBUFFERSEXTPROC epoxy_glGenFramebuffersEXT = epoxy_glGenFramebuffersEXT_global_rewrite_ptr;

PFNGLGENFRAMEBUFFERSOESPROC epoxy_glGenFramebuffersOES = epoxy_glGenFramebuffersOES_global_rewrite_ptr;

PFNGLGENLISTSPROC epoxy_glGenLists = epoxy_glGenLists_global_rewrite_ptr;

PFNGLGENNAMESAMDPROC epoxy_glGenNamesAMD = epoxy_glGenNamesAMD_global_rewrite_ptr;

PFNGLGENOCCLUSIONQUERIESNVPROC epoxy_glGenOcclusionQueriesNV = epoxy_glGenOcclusionQueriesNV_global_rewrite_ptr;

PFNGLGENPATHSNVPROC epoxy_glGenPathsNV = epoxy_glGenPathsNV_global_rewrite_ptr;

PFNGLGENPERFMONITORSAMDPROC epoxy_glGenPerfMonitorsAMD = epoxy_glGenPerfMonitorsAMD_global_rewrite_ptr;

PFNGLGENPROGRAMPIPELINESPROC epoxy_glGenProgramPipelines = epoxy_glGenProgramPipelines_global_rewrite_ptr;

PFNGLGENPROGRAMPIPELINESEXTPROC epoxy_glGenProgramPipelinesEXT = epoxy_glGenProgramPipelinesEXT_global_rewrite_ptr;

PFNGLGENPROGRAMSARBPROC epoxy_glGenProgramsARB = epoxy_glGenProgramsARB_global_rewrite_ptr;

PFNGLGENPROGRAMSNVPROC epoxy_glGenProgramsNV = epoxy_glGenProgramsNV_global_rewrite_ptr;

PFNGLGENQUERIESPROC epoxy_glGenQueries = epoxy_glGenQueries_global_rewrite_ptr;

PFNGLGENQUERIESARBPROC epoxy_glGenQueriesARB = epoxy_glGenQueriesARB_global_rewrite_ptr;

PFNGLGENQUERIESEXTPROC epoxy_glGenQueriesEXT = epoxy_glGenQueriesEXT_global_rewrite_ptr;

PFNGLGENQUERYRESOURCETAGNVPROC epoxy_glGenQueryResourceTagNV = epoxy_glGenQueryResourceTagNV_global_rewrite_ptr;

PFNGLGENRENDERBUFFERSPROC epoxy_glGenRenderbuffers = epoxy_glGenRenderbuffers_global_rewrite_ptr;

PFNGLGENRENDERBUFFERSEXTPROC epoxy_glGenRenderbuffersEXT = epoxy_glGenRenderbuffersEXT_global_rewrite_ptr;

PFNGLGENRENDERBUFFERSOESPROC epoxy_glGenRenderbuffersOES = epoxy_glGenRenderbuffersOES_global_rewrite_ptr;

PFNGLGENSAMPLERSPROC epoxy_glGenSamplers = epoxy_glGenSamplers_global_rewrite_ptr;

PFNGLGENSEMAPHORESEXTPROC epoxy_glGenSemaphoresEXT = epoxy_glGenSemaphoresEXT_global_rewrite_ptr;

PFNGLGENSYMBOLSEXTPROC epoxy_glGenSymbolsEXT = epoxy_glGenSymbolsEXT_global_rewrite_ptr;

PFNGLGENTEXTURESPROC epoxy_glGenTextures = epoxy_glGenTextures_global_rewrite_ptr;

PFNGLGENTEXTURESEXTPROC epoxy_glGenTexturesEXT = epoxy_glGenTexturesEXT_global_rewrite_ptr;

PFNGLGENTRANSFORMFEEDBACKSPROC epoxy_glGenTransformFeedbacks = epoxy_glGenTransformFeedbacks_global_rewrite_ptr;

PFNGLGENTRANSFORMFEEDBACKSNVPROC epoxy_glGenTransformFeedbacksNV = epoxy_glGenTransformFeedbacksNV_global_rewrite_ptr;

PFNGLGENVERTEXARRAYSPROC epoxy_glGenVertexArrays = epoxy_glGenVertexArrays_global_rewrite_ptr;

PFNGLGENVERTEXARRAYSAPPLEPROC epoxy_glGenVertexArraysAPPLE = epoxy_glGenVertexArraysAPPLE_global_rewrite_ptr;

PFNGLGENVERTEXARRAYSOESPROC epoxy_glGenVertexArraysOES = epoxy_glGenVertexArraysOES_global_rewrite_ptr;

PFNGLGENVERTEXSHADERSEXTPROC epoxy_glGenVertexShadersEXT = epoxy_glGenVertexShadersEXT_global_rewrite_ptr;

PFNGLGENERATEMIPMAPPROC epoxy_glGenerateMipmap = epoxy_glGenerateMipmap_global_rewrite_ptr;

PFNGLGENERATEMIPMAPEXTPROC epoxy_glGenerateMipmapEXT = epoxy_glGenerateMipmapEXT_global_rewrite_ptr;

PFNGLGENERATEMIPMAPOESPROC epoxy_glGenerateMipmapOES = epoxy_glGenerateMipmapOES_global_rewrite_ptr;

PFNGLGENERATEMULTITEXMIPMAPEXTPROC epoxy_glGenerateMultiTexMipmapEXT = epoxy_glGenerateMultiTexMipmapEXT_global_rewrite_ptr;

PFNGLGENERATETEXTUREMIPMAPPROC epoxy_glGenerateTextureMipmap = epoxy_glGenerateTextureMipmap_global_rewrite_ptr;

PFNGLGENERATETEXTUREMIPMAPEXTPROC epoxy_glGenerateTextureMipmapEXT = epoxy_glGenerateTextureMipmapEXT_global_rewrite_ptr;

PFNGLGETACTIVEATOMICCOUNTERBUFFERIVPROC epoxy_glGetActiveAtomicCounterBufferiv = epoxy_glGetActiveAtomicCounterBufferiv_global_rewrite_ptr;

PFNGLGETACTIVEATTRIBPROC epoxy_glGetActiveAttrib = epoxy_glGetActiveAttrib_global_rewrite_ptr;

PFNGLGETACTIVEATTRIBARBPROC epoxy_glGetActiveAttribARB = epoxy_glGetActiveAttribARB_global_rewrite_ptr;

PFNGLGETACTIVESUBROUTINENAMEPROC epoxy_glGetActiveSubroutineName = epoxy_glGetActiveSubroutineName_global_rewrite_ptr;

PFNGLGETACTIVESUBROUTINEUNIFORMNAMEPROC epoxy_glGetActiveSubroutineUniformName = epoxy_glGetActiveSubroutineUniformName_global_rewrite_ptr;

PFNGLGETACTIVESUBROUTINEUNIFORMIVPROC epoxy_glGetActiveSubroutineUniformiv = epoxy_glGetActiveSubroutineUniformiv_global_rewrite_ptr;

PFNGLGETACTIVEUNIFORMPROC epoxy_glGetActiveUniform = epoxy_glGetActiveUniform_global_rewrite_ptr;

PFNGLGETACTIVEUNIFORMARBPROC epoxy_glGetActiveUniformARB = epoxy_glGetActiveUniformARB_global_rewrite_ptr;

PFNGLGETACTIVEUNIFORMBLOCKNAMEPROC epoxy_glGetActiveUniformBlockName = epoxy_glGetActiveUniformBlockName_global_rewrite_ptr;

PFNGLGETACTIVEUNIFORMBLOCKIVPROC epoxy_glGetActiveUniformBlockiv = epoxy_glGetActiveUniformBlockiv_global_rewrite_ptr;

PFNGLGETACTIVEUNIFORMNAMEPROC epoxy_glGetActiveUniformName = epoxy_glGetActiveUniformName_global_rewrite_ptr;

PFNGLGETACTIVEUNIFORMSIVPROC epoxy_glGetActiveUniformsiv = epoxy_glGetActiveUniformsiv_global_rewrite_ptr;

PFNGLGETACTIVEVARYINGNVPROC epoxy_glGetActiveVaryingNV = epoxy_glGetActiveVaryingNV_global_rewrite_ptr;

PFNGLGETARRAYOBJECTFVATIPROC epoxy_glGetArrayObjectfvATI = epoxy_glGetArrayObjectfvATI_global_rewrite_ptr;

PFNGLGETARRAYOBJECTIVATIPROC epoxy_glGetArrayObjectivATI = epoxy_glGetArrayObjectivATI_global_rewrite_ptr;

PFNGLGETATTACHEDOBJECTSARBPROC epoxy_glGetAttachedObjectsARB = epoxy_glGetAttachedObjectsARB_global_rewrite_ptr;

PFNGLGETATTACHEDSHADERSPROC epoxy_glGetAttachedShaders = epoxy_glGetAttachedShaders_global_rewrite_ptr;

PFNGLGETATTRIBLOCATIONPROC epoxy_glGetAttribLocation = epoxy_glGetAttribLocation_global_rewrite_ptr;

PFNGLGETATTRIBLOCATIONARBPROC epoxy_glGetAttribLocationARB = epoxy_glGetAttribLocationARB_global_rewrite_ptr;

PFNGLGETBOOLEANINDEXEDVEXTPROC epoxy_glGetBooleanIndexedvEXT = epoxy_glGetBooleanIndexedvEXT_global_rewrite_ptr;

PFNGLGETBOOLEANI_VPROC epoxy_glGetBooleani_v = epoxy_glGetBooleani_v_global_rewrite_ptr;

PFNGLGETBOOLEANVPROC epoxy_glGetBooleanv = epoxy_glGetBooleanv_global_rewrite_ptr;

PFNGLGETBUFFERPARAMETERI64VPROC epoxy_glGetBufferParameteri64v = epoxy_glGetBufferParameteri64v_global_rewrite_ptr;

PFNGLGETBUFFERPARAMETERIVPROC epoxy_glGetBufferParameteriv = epoxy_glGetBufferParameteriv_global_rewrite_ptr;

PFNGLGETBUFFERPARAMETERIVARBPROC epoxy_glGetBufferParameterivARB = epoxy_glGetBufferParameterivARB_global_rewrite_ptr;

PFNGLGETBUFFERPARAMETERUI64VNVPROC epoxy_glGetBufferParameterui64vNV = epoxy_glGetBufferParameterui64vNV_global_rewrite_ptr;

PFNGLGETBUFFERPOINTERVPROC epoxy_glGetBufferPointerv = epoxy_glGetBufferPointerv_global_rewrite_ptr;

PFNGLGETBUFFERPOINTERVARBPROC epoxy_glGetBufferPointervARB = epoxy_glGetBufferPointervARB_global_rewrite_ptr;

PFNGLGETBUFFERPOINTERVOESPROC epoxy_glGetBufferPointervOES = epoxy_glGetBufferPointervOES_global_rewrite_ptr;

PFNGLGETBUFFERSUBDATAPROC epoxy_glGetBufferSubData = epoxy_glGetBufferSubData_global_rewrite_ptr;

PFNGLGETBUFFERSUBDATAARBPROC epoxy_glGetBufferSubDataARB = epoxy_glGetBufferSubDataARB_global_rewrite_ptr;

PFNGLGETCLIPPLANEPROC epoxy_glGetClipPlane = epoxy_glGetClipPlane_global_rewrite_ptr;

PFNGLGETCLIPPLANEFPROC epoxy_glGetClipPlanef = epoxy_glGetClipPlanef_global_rewrite_ptr;

PFNGLGETCLIPPLANEFOESPROC epoxy_glGetClipPlanefOES = epoxy_glGetClipPlanefOES_global_rewrite_ptr;

PFNGLGETCLIPPLANEXPROC epoxy_glGetClipPlanex = epoxy_glGetClipPlanex_global_rewrite_ptr;

PFNGLGETCLIPPLANEXOESPROC epoxy_glGetClipPlanexOES = epoxy_glGetClipPlanexOES_global_rewrite_ptr;

PFNGLGETCOLORTABLEPROC epoxy_glGetColorTable = epoxy_glGetColorTable_global_rewrite_ptr;

PFNGLGETCOLORTABLEEXTPROC epoxy_glGetColorTableEXT = epoxy_glGetColorTableEXT_global_rewrite_ptr;

PFNGLGETCOLORTABLEPARAMETERFVPROC epoxy_glGetColorTableParameterfv = epoxy_glGetColorTableParameterfv_global_rewrite_ptr;

PFNGLGETCOLORTABLEPARAMETERFVEXTPROC epoxy_glGetColorTableParameterfvEXT = epoxy_glGetColorTableParameterfvEXT_global_rewrite_ptr;

PFNGLGETCOLORTABLEPARAMETERFVSGIPROC epoxy_glGetColorTableParameterfvSGI = epoxy_glGetColorTableParameterfvSGI_global_rewrite_ptr;

PFNGLGETCOLORTABLEPARAMETERIVPROC epoxy_glGetColorTableParameteriv = epoxy_glGetColorTableParameteriv_global_rewrite_ptr;

PFNGLGETCOLORTABLEPARAMETERIVEXTPROC epoxy_glGetColorTableParameterivEXT = epoxy_glGetColorTableParameterivEXT_global_rewrite_ptr;

PFNGLGETCOLORTABLEPARAMETERIVSGIPROC epoxy_glGetColorTableParameterivSGI = epoxy_glGetColorTableParameterivSGI_global_rewrite_ptr;

PFNGLGETCOLORTABLESGIPROC epoxy_glGetColorTableSGI = epoxy_glGetColorTableSGI_global_rewrite_ptr;

PFNGLGETCOMBINERINPUTPARAMETERFVNVPROC epoxy_glGetCombinerInputParameterfvNV = epoxy_glGetCombinerInputParameterfvNV_global_rewrite_ptr;

PFNGLGETCOMBINERINPUTPARAMETERIVNVPROC epoxy_glGetCombinerInputParameterivNV = epoxy_glGetCombinerInputParameterivNV_global_rewrite_ptr;

PFNGLGETCOMBINEROUTPUTPARAMETERFVNVPROC epoxy_glGetCombinerOutputParameterfvNV = epoxy_glGetCombinerOutputParameterfvNV_global_rewrite_ptr;

PFNGLGETCOMBINEROUTPUTPARAMETERIVNVPROC epoxy_glGetCombinerOutputParameterivNV = epoxy_glGetCombinerOutputParameterivNV_global_rewrite_ptr;

PFNGLGETCOMBINERSTAGEPARAMETERFVNVPROC epoxy_glGetCombinerStageParameterfvNV = epoxy_glGetCombinerStageParameterfvNV_global_rewrite_ptr;

PFNGLGETCOMMANDHEADERNVPROC epoxy_glGetCommandHeaderNV = epoxy_glGetCommandHeaderNV_global_rewrite_ptr;

PFNGLGETCOMPRESSEDMULTITEXIMAGEEXTPROC epoxy_glGetCompressedMultiTexImageEXT = epoxy_glGetCompressedMultiTexImageEXT_global_rewrite_ptr;

PFNGLGETCOMPRESSEDTEXIMAGEPROC epoxy_glGetCompressedTexImage = epoxy_glGetCompressedTexImage_global_rewrite_ptr;

PFNGLGETCOMPRESSEDTEXIMAGEARBPROC epoxy_glGetCompressedTexImageARB = epoxy_glGetCompressedTexImageARB_global_rewrite_ptr;

PFNGLGETCOMPRESSEDTEXTUREIMAGEPROC epoxy_glGetCompressedTextureImage = epoxy_glGetCompressedTextureImage_global_rewrite_ptr;

PFNGLGETCOMPRESSEDTEXTUREIMAGEEXTPROC epoxy_glGetCompressedTextureImageEXT = epoxy_glGetCompressedTextureImageEXT_global_rewrite_ptr;

PFNGLGETCOMPRESSEDTEXTURESUBIMAGEPROC epoxy_glGetCompressedTextureSubImage = epoxy_glGetCompressedTextureSubImage_global_rewrite_ptr;

PFNGLGETCONVOLUTIONFILTERPROC epoxy_glGetConvolutionFilter = epoxy_glGetConvolutionFilter_global_rewrite_ptr;

PFNGLGETCONVOLUTIONFILTEREXTPROC epoxy_glGetConvolutionFilterEXT = epoxy_glGetConvolutionFilterEXT_global_rewrite_ptr;

PFNGLGETCONVOLUTIONPARAMETERFVPROC epoxy_glGetConvolutionParameterfv = epoxy_glGetConvolutionParameterfv_global_rewrite_ptr;

PFNGLGETCONVOLUTIONPARAMETERFVEXTPROC epoxy_glGetConvolutionParameterfvEXT = epoxy_glGetConvolutionParameterfvEXT_global_rewrite_ptr;

PFNGLGETCONVOLUTIONPARAMETERIVPROC epoxy_glGetConvolutionParameteriv = epoxy_glGetConvolutionParameteriv_global_rewrite_ptr;

PFNGLGETCONVOLUTIONPARAMETERIVEXTPROC epoxy_glGetConvolutionParameterivEXT = epoxy_glGetConvolutionParameterivEXT_global_rewrite_ptr;

PFNGLGETCONVOLUTIONPARAMETERXVOESPROC epoxy_glGetConvolutionParameterxvOES = epoxy_glGetConvolutionParameterxvOES_global_rewrite_ptr;

PFNGLGETCOVERAGEMODULATIONTABLENVPROC epoxy_glGetCoverageModulationTableNV = epoxy_glGetCoverageModulationTableNV_global_rewrite_ptr;

PFNGLGETDEBUGMESSAGELOGPROC epoxy_glGetDebugMessageLog = epoxy_glGetDebugMessageLog_global_rewrite_ptr;

PFNGLGETDEBUGMESSAGELOGAMDPROC epoxy_glGetDebugMessageLogAMD = epoxy_glGetDebugMessageLogAMD_global_rewrite_ptr;

PFNGLGETDEBUGMESSAGELOGARBPROC epoxy_glGetDebugMessageLogARB = epoxy_glGetDebugMessageLogARB_global_rewrite_ptr;

PFNGLGETDEBUGMESSAGELOGKHRPROC epoxy_glGetDebugMessageLogKHR = epoxy_glGetDebugMessageLogKHR_global_rewrite_ptr;

PFNGLGETDETAILTEXFUNCSGISPROC epoxy_glGetDetailTexFuncSGIS = epoxy_glGetDetailTexFuncSGIS_global_rewrite_ptr;

PFNGLGETDOUBLEINDEXEDVEXTPROC epoxy_glGetDoubleIndexedvEXT = epoxy_glGetDoubleIndexedvEXT_global_rewrite_ptr;

PFNGLGETDOUBLEI_VPROC epoxy_glGetDoublei_v = epoxy_glGetDoublei_v_global_rewrite_ptr;

PFNGLGETDOUBLEI_VEXTPROC epoxy_glGetDoublei_vEXT = epoxy_glGetDoublei_vEXT_global_rewrite_ptr;

PFNGLGETDOUBLEVPROC epoxy_glGetDoublev = epoxy_glGetDoublev_global_rewrite_ptr;

PFNGLGETDRIVERCONTROLSTRINGQCOMPROC epoxy_glGetDriverControlStringQCOM = epoxy_glGetDriverControlStringQCOM_global_rewrite_ptr;

PFNGLGETDRIVERCONTROLSQCOMPROC epoxy_glGetDriverControlsQCOM = epoxy_glGetDriverControlsQCOM_global_rewrite_ptr;

PFNGLGETERRORPROC epoxy_glGetError = epoxy_glGetError_global_rewrite_ptr;

PFNGLGETFENCEIVNVPROC epoxy_glGetFenceivNV = epoxy_glGetFenceivNV_global_rewrite_ptr;

PFNGLGETFINALCOMBINERINPUTPARAMETERFVNVPROC epoxy_glGetFinalCombinerInputParameterfvNV = epoxy_glGetFinalCombinerInputParameterfvNV_global_rewrite_ptr;

PFNGLGETFINALCOMBINERINPUTPARAMETERIVNVPROC epoxy_glGetFinalCombinerInputParameterivNV = epoxy_glGetFinalCombinerInputParameterivNV_global_rewrite_ptr;

PFNGLGETFIRSTPERFQUERYIDINTELPROC epoxy_glGetFirstPerfQueryIdINTEL = epoxy_glGetFirstPerfQueryIdINTEL_global_rewrite_ptr;

PFNGLGETFIXEDVPROC epoxy_glGetFixedv = epoxy_glGetFixedv_global_rewrite_ptr;

PFNGLGETFIXEDVOESPROC epoxy_glGetFixedvOES = epoxy_glGetFixedvOES_global_rewrite_ptr;

PFNGLGETFLOATINDEXEDVEXTPROC epoxy_glGetFloatIndexedvEXT = epoxy_glGetFloatIndexedvEXT_global_rewrite_ptr;

PFNGLGETFLOATI_VPROC epoxy_glGetFloati_v = epoxy_glGetFloati_v_global_rewrite_ptr;

PFNGLGETFLOATI_VEXTPROC epoxy_glGetFloati_vEXT = epoxy_glGetFloati_vEXT_global_rewrite_ptr;

PFNGLGETFLOATI_VNVPROC epoxy_glGetFloati_vNV = epoxy_glGetFloati_vNV_global_rewrite_ptr;

PFNGLGETFLOATI_VOESPROC epoxy_glGetFloati_vOES = epoxy_glGetFloati_vOES_global_rewrite_ptr;

PFNGLGETFLOATVPROC epoxy_glGetFloatv = epoxy_glGetFloatv_global_rewrite_ptr;

PFNGLGETFOGFUNCSGISPROC epoxy_glGetFogFuncSGIS = epoxy_glGetFogFuncSGIS_global_rewrite_ptr;

PFNGLGETFRAGDATAINDEXPROC epoxy_glGetFragDataIndex = epoxy_glGetFragDataIndex_global_rewrite_ptr;

PFNGLGETFRAGDATAINDEXEXTPROC epoxy_glGetFragDataIndexEXT = epoxy_glGetFragDataIndexEXT_global_rewrite_ptr;

PFNGLGETFRAGDATALOCATIONPROC epoxy_glGetFragDataLocation = epoxy_glGetFragDataLocation_global_rewrite_ptr;

PFNGLGETFRAGDATALOCATIONEXTPROC epoxy_glGetFragDataLocationEXT = epoxy_glGetFragDataLocationEXT_global_rewrite_ptr;

PFNGLGETFRAGMENTLIGHTFVSGIXPROC epoxy_glGetFragmentLightfvSGIX = epoxy_glGetFragmentLightfvSGIX_global_rewrite_ptr;

PFNGLGETFRAGMENTLIGHTIVSGIXPROC epoxy_glGetFragmentLightivSGIX = epoxy_glGetFragmentLightivSGIX_global_rewrite_ptr;

PFNGLGETFRAGMENTMATERIALFVSGIXPROC epoxy_glGetFragmentMaterialfvSGIX = epoxy_glGetFragmentMaterialfvSGIX_global_rewrite_ptr;

PFNGLGETFRAGMENTMATERIALIVSGIXPROC epoxy_glGetFragmentMaterialivSGIX = epoxy_glGetFragmentMaterialivSGIX_global_rewrite_ptr;

PFNGLGETFRAMEBUFFERATTACHMENTPARAMETERIVPROC epoxy_glGetFramebufferAttachmentParameteriv = epoxy_glGetFramebufferAttachmentParameteriv_global_rewrite_ptr;

PFNGLGETFRAMEBUFFERATTACHMENTPARAMETERIVEXTPROC epoxy_glGetFramebufferAttachmentParameterivEXT = epoxy_glGetFramebufferAttachmentParameterivEXT_global_rewrite_ptr;

PFNGLGETFRAMEBUFFERATTACHMENTPARAMETERIVOESPROC epoxy_glGetFramebufferAttachmentParameterivOES = epoxy_glGetFramebufferAttachmentParameterivOES_global_rewrite_ptr;

PFNGLGETFRAMEBUFFERPARAMETERFVAMDPROC epoxy_glGetFramebufferParameterfvAMD = epoxy_glGetFramebufferParameterfvAMD_global_rewrite_ptr;

PFNGLGETFRAMEBUFFERPARAMETERIVPROC epoxy_glGetFramebufferParameteriv = epoxy_glGetFramebufferParameteriv_global_rewrite_ptr;

PFNGLGETFRAMEBUFFERPARAMETERIVEXTPROC epoxy_glGetFramebufferParameterivEXT = epoxy_glGetFramebufferParameterivEXT_global_rewrite_ptr;

PFNGLGETFRAMEBUFFERPARAMETERIVMESAPROC epoxy_glGetFramebufferParameterivMESA = epoxy_glGetFramebufferParameterivMESA_global_rewrite_ptr;

PFNGLGETFRAMEBUFFERPIXELLOCALSTORAGESIZEEXTPROC epoxy_glGetFramebufferPixelLocalStorageSizeEXT = epoxy_glGetFramebufferPixelLocalStorageSizeEXT_global_rewrite_ptr;

PFNGLGETGRAPHICSRESETSTATUSPROC epoxy_glGetGraphicsResetStatus = epoxy_glGetGraphicsResetStatus_global_rewrite_ptr;

PFNGLGETGRAPHICSRESETSTATUSARBPROC epoxy_glGetGraphicsResetStatusARB = epoxy_glGetGraphicsResetStatusARB_global_rewrite_ptr;

PFNGLGETGRAPHICSRESETSTATUSEXTPROC epoxy_glGetGraphicsResetStatusEXT = epoxy_glGetGraphicsResetStatusEXT_global_rewrite_ptr;

PFNGLGETGRAPHICSRESETSTATUSKHRPROC epoxy_glGetGraphicsResetStatusKHR = epoxy_glGetGraphicsResetStatusKHR_global_rewrite_ptr;

PFNGLGETHANDLEARBPROC epoxy_glGetHandleARB = epoxy_glGetHandleARB_global_rewrite_ptr;

PFNGLGETHISTOGRAMPROC epoxy_glGetHistogram = epoxy_glGetHistogram_global_rewrite_ptr;

PFNGLGETHISTOGRAMEXTPROC epoxy_glGetHistogramEXT = epoxy_glGetHistogramEXT_global_rewrite_ptr;

PFNGLGETHISTOGRAMPARAMETERFVPROC epoxy_glGetHistogramParameterfv = epoxy_glGetHistogramParameterfv_global_rewrite_ptr;

PFNGLGETHISTOGRAMPARAMETERFVEXTPROC epoxy_glGetHistogramParameterfvEXT = epoxy_glGetHistogramParameterfvEXT_global_rewrite_ptr;

PFNGLGETHISTOGRAMPARAMETERIVPROC epoxy_glGetHistogramParameteriv = epoxy_glGetHistogramParameteriv_global_rewrite_ptr;

PFNGLGETHISTOGRAMPARAMETERIVEXTPROC epoxy_glGetHistogramParameterivEXT = epoxy_glGetHistogramParameterivEXT_global_rewrite_ptr;

PFNGLGETHISTOGRAMPARAMETERXVOESPROC epoxy_glGetHistogramParameterxvOES = epoxy_glGetHistogramParameterxvOES_global_rewrite_ptr;

PFNGLGETIMAGEHANDLEARBPROC epoxy_glGetImageHandleARB = epoxy_glGetImageHandleARB_global_rewrite_ptr;

PFNGLGETIMAGEHANDLENVPROC epoxy_glGetImageHandleNV = epoxy_glGetImageHandleNV_global_rewrite_ptr;

PFNGLGETIMAGETRANSFORMPARAMETERFVHPPROC epoxy_glGetImageTransformParameterfvHP = epoxy_glGetImageTransformParameterfvHP_global_rewrite_ptr;

PFNGLGETIMAGETRANSFORMPARAMETERIVHPPROC epoxy_glGetImageTransformParameterivHP = epoxy_glGetImageTransformParameterivHP_global_rewrite_ptr;

PFNGLGETINFOLOGARBPROC epoxy_glGetInfoLogARB = epoxy_glGetInfoLogARB_global_rewrite_ptr;

PFNGLGETINSTRUMENTSSGIXPROC epoxy_glGetInstrumentsSGIX = epoxy_glGetInstrumentsSGIX_global_rewrite_ptr;

PFNGLGETINTEGER64I_VPROC epoxy_glGetInteger64i_v = epoxy_glGetInteger64i_v_global_rewrite_ptr;

PFNGLGETINTEGER64VPROC epoxy_glGetInteger64v = epoxy_glGetInteger64v_global_rewrite_ptr;

PFNGLGETINTEGER64VAPPLEPROC epoxy_glGetInteger64vAPPLE = epoxy_glGetInteger64vAPPLE_global_rewrite_ptr;

PFNGLGETINTEGERINDEXEDVEXTPROC epoxy_glGetIntegerIndexedvEXT = epoxy_glGetIntegerIndexedvEXT_global_rewrite_ptr;

PFNGLGETINTEGERI_VPROC epoxy_glGetIntegeri_v = epoxy_glGetIntegeri_v_global_rewrite_ptr;

PFNGLGETINTEGERI_VEXTPROC epoxy_glGetIntegeri_vEXT = epoxy_glGetIntegeri_vEXT_global_rewrite_ptr;

PFNGLGETINTEGERUI64I_VNVPROC epoxy_glGetIntegerui64i_vNV = epoxy_glGetIntegerui64i_vNV_global_rewrite_ptr;

PFNGLGETINTEGERUI64VNVPROC epoxy_glGetIntegerui64vNV = epoxy_glGetIntegerui64vNV_global_rewrite_ptr;

PFNGLGETINTEGERVPROC epoxy_glGetIntegerv = epoxy_glGetIntegerv_global_rewrite_ptr;

PFNGLGETINTERNALFORMATSAMPLEIVNVPROC epoxy_glGetInternalformatSampleivNV = epoxy_glGetInternalformatSampleivNV_global_rewrite_ptr;

PFNGLGETINTERNALFORMATI64VPROC epoxy_glGetInternalformati64v = epoxy_glGetInternalformati64v_global_rewrite_ptr;

PFNGLGETINTERNALFORMATIVPROC epoxy_glGetInternalformativ = epoxy_glGetInternalformativ_global_rewrite_ptr;

PFNGLGETINVARIANTBOOLEANVEXTPROC epoxy_glGetInvariantBooleanvEXT = epoxy_glGetInvariantBooleanvEXT_global_rewrite_ptr;

PFNGLGETINVARIANTFLOATVEXTPROC epoxy_glGetInvariantFloatvEXT = epoxy_glGetInvariantFloatvEXT_global_rewrite_ptr;

PFNGLGETINVARIANTINTEGERVEXTPROC epoxy_glGetInvariantIntegervEXT = epoxy_glGetInvariantIntegervEXT_global_rewrite_ptr;

PFNGLGETLIGHTFVPROC epoxy_glGetLightfv = epoxy_glGetLightfv_global_rewrite_ptr;

PFNGLGETLIGHTIVPROC epoxy_glGetLightiv = epoxy_glGetLightiv_global_rewrite_ptr;

PFNGLGETLIGHTXOESPROC epoxy_glGetLightxOES = epoxy_glGetLightxOES_global_rewrite_ptr;

PFNGLGETLIGHTXVPROC epoxy_glGetLightxv = epoxy_glGetLightxv_global_rewrite_ptr;

PFNGLGETLIGHTXVOESPROC epoxy_glGetLightxvOES = epoxy_glGetLightxvOES_global_rewrite_ptr;

PFNGLGETLISTPARAMETERFVSGIXPROC epoxy_glGetListParameterfvSGIX = epoxy_glGetListParameterfvSGIX_global_rewrite_ptr;

PFNGLGETLISTPARAMETERIVSGIXPROC epoxy_glGetListParameterivSGIX = epoxy_glGetListParameterivSGIX_global_rewrite_ptr;

PFNGLGETLOCALCONSTANTBOOLEANVEXTPROC epoxy_glGetLocalConstantBooleanvEXT = epoxy_glGetLocalConstantBooleanvEXT_global_rewrite_ptr;

PFNGLGETLOCALCONSTANTFLOATVEXTPROC epoxy_glGetLocalConstantFloatvEXT = epoxy_glGetLocalConstantFloatvEXT_global_rewrite_ptr;

PFNGLGETLOCALCONSTANTINTEGERVEXTPROC epoxy_glGetLocalConstantIntegervEXT = epoxy_glGetLocalConstantIntegervEXT_global_rewrite_ptr;

PFNGLGETMAPATTRIBPARAMETERFVNVPROC epoxy_glGetMapAttribParameterfvNV = epoxy_glGetMapAttribParameterfvNV_global_rewrite_ptr;

PFNGLGETMAPATTRIBPARAMETERIVNVPROC epoxy_glGetMapAttribParameterivNV = epoxy_glGetMapAttribParameterivNV_global_rewrite_ptr;

PFNGLGETMAPCONTROLPOINTSNVPROC epoxy_glGetMapControlPointsNV = epoxy_glGetMapControlPointsNV_global_rewrite_ptr;

PFNGLGETMAPPARAMETERFVNVPROC epoxy_glGetMapParameterfvNV = epoxy_glGetMapParameterfvNV_global_rewrite_ptr;

PFNGLGETMAPPARAMETERIVNVPROC epoxy_glGetMapParameterivNV = epoxy_glGetMapParameterivNV_global_rewrite_ptr;

PFNGLGETMAPDVPROC epoxy_glGetMapdv = epoxy_glGetMapdv_global_rewrite_ptr;

PFNGLGETMAPFVPROC epoxy_glGetMapfv = epoxy_glGetMapfv_global_rewrite_ptr;

PFNGLGETMAPIVPROC epoxy_glGetMapiv = epoxy_glGetMapiv_global_rewrite_ptr;

PFNGLGETMAPXVOESPROC epoxy_glGetMapxvOES = epoxy_glGetMapxvOES_global_rewrite_ptr;

PFNGLGETMATERIALFVPROC epoxy_glGetMaterialfv = epoxy_glGetMaterialfv_global_rewrite_ptr;

PFNGLGETMATERIALIVPROC epoxy_glGetMaterialiv = epoxy_glGetMaterialiv_global_rewrite_ptr;

PFNGLGETMATERIALXOESPROC epoxy_glGetMaterialxOES = epoxy_glGetMaterialxOES_global_rewrite_ptr;

PFNGLGETMATERIALXVPROC epoxy_glGetMaterialxv = epoxy_glGetMaterialxv_global_rewrite_ptr;

PFNGLGETMATERIALXVOESPROC epoxy_glGetMaterialxvOES = epoxy_glGetMaterialxvOES_global_rewrite_ptr;

PFNGLGETMEMORYOBJECTDETACHEDRESOURCESUIVNVPROC epoxy_glGetMemoryObjectDetachedResourcesuivNV = epoxy_glGetMemoryObjectDetachedResourcesuivNV_global_rewrite_ptr;

PFNGLGETMEMORYOBJECTPARAMETERIVEXTPROC epoxy_glGetMemoryObjectParameterivEXT = epoxy_glGetMemoryObjectParameterivEXT_global_rewrite_ptr;

PFNGLGETMINMAXPROC epoxy_glGetMinmax = epoxy_glGetMinmax_global_rewrite_ptr;

PFNGLGETMINMAXEXTPROC epoxy_glGetMinmaxEXT = epoxy_glGetMinmaxEXT_global_rewrite_ptr;

PFNGLGETMINMAXPARAMETERFVPROC epoxy_glGetMinmaxParameterfv = epoxy_glGetMinmaxParameterfv_global_rewrite_ptr;

PFNGLGETMINMAXPARAMETERFVEXTPROC epoxy_glGetMinmaxParameterfvEXT = epoxy_glGetMinmaxParameterfvEXT_global_rewrite_ptr;

PFNGLGETMINMAXPARAMETERIVPROC epoxy_glGetMinmaxParameteriv = epoxy_glGetMinmaxParameteriv_global_rewrite_ptr;

PFNGLGETMINMAXPARAMETERIVEXTPROC epoxy_glGetMinmaxParameterivEXT = epoxy_glGetMinmaxParameterivEXT_global_rewrite_ptr;

PFNGLGETMULTITEXENVFVEXTPROC epoxy_glGetMultiTexEnvfvEXT = epoxy_glGetMultiTexEnvfvEXT_global_rewrite_ptr;

PFNGLGETMULTITEXENVIVEXTPROC epoxy_glGetMultiTexEnvivEXT = epoxy_glGetMultiTexEnvivEXT_global_rewrite_ptr;

PFNGLGETMULTITEXGENDVEXTPROC epoxy_glGetMultiTexGendvEXT = epoxy_glGetMultiTexGendvEXT_global_rewrite_ptr;

PFNGLGETMULTITEXGENFVEXTPROC epoxy_glGetMultiTexGenfvEXT = epoxy_glGetMultiTexGenfvEXT_global_rewrite_ptr;

PFNGLGETMULTITEXGENIVEXTPROC epoxy_glGetMultiTexGenivEXT = epoxy_glGetMultiTexGenivEXT_global_rewrite_ptr;

PFNGLGETMULTITEXIMAGEEXTPROC epoxy_glGetMultiTexImageEXT = epoxy_glGetMultiTexImageEXT_global_rewrite_ptr;

PFNGLGETMULTITEXLEVELPARAMETERFVEXTPROC epoxy_glGetMultiTexLevelParameterfvEXT = epoxy_glGetMultiTexLevelParameterfvEXT_global_rewrite_ptr;

PFNGLGETMULTITEXLEVELPARAMETERIVEXTPROC epoxy_glGetMultiTexLevelParameterivEXT = epoxy_glGetMultiTexLevelParameterivEXT_global_rewrite_ptr;

PFNGLGETMULTITEXPARAMETERIIVEXTPROC epoxy_glGetMultiTexParameterIivEXT = epoxy_glGetMultiTexParameterIivEXT_global_rewrite_ptr;

PFNGLGETMULTITEXPARAMETERIUIVEXTPROC epoxy_glGetMultiTexParameterIuivEXT = epoxy_glGetMultiTexParameterIuivEXT_global_rewrite_ptr;

PFNGLGETMULTITEXPARAMETERFVEXTPROC epoxy_glGetMultiTexParameterfvEXT = epoxy_glGetMultiTexParameterfvEXT_global_rewrite_ptr;

PFNGLGETMULTITEXPARAMETERIVEXTPROC epoxy_glGetMultiTexParameterivEXT = epoxy_glGetMultiTexParameterivEXT_global_rewrite_ptr;

PFNGLGETMULTISAMPLEFVPROC epoxy_glGetMultisamplefv = epoxy_glGetMultisamplefv_global_rewrite_ptr;

PFNGLGETMULTISAMPLEFVNVPROC epoxy_glGetMultisamplefvNV = epoxy_glGetMultisamplefvNV_global_rewrite_ptr;

PFNGLGETNAMEDBUFFERPARAMETERI64VPROC epoxy_glGetNamedBufferParameteri64v = epoxy_glGetNamedBufferParameteri64v_global_rewrite_ptr;

PFNGLGETNAMEDBUFFERPARAMETERIVPROC epoxy_glGetNamedBufferParameteriv = epoxy_glGetNamedBufferParameteriv_global_rewrite_ptr;

PFNGLGETNAMEDBUFFERPARAMETERIVEXTPROC epoxy_glGetNamedBufferParameterivEXT = epoxy_glGetNamedBufferParameterivEXT_global_rewrite_ptr;

PFNGLGETNAMEDBUFFERPARAMETERUI64VNVPROC epoxy_glGetNamedBufferParameterui64vNV = epoxy_glGetNamedBufferParameterui64vNV_global_rewrite_ptr;

PFNGLGETNAMEDBUFFERPOINTERVPROC epoxy_glGetNamedBufferPointerv = epoxy_glGetNamedBufferPointerv_global_rewrite_ptr;

PFNGLGETNAMEDBUFFERPOINTERVEXTPROC epoxy_glGetNamedBufferPointervEXT = epoxy_glGetNamedBufferPointervEXT_global_rewrite_ptr;

PFNGLGETNAMEDBUFFERSUBDATAPROC epoxy_glGetNamedBufferSubData = epoxy_glGetNamedBufferSubData_global_rewrite_ptr;

PFNGLGETNAMEDBUFFERSUBDATAEXTPROC epoxy_glGetNamedBufferSubDataEXT = epoxy_glGetNamedBufferSubDataEXT_global_rewrite_ptr;

PFNGLGETNAMEDFRAMEBUFFERATTACHMENTPARAMETERIVPROC epoxy_glGetNamedFramebufferAttachmentParameteriv = epoxy_glGetNamedFramebufferAttachmentParameteriv_global_rewrite_ptr;

PFNGLGETNAMEDFRAMEBUFFERATTACHMENTPARAMETERIVEXTPROC epoxy_glGetNamedFramebufferAttachmentParameterivEXT = epoxy_glGetNamedFramebufferAttachmentParameterivEXT_global_rewrite_ptr;

PFNGLGETNAMEDFRAMEBUFFERPARAMETERFVAMDPROC epoxy_glGetNamedFramebufferParameterfvAMD = epoxy_glGetNamedFramebufferParameterfvAMD_global_rewrite_ptr;

PFNGLGETNAMEDFRAMEBUFFERPARAMETERIVPROC epoxy_glGetNamedFramebufferParameteriv = epoxy_glGetNamedFramebufferParameteriv_global_rewrite_ptr;

PFNGLGETNAMEDFRAMEBUFFERPARAMETERIVEXTPROC epoxy_glGetNamedFramebufferParameterivEXT = epoxy_glGetNamedFramebufferParameterivEXT_global_rewrite_ptr;

PFNGLGETNAMEDPROGRAMLOCALPARAMETERIIVEXTPROC epoxy_glGetNamedProgramLocalParameterIivEXT = epoxy_glGetNamedProgramLocalParameterIivEXT_global_rewrite_ptr;

PFNGLGETNAMEDPROGRAMLOCALPARAMETERIUIVEXTPROC epoxy_glGetNamedProgramLocalParameterIuivEXT = epoxy_glGetNamedProgramLocalParameterIuivEXT_global_rewrite_ptr;

PFNGLGETNAMEDPROGRAMLOCALPARAMETERDVEXTPROC epoxy_glGetNamedProgramLocalParameterdvEXT = epoxy_glGetNamedProgramLocalParameterdvEXT_global_rewrite_ptr;

PFNGLGETNAMEDPROGRAMLOCALPARAMETERFVEXTPROC epoxy_glGetNamedProgramLocalParameterfvEXT = epoxy_glGetNamedProgramLocalParameterfvEXT_global_rewrite_ptr;

PFNGLGETNAMEDPROGRAMSTRINGEXTPROC epoxy_glGetNamedProgramStringEXT = epoxy_glGetNamedProgramStringEXT_global_rewrite_ptr;

PFNGLGETNAMEDPROGRAMIVEXTPROC epoxy_glGetNamedProgramivEXT = epoxy_glGetNamedProgramivEXT_global_rewrite_ptr;

PFNGLGETNAMEDRENDERBUFFERPARAMETERIVPROC epoxy_glGetNamedRenderbufferParameteriv = epoxy_glGetNamedRenderbufferParameteriv_global_rewrite_ptr;

PFNGLGETNAMEDRENDERBUFFERPARAMETERIVEXTPROC epoxy_glGetNamedRenderbufferParameterivEXT = epoxy_glGetNamedRenderbufferParameterivEXT_global_rewrite_ptr;

PFNGLGETNAMEDSTRINGARBPROC epoxy_glGetNamedStringARB = epoxy_glGetNamedStringARB_global_rewrite_ptr;

PFNGLGETNAMEDSTRINGIVARBPROC epoxy_glGetNamedStringivARB = epoxy_glGetNamedStringivARB_global_rewrite_ptr;

PFNGLGETNEXTPERFQUERYIDINTELPROC epoxy_glGetNextPerfQueryIdINTEL = epoxy_glGetNextPerfQueryIdINTEL_global_rewrite_ptr;

PFNGLGETOBJECTBUFFERFVATIPROC epoxy_glGetObjectBufferfvATI = epoxy_glGetObjectBufferfvATI_global_rewrite_ptr;

PFNGLGETOBJECTBUFFERIVATIPROC epoxy_glGetObjectBufferivATI = epoxy_glGetObjectBufferivATI_global_rewrite_ptr;

PFNGLGETOBJECTLABELPROC epoxy_glGetObjectLabel = epoxy_glGetObjectLabel_global_rewrite_ptr;

PFNGLGETOBJECTLABELEXTPROC epoxy_glGetObjectLabelEXT = epoxy_glGetObjectLabelEXT_global_rewrite_ptr;

PFNGLGETOBJECTLABELKHRPROC epoxy_glGetObjectLabelKHR = epoxy_glGetObjectLabelKHR_global_rewrite_ptr;

PFNGLGETOBJECTPARAMETERFVARBPROC epoxy_glGetObjectParameterfvARB = epoxy_glGetObjectParameterfvARB_global_rewrite_ptr;

PFNGLGETOBJECTPARAMETERIVAPPLEPROC epoxy_glGetObjectParameterivAPPLE = epoxy_glGetObjectParameterivAPPLE_global_rewrite_ptr;

PFNGLGETOBJECTPARAMETERIVARBPROC epoxy_glGetObjectParameterivARB = epoxy_glGetObjectParameterivARB_global_rewrite_ptr;

PFNGLGETOBJECTPTRLABELPROC epoxy_glGetObjectPtrLabel = epoxy_glGetObjectPtrLabel_global_rewrite_ptr;

PFNGLGETOBJECTPTRLABELKHRPROC epoxy_glGetObjectPtrLabelKHR = epoxy_glGetObjectPtrLabelKHR_global_rewrite_ptr;

PFNGLGETOCCLUSIONQUERYIVNVPROC epoxy_glGetOcclusionQueryivNV = epoxy_glGetOcclusionQueryivNV_global_rewrite_ptr;

PFNGLGETOCCLUSIONQUERYUIVNVPROC epoxy_glGetOcclusionQueryuivNV = epoxy_glGetOcclusionQueryuivNV_global_rewrite_ptr;

PFNGLGETPATHCOLORGENFVNVPROC epoxy_glGetPathColorGenfvNV = epoxy_glGetPathColorGenfvNV_global_rewrite_ptr;

PFNGLGETPATHCOLORGENIVNVPROC epoxy_glGetPathColorGenivNV = epoxy_glGetPathColorGenivNV_global_rewrite_ptr;

PFNGLGETPATHCOMMANDSNVPROC epoxy_glGetPathCommandsNV = epoxy_glGetPathCommandsNV_global_rewrite_ptr;

PFNGLGETPATHCOORDSNVPROC epoxy_glGetPathCoordsNV = epoxy_glGetPathCoordsNV_global_rewrite_ptr;

PFNGLGETPATHDASHARRAYNVPROC epoxy_glGetPathDashArrayNV = epoxy_glGetPathDashArrayNV_global_rewrite_ptr;

PFNGLGETPATHLENGTHNVPROC epoxy_glGetPathLengthNV = epoxy_glGetPathLengthNV_global_rewrite_ptr;

PFNGLGETPATHMETRICRANGENVPROC epoxy_glGetPathMetricRangeNV = epoxy_glGetPathMetricRangeNV_global_rewrite_ptr;

PFNGLGETPATHMETRICSNVPROC epoxy_glGetPathMetricsNV = epoxy_glGetPathMetricsNV_global_rewrite_ptr;

PFNGLGETPATHPARAMETERFVNVPROC epoxy_glGetPathParameterfvNV = epoxy_glGetPathParameterfvNV_global_rewrite_ptr;

PFNGLGETPATHPARAMETERIVNVPROC epoxy_glGetPathParameterivNV = epoxy_glGetPathParameterivNV_global_rewrite_ptr;

PFNGLGETPATHSPACINGNVPROC epoxy_glGetPathSpacingNV = epoxy_glGetPathSpacingNV_global_rewrite_ptr;

PFNGLGETPATHTEXGENFVNVPROC epoxy_glGetPathTexGenfvNV = epoxy_glGetPathTexGenfvNV_global_rewrite_ptr;

PFNGLGETPATHTEXGENIVNVPROC epoxy_glGetPathTexGenivNV = epoxy_glGetPathTexGenivNV_global_rewrite_ptr;

PFNGLGETPERFCOUNTERINFOINTELPROC epoxy_glGetPerfCounterInfoINTEL = epoxy_glGetPerfCounterInfoINTEL_global_rewrite_ptr;

PFNGLGETPERFMONITORCOUNTERDATAAMDPROC epoxy_glGetPerfMonitorCounterDataAMD = epoxy_glGetPerfMonitorCounterDataAMD_global_rewrite_ptr;

PFNGLGETPERFMONITORCOUNTERINFOAMDPROC epoxy_glGetPerfMonitorCounterInfoAMD = epoxy_glGetPerfMonitorCounterInfoAMD_global_rewrite_ptr;

PFNGLGETPERFMONITORCOUNTERSTRINGAMDPROC epoxy_glGetPerfMonitorCounterStringAMD = epoxy_glGetPerfMonitorCounterStringAMD_global_rewrite_ptr;

PFNGLGETPERFMONITORCOUNTERSAMDPROC epoxy_glGetPerfMonitorCountersAMD = epoxy_glGetPerfMonitorCountersAMD_global_rewrite_ptr;

PFNGLGETPERFMONITORGROUPSTRINGAMDPROC epoxy_glGetPerfMonitorGroupStringAMD = epoxy_glGetPerfMonitorGroupStringAMD_global_rewrite_ptr;

PFNGLGETPERFMONITORGROUPSAMDPROC epoxy_glGetPerfMonitorGroupsAMD = epoxy_glGetPerfMonitorGroupsAMD_global_rewrite_ptr;

PFNGLGETPERFQUERYDATAINTELPROC epoxy_glGetPerfQueryDataINTEL = epoxy_glGetPerfQueryDataINTEL_global_rewrite_ptr;

PFNGLGETPERFQUERYIDBYNAMEINTELPROC epoxy_glGetPerfQueryIdByNameINTEL = epoxy_glGetPerfQueryIdByNameINTEL_global_rewrite_ptr;

PFNGLGETPERFQUERYINFOINTELPROC epoxy_glGetPerfQueryInfoINTEL = epoxy_glGetPerfQueryInfoINTEL_global_rewrite_ptr;

PFNGLGETPIXELMAPFVPROC epoxy_glGetPixelMapfv = epoxy_glGetPixelMapfv_global_rewrite_ptr;

PFNGLGETPIXELMAPUIVPROC epoxy_glGetPixelMapuiv = epoxy_glGetPixelMapuiv_global_rewrite_ptr;

PFNGLGETPIXELMAPUSVPROC epoxy_glGetPixelMapusv = epoxy_glGetPixelMapusv_global_rewrite_ptr;

PFNGLGETPIXELMAPXVPROC epoxy_glGetPixelMapxv = epoxy_glGetPixelMapxv_global_rewrite_ptr;

PFNGLGETPIXELTEXGENPARAMETERFVSGISPROC epoxy_glGetPixelTexGenParameterfvSGIS = epoxy_glGetPixelTexGenParameterfvSGIS_global_rewrite_ptr;

PFNGLGETPIXELTEXGENPARAMETERIVSGISPROC epoxy_glGetPixelTexGenParameterivSGIS = epoxy_glGetPixelTexGenParameterivSGIS_global_rewrite_ptr;

PFNGLGETPIXELTRANSFORMPARAMETERFVEXTPROC epoxy_glGetPixelTransformParameterfvEXT = epoxy_glGetPixelTransformParameterfvEXT_global_rewrite_ptr;

PFNGLGETPIXELTRANSFORMPARAMETERIVEXTPROC epoxy_glGetPixelTransformParameterivEXT = epoxy_glGetPixelTransformParameterivEXT_global_rewrite_ptr;

PFNGLGETPOINTERINDEXEDVEXTPROC epoxy_glGetPointerIndexedvEXT = epoxy_glGetPointerIndexedvEXT_global_rewrite_ptr;

PFNGLGETPOINTERI_VEXTPROC epoxy_glGetPointeri_vEXT = epoxy_glGetPointeri_vEXT_global_rewrite_ptr;

PFNGLGETPOINTERVPROC epoxy_glGetPointerv = epoxy_glGetPointerv_global_rewrite_ptr;

PFNGLGETPOINTERVEXTPROC epoxy_glGetPointervEXT = epoxy_glGetPointervEXT_global_rewrite_ptr;

PFNGLGETPOINTERVKHRPROC epoxy_glGetPointervKHR = epoxy_glGetPointervKHR_global_rewrite_ptr;

PFNGLGETPOLYGONSTIPPLEPROC epoxy_glGetPolygonStipple = epoxy_glGetPolygonStipple_global_rewrite_ptr;

PFNGLGETPROGRAMBINARYPROC epoxy_glGetProgramBinary = epoxy_glGetProgramBinary_global_rewrite_ptr;

PFNGLGETPROGRAMBINARYOESPROC epoxy_glGetProgramBinaryOES = epoxy_glGetProgramBinaryOES_global_rewrite_ptr;

PFNGLGETPROGRAMENVPARAMETERIIVNVPROC epoxy_glGetProgramEnvParameterIivNV = epoxy_glGetProgramEnvParameterIivNV_global_rewrite_ptr;

PFNGLGETPROGRAMENVPARAMETERIUIVNVPROC epoxy_glGetProgramEnvParameterIuivNV = epoxy_glGetProgramEnvParameterIuivNV_global_rewrite_ptr;

PFNGLGETPROGRAMENVPARAMETERDVARBPROC epoxy_glGetProgramEnvParameterdvARB = epoxy_glGetProgramEnvParameterdvARB_global_rewrite_ptr;

PFNGLGETPROGRAMENVPARAMETERFVARBPROC epoxy_glGetProgramEnvParameterfvARB = epoxy_glGetProgramEnvParameterfvARB_global_rewrite_ptr;

PFNGLGETPROGRAMINFOLOGPROC epoxy_glGetProgramInfoLog = epoxy_glGetProgramInfoLog_global_rewrite_ptr;

PFNGLGETPROGRAMINTERFACEIVPROC epoxy_glGetProgramInterfaceiv = epoxy_glGetProgramInterfaceiv_global_rewrite_ptr;

PFNGLGETPROGRAMLOCALPARAMETERIIVNVPROC epoxy_glGetProgramLocalParameterIivNV = epoxy_glGetProgramLocalParameterIivNV_global_rewrite_ptr;

PFNGLGETPROGRAMLOCALPARAMETERIUIVNVPROC epoxy_glGetProgramLocalParameterIuivNV = epoxy_glGetProgramLocalParameterIuivNV_global_rewrite_ptr;

PFNGLGETPROGRAMLOCALPARAMETERDVARBPROC epoxy_glGetProgramLocalParameterdvARB = epoxy_glGetProgramLocalParameterdvARB_global_rewrite_ptr;

PFNGLGETPROGRAMLOCALPARAMETERFVARBPROC epoxy_glGetProgramLocalParameterfvARB = epoxy_glGetProgramLocalParameterfvARB_global_rewrite_ptr;

PFNGLGETPROGRAMNAMEDPARAMETERDVNVPROC epoxy_glGetProgramNamedParameterdvNV = epoxy_glGetProgramNamedParameterdvNV_global_rewrite_ptr;

PFNGLGETPROGRAMNAMEDPARAMETERFVNVPROC epoxy_glGetProgramNamedParameterfvNV = epoxy_glGetProgramNamedParameterfvNV_global_rewrite_ptr;

PFNGLGETPROGRAMPARAMETERDVNVPROC epoxy_glGetProgramParameterdvNV = epoxy_glGetProgramParameterdvNV_global_rewrite_ptr;

PFNGLGETPROGRAMPARAMETERFVNVPROC epoxy_glGetProgramParameterfvNV = epoxy_glGetProgramParameterfvNV_global_rewrite_ptr;

PFNGLGETPROGRAMPIPELINEINFOLOGPROC epoxy_glGetProgramPipelineInfoLog = epoxy_glGetProgramPipelineInfoLog_global_rewrite_ptr;

PFNGLGETPROGRAMPIPELINEINFOLOGEXTPROC epoxy_glGetProgramPipelineInfoLogEXT = epoxy_glGetProgramPipelineInfoLogEXT_global_rewrite_ptr;

PFNGLGETPROGRAMPIPELINEIVPROC epoxy_glGetProgramPipelineiv = epoxy_glGetProgramPipelineiv_global_rewrite_ptr;

PFNGLGETPROGRAMPIPELINEIVEXTPROC epoxy_glGetProgramPipelineivEXT = epoxy_glGetProgramPipelineivEXT_global_rewrite_ptr;

PFNGLGETPROGRAMRESOURCEINDEXPROC epoxy_glGetProgramResourceIndex = epoxy_glGetProgramResourceIndex_global_rewrite_ptr;

PFNGLGETPROGRAMRESOURCELOCATIONPROC epoxy_glGetProgramResourceLocation = epoxy_glGetProgramResourceLocation_global_rewrite_ptr;

PFNGLGETPROGRAMRESOURCELOCATIONINDEXPROC epoxy_glGetProgramResourceLocationIndex = epoxy_glGetProgramResourceLocationIndex_global_rewrite_ptr;

PFNGLGETPROGRAMRESOURCELOCATIONINDEXEXTPROC epoxy_glGetProgramResourceLocationIndexEXT = epoxy_glGetProgramResourceLocationIndexEXT_global_rewrite_ptr;

PFNGLGETPROGRAMRESOURCENAMEPROC epoxy_glGetProgramResourceName = epoxy_glGetProgramResourceName_global_rewrite_ptr;

PFNGLGETPROGRAMRESOURCEFVNVPROC epoxy_glGetProgramResourcefvNV = epoxy_glGetProgramResourcefvNV_global_rewrite_ptr;

PFNGLGETPROGRAMRESOURCEIVPROC epoxy_glGetProgramResourceiv = epoxy_glGetProgramResourceiv_global_rewrite_ptr;

PFNGLGETPROGRAMSTAGEIVPROC epoxy_glGetProgramStageiv = epoxy_glGetProgramStageiv_global_rewrite_ptr;

PFNGLGETPROGRAMSTRINGARBPROC epoxy_glGetProgramStringARB = epoxy_glGetProgramStringARB_global_rewrite_ptr;

PFNGLGETPROGRAMSTRINGNVPROC epoxy_glGetProgramStringNV = epoxy_glGetProgramStringNV_global_rewrite_ptr;

PFNGLGETPROGRAMSUBROUTINEPARAMETERUIVNVPROC epoxy_glGetProgramSubroutineParameteruivNV = epoxy_glGetProgramSubroutineParameteruivNV_global_rewrite_ptr;

PFNGLGETPROGRAMIVPROC epoxy_glGetProgramiv = epoxy_glGetProgramiv_global_rewrite_ptr;

PFNGLGETPROGRAMIVARBPROC epoxy_glGetProgramivARB = epoxy_glGetProgramivARB_global_rewrite_ptr;

PFNGLGETPROGRAMIVNVPROC epoxy_glGetProgramivNV = epoxy_glGetProgramivNV_global_rewrite_ptr;

PFNGLGETQUERYBUFFEROBJECTI64VPROC epoxy_glGetQueryBufferObjecti64v = epoxy_glGetQueryBufferObjecti64v_global_rewrite_ptr;

PFNGLGETQUERYBUFFEROBJECTIVPROC epoxy_glGetQueryBufferObjectiv = epoxy_glGetQueryBufferObjectiv_global_rewrite_ptr;

PFNGLGETQUERYBUFFEROBJECTUI64VPROC epoxy_glGetQueryBufferObjectui64v = epoxy_glGetQueryBufferObjectui64v_global_rewrite_ptr;

PFNGLGETQUERYBUFFEROBJECTUIVPROC epoxy_glGetQueryBufferObjectuiv = epoxy_glGetQueryBufferObjectuiv_global_rewrite_ptr;

PFNGLGETQUERYINDEXEDIVPROC epoxy_glGetQueryIndexediv = epoxy_glGetQueryIndexediv_global_rewrite_ptr;

PFNGLGETQUERYOBJECTI64VPROC epoxy_glGetQueryObjecti64v = epoxy_glGetQueryObjecti64v_global_rewrite_ptr;

PFNGLGETQUERYOBJECTI64VEXTPROC epoxy_glGetQueryObjecti64vEXT = epoxy_glGetQueryObjecti64vEXT_global_rewrite_ptr;

PFNGLGETQUERYOBJECTIVPROC epoxy_glGetQueryObjectiv = epoxy_glGetQueryObjectiv_global_rewrite_ptr;

PFNGLGETQUERYOBJECTIVARBPROC epoxy_glGetQueryObjectivARB = epoxy_glGetQueryObjectivARB_global_rewrite_ptr;

PFNGLGETQUERYOBJECTIVEXTPROC epoxy_glGetQueryObjectivEXT = epoxy_glGetQueryObjectivEXT_global_rewrite_ptr;

PFNGLGETQUERYOBJECTUI64VPROC epoxy_glGetQueryObjectui64v = epoxy_glGetQueryObjectui64v_global_rewrite_ptr;

PFNGLGETQUERYOBJECTUI64VEXTPROC epoxy_glGetQueryObjectui64vEXT = epoxy_glGetQueryObjectui64vEXT_global_rewrite_ptr;

PFNGLGETQUERYOBJECTUIVPROC epoxy_glGetQueryObjectuiv = epoxy_glGetQueryObjectuiv_global_rewrite_ptr;

PFNGLGETQUERYOBJECTUIVARBPROC epoxy_glGetQueryObjectuivARB = epoxy_glGetQueryObjectuivARB_global_rewrite_ptr;

PFNGLGETQUERYOBJECTUIVEXTPROC epoxy_glGetQueryObjectuivEXT = epoxy_glGetQueryObjectuivEXT_global_rewrite_ptr;

PFNGLGETQUERYIVPROC epoxy_glGetQueryiv = epoxy_glGetQueryiv_global_rewrite_ptr;

PFNGLGETQUERYIVARBPROC epoxy_glGetQueryivARB = epoxy_glGetQueryivARB_global_rewrite_ptr;

PFNGLGETQUERYIVEXTPROC epoxy_glGetQueryivEXT = epoxy_glGetQueryivEXT_global_rewrite_ptr;

PFNGLGETRENDERBUFFERPARAMETERIVPROC epoxy_glGetRenderbufferParameteriv = epoxy_glGetRenderbufferParameteriv_global_rewrite_ptr;

PFNGLGETRENDERBUFFERPARAMETERIVEXTPROC epoxy_glGetRenderbufferParameterivEXT = epoxy_glGetRenderbufferParameterivEXT_global_rewrite_ptr;

PFNGLGETRENDERBUFFERPARAMETERIVOESPROC epoxy_glGetRenderbufferParameterivOES = epoxy_glGetRenderbufferParameterivOES_global_rewrite_ptr;

PFNGLGETSAMPLERPARAMETERIIVPROC epoxy_glGetSamplerParameterIiv = epoxy_glGetSamplerParameterIiv_global_rewrite_ptr;

PFNGLGETSAMPLERPARAMETERIIVEXTPROC epoxy_glGetSamplerParameterIivEXT = epoxy_glGetSamplerParameterIivEXT_global_rewrite_ptr;

PFNGLGETSAMPLERPARAMETERIIVOESPROC epoxy_glGetSamplerParameterIivOES = epoxy_glGetSamplerParameterIivOES_global_rewrite_ptr;

PFNGLGETSAMPLERPARAMETERIUIVPROC epoxy_glGetSamplerParameterIuiv = epoxy_glGetSamplerParameterIuiv_global_rewrite_ptr;

PFNGLGETSAMPLERPARAMETERIUIVEXTPROC epoxy_glGetSamplerParameterIuivEXT = epoxy_glGetSamplerParameterIuivEXT_global_rewrite_ptr;

PFNGLGETSAMPLERPARAMETERIUIVOESPROC epoxy_glGetSamplerParameterIuivOES = epoxy_glGetSamplerParameterIuivOES_global_rewrite_ptr;

PFNGLGETSAMPLERPARAMETERFVPROC epoxy_glGetSamplerParameterfv = epoxy_glGetSamplerParameterfv_global_rewrite_ptr;

PFNGLGETSAMPLERPARAMETERIVPROC epoxy_glGetSamplerParameteriv = epoxy_glGetSamplerParameteriv_global_rewrite_ptr;

PFNGLGETSEMAPHOREPARAMETERUI64VEXTPROC epoxy_glGetSemaphoreParameterui64vEXT = epoxy_glGetSemaphoreParameterui64vEXT_global_rewrite_ptr;

PFNGLGETSEPARABLEFILTERPROC epoxy_glGetSeparableFilter = epoxy_glGetSeparableFilter_global_rewrite_ptr;

PFNGLGETSEPARABLEFILTEREXTPROC epoxy_glGetSeparableFilterEXT = epoxy_glGetSeparableFilterEXT_global_rewrite_ptr;

PFNGLGETSHADERINFOLOGPROC epoxy_glGetShaderInfoLog = epoxy_glGetShaderInfoLog_global_rewrite_ptr;

PFNGLGETSHADERPRECISIONFORMATPROC epoxy_glGetShaderPrecisionFormat = epoxy_glGetShaderPrecisionFormat_global_rewrite_ptr;

PFNGLGETSHADERSOURCEPROC epoxy_glGetShaderSource = epoxy_glGetShaderSource_global_rewrite_ptr;

PFNGLGETSHADERSOURCEARBPROC epoxy_glGetShaderSourceARB = epoxy_glGetShaderSourceARB_global_rewrite_ptr;

PFNGLGETSHADERIVPROC epoxy_glGetShaderiv = epoxy_glGetShaderiv_global_rewrite_ptr;

PFNGLGETSHADINGRATEIMAGEPALETTENVPROC epoxy_glGetShadingRateImagePaletteNV = epoxy_glGetShadingRateImagePaletteNV_global_rewrite_ptr;

PFNGLGETSHADINGRATESAMPLELOCATIONIVNVPROC epoxy_glGetShadingRateSampleLocationivNV = epoxy_glGetShadingRateSampleLocationivNV_global_rewrite_ptr;

PFNGLGETSHARPENTEXFUNCSGISPROC epoxy_glGetSharpenTexFuncSGIS = epoxy_glGetSharpenTexFuncSGIS_global_rewrite_ptr;

PFNGLGETSTAGEINDEXNVPROC epoxy_glGetStageIndexNV = epoxy_glGetStageIndexNV_global_rewrite_ptr;

PFNGLGETSTRINGPROC epoxy_glGetString = epoxy_glGetString_global_rewrite_ptr;

PFNGLGETSTRINGIPROC epoxy_glGetStringi = epoxy_glGetStringi_global_rewrite_ptr;

PFNGLGETSUBROUTINEINDEXPROC epoxy_glGetSubroutineIndex = epoxy_glGetSubroutineIndex_global_rewrite_ptr;

PFNGLGETSUBROUTINEUNIFORMLOCATIONPROC epoxy_glGetSubroutineUniformLocation = epoxy_glGetSubroutineUniformLocation_global_rewrite_ptr;

PFNGLGETSYNCIVPROC epoxy_glGetSynciv = epoxy_glGetSynciv_global_rewrite_ptr;

PFNGLGETSYNCIVAPPLEPROC epoxy_glGetSyncivAPPLE = epoxy_glGetSyncivAPPLE_global_rewrite_ptr;

PFNGLGETTEXBUMPPARAMETERFVATIPROC epoxy_glGetTexBumpParameterfvATI = epoxy_glGetTexBumpParameterfvATI_global_rewrite_ptr;

PFNGLGETTEXBUMPPARAMETERIVATIPROC epoxy_glGetTexBumpParameterivATI = epoxy_glGetTexBumpParameterivATI_global_rewrite_ptr;

PFNGLGETTEXENVFVPROC epoxy_glGetTexEnvfv = epoxy_glGetTexEnvfv_global_rewrite_ptr;

PFNGLGETTEXENVIVPROC epoxy_glGetTexEnviv = epoxy_glGetTexEnviv_global_rewrite_ptr;

PFNGLGETTEXENVXVPROC epoxy_glGetTexEnvxv = epoxy_glGetTexEnvxv_global_rewrite_ptr;

PFNGLGETTEXENVXVOESPROC epoxy_glGetTexEnvxvOES = epoxy_glGetTexEnvxvOES_global_rewrite_ptr;

PFNGLGETTEXFILTERFUNCSGISPROC epoxy_glGetTexFilterFuncSGIS = epoxy_glGetTexFilterFuncSGIS_global_rewrite_ptr;

PFNGLGETTEXGENDVPROC epoxy_glGetTexGendv = epoxy_glGetTexGendv_global_rewrite_ptr;

PFNGLGETTEXGENFVPROC epoxy_glGetTexGenfv = epoxy_glGetTexGenfv_global_rewrite_ptr;

PFNGLGETTEXGENFVOESPROC epoxy_glGetTexGenfvOES = epoxy_glGetTexGenfvOES_global_rewrite_ptr;

PFNGLGETTEXGENIVPROC epoxy_glGetTexGeniv = epoxy_glGetTexGeniv_global_rewrite_ptr;

PFNGLGETTEXGENIVOESPROC epoxy_glGetTexGenivOES = epoxy_glGetTexGenivOES_global_rewrite_ptr;

PFNGLGETTEXGENXVOESPROC epoxy_glGetTexGenxvOES = epoxy_glGetTexGenxvOES_global_rewrite_ptr;

PFNGLGETTEXIMAGEPROC epoxy_glGetTexImage = epoxy_glGetTexImage_global_rewrite_ptr;

PFNGLGETTEXLEVELPARAMETERFVPROC epoxy_glGetTexLevelParameterfv = epoxy_glGetTexLevelParameterfv_global_rewrite_ptr;

PFNGLGETTEXLEVELPARAMETERIVPROC epoxy_glGetTexLevelParameteriv = epoxy_glGetTexLevelParameteriv_global_rewrite_ptr;

PFNGLGETTEXLEVELPARAMETERXVOESPROC epoxy_glGetTexLevelParameterxvOES = epoxy_glGetTexLevelParameterxvOES_global_rewrite_ptr;

PFNGLGETTEXPARAMETERIIVPROC epoxy_glGetTexParameterIiv = epoxy_glGetTexParameterIiv_global_rewrite_ptr;

PFNGLGETTEXPARAMETERIIVEXTPROC epoxy_glGetTexParameterIivEXT = epoxy_glGetTexParameterIivEXT_global_rewrite_ptr;

PFNGLGETTEXPARAMETERIIVOESPROC epoxy_glGetTexParameterIivOES = epoxy_glGetTexParameterIivOES_global_rewrite_ptr;

PFNGLGETTEXPARAMETERIUIVPROC epoxy_glGetTexParameterIuiv = epoxy_glGetTexParameterIuiv_global_rewrite_ptr;

PFNGLGETTEXPARAMETERIUIVEXTPROC epoxy_glGetTexParameterIuivEXT = epoxy_glGetTexParameterIuivEXT_global_rewrite_ptr;

PFNGLGETTEXPARAMETERIUIVOESPROC epoxy_glGetTexParameterIuivOES = epoxy_glGetTexParameterIuivOES_global_rewrite_ptr;

PFNGLGETTEXPARAMETERPOINTERVAPPLEPROC epoxy_glGetTexParameterPointervAPPLE = epoxy_glGetTexParameterPointervAPPLE_global_rewrite_ptr;

PFNGLGETTEXPARAMETERFVPROC epoxy_glGetTexParameterfv = epoxy_glGetTexParameterfv_global_rewrite_ptr;

PFNGLGETTEXPARAMETERIVPROC epoxy_glGetTexParameteriv = epoxy_glGetTexParameteriv_global_rewrite_ptr;

PFNGLGETTEXPARAMETERXVPROC epoxy_glGetTexParameterxv = epoxy_glGetTexParameterxv_global_rewrite_ptr;

PFNGLGETTEXPARAMETERXVOESPROC epoxy_glGetTexParameterxvOES = epoxy_glGetTexParameterxvOES_global_rewrite_ptr;

PFNGLGETTEXTUREHANDLEARBPROC epoxy_glGetTextureHandleARB = epoxy_glGetTextureHandleARB_global_rewrite_ptr;

PFNGLGETTEXTUREHANDLEIMGPROC epoxy_glGetTextureHandleIMG = epoxy_glGetTextureHandleIMG_global_rewrite_ptr;

PFNGLGETTEXTUREHANDLENVPROC epoxy_glGetTextureHandleNV = epoxy_glGetTextureHandleNV_global_rewrite_ptr;

PFNGLGETTEXTUREIMAGEPROC epoxy_glGetTextureImage = epoxy_glGetTextureImage_global_rewrite_ptr;

PFNGLGETTEXTUREIMAGEEXTPROC epoxy_glGetTextureImageEXT = epoxy_glGetTextureImageEXT_global_rewrite_ptr;

PFNGLGETTEXTURELEVELPARAMETERFVPROC epoxy_glGetTextureLevelParameterfv = epoxy_glGetTextureLevelParameterfv_global_rewrite_ptr;

PFNGLGETTEXTURELEVELPARAMETERFVEXTPROC epoxy_glGetTextureLevelParameterfvEXT = epoxy_glGetTextureLevelParameterfvEXT_global_rewrite_ptr;

PFNGLGETTEXTURELEVELPARAMETERIVPROC epoxy_glGetTextureLevelParameteriv = epoxy_glGetTextureLevelParameteriv_global_rewrite_ptr;

PFNGLGETTEXTURELEVELPARAMETERIVEXTPROC epoxy_glGetTextureLevelParameterivEXT = epoxy_glGetTextureLevelParameterivEXT_global_rewrite_ptr;

PFNGLGETTEXTUREPARAMETERIIVPROC epoxy_glGetTextureParameterIiv = epoxy_glGetTextureParameterIiv_global_rewrite_ptr;

PFNGLGETTEXTUREPARAMETERIIVEXTPROC epoxy_glGetTextureParameterIivEXT = epoxy_glGetTextureParameterIivEXT_global_rewrite_ptr;

PFNGLGETTEXTUREPARAMETERIUIVPROC epoxy_glGetTextureParameterIuiv = epoxy_glGetTextureParameterIuiv_global_rewrite_ptr;

PFNGLGETTEXTUREPARAMETERIUIVEXTPROC epoxy_glGetTextureParameterIuivEXT = epoxy_glGetTextureParameterIuivEXT_global_rewrite_ptr;

PFNGLGETTEXTUREPARAMETERFVPROC epoxy_glGetTextureParameterfv = epoxy_glGetTextureParameterfv_global_rewrite_ptr;

PFNGLGETTEXTUREPARAMETERFVEXTPROC epoxy_glGetTextureParameterfvEXT = epoxy_glGetTextureParameterfvEXT_global_rewrite_ptr;

PFNGLGETTEXTUREPARAMETERIVPROC epoxy_glGetTextureParameteriv = epoxy_glGetTextureParameteriv_global_rewrite_ptr;

PFNGLGETTEXTUREPARAMETERIVEXTPROC epoxy_glGetTextureParameterivEXT = epoxy_glGetTextureParameterivEXT_global_rewrite_ptr;

PFNGLGETTEXTURESAMPLERHANDLEARBPROC epoxy_glGetTextureSamplerHandleARB = epoxy_glGetTextureSamplerHandleARB_global_rewrite_ptr;

PFNGLGETTEXTURESAMPLERHANDLEIMGPROC epoxy_glGetTextureSamplerHandleIMG = epoxy_glGetTextureSamplerHandleIMG_global_rewrite_ptr;

PFNGLGETTEXTURESAMPLERHANDLENVPROC epoxy_glGetTextureSamplerHandleNV = epoxy_glGetTextureSamplerHandleNV_global_rewrite_ptr;

PFNGLGETTEXTURESUBIMAGEPROC epoxy_glGetTextureSubImage = epoxy_glGetTextureSubImage_global_rewrite_ptr;

PFNGLGETTRACKMATRIXIVNVPROC epoxy_glGetTrackMatrixivNV = epoxy_glGetTrackMatrixivNV_global_rewrite_ptr;

PFNGLGETTRANSFORMFEEDBACKVARYINGPROC epoxy_glGetTransformFeedbackVarying = epoxy_glGetTransformFeedbackVarying_global_rewrite_ptr;

PFNGLGETTRANSFORMFEEDBACKVARYINGEXTPROC epoxy_glGetTransformFeedbackVaryingEXT = epoxy_glGetTransformFeedbackVaryingEXT_global_rewrite_ptr;

PFNGLGETTRANSFORMFEEDBACKVARYINGNVPROC epoxy_glGetTransformFeedbackVaryingNV = epoxy_glGetTransformFeedbackVaryingNV_global_rewrite_ptr;

PFNGLGETTRANSFORMFEEDBACKI64_VPROC epoxy_glGetTransformFeedbacki64_v = epoxy_glGetTransformFeedbacki64_v_global_rewrite_ptr;

PFNGLGETTRANSFORMFEEDBACKI_VPROC epoxy_glGetTransformFeedbacki_v = epoxy_glGetTransformFeedbacki_v_global_rewrite_ptr;

PFNGLGETTRANSFORMFEEDBACKIVPROC epoxy_glGetTransformFeedbackiv = epoxy_glGetTransformFeedbackiv_global_rewrite_ptr;

PFNGLGETTRANSLATEDSHADERSOURCEANGLEPROC epoxy_glGetTranslatedShaderSourceANGLE = epoxy_glGetTranslatedShaderSourceANGLE_global_rewrite_ptr;

PFNGLGETUNIFORMBLOCKINDEXPROC epoxy_glGetUniformBlockIndex = epoxy_glGetUniformBlockIndex_global_rewrite_ptr;

PFNGLGETUNIFORMBUFFERSIZEEXTPROC epoxy_glGetUniformBufferSizeEXT = epoxy_glGetUniformBufferSizeEXT_global_rewrite_ptr;

PFNGLGETUNIFORMINDICESPROC epoxy_glGetUniformIndices = epoxy_glGetUniformIndices_global_rewrite_ptr;

PFNGLGETUNIFORMLOCATIONPROC epoxy_glGetUniformLocation = epoxy_glGetUniformLocation_global_rewrite_ptr;

PFNGLGETUNIFORMLOCATIONARBPROC epoxy_glGetUniformLocationARB = epoxy_glGetUniformLocationARB_global_rewrite_ptr;

PFNGLGETUNIFORMOFFSETEXTPROC epoxy_glGetUniformOffsetEXT = epoxy_glGetUniformOffsetEXT_global_rewrite_ptr;

PFNGLGETUNIFORMSUBROUTINEUIVPROC epoxy_glGetUniformSubroutineuiv = epoxy_glGetUniformSubroutineuiv_global_rewrite_ptr;

PFNGLGETUNIFORMDVPROC epoxy_glGetUniformdv = epoxy_glGetUniformdv_global_rewrite_ptr;

PFNGLGETUNIFORMFVPROC epoxy_glGetUniformfv = epoxy_glGetUniformfv_global_rewrite_ptr;

PFNGLGETUNIFORMFVARBPROC epoxy_glGetUniformfvARB = epoxy_glGetUniformfvARB_global_rewrite_ptr;

PFNGLGETUNIFORMI64VARBPROC epoxy_glGetUniformi64vARB = epoxy_glGetUniformi64vARB_global_rewrite_ptr;

PFNGLGETUNIFORMI64VNVPROC epoxy_glGetUniformi64vNV = epoxy_glGetUniformi64vNV_global_rewrite_ptr;

PFNGLGETUNIFORMIVPROC epoxy_glGetUniformiv = epoxy_glGetUniformiv_global_rewrite_ptr;

PFNGLGETUNIFORMIVARBPROC epoxy_glGetUniformivARB = epoxy_glGetUniformivARB_global_rewrite_ptr;

PFNGLGETUNIFORMUI64VARBPROC epoxy_glGetUniformui64vARB = epoxy_glGetUniformui64vARB_global_rewrite_ptr;

PFNGLGETUNIFORMUI64VNVPROC epoxy_glGetUniformui64vNV = epoxy_glGetUniformui64vNV_global_rewrite_ptr;

PFNGLGETUNIFORMUIVPROC epoxy_glGetUniformuiv = epoxy_glGetUniformuiv_global_rewrite_ptr;

PFNGLGETUNIFORMUIVEXTPROC epoxy_glGetUniformuivEXT = epoxy_glGetUniformuivEXT_global_rewrite_ptr;

PFNGLGETUNSIGNEDBYTEI_VEXTPROC epoxy_glGetUnsignedBytei_vEXT = epoxy_glGetUnsignedBytei_vEXT_global_rewrite_ptr;

PFNGLGETUNSIGNEDBYTEVEXTPROC epoxy_glGetUnsignedBytevEXT = epoxy_glGetUnsignedBytevEXT_global_rewrite_ptr;

PFNGLGETVARIANTARRAYOBJECTFVATIPROC epoxy_glGetVariantArrayObjectfvATI = epoxy_glGetVariantArrayObjectfvATI_global_rewrite_ptr;

PFNGLGETVARIANTARRAYOBJECTIVATIPROC epoxy_glGetVariantArrayObjectivATI = epoxy_glGetVariantArrayObjectivATI_global_rewrite_ptr;

PFNGLGETVARIANTBOOLEANVEXTPROC epoxy_glGetVariantBooleanvEXT = epoxy_glGetVariantBooleanvEXT_global_rewrite_ptr;

PFNGLGETVARIANTFLOATVEXTPROC epoxy_glGetVariantFloatvEXT = epoxy_glGetVariantFloatvEXT_global_rewrite_ptr;

PFNGLGETVARIANTINTEGERVEXTPROC epoxy_glGetVariantIntegervEXT = epoxy_glGetVariantIntegervEXT_global_rewrite_ptr;

PFNGLGETVARIANTPOINTERVEXTPROC epoxy_glGetVariantPointervEXT = epoxy_glGetVariantPointervEXT_global_rewrite_ptr;

PFNGLGETVARYINGLOCATIONNVPROC epoxy_glGetVaryingLocationNV = epoxy_glGetVaryingLocationNV_global_rewrite_ptr;

PFNGLGETVERTEXARRAYINDEXED64IVPROC epoxy_glGetVertexArrayIndexed64iv = epoxy_glGetVertexArrayIndexed64iv_global_rewrite_ptr;

PFNGLGETVERTEXARRAYINDEXEDIVPROC epoxy_glGetVertexArrayIndexediv = epoxy_glGetVertexArrayIndexediv_global_rewrite_ptr;

PFNGLGETVERTEXARRAYINTEGERI_VEXTPROC epoxy_glGetVertexArrayIntegeri_vEXT = epoxy_glGetVertexArrayIntegeri_vEXT_global_rewrite_ptr;

PFNGLGETVERTEXARRAYINTEGERVEXTPROC epoxy_glGetVertexArrayIntegervEXT = epoxy_glGetVertexArrayIntegervEXT_global_rewrite_ptr;

PFNGLGETVERTEXARRAYPOINTERI_VEXTPROC epoxy_glGetVertexArrayPointeri_vEXT = epoxy_glGetVertexArrayPointeri_vEXT_global_rewrite_ptr;

PFNGLGETVERTEXARRAYPOINTERVEXTPROC epoxy_glGetVertexArrayPointervEXT = epoxy_glGetVertexArrayPointervEXT_global_rewrite_ptr;

PFNGLGETVERTEXARRAYIVPROC epoxy_glGetVertexArrayiv = epoxy_glGetVertexArrayiv_global_rewrite_ptr;

PFNGLGETVERTEXATTRIBARRAYOBJECTFVATIPROC epoxy_glGetVertexAttribArrayObjectfvATI = epoxy_glGetVertexAttribArrayObjectfvATI_global_rewrite_ptr;

PFNGLGETVERTEXATTRIBARRAYOBJECTIVATIPROC epoxy_glGetVertexAttribArrayObjectivATI = epoxy_glGetVertexAttribArrayObjectivATI_global_rewrite_ptr;

PFNGLGETVERTEXATTRIBIIVPROC epoxy_glGetVertexAttribIiv = epoxy_glGetVertexAttribIiv_global_rewrite_ptr;

PFNGLGETVERTEXATTRIBIIVEXTPROC epoxy_glGetVertexAttribIivEXT = epoxy_glGetVertexAttribIivEXT_global_rewrite_ptr;

PFNGLGETVERTEXATTRIBIUIVPROC epoxy_glGetVertexAttribIuiv = epoxy_glGetVertexAttribIuiv_global_rewrite_ptr;

PFNGLGETVERTEXATTRIBIUIVEXTPROC epoxy_glGetVertexAttribIuivEXT = epoxy_glGetVertexAttribIuivEXT_global_rewrite_ptr;

PFNGLGETVERTEXATTRIBLDVPROC epoxy_glGetVertexAttribLdv = epoxy_glGetVertexAttribLdv_global_rewrite_ptr;

PFNGLGETVERTEXATTRIBLDVEXTPROC epoxy_glGetVertexAttribLdvEXT = epoxy_glGetVertexAttribLdvEXT_global_rewrite_ptr;

PFNGLGETVERTEXATTRIBLI64VNVPROC epoxy_glGetVertexAttribLi64vNV = epoxy_glGetVertexAttribLi64vNV_global_rewrite_ptr;

PFNGLGETVERTEXATTRIBLUI64VARBPROC epoxy_glGetVertexAttribLui64vARB = epoxy_glGetVertexAttribLui64vARB_global_rewrite_ptr;

PFNGLGETVERTEXATTRIBLUI64VNVPROC epoxy_glGetVertexAttribLui64vNV = epoxy_glGetVertexAttribLui64vNV_global_rewrite_ptr;

PFNGLGETVERTEXATTRIBPOINTERVPROC epoxy_glGetVertexAttribPointerv = epoxy_glGetVertexAttribPointerv_global_rewrite_ptr;

PFNGLGETVERTEXATTRIBPOINTERVARBPROC epoxy_glGetVertexAttribPointervARB = epoxy_glGetVertexAttribPointervARB_global_rewrite_ptr;

PFNGLGETVERTEXATTRIBPOINTERVNVPROC epoxy_glGetVertexAttribPointervNV = epoxy_glGetVertexAttribPointervNV_global_rewrite_ptr;

PFNGLGETVERTEXATTRIBDVPROC epoxy_glGetVertexAttribdv = epoxy_glGetVertexAttribdv_global_rewrite_ptr;

PFNGLGETVERTEXATTRIBDVARBPROC epoxy_glGetVertexAttribdvARB = epoxy_glGetVertexAttribdvARB_global_rewrite_ptr;

PFNGLGETVERTEXATTRIBDVNVPROC epoxy_glGetVertexAttribdvNV = epoxy_glGetVertexAttribdvNV_global_rewrite_ptr;

PFNGLGETVERTEXATTRIBFVPROC epoxy_glGetVertexAttribfv = epoxy_glGetVertexAttribfv_global_rewrite_ptr;

PFNGLGETVERTEXATTRIBFVARBPROC epoxy_glGetVertexAttribfvARB = epoxy_glGetVertexAttribfvARB_global_rewrite_ptr;

PFNGLGETVERTEXATTRIBFVNVPROC epoxy_glGetVertexAttribfvNV = epoxy_glGetVertexAttribfvNV_global_rewrite_ptr;

PFNGLGETVERTEXATTRIBIVPROC epoxy_glGetVertexAttribiv = epoxy_glGetVertexAttribiv_global_rewrite_ptr;

PFNGLGETVERTEXATTRIBIVARBPROC epoxy_glGetVertexAttribivARB = epoxy_glGetVertexAttribivARB_global_rewrite_ptr;

PFNGLGETVERTEXATTRIBIVNVPROC epoxy_glGetVertexAttribivNV = epoxy_glGetVertexAttribivNV_global_rewrite_ptr;

PFNGLGETVIDEOCAPTURESTREAMDVNVPROC epoxy_glGetVideoCaptureStreamdvNV = epoxy_glGetVideoCaptureStreamdvNV_global_rewrite_ptr;

PFNGLGETVIDEOCAPTURESTREAMFVNVPROC epoxy_glGetVideoCaptureStreamfvNV = epoxy_glGetVideoCaptureStreamfvNV_global_rewrite_ptr;

PFNGLGETVIDEOCAPTURESTREAMIVNVPROC epoxy_glGetVideoCaptureStreamivNV = epoxy_glGetVideoCaptureStreamivNV_global_rewrite_ptr;

PFNGLGETVIDEOCAPTUREIVNVPROC epoxy_glGetVideoCaptureivNV = epoxy_glGetVideoCaptureivNV_global_rewrite_ptr;

PFNGLGETVIDEOI64VNVPROC epoxy_glGetVideoi64vNV = epoxy_glGetVideoi64vNV_global_rewrite_ptr;

PFNGLGETVIDEOIVNVPROC epoxy_glGetVideoivNV = epoxy_glGetVideoivNV_global_rewrite_ptr;

PFNGLGETVIDEOUI64VNVPROC epoxy_glGetVideoui64vNV = epoxy_glGetVideoui64vNV_global_rewrite_ptr;

PFNGLGETVIDEOUIVNVPROC epoxy_glGetVideouivNV = epoxy_glGetVideouivNV_global_rewrite_ptr;

PFNGLGETVKPROCADDRNVPROC epoxy_glGetVkProcAddrNV = epoxy_glGetVkProcAddrNV_global_rewrite_ptr;

PFNGLGETNCOLORTABLEPROC epoxy_glGetnColorTable = epoxy_glGetnColorTable_global_rewrite_ptr;

PFNGLGETNCOLORTABLEARBPROC epoxy_glGetnColorTableARB = epoxy_glGetnColorTableARB_global_rewrite_ptr;

PFNGLGETNCOMPRESSEDTEXIMAGEPROC epoxy_glGetnCompressedTexImage = epoxy_glGetnCompressedTexImage_global_rewrite_ptr;

PFNGLGETNCOMPRESSEDTEXIMAGEARBPROC epoxy_glGetnCompressedTexImageARB = epoxy_glGetnCompressedTexImageARB_global_rewrite_ptr;

PFNGLGETNCONVOLUTIONFILTERPROC epoxy_glGetnConvolutionFilter = epoxy_glGetnConvolutionFilter_global_rewrite_ptr;

PFNGLGETNCONVOLUTIONFILTERARBPROC epoxy_glGetnConvolutionFilterARB = epoxy_glGetnConvolutionFilterARB_global_rewrite_ptr;

PFNGLGETNHISTOGRAMPROC epoxy_glGetnHistogram = epoxy_glGetnHistogram_global_rewrite_ptr;

PFNGLGETNHISTOGRAMARBPROC epoxy_glGetnHistogramARB = epoxy_glGetnHistogramARB_global_rewrite_ptr;

PFNGLGETNMAPDVPROC epoxy_glGetnMapdv = epoxy_glGetnMapdv_global_rewrite_ptr;

PFNGLGETNMAPDVARBPROC epoxy_glGetnMapdvARB = epoxy_glGetnMapdvARB_global_rewrite_ptr;

PFNGLGETNMAPFVPROC epoxy_glGetnMapfv = epoxy_glGetnMapfv_global_rewrite_ptr;

PFNGLGETNMAPFVARBPROC epoxy_glGetnMapfvARB = epoxy_glGetnMapfvARB_global_rewrite_ptr;

PFNGLGETNMAPIVPROC epoxy_glGetnMapiv = epoxy_glGetnMapiv_global_rewrite_ptr;

PFNGLGETNMAPIVARBPROC epoxy_glGetnMapivARB = epoxy_glGetnMapivARB_global_rewrite_ptr;

PFNGLGETNMINMAXPROC epoxy_glGetnMinmax = epoxy_glGetnMinmax_global_rewrite_ptr;

PFNGLGETNMINMAXARBPROC epoxy_glGetnMinmaxARB = epoxy_glGetnMinmaxARB_global_rewrite_ptr;

PFNGLGETNPIXELMAPFVPROC epoxy_glGetnPixelMapfv = epoxy_glGetnPixelMapfv_global_rewrite_ptr;

PFNGLGETNPIXELMAPFVARBPROC epoxy_glGetnPixelMapfvARB = epoxy_glGetnPixelMapfvARB_global_rewrite_ptr;

PFNGLGETNPIXELMAPUIVPROC epoxy_glGetnPixelMapuiv = epoxy_glGetnPixelMapuiv_global_rewrite_ptr;

PFNGLGETNPIXELMAPUIVARBPROC epoxy_glGetnPixelMapuivARB = epoxy_glGetnPixelMapuivARB_global_rewrite_ptr;

PFNGLGETNPIXELMAPUSVPROC epoxy_glGetnPixelMapusv = epoxy_glGetnPixelMapusv_global_rewrite_ptr;

PFNGLGETNPIXELMAPUSVARBPROC epoxy_glGetnPixelMapusvARB = epoxy_glGetnPixelMapusvARB_global_rewrite_ptr;

PFNGLGETNPOLYGONSTIPPLEPROC epoxy_glGetnPolygonStipple = epoxy_glGetnPolygonStipple_global_rewrite_ptr;

PFNGLGETNPOLYGONSTIPPLEARBPROC epoxy_glGetnPolygonStippleARB = epoxy_glGetnPolygonStippleARB_global_rewrite_ptr;

PFNGLGETNSEPARABLEFILTERPROC epoxy_glGetnSeparableFilter = epoxy_glGetnSeparableFilter_global_rewrite_ptr;

PFNGLGETNSEPARABLEFILTERARBPROC epoxy_glGetnSeparableFilterARB = epoxy_glGetnSeparableFilterARB_global_rewrite_ptr;

PFNGLGETNTEXIMAGEPROC epoxy_glGetnTexImage = epoxy_glGetnTexImage_global_rewrite_ptr;

PFNGLGETNTEXIMAGEARBPROC epoxy_glGetnTexImageARB = epoxy_glGetnTexImageARB_global_rewrite_ptr;

PFNGLGETNUNIFORMDVPROC epoxy_glGetnUniformdv = epoxy_glGetnUniformdv_global_rewrite_ptr;

PFNGLGETNUNIFORMDVARBPROC epoxy_glGetnUniformdvARB = epoxy_glGetnUniformdvARB_global_rewrite_ptr;

PFNGLGETNUNIFORMFVPROC epoxy_glGetnUniformfv = epoxy_glGetnUniformfv_global_rewrite_ptr;

PFNGLGETNUNIFORMFVARBPROC epoxy_glGetnUniformfvARB = epoxy_glGetnUniformfvARB_global_rewrite_ptr;

PFNGLGETNUNIFORMFVEXTPROC epoxy_glGetnUniformfvEXT = epoxy_glGetnUniformfvEXT_global_rewrite_ptr;

PFNGLGETNUNIFORMFVKHRPROC epoxy_glGetnUniformfvKHR = epoxy_glGetnUniformfvKHR_global_rewrite_ptr;

PFNGLGETNUNIFORMI64VARBPROC epoxy_glGetnUniformi64vARB = epoxy_glGetnUniformi64vARB_global_rewrite_ptr;

PFNGLGETNUNIFORMIVPROC epoxy_glGetnUniformiv = epoxy_glGetnUniformiv_global_rewrite_ptr;

PFNGLGETNUNIFORMIVARBPROC epoxy_glGetnUniformivARB = epoxy_glGetnUniformivARB_global_rewrite_ptr;

PFNGLGETNUNIFORMIVEXTPROC epoxy_glGetnUniformivEXT = epoxy_glGetnUniformivEXT_global_rewrite_ptr;

PFNGLGETNUNIFORMIVKHRPROC epoxy_glGetnUniformivKHR = epoxy_glGetnUniformivKHR_global_rewrite_ptr;

PFNGLGETNUNIFORMUI64VARBPROC epoxy_glGetnUniformui64vARB = epoxy_glGetnUniformui64vARB_global_rewrite_ptr;

PFNGLGETNUNIFORMUIVPROC epoxy_glGetnUniformuiv = epoxy_glGetnUniformuiv_global_rewrite_ptr;

PFNGLGETNUNIFORMUIVARBPROC epoxy_glGetnUniformuivARB = epoxy_glGetnUniformuivARB_global_rewrite_ptr;

PFNGLGETNUNIFORMUIVKHRPROC epoxy_glGetnUniformuivKHR = epoxy_glGetnUniformuivKHR_global_rewrite_ptr;

PFNGLGLOBALALPHAFACTORBSUNPROC epoxy_glGlobalAlphaFactorbSUN = epoxy_glGlobalAlphaFactorbSUN_global_rewrite_ptr;

PFNGLGLOBALALPHAFACTORDSUNPROC epoxy_glGlobalAlphaFactordSUN = epoxy_glGlobalAlphaFactordSUN_global_rewrite_ptr;

PFNGLGLOBALALPHAFACTORFSUNPROC epoxy_glGlobalAlphaFactorfSUN = epoxy_glGlobalAlphaFactorfSUN_global_rewrite_ptr;

PFNGLGLOBALALPHAFACTORISUNPROC epoxy_glGlobalAlphaFactoriSUN = epoxy_glGlobalAlphaFactoriSUN_global_rewrite_ptr;

PFNGLGLOBALALPHAFACTORSSUNPROC epoxy_glGlobalAlphaFactorsSUN = epoxy_glGlobalAlphaFactorsSUN_global_rewrite_ptr;

PFNGLGLOBALALPHAFACTORUBSUNPROC epoxy_glGlobalAlphaFactorubSUN = epoxy_glGlobalAlphaFactorubSUN_global_rewrite_ptr;

PFNGLGLOBALALPHAFACTORUISUNPROC epoxy_glGlobalAlphaFactoruiSUN = epoxy_glGlobalAlphaFactoruiSUN_global_rewrite_ptr;

PFNGLGLOBALALPHAFACTORUSSUNPROC epoxy_glGlobalAlphaFactorusSUN = epoxy_glGlobalAlphaFactorusSUN_global_rewrite_ptr;

PFNGLHINTPROC epoxy_glHint = epoxy_glHint_global_rewrite_ptr;

PFNGLHINTPGIPROC epoxy_glHintPGI = epoxy_glHintPGI_global_rewrite_ptr;

PFNGLHISTOGRAMPROC epoxy_glHistogram = epoxy_glHistogram_global_rewrite_ptr;

PFNGLHISTOGRAMEXTPROC epoxy_glHistogramEXT = epoxy_glHistogramEXT_global_rewrite_ptr;

PFNGLIGLOOINTERFACESGIXPROC epoxy_glIglooInterfaceSGIX = epoxy_glIglooInterfaceSGIX_global_rewrite_ptr;

PFNGLIMAGETRANSFORMPARAMETERFHPPROC epoxy_glImageTransformParameterfHP = epoxy_glImageTransformParameterfHP_global_rewrite_ptr;

PFNGLIMAGETRANSFORMPARAMETERFVHPPROC epoxy_glImageTransformParameterfvHP = epoxy_glImageTransformParameterfvHP_global_rewrite_ptr;

PFNGLIMAGETRANSFORMPARAMETERIHPPROC epoxy_glImageTransformParameteriHP = epoxy_glImageTransformParameteriHP_global_rewrite_ptr;

PFNGLIMAGETRANSFORMPARAMETERIVHPPROC epoxy_glImageTransformParameterivHP = epoxy_glImageTransformParameterivHP_global_rewrite_ptr;

PFNGLIMPORTMEMORYFDEXTPROC epoxy_glImportMemoryFdEXT = epoxy_glImportMemoryFdEXT_global_rewrite_ptr;

PFNGLIMPORTMEMORYWIN32HANDLEEXTPROC epoxy_glImportMemoryWin32HandleEXT = epoxy_glImportMemoryWin32HandleEXT_global_rewrite_ptr;

PFNGLIMPORTMEMORYWIN32NAMEEXTPROC epoxy_glImportMemoryWin32NameEXT = epoxy_glImportMemoryWin32NameEXT_global_rewrite_ptr;

PFNGLIMPORTSEMAPHOREFDEXTPROC epoxy_glImportSemaphoreFdEXT = epoxy_glImportSemaphoreFdEXT_global_rewrite_ptr;

PFNGLIMPORTSEMAPHOREWIN32HANDLEEXTPROC epoxy_glImportSemaphoreWin32HandleEXT = epoxy_glImportSemaphoreWin32HandleEXT_global_rewrite_ptr;

PFNGLIMPORTSEMAPHOREWIN32NAMEEXTPROC epoxy_glImportSemaphoreWin32NameEXT = epoxy_glImportSemaphoreWin32NameEXT_global_rewrite_ptr;

PFNGLIMPORTSYNCEXTPROC epoxy_glImportSyncEXT = epoxy_glImportSyncEXT_global_rewrite_ptr;

PFNGLINDEXFORMATNVPROC epoxy_glIndexFormatNV = epoxy_glIndexFormatNV_global_rewrite_ptr;

PFNGLINDEXFUNCEXTPROC epoxy_glIndexFuncEXT = epoxy_glIndexFuncEXT_global_rewrite_ptr;

PFNGLINDEXMASKPROC epoxy_glIndexMask = epoxy_glIndexMask_global_rewrite_ptr;

PFNGLINDEXMATERIALEXTPROC epoxy_glIndexMaterialEXT = epoxy_glIndexMaterialEXT_global_rewrite_ptr;

PFNGLINDEXPOINTERPROC epoxy_glIndexPointer = epoxy_glIndexPointer_global_rewrite_ptr;

PFNGLINDEXPOINTEREXTPROC epoxy_glIndexPointerEXT = epoxy_glIndexPointerEXT_global_rewrite_ptr;

PFNGLINDEXPOINTERLISTIBMPROC epoxy_glIndexPointerListIBM = epoxy_glIndexPointerListIBM_global_rewrite_ptr;

PFNGLINDEXDPROC epoxy_glIndexd = epoxy_glIndexd_global_rewrite_ptr;

PFNGLINDEXDVPROC epoxy_glIndexdv = epoxy_glIndexdv_global_rewrite_ptr;

PFNGLINDEXFPROC epoxy_glIndexf = epoxy_glIndexf_global_rewrite_ptr;

PFNGLINDEXFVPROC epoxy_glIndexfv = epoxy_glIndexfv_global_rewrite_ptr;

PFNGLINDEXIPROC epoxy_glIndexi = epoxy_glIndexi_global_rewrite_ptr;

PFNGLINDEXIVPROC epoxy_glIndexiv = epoxy_glIndexiv_global_rewrite_ptr;

PFNGLINDEXSPROC epoxy_glIndexs = epoxy_glIndexs_global_rewrite_ptr;

PFNGLINDEXSVPROC epoxy_glIndexsv = epoxy_glIndexsv_global_rewrite_ptr;

PFNGLINDEXUBPROC epoxy_glIndexub = epoxy_glIndexub_global_rewrite_ptr;

PFNGLINDEXUBVPROC epoxy_glIndexubv = epoxy_glIndexubv_global_rewrite_ptr;

PFNGLINDEXXOESPROC epoxy_glIndexxOES = epoxy_glIndexxOES_global_rewrite_ptr;

PFNGLINDEXXVOESPROC epoxy_glIndexxvOES = epoxy_glIndexxvOES_global_rewrite_ptr;

PFNGLINITNAMESPROC epoxy_glInitNames = epoxy_glInitNames_global_rewrite_ptr;

PFNGLINSERTCOMPONENTEXTPROC epoxy_glInsertComponentEXT = epoxy_glInsertComponentEXT_global_rewrite_ptr;

PFNGLINSERTEVENTMARKEREXTPROC epoxy_glInsertEventMarkerEXT = epoxy_glInsertEventMarkerEXT_global_rewrite_ptr;

PFNGLINSTRUMENTSBUFFERSGIXPROC epoxy_glInstrumentsBufferSGIX = epoxy_glInstrumentsBufferSGIX_global_rewrite_ptr;

PFNGLINTERLEAVEDARRAYSPROC epoxy_glInterleavedArrays = epoxy_glInterleavedArrays_global_rewrite_ptr;

PFNGLINTERPOLATEPATHSNVPROC epoxy_glInterpolatePathsNV = epoxy_glInterpolatePathsNV_global_rewrite_ptr;

PFNGLINVALIDATEBUFFERDATAPROC epoxy_glInvalidateBufferData = epoxy_glInvalidateBufferData_global_rewrite_ptr;

PFNGLINVALIDATEBUFFERSUBDATAPROC epoxy_glInvalidateBufferSubData = epoxy_glInvalidateBufferSubData_global_rewrite_ptr;

PFNGLINVALIDATEFRAMEBUFFERPROC epoxy_glInvalidateFramebuffer = epoxy_glInvalidateFramebuffer_global_rewrite_ptr;

PFNGLINVALIDATENAMEDFRAMEBUFFERDATAPROC epoxy_glInvalidateNamedFramebufferData = epoxy_glInvalidateNamedFramebufferData_global_rewrite_ptr;

PFNGLINVALIDATENAMEDFRAMEBUFFERSUBDATAPROC epoxy_glInvalidateNamedFramebufferSubData = epoxy_glInvalidateNamedFramebufferSubData_global_rewrite_ptr;

PFNGLINVALIDATESUBFRAMEBUFFERPROC epoxy_glInvalidateSubFramebuffer = epoxy_glInvalidateSubFramebuffer_global_rewrite_ptr;

PFNGLINVALIDATETEXIMAGEPROC epoxy_glInvalidateTexImage = epoxy_glInvalidateTexImage_global_rewrite_ptr;

PFNGLINVALIDATETEXSUBIMAGEPROC epoxy_glInvalidateTexSubImage = epoxy_glInvalidateTexSubImage_global_rewrite_ptr;

PFNGLISASYNCMARKERSGIXPROC epoxy_glIsAsyncMarkerSGIX = epoxy_glIsAsyncMarkerSGIX_global_rewrite_ptr;

PFNGLISBUFFERPROC epoxy_glIsBuffer = epoxy_glIsBuffer_global_rewrite_ptr;

PFNGLISBUFFERARBPROC epoxy_glIsBufferARB = epoxy_glIsBufferARB_global_rewrite_ptr;

PFNGLISBUFFERRESIDENTNVPROC epoxy_glIsBufferResidentNV = epoxy_glIsBufferResidentNV_global_rewrite_ptr;

PFNGLISCOMMANDLISTNVPROC epoxy_glIsCommandListNV = epoxy_glIsCommandListNV_global_rewrite_ptr;

PFNGLISENABLEDPROC epoxy_glIsEnabled = epoxy_glIsEnabled_global_rewrite_ptr;

PFNGLISENABLEDINDEXEDEXTPROC epoxy_glIsEnabledIndexedEXT = epoxy_glIsEnabledIndexedEXT_global_rewrite_ptr;

PFNGLISENABLEDIPROC epoxy_glIsEnabledi = epoxy_glIsEnabledi_global_rewrite_ptr;

PFNGLISENABLEDIEXTPROC epoxy_glIsEnablediEXT = epoxy_glIsEnablediEXT_global_rewrite_ptr;

PFNGLISENABLEDINVPROC epoxy_glIsEnablediNV = epoxy_glIsEnablediNV_global_rewrite_ptr;

PFNGLISENABLEDIOESPROC epoxy_glIsEnablediOES = epoxy_glIsEnablediOES_global_rewrite_ptr;

PFNGLISFENCEAPPLEPROC epoxy_glIsFenceAPPLE = epoxy_glIsFenceAPPLE_global_rewrite_ptr;

PFNGLISFENCENVPROC epoxy_glIsFenceNV = epoxy_glIsFenceNV_global_rewrite_ptr;

PFNGLISFRAMEBUFFERPROC epoxy_glIsFramebuffer = epoxy_glIsFramebuffer_global_rewrite_ptr;

PFNGLISFRAMEBUFFEREXTPROC epoxy_glIsFramebufferEXT = epoxy_glIsFramebufferEXT_global_rewrite_ptr;

PFNGLISFRAMEBUFFEROESPROC epoxy_glIsFramebufferOES = epoxy_glIsFramebufferOES_global_rewrite_ptr;

PFNGLISIMAGEHANDLERESIDENTARBPROC epoxy_glIsImageHandleResidentARB = epoxy_glIsImageHandleResidentARB_global_rewrite_ptr;

PFNGLISIMAGEHANDLERESIDENTNVPROC epoxy_glIsImageHandleResidentNV = epoxy_glIsImageHandleResidentNV_global_rewrite_ptr;

PFNGLISLISTPROC epoxy_glIsList = epoxy_glIsList_global_rewrite_ptr;

PFNGLISMEMORYOBJECTEXTPROC epoxy_glIsMemoryObjectEXT = epoxy_glIsMemoryObjectEXT_global_rewrite_ptr;

PFNGLISNAMEAMDPROC epoxy_glIsNameAMD = epoxy_glIsNameAMD_global_rewrite_ptr;

PFNGLISNAMEDBUFFERRESIDENTNVPROC epoxy_glIsNamedBufferResidentNV = epoxy_glIsNamedBufferResidentNV_global_rewrite_ptr;

PFNGLISNAMEDSTRINGARBPROC epoxy_glIsNamedStringARB = epoxy_glIsNamedStringARB_global_rewrite_ptr;

PFNGLISOBJECTBUFFERATIPROC epoxy_glIsObjectBufferATI = epoxy_glIsObjectBufferATI_global_rewrite_ptr;

PFNGLISOCCLUSIONQUERYNVPROC epoxy_glIsOcclusionQueryNV = epoxy_glIsOcclusionQueryNV_global_rewrite_ptr;

PFNGLISPATHNVPROC epoxy_glIsPathNV = epoxy_glIsPathNV_global_rewrite_ptr;

PFNGLISPOINTINFILLPATHNVPROC epoxy_glIsPointInFillPathNV = epoxy_glIsPointInFillPathNV_global_rewrite_ptr;

PFNGLISPOINTINSTROKEPATHNVPROC epoxy_glIsPointInStrokePathNV = epoxy_glIsPointInStrokePathNV_global_rewrite_ptr;

PFNGLISPROGRAMPROC epoxy_glIsProgram = epoxy_glIsProgram_global_rewrite_ptr;

PFNGLISPROGRAMARBPROC epoxy_glIsProgramARB = epoxy_glIsProgramARB_global_rewrite_ptr;

PFNGLISPROGRAMNVPROC epoxy_glIsProgramNV = epoxy_glIsProgramNV_global_rewrite_ptr;

PFNGLISPROGRAMPIPELINEPROC epoxy_glIsProgramPipeline = epoxy_glIsProgramPipeline_global_rewrite_ptr;

PFNGLISPROGRAMPIPELINEEXTPROC epoxy_glIsProgramPipelineEXT = epoxy_glIsProgramPipelineEXT_global_rewrite_ptr;

PFNGLISQUERYPROC epoxy_glIsQuery = epoxy_glIsQuery_global_rewrite_ptr;

PFNGLISQUERYARBPROC epoxy_glIsQueryARB = epoxy_glIsQueryARB_global_rewrite_ptr;

PFNGLISQUERYEXTPROC epoxy_glIsQueryEXT = epoxy_glIsQueryEXT_global_rewrite_ptr;

PFNGLISRENDERBUFFERPROC epoxy_glIsRenderbuffer = epoxy_glIsRenderbuffer_global_rewrite_ptr;

PFNGLISRENDERBUFFEREXTPROC epoxy_glIsRenderbufferEXT = epoxy_glIsRenderbufferEXT_global_rewrite_ptr;

PFNGLISRENDERBUFFEROESPROC epoxy_glIsRenderbufferOES = epoxy_glIsRenderbufferOES_global_rewrite_ptr;

PFNGLISSAMPLERPROC epoxy_glIsSampler = epoxy_glIsSampler_global_rewrite_ptr;

PFNGLISSEMAPHOREEXTPROC epoxy_glIsSemaphoreEXT = epoxy_glIsSemaphoreEXT_global_rewrite_ptr;

PFNGLISSHADERPROC epoxy_glIsShader = epoxy_glIsShader_global_rewrite_ptr;

PFNGLISSTATENVPROC epoxy_glIsStateNV = epoxy_glIsStateNV_global_rewrite_ptr;

PFNGLISSYNCPROC epoxy_glIsSync = epoxy_glIsSync_global_rewrite_ptr;

PFNGLISSYNCAPPLEPROC epoxy_glIsSyncAPPLE = epoxy_glIsSyncAPPLE_global_rewrite_ptr;

PFNGLISTEXTUREPROC epoxy_glIsTexture = epoxy_glIsTexture_global_rewrite_ptr;

PFNGLISTEXTUREEXTPROC epoxy_glIsTextureEXT = epoxy_glIsTextureEXT_global_rewrite_ptr;

PFNGLISTEXTUREHANDLERESIDENTARBPROC epoxy_glIsTextureHandleResidentARB = epoxy_glIsTextureHandleResidentARB_global_rewrite_ptr;

PFNGLISTEXTUREHANDLERESIDENTNVPROC epoxy_glIsTextureHandleResidentNV = epoxy_glIsTextureHandleResidentNV_global_rewrite_ptr;

PFNGLISTRANSFORMFEEDBACKPROC epoxy_glIsTransformFeedback = epoxy_glIsTransformFeedback_global_rewrite_ptr;

PFNGLISTRANSFORMFEEDBACKNVPROC epoxy_glIsTransformFeedbackNV = epoxy_glIsTransformFeedbackNV_global_rewrite_ptr;

PFNGLISVARIANTENABLEDEXTPROC epoxy_glIsVariantEnabledEXT = epoxy_glIsVariantEnabledEXT_global_rewrite_ptr;

PFNGLISVERTEXARRAYPROC epoxy_glIsVertexArray = epoxy_glIsVertexArray_global_rewrite_ptr;

PFNGLISVERTEXARRAYAPPLEPROC epoxy_glIsVertexArrayAPPLE = epoxy_glIsVertexArrayAPPLE_global_rewrite_ptr;

PFNGLISVERTEXARRAYOESPROC epoxy_glIsVertexArrayOES = epoxy_glIsVertexArrayOES_global_rewrite_ptr;

PFNGLISVERTEXATTRIBENABLEDAPPLEPROC epoxy_glIsVertexAttribEnabledAPPLE = epoxy_glIsVertexAttribEnabledAPPLE_global_rewrite_ptr;

PFNGLLGPUCOPYIMAGESUBDATANVXPROC epoxy_glLGPUCopyImageSubDataNVX = epoxy_glLGPUCopyImageSubDataNVX_global_rewrite_ptr;

PFNGLLGPUINTERLOCKNVXPROC epoxy_glLGPUInterlockNVX = epoxy_glLGPUInterlockNVX_global_rewrite_ptr;

PFNGLLGPUNAMEDBUFFERSUBDATANVXPROC epoxy_glLGPUNamedBufferSubDataNVX = epoxy_glLGPUNamedBufferSubDataNVX_global_rewrite_ptr;

PFNGLLABELOBJECTEXTPROC epoxy_glLabelObjectEXT = epoxy_glLabelObjectEXT_global_rewrite_ptr;

PFNGLLIGHTENVISGIXPROC epoxy_glLightEnviSGIX = epoxy_glLightEnviSGIX_global_rewrite_ptr;

PFNGLLIGHTMODELFPROC epoxy_glLightModelf = epoxy_glLightModelf_global_rewrite_ptr;

PFNGLLIGHTMODELFVPROC epoxy_glLightModelfv = epoxy_glLightModelfv_global_rewrite_ptr;

PFNGLLIGHTMODELIPROC epoxy_glLightModeli = epoxy_glLightModeli_global_rewrite_ptr;

PFNGLLIGHTMODELIVPROC epoxy_glLightModeliv = epoxy_glLightModeliv_global_rewrite_ptr;

PFNGLLIGHTMODELXPROC epoxy_glLightModelx = epoxy_glLightModelx_global_rewrite_ptr;

PFNGLLIGHTMODELXOESPROC epoxy_glLightModelxOES = epoxy_glLightModelxOES_global_rewrite_ptr;

PFNGLLIGHTMODELXVPROC epoxy_glLightModelxv = epoxy_glLightModelxv_global_rewrite_ptr;

PFNGLLIGHTMODELXVOESPROC epoxy_glLightModelxvOES = epoxy_glLightModelxvOES_global_rewrite_ptr;

PFNGLLIGHTFPROC epoxy_glLightf = epoxy_glLightf_global_rewrite_ptr;

PFNGLLIGHTFVPROC epoxy_glLightfv = epoxy_glLightfv_global_rewrite_ptr;

PFNGLLIGHTIPROC epoxy_glLighti = epoxy_glLighti_global_rewrite_ptr;

PFNGLLIGHTIVPROC epoxy_glLightiv = epoxy_glLightiv_global_rewrite_ptr;

PFNGLLIGHTXPROC epoxy_glLightx = epoxy_glLightx_global_rewrite_ptr;

PFNGLLIGHTXOESPROC epoxy_glLightxOES = epoxy_glLightxOES_global_rewrite_ptr;

PFNGLLIGHTXVPROC epoxy_glLightxv = epoxy_glLightxv_global_rewrite_ptr;

PFNGLLIGHTXVOESPROC epoxy_glLightxvOES = epoxy_glLightxvOES_global_rewrite_ptr;

PFNGLLINESTIPPLEPROC epoxy_glLineStipple = epoxy_glLineStipple_global_rewrite_ptr;

PFNGLLINEWIDTHPROC epoxy_glLineWidth = epoxy_glLineWidth_global_rewrite_ptr;

PFNGLLINEWIDTHXPROC epoxy_glLineWidthx = epoxy_glLineWidthx_global_rewrite_ptr;

PFNGLLINEWIDTHXOESPROC epoxy_glLineWidthxOES = epoxy_glLineWidthxOES_global_rewrite_ptr;

PFNGLLINKPROGRAMPROC epoxy_glLinkProgram = epoxy_glLinkProgram_global_rewrite_ptr;

PFNGLLINKPROGRAMARBPROC epoxy_glLinkProgramARB = epoxy_glLinkProgramARB_global_rewrite_ptr;

PFNGLLISTBASEPROC epoxy_glListBase = epoxy_glListBase_global_rewrite_ptr;

PFNGLLISTDRAWCOMMANDSSTATESCLIENTNVPROC epoxy_glListDrawCommandsStatesClientNV = epoxy_glListDrawCommandsStatesClientNV_global_rewrite_ptr;

PFNGLLISTPARAMETERFSGIXPROC epoxy_glListParameterfSGIX = epoxy_glListParameterfSGIX_global_rewrite_ptr;

PFNGLLISTPARAMETERFVSGIXPROC epoxy_glListParameterfvSGIX = epoxy_glListParameterfvSGIX_global_rewrite_ptr;

PFNGLLISTPARAMETERISGIXPROC epoxy_glListParameteriSGIX = epoxy_glListParameteriSGIX_global_rewrite_ptr;

PFNGLLISTPARAMETERIVSGIXPROC epoxy_glListParameterivSGIX = epoxy_glListParameterivSGIX_global_rewrite_ptr;

PFNGLLOADIDENTITYPROC epoxy_glLoadIdentity = epoxy_glLoadIdentity_global_rewrite_ptr;

PFNGLLOADIDENTITYDEFORMATIONMAPSGIXPROC epoxy_glLoadIdentityDeformationMapSGIX = epoxy_glLoadIdentityDeformationMapSGIX_global_rewrite_ptr;

PFNGLLOADMATRIXDPROC epoxy_glLoadMatrixd = epoxy_glLoadMatrixd_global_rewrite_ptr;

PFNGLLOADMATRIXFPROC epoxy_glLoadMatrixf = epoxy_glLoadMatrixf_global_rewrite_ptr;

PFNGLLOADMATRIXXPROC epoxy_glLoadMatrixx = epoxy_glLoadMatrixx_global_rewrite_ptr;

PFNGLLOADMATRIXXOESPROC epoxy_glLoadMatrixxOES = epoxy_glLoadMatrixxOES_global_rewrite_ptr;

PFNGLLOADNAMEPROC epoxy_glLoadName = epoxy_glLoadName_global_rewrite_ptr;

PFNGLLOADPALETTEFROMMODELVIEWMATRIXOESPROC epoxy_glLoadPaletteFromModelViewMatrixOES = epoxy_glLoadPaletteFromModelViewMatrixOES_global_rewrite_ptr;

PFNGLLOADPROGRAMNVPROC epoxy_glLoadProgramNV = epoxy_glLoadProgramNV_global_rewrite_ptr;

PFNGLLOADTRANSPOSEMATRIXDPROC epoxy_glLoadTransposeMatrixd = epoxy_glLoadTransposeMatrixd_global_rewrite_ptr;

PFNGLLOADTRANSPOSEMATRIXDARBPROC epoxy_glLoadTransposeMatrixdARB = epoxy_glLoadTransposeMatrixdARB_global_rewrite_ptr;

PFNGLLOADTRANSPOSEMATRIXFPROC epoxy_glLoadTransposeMatrixf = epoxy_glLoadTransposeMatrixf_global_rewrite_ptr;

PFNGLLOADTRANSPOSEMATRIXFARBPROC epoxy_glLoadTransposeMatrixfARB = epoxy_glLoadTransposeMatrixfARB_global_rewrite_ptr;

PFNGLLOADTRANSPOSEMATRIXXOESPROC epoxy_glLoadTransposeMatrixxOES = epoxy_glLoadTransposeMatrixxOES_global_rewrite_ptr;

PFNGLLOCKARRAYSEXTPROC epoxy_glLockArraysEXT = epoxy_glLockArraysEXT_global_rewrite_ptr;

PFNGLLOGICOPPROC epoxy_glLogicOp = epoxy_glLogicOp_global_rewrite_ptr;

PFNGLMAKEBUFFERNONRESIDENTNVPROC epoxy_glMakeBufferNonResidentNV = epoxy_glMakeBufferNonResidentNV_global_rewrite_ptr;

PFNGLMAKEBUFFERRESIDENTNVPROC epoxy_glMakeBufferResidentNV = epoxy_glMakeBufferResidentNV_global_rewrite_ptr;

PFNGLMAKEIMAGEHANDLENONRESIDENTARBPROC epoxy_glMakeImageHandleNonResidentARB = epoxy_glMakeImageHandleNonResidentARB_global_rewrite_ptr;

PFNGLMAKEIMAGEHANDLENONRESIDENTNVPROC epoxy_glMakeImageHandleNonResidentNV = epoxy_glMakeImageHandleNonResidentNV_global_rewrite_ptr;

PFNGLMAKEIMAGEHANDLERESIDENTARBPROC epoxy_glMakeImageHandleResidentARB = epoxy_glMakeImageHandleResidentARB_global_rewrite_ptr;

PFNGLMAKEIMAGEHANDLERESIDENTNVPROC epoxy_glMakeImageHandleResidentNV = epoxy_glMakeImageHandleResidentNV_global_rewrite_ptr;

PFNGLMAKENAMEDBUFFERNONRESIDENTNVPROC epoxy_glMakeNamedBufferNonResidentNV = epoxy_glMakeNamedBufferNonResidentNV_global_rewrite_ptr;

PFNGLMAKENAMEDBUFFERRESIDENTNVPROC epoxy_glMakeNamedBufferResidentNV = epoxy_glMakeNamedBufferResidentNV_global_rewrite_ptr;

PFNGLMAKETEXTUREHANDLENONRESIDENTARBPROC epoxy_glMakeTextureHandleNonResidentARB = epoxy_glMakeTextureHandleNonResidentARB_global_rewrite_ptr;

PFNGLMAKETEXTUREHANDLENONRESIDENTNVPROC epoxy_glMakeTextureHandleNonResidentNV = epoxy_glMakeTextureHandleNonResidentNV_global_rewrite_ptr;

PFNGLMAKETEXTUREHANDLERESIDENTARBPROC epoxy_glMakeTextureHandleResidentARB = epoxy_glMakeTextureHandleResidentARB_global_rewrite_ptr;

PFNGLMAKETEXTUREHANDLERESIDENTNVPROC epoxy_glMakeTextureHandleResidentNV = epoxy_glMakeTextureHandleResidentNV_global_rewrite_ptr;

PFNGLMAP1DPROC epoxy_glMap1d = epoxy_glMap1d_global_rewrite_ptr;

PFNGLMAP1FPROC epoxy_glMap1f = epoxy_glMap1f_global_rewrite_ptr;

PFNGLMAP1XOESPROC epoxy_glMap1xOES = epoxy_glMap1xOES_global_rewrite_ptr;

PFNGLMAP2DPROC epoxy_glMap2d = epoxy_glMap2d_global_rewrite_ptr;

PFNGLMAP2FPROC epoxy_glMap2f = epoxy_glMap2f_global_rewrite_ptr;

PFNGLMAP2XOESPROC epoxy_glMap2xOES = epoxy_glMap2xOES_global_rewrite_ptr;

PFNGLMAPBUFFERPROC epoxy_glMapBuffer = epoxy_glMapBuffer_global_rewrite_ptr;

PFNGLMAPBUFFERARBPROC epoxy_glMapBufferARB = epoxy_glMapBufferARB_global_rewrite_ptr;

PFNGLMAPBUFFEROESPROC epoxy_glMapBufferOES = epoxy_glMapBufferOES_global_rewrite_ptr;

PFNGLMAPBUFFERRANGEPROC epoxy_glMapBufferRange = epoxy_glMapBufferRange_global_rewrite_ptr;

PFNGLMAPBUFFERRANGEEXTPROC epoxy_glMapBufferRangeEXT = epoxy_glMapBufferRangeEXT_global_rewrite_ptr;

PFNGLMAPCONTROLPOINTSNVPROC epoxy_glMapControlPointsNV = epoxy_glMapControlPointsNV_global_rewrite_ptr;

PFNGLMAPGRID1DPROC epoxy_glMapGrid1d = epoxy_glMapGrid1d_global_rewrite_ptr;

PFNGLMAPGRID1FPROC epoxy_glMapGrid1f = epoxy_glMapGrid1f_global_rewrite_ptr;

PFNGLMAPGRID1XOESPROC epoxy_glMapGrid1xOES = epoxy_glMapGrid1xOES_global_rewrite_ptr;

PFNGLMAPGRID2DPROC epoxy_glMapGrid2d = epoxy_glMapGrid2d_global_rewrite_ptr;

PFNGLMAPGRID2FPROC epoxy_glMapGrid2f = epoxy_glMapGrid2f_global_rewrite_ptr;

PFNGLMAPGRID2XOESPROC epoxy_glMapGrid2xOES = epoxy_glMapGrid2xOES_global_rewrite_ptr;

PFNGLMAPNAMEDBUFFERPROC epoxy_glMapNamedBuffer = epoxy_glMapNamedBuffer_global_rewrite_ptr;

PFNGLMAPNAMEDBUFFEREXTPROC epoxy_glMapNamedBufferEXT = epoxy_glMapNamedBufferEXT_global_rewrite_ptr;

PFNGLMAPNAMEDBUFFERRANGEPROC epoxy_glMapNamedBufferRange = epoxy_glMapNamedBufferRange_global_rewrite_ptr;

PFNGLMAPNAMEDBUFFERRANGEEXTPROC epoxy_glMapNamedBufferRangeEXT = epoxy_glMapNamedBufferRangeEXT_global_rewrite_ptr;

PFNGLMAPOBJECTBUFFERATIPROC epoxy_glMapObjectBufferATI = epoxy_glMapObjectBufferATI_global_rewrite_ptr;

PFNGLMAPPARAMETERFVNVPROC epoxy_glMapParameterfvNV = epoxy_glMapParameterfvNV_global_rewrite_ptr;

PFNGLMAPPARAMETERIVNVPROC epoxy_glMapParameterivNV = epoxy_glMapParameterivNV_global_rewrite_ptr;

PFNGLMAPTEXTURE2DINTELPROC epoxy_glMapTexture2DINTEL = epoxy_glMapTexture2DINTEL_global_rewrite_ptr;

PFNGLMAPVERTEXATTRIB1DAPPLEPROC epoxy_glMapVertexAttrib1dAPPLE = epoxy_glMapVertexAttrib1dAPPLE_global_rewrite_ptr;

PFNGLMAPVERTEXATTRIB1FAPPLEPROC epoxy_glMapVertexAttrib1fAPPLE = epoxy_glMapVertexAttrib1fAPPLE_global_rewrite_ptr;

PFNGLMAPVERTEXATTRIB2DAPPLEPROC epoxy_glMapVertexAttrib2dAPPLE = epoxy_glMapVertexAttrib2dAPPLE_global_rewrite_ptr;

PFNGLMAPVERTEXATTRIB2FAPPLEPROC epoxy_glMapVertexAttrib2fAPPLE = epoxy_glMapVertexAttrib2fAPPLE_global_rewrite_ptr;

PFNGLMATERIALFPROC epoxy_glMaterialf = epoxy_glMaterialf_global_rewrite_ptr;

PFNGLMATERIALFVPROC epoxy_glMaterialfv = epoxy_glMaterialfv_global_rewrite_ptr;

PFNGLMATERIALIPROC epoxy_glMateriali = epoxy_glMateriali_global_rewrite_ptr;

PFNGLMATERIALIVPROC epoxy_glMaterialiv = epoxy_glMaterialiv_global_rewrite_ptr;

PFNGLMATERIALXPROC epoxy_glMaterialx = epoxy_glMaterialx_global_rewrite_ptr;

PFNGLMATERIALXOESPROC epoxy_glMaterialxOES = epoxy_glMaterialxOES_global_rewrite_ptr;

PFNGLMATERIALXVPROC epoxy_glMaterialxv = epoxy_glMaterialxv_global_rewrite_ptr;

PFNGLMATERIALXVOESPROC epoxy_glMaterialxvOES = epoxy_glMaterialxvOES_global_rewrite_ptr;

PFNGLMATRIXFRUSTUMEXTPROC epoxy_glMatrixFrustumEXT = epoxy_glMatrixFrustumEXT_global_rewrite_ptr;

PFNGLMATRIXINDEXPOINTERARBPROC epoxy_glMatrixIndexPointerARB = epoxy_glMatrixIndexPointerARB_global_rewrite_ptr;

PFNGLMATRIXINDEXPOINTEROESPROC epoxy_glMatrixIndexPointerOES = epoxy_glMatrixIndexPointerOES_global_rewrite_ptr;

PFNGLMATRIXINDEXUBVARBPROC epoxy_glMatrixIndexubvARB = epoxy_glMatrixIndexubvARB_global_rewrite_ptr;

PFNGLMATRIXINDEXUIVARBPROC epoxy_glMatrixIndexuivARB = epoxy_glMatrixIndexuivARB_global_rewrite_ptr;

PFNGLMATRIXINDEXUSVARBPROC epoxy_glMatrixIndexusvARB = epoxy_glMatrixIndexusvARB_global_rewrite_ptr;

PFNGLMATRIXLOAD3X2FNVPROC epoxy_glMatrixLoad3x2fNV = epoxy_glMatrixLoad3x2fNV_global_rewrite_ptr;

PFNGLMATRIXLOAD3X3FNVPROC epoxy_glMatrixLoad3x3fNV = epoxy_glMatrixLoad3x3fNV_global_rewrite_ptr;

PFNGLMATRIXLOADIDENTITYEXTPROC epoxy_glMatrixLoadIdentityEXT = epoxy_glMatrixLoadIdentityEXT_global_rewrite_ptr;

PFNGLMATRIXLOADTRANSPOSE3X3FNVPROC epoxy_glMatrixLoadTranspose3x3fNV = epoxy_glMatrixLoadTranspose3x3fNV_global_rewrite_ptr;

PFNGLMATRIXLOADTRANSPOSEDEXTPROC epoxy_glMatrixLoadTransposedEXT = epoxy_glMatrixLoadTransposedEXT_global_rewrite_ptr;

PFNGLMATRIXLOADTRANSPOSEFEXTPROC epoxy_glMatrixLoadTransposefEXT = epoxy_glMatrixLoadTransposefEXT_global_rewrite_ptr;

PFNGLMATRIXLOADDEXTPROC epoxy_glMatrixLoaddEXT = epoxy_glMatrixLoaddEXT_global_rewrite_ptr;

PFNGLMATRIXLOADFEXTPROC epoxy_glMatrixLoadfEXT = epoxy_glMatrixLoadfEXT_global_rewrite_ptr;

PFNGLMATRIXMODEPROC epoxy_glMatrixMode = epoxy_glMatrixMode_global_rewrite_ptr;

PFNGLMATRIXMULT3X2FNVPROC epoxy_glMatrixMult3x2fNV = epoxy_glMatrixMult3x2fNV_global_rewrite_ptr;

PFNGLMATRIXMULT3X3FNVPROC epoxy_glMatrixMult3x3fNV = epoxy_glMatrixMult3x3fNV_global_rewrite_ptr;

PFNGLMATRIXMULTTRANSPOSE3X3FNVPROC epoxy_glMatrixMultTranspose3x3fNV = epoxy_glMatrixMultTranspose3x3fNV_global_rewrite_ptr;

PFNGLMATRIXMULTTRANSPOSEDEXTPROC epoxy_glMatrixMultTransposedEXT = epoxy_glMatrixMultTransposedEXT_global_rewrite_ptr;

PFNGLMATRIXMULTTRANSPOSEFEXTPROC epoxy_glMatrixMultTransposefEXT = epoxy_glMatrixMultTransposefEXT_global_rewrite_ptr;

PFNGLMATRIXMULTDEXTPROC epoxy_glMatrixMultdEXT = epoxy_glMatrixMultdEXT_global_rewrite_ptr;

PFNGLMATRIXMULTFEXTPROC epoxy_glMatrixMultfEXT = epoxy_glMatrixMultfEXT_global_rewrite_ptr;

PFNGLMATRIXORTHOEXTPROC epoxy_glMatrixOrthoEXT = epoxy_glMatrixOrthoEXT_global_rewrite_ptr;

PFNGLMATRIXPOPEXTPROC epoxy_glMatrixPopEXT = epoxy_glMatrixPopEXT_global_rewrite_ptr;

PFNGLMATRIXPUSHEXTPROC epoxy_glMatrixPushEXT = epoxy_glMatrixPushEXT_global_rewrite_ptr;

PFNGLMATRIXROTATEDEXTPROC epoxy_glMatrixRotatedEXT = epoxy_glMatrixRotatedEXT_global_rewrite_ptr;

PFNGLMATRIXROTATEFEXTPROC epoxy_glMatrixRotatefEXT = epoxy_glMatrixRotatefEXT_global_rewrite_ptr;

PFNGLMATRIXSCALEDEXTPROC epoxy_glMatrixScaledEXT = epoxy_glMatrixScaledEXT_global_rewrite_ptr;

PFNGLMATRIXSCALEFEXTPROC epoxy_glMatrixScalefEXT = epoxy_glMatrixScalefEXT_global_rewrite_ptr;

PFNGLMATRIXTRANSLATEDEXTPROC epoxy_glMatrixTranslatedEXT = epoxy_glMatrixTranslatedEXT_global_rewrite_ptr;

PFNGLMATRIXTRANSLATEFEXTPROC epoxy_glMatrixTranslatefEXT = epoxy_glMatrixTranslatefEXT_global_rewrite_ptr;

PFNGLMAXSHADERCOMPILERTHREADSARBPROC epoxy_glMaxShaderCompilerThreadsARB = epoxy_glMaxShaderCompilerThreadsARB_global_rewrite_ptr;

PFNGLMAXSHADERCOMPILERTHREADSKHRPROC epoxy_glMaxShaderCompilerThreadsKHR = epoxy_glMaxShaderCompilerThreadsKHR_global_rewrite_ptr;

PFNGLMEMORYBARRIERPROC epoxy_glMemoryBarrier = epoxy_glMemoryBarrier_global_rewrite_ptr;

PFNGLMEMORYBARRIERBYREGIONPROC epoxy_glMemoryBarrierByRegion = epoxy_glMemoryBarrierByRegion_global_rewrite_ptr;

PFNGLMEMORYBARRIEREXTPROC epoxy_glMemoryBarrierEXT = epoxy_glMemoryBarrierEXT_global_rewrite_ptr;

PFNGLMEMORYOBJECTPARAMETERIVEXTPROC epoxy_glMemoryObjectParameterivEXT = epoxy_glMemoryObjectParameterivEXT_global_rewrite_ptr;

PFNGLMINSAMPLESHADINGPROC epoxy_glMinSampleShading = epoxy_glMinSampleShading_global_rewrite_ptr;

PFNGLMINSAMPLESHADINGARBPROC epoxy_glMinSampleShadingARB = epoxy_glMinSampleShadingARB_global_rewrite_ptr;

PFNGLMINSAMPLESHADINGOESPROC epoxy_glMinSampleShadingOES = epoxy_glMinSampleShadingOES_global_rewrite_ptr;

PFNGLMINMAXPROC epoxy_glMinmax = epoxy_glMinmax_global_rewrite_ptr;

PFNGLMINMAXEXTPROC epoxy_glMinmaxEXT = epoxy_glMinmaxEXT_global_rewrite_ptr;

PFNGLMULTMATRIXDPROC epoxy_glMultMatrixd = epoxy_glMultMatrixd_global_rewrite_ptr;

PFNGLMULTMATRIXFPROC epoxy_glMultMatrixf = epoxy_glMultMatrixf_global_rewrite_ptr;

PFNGLMULTMATRIXXPROC epoxy_glMultMatrixx = epoxy_glMultMatrixx_global_rewrite_ptr;

PFNGLMULTMATRIXXOESPROC epoxy_glMultMatrixxOES = epoxy_glMultMatrixxOES_global_rewrite_ptr;

PFNGLMULTTRANSPOSEMATRIXDPROC epoxy_glMultTransposeMatrixd = epoxy_glMultTransposeMatrixd_global_rewrite_ptr;

PFNGLMULTTRANSPOSEMATRIXDARBPROC epoxy_glMultTransposeMatrixdARB = epoxy_glMultTransposeMatrixdARB_global_rewrite_ptr;

PFNGLMULTTRANSPOSEMATRIXFPROC epoxy_glMultTransposeMatrixf = epoxy_glMultTransposeMatrixf_global_rewrite_ptr;

PFNGLMULTTRANSPOSEMATRIXFARBPROC epoxy_glMultTransposeMatrixfARB = epoxy_glMultTransposeMatrixfARB_global_rewrite_ptr;

PFNGLMULTTRANSPOSEMATRIXXOESPROC epoxy_glMultTransposeMatrixxOES = epoxy_glMultTransposeMatrixxOES_global_rewrite_ptr;

PFNGLMULTIDRAWARRAYSPROC epoxy_glMultiDrawArrays = epoxy_glMultiDrawArrays_global_rewrite_ptr;

PFNGLMULTIDRAWARRAYSEXTPROC epoxy_glMultiDrawArraysEXT = epoxy_glMultiDrawArraysEXT_global_rewrite_ptr;

PFNGLMULTIDRAWARRAYSINDIRECTPROC epoxy_glMultiDrawArraysIndirect = epoxy_glMultiDrawArraysIndirect_global_rewrite_ptr;

PFNGLMULTIDRAWARRAYSINDIRECTAMDPROC epoxy_glMultiDrawArraysIndirectAMD = epoxy_glMultiDrawArraysIndirectAMD_global_rewrite_ptr;

PFNGLMULTIDRAWARRAYSINDIRECTBINDLESSCOUNTNVPROC epoxy_glMultiDrawArraysIndirectBindlessCountNV = epoxy_glMultiDrawArraysIndirectBindlessCountNV_global_rewrite_ptr;

PFNGLMULTIDRAWARRAYSINDIRECTBINDLESSNVPROC epoxy_glMultiDrawArraysIndirectBindlessNV = epoxy_glMultiDrawArraysIndirectBindlessNV_global_rewrite_ptr;

PFNGLMULTIDRAWARRAYSINDIRECTCOUNTPROC epoxy_glMultiDrawArraysIndirectCount = epoxy_glMultiDrawArraysIndirectCount_global_rewrite_ptr;

PFNGLMULTIDRAWARRAYSINDIRECTCOUNTARBPROC epoxy_glMultiDrawArraysIndirectCountARB = epoxy_glMultiDrawArraysIndirectCountARB_global_rewrite_ptr;

PFNGLMULTIDRAWARRAYSINDIRECTEXTPROC epoxy_glMultiDrawArraysIndirectEXT = epoxy_glMultiDrawArraysIndirectEXT_global_rewrite_ptr;

PFNGLMULTIDRAWELEMENTARRAYAPPLEPROC epoxy_glMultiDrawElementArrayAPPLE = epoxy_glMultiDrawElementArrayAPPLE_global_rewrite_ptr;

PFNGLMULTIDRAWELEMENTSPROC epoxy_glMultiDrawElements = epoxy_glMultiDrawElements_global_rewrite_ptr;

PFNGLMULTIDRAWELEMENTSBASEVERTEXPROC epoxy_glMultiDrawElementsBaseVertex = epoxy_glMultiDrawElementsBaseVertex_global_rewrite_ptr;

PFNGLMULTIDRAWELEMENTSBASEVERTEXEXTPROC epoxy_glMultiDrawElementsBaseVertexEXT = epoxy_glMultiDrawElementsBaseVertexEXT_global_rewrite_ptr;

PFNGLMULTIDRAWELEMENTSEXTPROC epoxy_glMultiDrawElementsEXT = epoxy_glMultiDrawElementsEXT_global_rewrite_ptr;

PFNGLMULTIDRAWELEMENTSINDIRECTPROC epoxy_glMultiDrawElementsIndirect = epoxy_glMultiDrawElementsIndirect_global_rewrite_ptr;

PFNGLMULTIDRAWELEMENTSINDIRECTAMDPROC epoxy_glMultiDrawElementsIndirectAMD = epoxy_glMultiDrawElementsIndirectAMD_global_rewrite_ptr;

PFNGLMULTIDRAWELEMENTSINDIRECTBINDLESSCOUNTNVPROC epoxy_glMultiDrawElementsIndirectBindlessCountNV = epoxy_glMultiDrawElementsIndirectBindlessCountNV_global_rewrite_ptr;

PFNGLMULTIDRAWELEMENTSINDIRECTBINDLESSNVPROC epoxy_glMultiDrawElementsIndirectBindlessNV = epoxy_glMultiDrawElementsIndirectBindlessNV_global_rewrite_ptr;

PFNGLMULTIDRAWELEMENTSINDIRECTCOUNTPROC epoxy_glMultiDrawElementsIndirectCount = epoxy_glMultiDrawElementsIndirectCount_global_rewrite_ptr;

PFNGLMULTIDRAWELEMENTSINDIRECTCOUNTARBPROC epoxy_glMultiDrawElementsIndirectCountARB = epoxy_glMultiDrawElementsIndirectCountARB_global_rewrite_ptr;

PFNGLMULTIDRAWELEMENTSINDIRECTEXTPROC epoxy_glMultiDrawElementsIndirectEXT = epoxy_glMultiDrawElementsIndirectEXT_global_rewrite_ptr;

PFNGLMULTIDRAWMESHTASKSINDIRECTCOUNTNVPROC epoxy_glMultiDrawMeshTasksIndirectCountNV = epoxy_glMultiDrawMeshTasksIndirectCountNV_global_rewrite_ptr;

PFNGLMULTIDRAWMESHTASKSINDIRECTNVPROC epoxy_glMultiDrawMeshTasksIndirectNV = epoxy_glMultiDrawMeshTasksIndirectNV_global_rewrite_ptr;

PFNGLMULTIDRAWRANGEELEMENTARRAYAPPLEPROC epoxy_glMultiDrawRangeElementArrayAPPLE = epoxy_glMultiDrawRangeElementArrayAPPLE_global_rewrite_ptr;

PFNGLMULTIMODEDRAWARRAYSIBMPROC epoxy_glMultiModeDrawArraysIBM = epoxy_glMultiModeDrawArraysIBM_global_rewrite_ptr;

PFNGLMULTIMODEDRAWELEMENTSIBMPROC epoxy_glMultiModeDrawElementsIBM = epoxy_glMultiModeDrawElementsIBM_global_rewrite_ptr;

PFNGLMULTITEXBUFFEREXTPROC epoxy_glMultiTexBufferEXT = epoxy_glMultiTexBufferEXT_global_rewrite_ptr;

PFNGLMULTITEXCOORD1BOESPROC epoxy_glMultiTexCoord1bOES = epoxy_glMultiTexCoord1bOES_global_rewrite_ptr;

PFNGLMULTITEXCOORD1BVOESPROC epoxy_glMultiTexCoord1bvOES = epoxy_glMultiTexCoord1bvOES_global_rewrite_ptr;

PFNGLMULTITEXCOORD1DPROC epoxy_glMultiTexCoord1d = epoxy_glMultiTexCoord1d_global_rewrite_ptr;

PFNGLMULTITEXCOORD1DARBPROC epoxy_glMultiTexCoord1dARB = epoxy_glMultiTexCoord1dARB_global_rewrite_ptr;

PFNGLMULTITEXCOORD1DVPROC epoxy_glMultiTexCoord1dv = epoxy_glMultiTexCoord1dv_global_rewrite_ptr;

PFNGLMULTITEXCOORD1DVARBPROC epoxy_glMultiTexCoord1dvARB = epoxy_glMultiTexCoord1dvARB_global_rewrite_ptr;

PFNGLMULTITEXCOORD1FPROC epoxy_glMultiTexCoord1f = epoxy_glMultiTexCoord1f_global_rewrite_ptr;

PFNGLMULTITEXCOORD1FARBPROC epoxy_glMultiTexCoord1fARB = epoxy_glMultiTexCoord1fARB_global_rewrite_ptr;

PFNGLMULTITEXCOORD1FVPROC epoxy_glMultiTexCoord1fv = epoxy_glMultiTexCoord1fv_global_rewrite_ptr;

PFNGLMULTITEXCOORD1FVARBPROC epoxy_glMultiTexCoord1fvARB = epoxy_glMultiTexCoord1fvARB_global_rewrite_ptr;

PFNGLMULTITEXCOORD1HNVPROC epoxy_glMultiTexCoord1hNV = epoxy_glMultiTexCoord1hNV_global_rewrite_ptr;

PFNGLMULTITEXCOORD1HVNVPROC epoxy_glMultiTexCoord1hvNV = epoxy_glMultiTexCoord1hvNV_global_rewrite_ptr;

PFNGLMULTITEXCOORD1IPROC epoxy_glMultiTexCoord1i = epoxy_glMultiTexCoord1i_global_rewrite_ptr;

PFNGLMULTITEXCOORD1IARBPROC epoxy_glMultiTexCoord1iARB = epoxy_glMultiTexCoord1iARB_global_rewrite_ptr;

PFNGLMULTITEXCOORD1IVPROC epoxy_glMultiTexCoord1iv = epoxy_glMultiTexCoord1iv_global_rewrite_ptr;

PFNGLMULTITEXCOORD1IVARBPROC epoxy_glMultiTexCoord1ivARB = epoxy_glMultiTexCoord1ivARB_global_rewrite_ptr;

PFNGLMULTITEXCOORD1SPROC epoxy_glMultiTexCoord1s = epoxy_glMultiTexCoord1s_global_rewrite_ptr;

PFNGLMULTITEXCOORD1SARBPROC epoxy_glMultiTexCoord1sARB = epoxy_glMultiTexCoord1sARB_global_rewrite_ptr;

PFNGLMULTITEXCOORD1SVPROC epoxy_glMultiTexCoord1sv = epoxy_glMultiTexCoord1sv_global_rewrite_ptr;

PFNGLMULTITEXCOORD1SVARBPROC epoxy_glMultiTexCoord1svARB = epoxy_glMultiTexCoord1svARB_global_rewrite_ptr;

PFNGLMULTITEXCOORD1XOESPROC epoxy_glMultiTexCoord1xOES = epoxy_glMultiTexCoord1xOES_global_rewrite_ptr;

PFNGLMULTITEXCOORD1XVOESPROC epoxy_glMultiTexCoord1xvOES = epoxy_glMultiTexCoord1xvOES_global_rewrite_ptr;

PFNGLMULTITEXCOORD2BOESPROC epoxy_glMultiTexCoord2bOES = epoxy_glMultiTexCoord2bOES_global_rewrite_ptr;

PFNGLMULTITEXCOORD2BVOESPROC epoxy_glMultiTexCoord2bvOES = epoxy_glMultiTexCoord2bvOES_global_rewrite_ptr;

PFNGLMULTITEXCOORD2DPROC epoxy_glMultiTexCoord2d = epoxy_glMultiTexCoord2d_global_rewrite_ptr;

PFNGLMULTITEXCOORD2DARBPROC epoxy_glMultiTexCoord2dARB = epoxy_glMultiTexCoord2dARB_global_rewrite_ptr;

PFNGLMULTITEXCOORD2DVPROC epoxy_glMultiTexCoord2dv = epoxy_glMultiTexCoord2dv_global_rewrite_ptr;

PFNGLMULTITEXCOORD2DVARBPROC epoxy_glMultiTexCoord2dvARB = epoxy_glMultiTexCoord2dvARB_global_rewrite_ptr;

PFNGLMULTITEXCOORD2FPROC epoxy_glMultiTexCoord2f = epoxy_glMultiTexCoord2f_global_rewrite_ptr;

PFNGLMULTITEXCOORD2FARBPROC epoxy_glMultiTexCoord2fARB = epoxy_glMultiTexCoord2fARB_global_rewrite_ptr;

PFNGLMULTITEXCOORD2FVPROC epoxy_glMultiTexCoord2fv = epoxy_glMultiTexCoord2fv_global_rewrite_ptr;

PFNGLMULTITEXCOORD2FVARBPROC epoxy_glMultiTexCoord2fvARB = epoxy_glMultiTexCoord2fvARB_global_rewrite_ptr;

PFNGLMULTITEXCOORD2HNVPROC epoxy_glMultiTexCoord2hNV = epoxy_glMultiTexCoord2hNV_global_rewrite_ptr;

PFNGLMULTITEXCOORD2HVNVPROC epoxy_glMultiTexCoord2hvNV = epoxy_glMultiTexCoord2hvNV_global_rewrite_ptr;

PFNGLMULTITEXCOORD2IPROC epoxy_glMultiTexCoord2i = epoxy_glMultiTexCoord2i_global_rewrite_ptr;

PFNGLMULTITEXCOORD2IARBPROC epoxy_glMultiTexCoord2iARB = epoxy_glMultiTexCoord2iARB_global_rewrite_ptr;

PFNGLMULTITEXCOORD2IVPROC epoxy_glMultiTexCoord2iv = epoxy_glMultiTexCoord2iv_global_rewrite_ptr;

PFNGLMULTITEXCOORD2IVARBPROC epoxy_glMultiTexCoord2ivARB = epoxy_glMultiTexCoord2ivARB_global_rewrite_ptr;

PFNGLMULTITEXCOORD2SPROC epoxy_glMultiTexCoord2s = epoxy_glMultiTexCoord2s_global_rewrite_ptr;

PFNGLMULTITEXCOORD2SARBPROC epoxy_glMultiTexCoord2sARB = epoxy_glMultiTexCoord2sARB_global_rewrite_ptr;

PFNGLMULTITEXCOORD2SVPROC epoxy_glMultiTexCoord2sv = epoxy_glMultiTexCoord2sv_global_rewrite_ptr;

PFNGLMULTITEXCOORD2SVARBPROC epoxy_glMultiTexCoord2svARB = epoxy_glMultiTexCoord2svARB_global_rewrite_ptr;

PFNGLMULTITEXCOORD2XOESPROC epoxy_glMultiTexCoord2xOES = epoxy_glMultiTexCoord2xOES_global_rewrite_ptr;

PFNGLMULTITEXCOORD2XVOESPROC epoxy_glMultiTexCoord2xvOES = epoxy_glMultiTexCoord2xvOES_global_rewrite_ptr;

PFNGLMULTITEXCOORD3BOESPROC epoxy_glMultiTexCoord3bOES = epoxy_glMultiTexCoord3bOES_global_rewrite_ptr;

PFNGLMULTITEXCOORD3BVOESPROC epoxy_glMultiTexCoord3bvOES = epoxy_glMultiTexCoord3bvOES_global_rewrite_ptr;

PFNGLMULTITEXCOORD3DPROC epoxy_glMultiTexCoord3d = epoxy_glMultiTexCoord3d_global_rewrite_ptr;

PFNGLMULTITEXCOORD3DARBPROC epoxy_glMultiTexCoord3dARB = epoxy_glMultiTexCoord3dARB_global_rewrite_ptr;

PFNGLMULTITEXCOORD3DVPROC epoxy_glMultiTexCoord3dv = epoxy_glMultiTexCoord3dv_global_rewrite_ptr;

PFNGLMULTITEXCOORD3DVARBPROC epoxy_glMultiTexCoord3dvARB = epoxy_glMultiTexCoord3dvARB_global_rewrite_ptr;

PFNGLMULTITEXCOORD3FPROC epoxy_glMultiTexCoord3f = epoxy_glMultiTexCoord3f_global_rewrite_ptr;

PFNGLMULTITEXCOORD3FARBPROC epoxy_glMultiTexCoord3fARB = epoxy_glMultiTexCoord3fARB_global_rewrite_ptr;

PFNGLMULTITEXCOORD3FVPROC epoxy_glMultiTexCoord3fv = epoxy_glMultiTexCoord3fv_global_rewrite_ptr;

PFNGLMULTITEXCOORD3FVARBPROC epoxy_glMultiTexCoord3fvARB = epoxy_glMultiTexCoord3fvARB_global_rewrite_ptr;

PFNGLMULTITEXCOORD3HNVPROC epoxy_glMultiTexCoord3hNV = epoxy_glMultiTexCoord3hNV_global_rewrite_ptr;

PFNGLMULTITEXCOORD3HVNVPROC epoxy_glMultiTexCoord3hvNV = epoxy_glMultiTexCoord3hvNV_global_rewrite_ptr;

PFNGLMULTITEXCOORD3IPROC epoxy_glMultiTexCoord3i = epoxy_glMultiTexCoord3i_global_rewrite_ptr;

PFNGLMULTITEXCOORD3IARBPROC epoxy_glMultiTexCoord3iARB = epoxy_glMultiTexCoord3iARB_global_rewrite_ptr;

PFNGLMULTITEXCOORD3IVPROC epoxy_glMultiTexCoord3iv = epoxy_glMultiTexCoord3iv_global_rewrite_ptr;

PFNGLMULTITEXCOORD3IVARBPROC epoxy_glMultiTexCoord3ivARB = epoxy_glMultiTexCoord3ivARB_global_rewrite_ptr;

PFNGLMULTITEXCOORD3SPROC epoxy_glMultiTexCoord3s = epoxy_glMultiTexCoord3s_global_rewrite_ptr;

PFNGLMULTITEXCOORD3SARBPROC epoxy_glMultiTexCoord3sARB = epoxy_glMultiTexCoord3sARB_global_rewrite_ptr;

PFNGLMULTITEXCOORD3SVPROC epoxy_glMultiTexCoord3sv = epoxy_glMultiTexCoord3sv_global_rewrite_ptr;

PFNGLMULTITEXCOORD3SVARBPROC epoxy_glMultiTexCoord3svARB = epoxy_glMultiTexCoord3svARB_global_rewrite_ptr;

PFNGLMULTITEXCOORD3XOESPROC epoxy_glMultiTexCoord3xOES = epoxy_glMultiTexCoord3xOES_global_rewrite_ptr;

PFNGLMULTITEXCOORD3XVOESPROC epoxy_glMultiTexCoord3xvOES = epoxy_glMultiTexCoord3xvOES_global_rewrite_ptr;

PFNGLMULTITEXCOORD4BOESPROC epoxy_glMultiTexCoord4bOES = epoxy_glMultiTexCoord4bOES_global_rewrite_ptr;

PFNGLMULTITEXCOORD4BVOESPROC epoxy_glMultiTexCoord4bvOES = epoxy_glMultiTexCoord4bvOES_global_rewrite_ptr;

PFNGLMULTITEXCOORD4DPROC epoxy_glMultiTexCoord4d = epoxy_glMultiTexCoord4d_global_rewrite_ptr;

PFNGLMULTITEXCOORD4DARBPROC epoxy_glMultiTexCoord4dARB = epoxy_glMultiTexCoord4dARB_global_rewrite_ptr;

PFNGLMULTITEXCOORD4DVPROC epoxy_glMultiTexCoord4dv = epoxy_glMultiTexCoord4dv_global_rewrite_ptr;

PFNGLMULTITEXCOORD4DVARBPROC epoxy_glMultiTexCoord4dvARB = epoxy_glMultiTexCoord4dvARB_global_rewrite_ptr;

PFNGLMULTITEXCOORD4FPROC epoxy_glMultiTexCoord4f = epoxy_glMultiTexCoord4f_global_rewrite_ptr;

PFNGLMULTITEXCOORD4FARBPROC epoxy_glMultiTexCoord4fARB = epoxy_glMultiTexCoord4fARB_global_rewrite_ptr;

PFNGLMULTITEXCOORD4FVPROC epoxy_glMultiTexCoord4fv = epoxy_glMultiTexCoord4fv_global_rewrite_ptr;

PFNGLMULTITEXCOORD4FVARBPROC epoxy_glMultiTexCoord4fvARB = epoxy_glMultiTexCoord4fvARB_global_rewrite_ptr;

PFNGLMULTITEXCOORD4HNVPROC epoxy_glMultiTexCoord4hNV = epoxy_glMultiTexCoord4hNV_global_rewrite_ptr;

PFNGLMULTITEXCOORD4HVNVPROC epoxy_glMultiTexCoord4hvNV = epoxy_glMultiTexCoord4hvNV_global_rewrite_ptr;

PFNGLMULTITEXCOORD4IPROC epoxy_glMultiTexCoord4i = epoxy_glMultiTexCoord4i_global_rewrite_ptr;

PFNGLMULTITEXCOORD4IARBPROC epoxy_glMultiTexCoord4iARB = epoxy_glMultiTexCoord4iARB_global_rewrite_ptr;

PFNGLMULTITEXCOORD4IVPROC epoxy_glMultiTexCoord4iv = epoxy_glMultiTexCoord4iv_global_rewrite_ptr;

PFNGLMULTITEXCOORD4IVARBPROC epoxy_glMultiTexCoord4ivARB = epoxy_glMultiTexCoord4ivARB_global_rewrite_ptr;

PFNGLMULTITEXCOORD4SPROC epoxy_glMultiTexCoord4s = epoxy_glMultiTexCoord4s_global_rewrite_ptr;

PFNGLMULTITEXCOORD4SARBPROC epoxy_glMultiTexCoord4sARB = epoxy_glMultiTexCoord4sARB_global_rewrite_ptr;

PFNGLMULTITEXCOORD4SVPROC epoxy_glMultiTexCoord4sv = epoxy_glMultiTexCoord4sv_global_rewrite_ptr;

PFNGLMULTITEXCOORD4SVARBPROC epoxy_glMultiTexCoord4svARB = epoxy_glMultiTexCoord4svARB_global_rewrite_ptr;

PFNGLMULTITEXCOORD4XPROC epoxy_glMultiTexCoord4x = epoxy_glMultiTexCoord4x_global_rewrite_ptr;

PFNGLMULTITEXCOORD4XOESPROC epoxy_glMultiTexCoord4xOES = epoxy_glMultiTexCoord4xOES_global_rewrite_ptr;

PFNGLMULTITEXCOORD4XVOESPROC epoxy_glMultiTexCoord4xvOES = epoxy_glMultiTexCoord4xvOES_global_rewrite_ptr;

PFNGLMULTITEXCOORDP1UIPROC epoxy_glMultiTexCoordP1ui = epoxy_glMultiTexCoordP1ui_global_rewrite_ptr;

PFNGLMULTITEXCOORDP1UIVPROC epoxy_glMultiTexCoordP1uiv = epoxy_glMultiTexCoordP1uiv_global_rewrite_ptr;

PFNGLMULTITEXCOORDP2UIPROC epoxy_glMultiTexCoordP2ui = epoxy_glMultiTexCoordP2ui_global_rewrite_ptr;

PFNGLMULTITEXCOORDP2UIVPROC epoxy_glMultiTexCoordP2uiv = epoxy_glMultiTexCoordP2uiv_global_rewrite_ptr;

PFNGLMULTITEXCOORDP3UIPROC epoxy_glMultiTexCoordP3ui = epoxy_glMultiTexCoordP3ui_global_rewrite_ptr;

PFNGLMULTITEXCOORDP3UIVPROC epoxy_glMultiTexCoordP3uiv = epoxy_glMultiTexCoordP3uiv_global_rewrite_ptr;

PFNGLMULTITEXCOORDP4UIPROC epoxy_glMultiTexCoordP4ui = epoxy_glMultiTexCoordP4ui_global_rewrite_ptr;

PFNGLMULTITEXCOORDP4UIVPROC epoxy_glMultiTexCoordP4uiv = epoxy_glMultiTexCoordP4uiv_global_rewrite_ptr;

PFNGLMULTITEXCOORDPOINTEREXTPROC epoxy_glMultiTexCoordPointerEXT = epoxy_glMultiTexCoordPointerEXT_global_rewrite_ptr;

PFNGLMULTITEXENVFEXTPROC epoxy_glMultiTexEnvfEXT = epoxy_glMultiTexEnvfEXT_global_rewrite_ptr;

PFNGLMULTITEXENVFVEXTPROC epoxy_glMultiTexEnvfvEXT = epoxy_glMultiTexEnvfvEXT_global_rewrite_ptr;

PFNGLMULTITEXENVIEXTPROC epoxy_glMultiTexEnviEXT = epoxy_glMultiTexEnviEXT_global_rewrite_ptr;

PFNGLMULTITEXENVIVEXTPROC epoxy_glMultiTexEnvivEXT = epoxy_glMultiTexEnvivEXT_global_rewrite_ptr;

PFNGLMULTITEXGENDEXTPROC epoxy_glMultiTexGendEXT = epoxy_glMultiTexGendEXT_global_rewrite_ptr;

PFNGLMULTITEXGENDVEXTPROC epoxy_glMultiTexGendvEXT = epoxy_glMultiTexGendvEXT_global_rewrite_ptr;

PFNGLMULTITEXGENFEXTPROC epoxy_glMultiTexGenfEXT = epoxy_glMultiTexGenfEXT_global_rewrite_ptr;

PFNGLMULTITEXGENFVEXTPROC epoxy_glMultiTexGenfvEXT = epoxy_glMultiTexGenfvEXT_global_rewrite_ptr;

PFNGLMULTITEXGENIEXTPROC epoxy_glMultiTexGeniEXT = epoxy_glMultiTexGeniEXT_global_rewrite_ptr;

PFNGLMULTITEXGENIVEXTPROC epoxy_glMultiTexGenivEXT = epoxy_glMultiTexGenivEXT_global_rewrite_ptr;

PFNGLMULTITEXIMAGE1DEXTPROC epoxy_glMultiTexImage1DEXT = epoxy_glMultiTexImage1DEXT_global_rewrite_ptr;

PFNGLMULTITEXIMAGE2DEXTPROC epoxy_glMultiTexImage2DEXT = epoxy_glMultiTexImage2DEXT_global_rewrite_ptr;

PFNGLMULTITEXIMAGE3DEXTPROC epoxy_glMultiTexImage3DEXT = epoxy_glMultiTexImage3DEXT_global_rewrite_ptr;

PFNGLMULTITEXPARAMETERIIVEXTPROC epoxy_glMultiTexParameterIivEXT = epoxy_glMultiTexParameterIivEXT_global_rewrite_ptr;

PFNGLMULTITEXPARAMETERIUIVEXTPROC epoxy_glMultiTexParameterIuivEXT = epoxy_glMultiTexParameterIuivEXT_global_rewrite_ptr;

PFNGLMULTITEXPARAMETERFEXTPROC epoxy_glMultiTexParameterfEXT = epoxy_glMultiTexParameterfEXT_global_rewrite_ptr;

PFNGLMULTITEXPARAMETERFVEXTPROC epoxy_glMultiTexParameterfvEXT = epoxy_glMultiTexParameterfvEXT_global_rewrite_ptr;

PFNGLMULTITEXPARAMETERIEXTPROC epoxy_glMultiTexParameteriEXT = epoxy_glMultiTexParameteriEXT_global_rewrite_ptr;

PFNGLMULTITEXPARAMETERIVEXTPROC epoxy_glMultiTexParameterivEXT = epoxy_glMultiTexParameterivEXT_global_rewrite_ptr;

PFNGLMULTITEXRENDERBUFFEREXTPROC epoxy_glMultiTexRenderbufferEXT = epoxy_glMultiTexRenderbufferEXT_global_rewrite_ptr;

PFNGLMULTITEXSUBIMAGE1DEXTPROC epoxy_glMultiTexSubImage1DEXT = epoxy_glMultiTexSubImage1DEXT_global_rewrite_ptr;

PFNGLMULTITEXSUBIMAGE2DEXTPROC epoxy_glMultiTexSubImage2DEXT = epoxy_glMultiTexSubImage2DEXT_global_rewrite_ptr;

PFNGLMULTITEXSUBIMAGE3DEXTPROC epoxy_glMultiTexSubImage3DEXT = epoxy_glMultiTexSubImage3DEXT_global_rewrite_ptr;

PFNGLMULTICASTBARRIERNVPROC epoxy_glMulticastBarrierNV = epoxy_glMulticastBarrierNV_global_rewrite_ptr;

PFNGLMULTICASTBLITFRAMEBUFFERNVPROC epoxy_glMulticastBlitFramebufferNV = epoxy_glMulticastBlitFramebufferNV_global_rewrite_ptr;

PFNGLMULTICASTBUFFERSUBDATANVPROC epoxy_glMulticastBufferSubDataNV = epoxy_glMulticastBufferSubDataNV_global_rewrite_ptr;

PFNGLMULTICASTCOPYBUFFERSUBDATANVPROC epoxy_glMulticastCopyBufferSubDataNV = epoxy_glMulticastCopyBufferSubDataNV_global_rewrite_ptr;

PFNGLMULTICASTCOPYIMAGESUBDATANVPROC epoxy_glMulticastCopyImageSubDataNV = epoxy_glMulticastCopyImageSubDataNV_global_rewrite_ptr;

PFNGLMULTICASTFRAMEBUFFERSAMPLELOCATIONSFVNVPROC epoxy_glMulticastFramebufferSampleLocationsfvNV = epoxy_glMulticastFramebufferSampleLocationsfvNV_global_rewrite_ptr;

PFNGLMULTICASTGETQUERYOBJECTI64VNVPROC epoxy_glMulticastGetQueryObjecti64vNV = epoxy_glMulticastGetQueryObjecti64vNV_global_rewrite_ptr;

PFNGLMULTICASTGETQUERYOBJECTIVNVPROC epoxy_glMulticastGetQueryObjectivNV = epoxy_glMulticastGetQueryObjectivNV_global_rewrite_ptr;

PFNGLMULTICASTGETQUERYOBJECTUI64VNVPROC epoxy_glMulticastGetQueryObjectui64vNV = epoxy_glMulticastGetQueryObjectui64vNV_global_rewrite_ptr;

PFNGLMULTICASTGETQUERYOBJECTUIVNVPROC epoxy_glMulticastGetQueryObjectuivNV = epoxy_glMulticastGetQueryObjectuivNV_global_rewrite_ptr;

PFNGLMULTICASTSCISSORARRAYVNVXPROC epoxy_glMulticastScissorArrayvNVX = epoxy_glMulticastScissorArrayvNVX_global_rewrite_ptr;

PFNGLMULTICASTVIEWPORTARRAYVNVXPROC epoxy_glMulticastViewportArrayvNVX = epoxy_glMulticastViewportArrayvNVX_global_rewrite_ptr;

PFNGLMULTICASTVIEWPORTPOSITIONWSCALENVXPROC epoxy_glMulticastViewportPositionWScaleNVX = epoxy_glMulticastViewportPositionWScaleNVX_global_rewrite_ptr;

PFNGLMULTICASTWAITSYNCNVPROC epoxy_glMulticastWaitSyncNV = epoxy_glMulticastWaitSyncNV_global_rewrite_ptr;

PFNGLNAMEDBUFFERATTACHMEMORYNVPROC epoxy_glNamedBufferAttachMemoryNV = epoxy_glNamedBufferAttachMemoryNV_global_rewrite_ptr;

PFNGLNAMEDBUFFERDATAPROC epoxy_glNamedBufferData = epoxy_glNamedBufferData_global_rewrite_ptr;

PFNGLNAMEDBUFFERDATAEXTPROC epoxy_glNamedBufferDataEXT = epoxy_glNamedBufferDataEXT_global_rewrite_ptr;

PFNGLNAMEDBUFFERPAGECOMMITMENTARBPROC epoxy_glNamedBufferPageCommitmentARB = epoxy_glNamedBufferPageCommitmentARB_global_rewrite_ptr;

PFNGLNAMEDBUFFERPAGECOMMITMENTEXTPROC epoxy_glNamedBufferPageCommitmentEXT = epoxy_glNamedBufferPageCommitmentEXT_global_rewrite_ptr;

PFNGLNAMEDBUFFERSTORAGEPROC epoxy_glNamedBufferStorage = epoxy_glNamedBufferStorage_global_rewrite_ptr;

PFNGLNAMEDBUFFERSTORAGEEXTPROC epoxy_glNamedBufferStorageEXT = epoxy_glNamedBufferStorageEXT_global_rewrite_ptr;

PFNGLNAMEDBUFFERSTORAGEEXTERNALEXTPROC epoxy_glNamedBufferStorageExternalEXT = epoxy_glNamedBufferStorageExternalEXT_global_rewrite_ptr;

PFNGLNAMEDBUFFERSTORAGEMEMEXTPROC epoxy_glNamedBufferStorageMemEXT = epoxy_glNamedBufferStorageMemEXT_global_rewrite_ptr;

PFNGLNAMEDBUFFERSUBDATAPROC epoxy_glNamedBufferSubData = epoxy_glNamedBufferSubData_global_rewrite_ptr;

PFNGLNAMEDBUFFERSUBDATAEXTPROC epoxy_glNamedBufferSubDataEXT = epoxy_glNamedBufferSubDataEXT_global_rewrite_ptr;

PFNGLNAMEDCOPYBUFFERSUBDATAEXTPROC epoxy_glNamedCopyBufferSubDataEXT = epoxy_glNamedCopyBufferSubDataEXT_global_rewrite_ptr;

PFNGLNAMEDFRAMEBUFFERDRAWBUFFERPROC epoxy_glNamedFramebufferDrawBuffer = epoxy_glNamedFramebufferDrawBuffer_global_rewrite_ptr;

PFNGLNAMEDFRAMEBUFFERDRAWBUFFERSPROC epoxy_glNamedFramebufferDrawBuffers = epoxy_glNamedFramebufferDrawBuffers_global_rewrite_ptr;

PFNGLNAMEDFRAMEBUFFERPARAMETERIPROC epoxy_glNamedFramebufferParameteri = epoxy_glNamedFramebufferParameteri_global_rewrite_ptr;

PFNGLNAMEDFRAMEBUFFERPARAMETERIEXTPROC epoxy_glNamedFramebufferParameteriEXT = epoxy_glNamedFramebufferParameteriEXT_global_rewrite_ptr;

PFNGLNAMEDFRAMEBUFFERREADBUFFERPROC epoxy_glNamedFramebufferReadBuffer = epoxy_glNamedFramebufferReadBuffer_global_rewrite_ptr;

PFNGLNAMEDFRAMEBUFFERRENDERBUFFERPROC epoxy_glNamedFramebufferRenderbuffer = epoxy_glNamedFramebufferRenderbuffer_global_rewrite_ptr;

PFNGLNAMEDFRAMEBUFFERRENDERBUFFEREXTPROC epoxy_glNamedFramebufferRenderbufferEXT = epoxy_glNamedFramebufferRenderbufferEXT_global_rewrite_ptr;

PFNGLNAMEDFRAMEBUFFERSAMPLELOCATIONSFVARBPROC epoxy_glNamedFramebufferSampleLocationsfvARB = epoxy_glNamedFramebufferSampleLocationsfvARB_global_rewrite_ptr;

PFNGLNAMEDFRAMEBUFFERSAMPLELOCATIONSFVNVPROC epoxy_glNamedFramebufferSampleLocationsfvNV = epoxy_glNamedFramebufferSampleLocationsfvNV_global_rewrite_ptr;

PFNGLNAMEDFRAMEBUFFERSAMPLEPOSITIONSFVAMDPROC epoxy_glNamedFramebufferSamplePositionsfvAMD = epoxy_glNamedFramebufferSamplePositionsfvAMD_global_rewrite_ptr;

PFNGLNAMEDFRAMEBUFFERTEXTUREPROC epoxy_glNamedFramebufferTexture = epoxy_glNamedFramebufferTexture_global_rewrite_ptr;

PFNGLNAMEDFRAMEBUFFERTEXTURE1DEXTPROC epoxy_glNamedFramebufferTexture1DEXT = epoxy_glNamedFramebufferTexture1DEXT_global_rewrite_ptr;

PFNGLNAMEDFRAMEBUFFERTEXTURE2DEXTPROC epoxy_glNamedFramebufferTexture2DEXT = epoxy_glNamedFramebufferTexture2DEXT_global_rewrite_ptr;

PFNGLNAMEDFRAMEBUFFERTEXTURE3DEXTPROC epoxy_glNamedFramebufferTexture3DEXT = epoxy_glNamedFramebufferTexture3DEXT_global_rewrite_ptr;

PFNGLNAMEDFRAMEBUFFERTEXTUREEXTPROC epoxy_glNamedFramebufferTextureEXT = epoxy_glNamedFramebufferTextureEXT_global_rewrite_ptr;

PFNGLNAMEDFRAMEBUFFERTEXTUREFACEEXTPROC epoxy_glNamedFramebufferTextureFaceEXT = epoxy_glNamedFramebufferTextureFaceEXT_global_rewrite_ptr;

PFNGLNAMEDFRAMEBUFFERTEXTURELAYERPROC epoxy_glNamedFramebufferTextureLayer = epoxy_glNamedFramebufferTextureLayer_global_rewrite_ptr;

PFNGLNAMEDFRAMEBUFFERTEXTURELAYEREXTPROC epoxy_glNamedFramebufferTextureLayerEXT = epoxy_glNamedFramebufferTextureLayerEXT_global_rewrite_ptr;

PFNGLNAMEDPROGRAMLOCALPARAMETER4DEXTPROC epoxy_glNamedProgramLocalParameter4dEXT = epoxy_glNamedProgramLocalParameter4dEXT_global_rewrite_ptr;

PFNGLNAMEDPROGRAMLOCALPARAMETER4DVEXTPROC epoxy_glNamedProgramLocalParameter4dvEXT = epoxy_glNamedProgramLocalParameter4dvEXT_global_rewrite_ptr;

PFNGLNAMEDPROGRAMLOCALPARAMETER4FEXTPROC epoxy_glNamedProgramLocalParameter4fEXT = epoxy_glNamedProgramLocalParameter4fEXT_global_rewrite_ptr;

PFNGLNAMEDPROGRAMLOCALPARAMETER4FVEXTPROC epoxy_glNamedProgramLocalParameter4fvEXT = epoxy_glNamedProgramLocalParameter4fvEXT_global_rewrite_ptr;

PFNGLNAMEDPROGRAMLOCALPARAMETERI4IEXTPROC epoxy_glNamedProgramLocalParameterI4iEXT = epoxy_glNamedProgramLocalParameterI4iEXT_global_rewrite_ptr;

PFNGLNAMEDPROGRAMLOCALPARAMETERI4IVEXTPROC epoxy_glNamedProgramLocalParameterI4ivEXT = epoxy_glNamedProgramLocalParameterI4ivEXT_global_rewrite_ptr;

PFNGLNAMEDPROGRAMLOCALPARAMETERI4UIEXTPROC epoxy_glNamedProgramLocalParameterI4uiEXT = epoxy_glNamedProgramLocalParameterI4uiEXT_global_rewrite_ptr;

PFNGLNAMEDPROGRAMLOCALPARAMETERI4UIVEXTPROC epoxy_glNamedProgramLocalParameterI4uivEXT = epoxy_glNamedProgramLocalParameterI4uivEXT_global_rewrite_ptr;

PFNGLNAMEDPROGRAMLOCALPARAMETERS4FVEXTPROC epoxy_glNamedProgramLocalParameters4fvEXT = epoxy_glNamedProgramLocalParameters4fvEXT_global_rewrite_ptr;

PFNGLNAMEDPROGRAMLOCALPARAMETERSI4IVEXTPROC epoxy_glNamedProgramLocalParametersI4ivEXT = epoxy_glNamedProgramLocalParametersI4ivEXT_global_rewrite_ptr;

PFNGLNAMEDPROGRAMLOCALPARAMETERSI4UIVEXTPROC epoxy_glNamedProgramLocalParametersI4uivEXT = epoxy_glNamedProgramLocalParametersI4uivEXT_global_rewrite_ptr;

PFNGLNAMEDPROGRAMSTRINGEXTPROC epoxy_glNamedProgramStringEXT = epoxy_glNamedProgramStringEXT_global_rewrite_ptr;

PFNGLNAMEDRENDERBUFFERSTORAGEPROC epoxy_glNamedRenderbufferStorage = epoxy_glNamedRenderbufferStorage_global_rewrite_ptr;

PFNGLNAMEDRENDERBUFFERSTORAGEEXTPROC epoxy_glNamedRenderbufferStorageEXT = epoxy_glNamedRenderbufferStorageEXT_global_rewrite_ptr;

PFNGLNAMEDRENDERBUFFERSTORAGEMULTISAMPLEPROC epoxy_glNamedRenderbufferStorageMultisample = epoxy_glNamedRenderbufferStorageMultisample_global_rewrite_ptr;

PFNGLNAMEDRENDERBUFFERSTORAGEMULTISAMPLEADVANCEDAMDPROC epoxy_glNamedRenderbufferStorageMultisampleAdvancedAMD = epoxy_glNamedRenderbufferStorageMultisampleAdvancedAMD_global_rewrite_ptr;

PFNGLNAMEDRENDERBUFFERSTORAGEMULTISAMPLECOVERAGEEXTPROC epoxy_glNamedRenderbufferStorageMultisampleCoverageEXT = epoxy_glNamedRenderbufferStorageMultisampleCoverageEXT_global_rewrite_ptr;

PFNGLNAMEDRENDERBUFFERSTORAGEMULTISAMPLEEXTPROC epoxy_glNamedRenderbufferStorageMultisampleEXT = epoxy_glNamedRenderbufferStorageMultisampleEXT_global_rewrite_ptr;

PFNGLNAMEDSTRINGARBPROC epoxy_glNamedStringARB = epoxy_glNamedStringARB_global_rewrite_ptr;

PFNGLNEWLISTPROC epoxy_glNewList = epoxy_glNewList_global_rewrite_ptr;

PFNGLNEWOBJECTBUFFERATIPROC epoxy_glNewObjectBufferATI = epoxy_glNewObjectBufferATI_global_rewrite_ptr;

PFNGLNORMAL3BPROC epoxy_glNormal3b = epoxy_glNormal3b_global_rewrite_ptr;

PFNGLNORMAL3BVPROC epoxy_glNormal3bv = epoxy_glNormal3bv_global_rewrite_ptr;

PFNGLNORMAL3DPROC epoxy_glNormal3d = epoxy_glNormal3d_global_rewrite_ptr;

PFNGLNORMAL3DVPROC epoxy_glNormal3dv = epoxy_glNormal3dv_global_rewrite_ptr;

PFNGLNORMAL3FPROC epoxy_glNormal3f = epoxy_glNormal3f_global_rewrite_ptr;

PFNGLNORMAL3FVERTEX3FSUNPROC epoxy_glNormal3fVertex3fSUN = epoxy_glNormal3fVertex3fSUN_global_rewrite_ptr;

PFNGLNORMAL3FVERTEX3FVSUNPROC epoxy_glNormal3fVertex3fvSUN = epoxy_glNormal3fVertex3fvSUN_global_rewrite_ptr;

PFNGLNORMAL3FVPROC epoxy_glNormal3fv = epoxy_glNormal3fv_global_rewrite_ptr;

PFNGLNORMAL3HNVPROC epoxy_glNormal3hNV = epoxy_glNormal3hNV_global_rewrite_ptr;

PFNGLNORMAL3HVNVPROC epoxy_glNormal3hvNV = epoxy_glNormal3hvNV_global_rewrite_ptr;

PFNGLNORMAL3IPROC epoxy_glNormal3i = epoxy_glNormal3i_global_rewrite_ptr;

PFNGLNORMAL3IVPROC epoxy_glNormal3iv = epoxy_glNormal3iv_global_rewrite_ptr;

PFNGLNORMAL3SPROC epoxy_glNormal3s = epoxy_glNormal3s_global_rewrite_ptr;

PFNGLNORMAL3SVPROC epoxy_glNormal3sv = epoxy_glNormal3sv_global_rewrite_ptr;

PFNGLNORMAL3XPROC epoxy_glNormal3x = epoxy_glNormal3x_global_rewrite_ptr;

PFNGLNORMAL3XOESPROC epoxy_glNormal3xOES = epoxy_glNormal3xOES_global_rewrite_ptr;

PFNGLNORMAL3XVOESPROC epoxy_glNormal3xvOES = epoxy_glNormal3xvOES_global_rewrite_ptr;

PFNGLNORMALFORMATNVPROC epoxy_glNormalFormatNV = epoxy_glNormalFormatNV_global_rewrite_ptr;

PFNGLNORMALP3UIPROC epoxy_glNormalP3ui = epoxy_glNormalP3ui_global_rewrite_ptr;

PFNGLNORMALP3UIVPROC epoxy_glNormalP3uiv = epoxy_glNormalP3uiv_global_rewrite_ptr;

PFNGLNORMALPOINTERPROC epoxy_glNormalPointer = epoxy_glNormalPointer_global_rewrite_ptr;

PFNGLNORMALPOINTEREXTPROC epoxy_glNormalPointerEXT = epoxy_glNormalPointerEXT_global_rewrite_ptr;

PFNGLNORMALPOINTERLISTIBMPROC epoxy_glNormalPointerListIBM = epoxy_glNormalPointerListIBM_global_rewrite_ptr;

PFNGLNORMALPOINTERVINTELPROC epoxy_glNormalPointervINTEL = epoxy_glNormalPointervINTEL_global_rewrite_ptr;

PFNGLNORMALSTREAM3BATIPROC epoxy_glNormalStream3bATI = epoxy_glNormalStream3bATI_global_rewrite_ptr;

PFNGLNORMALSTREAM3BVATIPROC epoxy_glNormalStream3bvATI = epoxy_glNormalStream3bvATI_global_rewrite_ptr;

PFNGLNORMALSTREAM3DATIPROC epoxy_glNormalStream3dATI = epoxy_glNormalStream3dATI_global_rewrite_ptr;

PFNGLNORMALSTREAM3DVATIPROC epoxy_glNormalStream3dvATI = epoxy_glNormalStream3dvATI_global_rewrite_ptr;

PFNGLNORMALSTREAM3FATIPROC epoxy_glNormalStream3fATI = epoxy_glNormalStream3fATI_global_rewrite_ptr;

PFNGLNORMALSTREAM3FVATIPROC epoxy_glNormalStream3fvATI = epoxy_glNormalStream3fvATI_global_rewrite_ptr;

PFNGLNORMALSTREAM3IATIPROC epoxy_glNormalStream3iATI = epoxy_glNormalStream3iATI_global_rewrite_ptr;

PFNGLNORMALSTREAM3IVATIPROC epoxy_glNormalStream3ivATI = epoxy_glNormalStream3ivATI_global_rewrite_ptr;

PFNGLNORMALSTREAM3SATIPROC epoxy_glNormalStream3sATI = epoxy_glNormalStream3sATI_global_rewrite_ptr;

PFNGLNORMALSTREAM3SVATIPROC epoxy_glNormalStream3svATI = epoxy_glNormalStream3svATI_global_rewrite_ptr;

PFNGLOBJECTLABELPROC epoxy_glObjectLabel = epoxy_glObjectLabel_global_rewrite_ptr;

PFNGLOBJECTLABELKHRPROC epoxy_glObjectLabelKHR = epoxy_glObjectLabelKHR_global_rewrite_ptr;

PFNGLOBJECTPTRLABELPROC epoxy_glObjectPtrLabel = epoxy_glObjectPtrLabel_global_rewrite_ptr;

PFNGLOBJECTPTRLABELKHRPROC epoxy_glObjectPtrLabelKHR = epoxy_glObjectPtrLabelKHR_global_rewrite_ptr;

PFNGLOBJECTPURGEABLEAPPLEPROC epoxy_glObjectPurgeableAPPLE = epoxy_glObjectPurgeableAPPLE_global_rewrite_ptr;

PFNGLOBJECTUNPURGEABLEAPPLEPROC epoxy_glObjectUnpurgeableAPPLE = epoxy_glObjectUnpurgeableAPPLE_global_rewrite_ptr;

PFNGLORTHOPROC epoxy_glOrtho = epoxy_glOrtho_global_rewrite_ptr;

PFNGLORTHOFPROC epoxy_glOrthof = epoxy_glOrthof_global_rewrite_ptr;

PFNGLORTHOFOESPROC epoxy_glOrthofOES = epoxy_glOrthofOES_global_rewrite_ptr;

PFNGLORTHOXPROC epoxy_glOrthox = epoxy_glOrthox_global_rewrite_ptr;

PFNGLORTHOXOESPROC epoxy_glOrthoxOES = epoxy_glOrthoxOES_global_rewrite_ptr;

PFNGLPNTRIANGLESFATIPROC epoxy_glPNTrianglesfATI = epoxy_glPNTrianglesfATI_global_rewrite_ptr;

PFNGLPNTRIANGLESIATIPROC epoxy_glPNTrianglesiATI = epoxy_glPNTrianglesiATI_global_rewrite_ptr;

PFNGLPASSTEXCOORDATIPROC epoxy_glPassTexCoordATI = epoxy_glPassTexCoordATI_global_rewrite_ptr;

PFNGLPASSTHROUGHPROC epoxy_glPassThrough = epoxy_glPassThrough_global_rewrite_ptr;

PFNGLPASSTHROUGHXOESPROC epoxy_glPassThroughxOES = epoxy_glPassThroughxOES_global_rewrite_ptr;

PFNGLPATCHPARAMETERFVPROC epoxy_glPatchParameterfv = epoxy_glPatchParameterfv_global_rewrite_ptr;

PFNGLPATCHPARAMETERIPROC epoxy_glPatchParameteri = epoxy_glPatchParameteri_global_rewrite_ptr;

PFNGLPATCHPARAMETERIEXTPROC epoxy_glPatchParameteriEXT = epoxy_glPatchParameteriEXT_global_rewrite_ptr;

PFNGLPATCHPARAMETERIOESPROC epoxy_glPatchParameteriOES = epoxy_glPatchParameteriOES_global_rewrite_ptr;

PFNGLPATHCOLORGENNVPROC epoxy_glPathColorGenNV = epoxy_glPathColorGenNV_global_rewrite_ptr;

PFNGLPATHCOMMANDSNVPROC epoxy_glPathCommandsNV = epoxy_glPathCommandsNV_global_rewrite_ptr;

PFNGLPATHCOORDSNVPROC epoxy_glPathCoordsNV = epoxy_glPathCoordsNV_global_rewrite_ptr;

PFNGLPATHCOVERDEPTHFUNCNVPROC epoxy_glPathCoverDepthFuncNV = epoxy_glPathCoverDepthFuncNV_global_rewrite_ptr;

PFNGLPATHDASHARRAYNVPROC epoxy_glPathDashArrayNV = epoxy_glPathDashArrayNV_global_rewrite_ptr;

PFNGLPATHFOGGENNVPROC epoxy_glPathFogGenNV = epoxy_glPathFogGenNV_global_rewrite_ptr;

PFNGLPATHGLYPHINDEXARRAYNVPROC epoxy_glPathGlyphIndexArrayNV = epoxy_glPathGlyphIndexArrayNV_global_rewrite_ptr;

PFNGLPATHGLYPHINDEXRANGENVPROC epoxy_glPathGlyphIndexRangeNV = epoxy_glPathGlyphIndexRangeNV_global_rewrite_ptr;

PFNGLPATHGLYPHRANGENVPROC epoxy_glPathGlyphRangeNV = epoxy_glPathGlyphRangeNV_global_rewrite_ptr;

PFNGLPATHGLYPHSNVPROC epoxy_glPathGlyphsNV = epoxy_glPathGlyphsNV_global_rewrite_ptr;

PFNGLPATHMEMORYGLYPHINDEXARRAYNVPROC epoxy_glPathMemoryGlyphIndexArrayNV = epoxy_glPathMemoryGlyphIndexArrayNV_global_rewrite_ptr;

PFNGLPATHPARAMETERFNVPROC epoxy_glPathParameterfNV = epoxy_glPathParameterfNV_global_rewrite_ptr;

PFNGLPATHPARAMETERFVNVPROC epoxy_glPathParameterfvNV = epoxy_glPathParameterfvNV_global_rewrite_ptr;

PFNGLPATHPARAMETERINVPROC epoxy_glPathParameteriNV = epoxy_glPathParameteriNV_global_rewrite_ptr;

PFNGLPATHPARAMETERIVNVPROC epoxy_glPathParameterivNV = epoxy_glPathParameterivNV_global_rewrite_ptr;

PFNGLPATHSTENCILDEPTHOFFSETNVPROC epoxy_glPathStencilDepthOffsetNV = epoxy_glPathStencilDepthOffsetNV_global_rewrite_ptr;

PFNGLPATHSTENCILFUNCNVPROC epoxy_glPathStencilFuncNV = epoxy_glPathStencilFuncNV_global_rewrite_ptr;

PFNGLPATHSTRINGNVPROC epoxy_glPathStringNV = epoxy_glPathStringNV_global_rewrite_ptr;

PFNGLPATHSUBCOMMANDSNVPROC epoxy_glPathSubCommandsNV = epoxy_glPathSubCommandsNV_global_rewrite_ptr;

PFNGLPATHSUBCOORDSNVPROC epoxy_glPathSubCoordsNV = epoxy_glPathSubCoordsNV_global_rewrite_ptr;

PFNGLPATHTEXGENNVPROC epoxy_glPathTexGenNV = epoxy_glPathTexGenNV_global_rewrite_ptr;

PFNGLPAUSETRANSFORMFEEDBACKPROC epoxy_glPauseTransformFeedback = epoxy_glPauseTransformFeedback_global_rewrite_ptr;

PFNGLPAUSETRANSFORMFEEDBACKNVPROC epoxy_glPauseTransformFeedbackNV = epoxy_glPauseTransformFeedbackNV_global_rewrite_ptr;

PFNGLPIXELDATARANGENVPROC epoxy_glPixelDataRangeNV = epoxy_glPixelDataRangeNV_global_rewrite_ptr;

PFNGLPIXELMAPFVPROC epoxy_glPixelMapfv = epoxy_glPixelMapfv_global_rewrite_ptr;

PFNGLPIXELMAPUIVPROC epoxy_glPixelMapuiv = epoxy_glPixelMapuiv_global_rewrite_ptr;

PFNGLPIXELMAPUSVPROC epoxy_glPixelMapusv = epoxy_glPixelMapusv_global_rewrite_ptr;

PFNGLPIXELMAPXPROC epoxy_glPixelMapx = epoxy_glPixelMapx_global_rewrite_ptr;

PFNGLPIXELSTOREFPROC epoxy_glPixelStoref = epoxy_glPixelStoref_global_rewrite_ptr;

PFNGLPIXELSTOREIPROC epoxy_glPixelStorei = epoxy_glPixelStorei_global_rewrite_ptr;

PFNGLPIXELSTOREXPROC epoxy_glPixelStorex = epoxy_glPixelStorex_global_rewrite_ptr;

PFNGLPIXELTEXGENPARAMETERFSGISPROC epoxy_glPixelTexGenParameterfSGIS = epoxy_glPixelTexGenParameterfSGIS_global_rewrite_ptr;

PFNGLPIXELTEXGENPARAMETERFVSGISPROC epoxy_glPixelTexGenParameterfvSGIS = epoxy_glPixelTexGenParameterfvSGIS_global_rewrite_ptr;

PFNGLPIXELTEXGENPARAMETERISGISPROC epoxy_glPixelTexGenParameteriSGIS = epoxy_glPixelTexGenParameteriSGIS_global_rewrite_ptr;

PFNGLPIXELTEXGENPARAMETERIVSGISPROC epoxy_glPixelTexGenParameterivSGIS = epoxy_glPixelTexGenParameterivSGIS_global_rewrite_ptr;

PFNGLPIXELTEXGENSGIXPROC epoxy_glPixelTexGenSGIX = epoxy_glPixelTexGenSGIX_global_rewrite_ptr;

PFNGLPIXELTRANSFERFPROC epoxy_glPixelTransferf = epoxy_glPixelTransferf_global_rewrite_ptr;

PFNGLPIXELTRANSFERIPROC epoxy_glPixelTransferi = epoxy_glPixelTransferi_global_rewrite_ptr;

PFNGLPIXELTRANSFERXOESPROC epoxy_glPixelTransferxOES = epoxy_glPixelTransferxOES_global_rewrite_ptr;

PFNGLPIXELTRANSFORMPARAMETERFEXTPROC epoxy_glPixelTransformParameterfEXT = epoxy_glPixelTransformParameterfEXT_global_rewrite_ptr;

PFNGLPIXELTRANSFORMPARAMETERFVEXTPROC epoxy_glPixelTransformParameterfvEXT = epoxy_glPixelTransformParameterfvEXT_global_rewrite_ptr;

PFNGLPIXELTRANSFORMPARAMETERIEXTPROC epoxy_glPixelTransformParameteriEXT = epoxy_glPixelTransformParameteriEXT_global_rewrite_ptr;

PFNGLPIXELTRANSFORMPARAMETERIVEXTPROC epoxy_glPixelTransformParameterivEXT = epoxy_glPixelTransformParameterivEXT_global_rewrite_ptr;

PFNGLPIXELZOOMPROC epoxy_glPixelZoom = epoxy_glPixelZoom_global_rewrite_ptr;

PFNGLPIXELZOOMXOESPROC epoxy_glPixelZoomxOES = epoxy_glPixelZoomxOES_global_rewrite_ptr;

PFNGLPOINTALONGPATHNVPROC epoxy_glPointAlongPathNV = epoxy_glPointAlongPathNV_global_rewrite_ptr;

PFNGLPOINTPARAMETERFPROC epoxy_glPointParameterf = epoxy_glPointParameterf_global_rewrite_ptr;

PFNGLPOINTPARAMETERFARBPROC epoxy_glPointParameterfARB = epoxy_glPointParameterfARB_global_rewrite_ptr;

PFNGLPOINTPARAMETERFEXTPROC epoxy_glPointParameterfEXT = epoxy_glPointParameterfEXT_global_rewrite_ptr;

PFNGLPOINTPARAMETERFSGISPROC epoxy_glPointParameterfSGIS = epoxy_glPointParameterfSGIS_global_rewrite_ptr;

PFNGLPOINTPARAMETERFVPROC epoxy_glPointParameterfv = epoxy_glPointParameterfv_global_rewrite_ptr;

PFNGLPOINTPARAMETERFVARBPROC epoxy_glPointParameterfvARB = epoxy_glPointParameterfvARB_global_rewrite_ptr;

PFNGLPOINTPARAMETERFVEXTPROC epoxy_glPointParameterfvEXT = epoxy_glPointParameterfvEXT_global_rewrite_ptr;

PFNGLPOINTPARAMETERFVSGISPROC epoxy_glPointParameterfvSGIS = epoxy_glPointParameterfvSGIS_global_rewrite_ptr;

PFNGLPOINTPARAMETERIPROC epoxy_glPointParameteri = epoxy_glPointParameteri_global_rewrite_ptr;

PFNGLPOINTPARAMETERINVPROC epoxy_glPointParameteriNV = epoxy_glPointParameteriNV_global_rewrite_ptr;

PFNGLPOINTPARAMETERIVPROC epoxy_glPointParameteriv = epoxy_glPointParameteriv_global_rewrite_ptr;

PFNGLPOINTPARAMETERIVNVPROC epoxy_glPointParameterivNV = epoxy_glPointParameterivNV_global_rewrite_ptr;

PFNGLPOINTPARAMETERXPROC epoxy_glPointParameterx = epoxy_glPointParameterx_global_rewrite_ptr;

PFNGLPOINTPARAMETERXOESPROC epoxy_glPointParameterxOES = epoxy_glPointParameterxOES_global_rewrite_ptr;

PFNGLPOINTPARAMETERXVPROC epoxy_glPointParameterxv = epoxy_glPointParameterxv_global_rewrite_ptr;

PFNGLPOINTPARAMETERXVOESPROC epoxy_glPointParameterxvOES = epoxy_glPointParameterxvOES_global_rewrite_ptr;

PFNGLPOINTSIZEPROC epoxy_glPointSize = epoxy_glPointSize_global_rewrite_ptr;

PFNGLPOINTSIZEPOINTEROESPROC epoxy_glPointSizePointerOES = epoxy_glPointSizePointerOES_global_rewrite_ptr;

PFNGLPOINTSIZEXPROC epoxy_glPointSizex = epoxy_glPointSizex_global_rewrite_ptr;

PFNGLPOINTSIZEXOESPROC epoxy_glPointSizexOES = epoxy_glPointSizexOES_global_rewrite_ptr;

PFNGLPOLLASYNCSGIXPROC epoxy_glPollAsyncSGIX = epoxy_glPollAsyncSGIX_global_rewrite_ptr;

PFNGLPOLLINSTRUMENTSSGIXPROC epoxy_glPollInstrumentsSGIX = epoxy_glPollInstrumentsSGIX_global_rewrite_ptr;

PFNGLPOLYGONMODEPROC epoxy_glPolygonMode = epoxy_glPolygonMode_global_rewrite_ptr;

PFNGLPOLYGONMODENVPROC epoxy_glPolygonModeNV = epoxy_glPolygonModeNV_global_rewrite_ptr;

PFNGLPOLYGONOFFSETPROC epoxy_glPolygonOffset = epoxy_glPolygonOffset_global_rewrite_ptr;

PFNGLPOLYGONOFFSETCLAMPPROC epoxy_glPolygonOffsetClamp = epoxy_glPolygonOffsetClamp_global_rewrite_ptr;

PFNGLPOLYGONOFFSETCLAMPEXTPROC epoxy_glPolygonOffsetClampEXT = epoxy_glPolygonOffsetClampEXT_global_rewrite_ptr;

PFNGLPOLYGONOFFSETEXTPROC epoxy_glPolygonOffsetEXT = epoxy_glPolygonOffsetEXT_global_rewrite_ptr;

PFNGLPOLYGONOFFSETXPROC epoxy_glPolygonOffsetx = epoxy_glPolygonOffsetx_global_rewrite_ptr;

PFNGLPOLYGONOFFSETXOESPROC epoxy_glPolygonOffsetxOES = epoxy_glPolygonOffsetxOES_global_rewrite_ptr;

PFNGLPOLYGONSTIPPLEPROC epoxy_glPolygonStipple = epoxy_glPolygonStipple_global_rewrite_ptr;

PFNGLPOPATTRIBPROC epoxy_glPopAttrib = epoxy_glPopAttrib_global_rewrite_ptr;

PFNGLPOPCLIENTATTRIBPROC epoxy_glPopClientAttrib = epoxy_glPopClientAttrib_global_rewrite_ptr;

PFNGLPOPDEBUGGROUPPROC epoxy_glPopDebugGroup = epoxy_glPopDebugGroup_global_rewrite_ptr;

PFNGLPOPDEBUGGROUPKHRPROC epoxy_glPopDebugGroupKHR = epoxy_glPopDebugGroupKHR_global_rewrite_ptr;

PFNGLPOPGROUPMARKEREXTPROC epoxy_glPopGroupMarkerEXT = epoxy_glPopGroupMarkerEXT_global_rewrite_ptr;

PFNGLPOPMATRIXPROC epoxy_glPopMatrix = epoxy_glPopMatrix_global_rewrite_ptr;

PFNGLPOPNAMEPROC epoxy_glPopName = epoxy_glPopName_global_rewrite_ptr;

PFNGLPRESENTFRAMEDUALFILLNVPROC epoxy_glPresentFrameDualFillNV = epoxy_glPresentFrameDualFillNV_global_rewrite_ptr;

PFNGLPRESENTFRAMEKEYEDNVPROC epoxy_glPresentFrameKeyedNV = epoxy_glPresentFrameKeyedNV_global_rewrite_ptr;

PFNGLPRIMITIVEBOUNDINGBOXPROC epoxy_glPrimitiveBoundingBox = epoxy_glPrimitiveBoundingBox_global_rewrite_ptr;

PFNGLPRIMITIVEBOUNDINGBOXARBPROC epoxy_glPrimitiveBoundingBoxARB = epoxy_glPrimitiveBoundingBoxARB_global_rewrite_ptr;

PFNGLPRIMITIVEBOUNDINGBOXEXTPROC epoxy_glPrimitiveBoundingBoxEXT = epoxy_glPrimitiveBoundingBoxEXT_global_rewrite_ptr;

PFNGLPRIMITIVEBOUNDINGBOXOESPROC epoxy_glPrimitiveBoundingBoxOES = epoxy_glPrimitiveBoundingBoxOES_global_rewrite_ptr;

PFNGLPRIMITIVERESTARTINDEXPROC epoxy_glPrimitiveRestartIndex = epoxy_glPrimitiveRestartIndex_global_rewrite_ptr;

PFNGLPRIMITIVERESTARTINDEXNVPROC epoxy_glPrimitiveRestartIndexNV = epoxy_glPrimitiveRestartIndexNV_global_rewrite_ptr;

PFNGLPRIMITIVERESTARTNVPROC epoxy_glPrimitiveRestartNV = epoxy_glPrimitiveRestartNV_global_rewrite_ptr;

PFNGLPRIORITIZETEXTURESPROC epoxy_glPrioritizeTextures = epoxy_glPrioritizeTextures_global_rewrite_ptr;

PFNGLPRIORITIZETEXTURESEXTPROC epoxy_glPrioritizeTexturesEXT = epoxy_glPrioritizeTexturesEXT_global_rewrite_ptr;

PFNGLPRIORITIZETEXTURESXOESPROC epoxy_glPrioritizeTexturesxOES = epoxy_glPrioritizeTexturesxOES_global_rewrite_ptr;

PFNGLPROGRAMBINARYPROC epoxy_glProgramBinary = epoxy_glProgramBinary_global_rewrite_ptr;

PFNGLPROGRAMBINARYOESPROC epoxy_glProgramBinaryOES = epoxy_glProgramBinaryOES_global_rewrite_ptr;

PFNGLPROGRAMBUFFERPARAMETERSIIVNVPROC epoxy_glProgramBufferParametersIivNV = epoxy_glProgramBufferParametersIivNV_global_rewrite_ptr;

PFNGLPROGRAMBUFFERPARAMETERSIUIVNVPROC epoxy_glProgramBufferParametersIuivNV = epoxy_glProgramBufferParametersIuivNV_global_rewrite_ptr;

PFNGLPROGRAMBUFFERPARAMETERSFVNVPROC epoxy_glProgramBufferParametersfvNV = epoxy_glProgramBufferParametersfvNV_global_rewrite_ptr;

PFNGLPROGRAMENVPARAMETER4DARBPROC epoxy_glProgramEnvParameter4dARB = epoxy_glProgramEnvParameter4dARB_global_rewrite_ptr;

PFNGLPROGRAMENVPARAMETER4DVARBPROC epoxy_glProgramEnvParameter4dvARB = epoxy_glProgramEnvParameter4dvARB_global_rewrite_ptr;

PFNGLPROGRAMENVPARAMETER4FARBPROC epoxy_glProgramEnvParameter4fARB = epoxy_glProgramEnvParameter4fARB_global_rewrite_ptr;

PFNGLPROGRAMENVPARAMETER4FVARBPROC epoxy_glProgramEnvParameter4fvARB = epoxy_glProgramEnvParameter4fvARB_global_rewrite_ptr;

PFNGLPROGRAMENVPARAMETERI4INVPROC epoxy_glProgramEnvParameterI4iNV = epoxy_glProgramEnvParameterI4iNV_global_rewrite_ptr;

PFNGLPROGRAMENVPARAMETERI4IVNVPROC epoxy_glProgramEnvParameterI4ivNV = epoxy_glProgramEnvParameterI4ivNV_global_rewrite_ptr;

PFNGLPROGRAMENVPARAMETERI4UINVPROC epoxy_glProgramEnvParameterI4uiNV = epoxy_glProgramEnvParameterI4uiNV_global_rewrite_ptr;

PFNGLPROGRAMENVPARAMETERI4UIVNVPROC epoxy_glProgramEnvParameterI4uivNV = epoxy_glProgramEnvParameterI4uivNV_global_rewrite_ptr;

PFNGLPROGRAMENVPARAMETERS4FVEXTPROC epoxy_glProgramEnvParameters4fvEXT = epoxy_glProgramEnvParameters4fvEXT_global_rewrite_ptr;

PFNGLPROGRAMENVPARAMETERSI4IVNVPROC epoxy_glProgramEnvParametersI4ivNV = epoxy_glProgramEnvParametersI4ivNV_global_rewrite_ptr;

PFNGLPROGRAMENVPARAMETERSI4UIVNVPROC epoxy_glProgramEnvParametersI4uivNV = epoxy_glProgramEnvParametersI4uivNV_global_rewrite_ptr;

PFNGLPROGRAMLOCALPARAMETER4DARBPROC epoxy_glProgramLocalParameter4dARB = epoxy_glProgramLocalParameter4dARB_global_rewrite_ptr;

PFNGLPROGRAMLOCALPARAMETER4DVARBPROC epoxy_glProgramLocalParameter4dvARB = epoxy_glProgramLocalParameter4dvARB_global_rewrite_ptr;

PFNGLPROGRAMLOCALPARAMETER4FARBPROC epoxy_glProgramLocalParameter4fARB = epoxy_glProgramLocalParameter4fARB_global_rewrite_ptr;

PFNGLPROGRAMLOCALPARAMETER4FVARBPROC epoxy_glProgramLocalParameter4fvARB = epoxy_glProgramLocalParameter4fvARB_global_rewrite_ptr;

PFNGLPROGRAMLOCALPARAMETERI4INVPROC epoxy_glProgramLocalParameterI4iNV = epoxy_glProgramLocalParameterI4iNV_global_rewrite_ptr;

PFNGLPROGRAMLOCALPARAMETERI4IVNVPROC epoxy_glProgramLocalParameterI4ivNV = epoxy_glProgramLocalParameterI4ivNV_global_rewrite_ptr;

PFNGLPROGRAMLOCALPARAMETERI4UINVPROC epoxy_glProgramLocalParameterI4uiNV = epoxy_glProgramLocalParameterI4uiNV_global_rewrite_ptr;

PFNGLPROGRAMLOCALPARAMETERI4UIVNVPROC epoxy_glProgramLocalParameterI4uivNV = epoxy_glProgramLocalParameterI4uivNV_global_rewrite_ptr;

PFNGLPROGRAMLOCALPARAMETERS4FVEXTPROC epoxy_glProgramLocalParameters4fvEXT = epoxy_glProgramLocalParameters4fvEXT_global_rewrite_ptr;

PFNGLPROGRAMLOCALPARAMETERSI4IVNVPROC epoxy_glProgramLocalParametersI4ivNV = epoxy_glProgramLocalParametersI4ivNV_global_rewrite_ptr;

PFNGLPROGRAMLOCALPARAMETERSI4UIVNVPROC epoxy_glProgramLocalParametersI4uivNV = epoxy_glProgramLocalParametersI4uivNV_global_rewrite_ptr;

PFNGLPROGRAMNAMEDPARAMETER4DNVPROC epoxy_glProgramNamedParameter4dNV = epoxy_glProgramNamedParameter4dNV_global_rewrite_ptr;

PFNGLPROGRAMNAMEDPARAMETER4DVNVPROC epoxy_glProgramNamedParameter4dvNV = epoxy_glProgramNamedParameter4dvNV_global_rewrite_ptr;

PFNGLPROGRAMNAMEDPARAMETER4FNVPROC epoxy_glProgramNamedParameter4fNV = epoxy_glProgramNamedParameter4fNV_global_rewrite_ptr;

PFNGLPROGRAMNAMEDPARAMETER4FVNVPROC epoxy_glProgramNamedParameter4fvNV = epoxy_glProgramNamedParameter4fvNV_global_rewrite_ptr;

PFNGLPROGRAMPARAMETER4DNVPROC epoxy_glProgramParameter4dNV = epoxy_glProgramParameter4dNV_global_rewrite_ptr;

PFNGLPROGRAMPARAMETER4DVNVPROC epoxy_glProgramParameter4dvNV = epoxy_glProgramParameter4dvNV_global_rewrite_ptr;

PFNGLPROGRAMPARAMETER4FNVPROC epoxy_glProgramParameter4fNV = epoxy_glProgramParameter4fNV_global_rewrite_ptr;

PFNGLPROGRAMPARAMETER4FVNVPROC epoxy_glProgramParameter4fvNV = epoxy_glProgramParameter4fvNV_global_rewrite_ptr;

PFNGLPROGRAMPARAMETERIPROC epoxy_glProgramParameteri = epoxy_glProgramParameteri_global_rewrite_ptr;

PFNGLPROGRAMPARAMETERIARBPROC epoxy_glProgramParameteriARB = epoxy_glProgramParameteriARB_global_rewrite_ptr;

PFNGLPROGRAMPARAMETERIEXTPROC epoxy_glProgramParameteriEXT = epoxy_glProgramParameteriEXT_global_rewrite_ptr;

PFNGLPROGRAMPARAMETERS4DVNVPROC epoxy_glProgramParameters4dvNV = epoxy_glProgramParameters4dvNV_global_rewrite_ptr;

PFNGLPROGRAMPARAMETERS4FVNVPROC epoxy_glProgramParameters4fvNV = epoxy_glProgramParameters4fvNV_global_rewrite_ptr;

PFNGLPROGRAMPATHFRAGMENTINPUTGENNVPROC epoxy_glProgramPathFragmentInputGenNV = epoxy_glProgramPathFragmentInputGenNV_global_rewrite_ptr;

PFNGLPROGRAMSTRINGARBPROC epoxy_glProgramStringARB = epoxy_glProgramStringARB_global_rewrite_ptr;

PFNGLPROGRAMSUBROUTINEPARAMETERSUIVNVPROC epoxy_glProgramSubroutineParametersuivNV = epoxy_glProgramSubroutineParametersuivNV_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM1DPROC epoxy_glProgramUniform1d = epoxy_glProgramUniform1d_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM1DEXTPROC epoxy_glProgramUniform1dEXT = epoxy_glProgramUniform1dEXT_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM1DVPROC epoxy_glProgramUniform1dv = epoxy_glProgramUniform1dv_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM1DVEXTPROC epoxy_glProgramUniform1dvEXT = epoxy_glProgramUniform1dvEXT_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM1FPROC epoxy_glProgramUniform1f = epoxy_glProgramUniform1f_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM1FEXTPROC epoxy_glProgramUniform1fEXT = epoxy_glProgramUniform1fEXT_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM1FVPROC epoxy_glProgramUniform1fv = epoxy_glProgramUniform1fv_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM1FVEXTPROC epoxy_glProgramUniform1fvEXT = epoxy_glProgramUniform1fvEXT_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM1IPROC epoxy_glProgramUniform1i = epoxy_glProgramUniform1i_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM1I64ARBPROC epoxy_glProgramUniform1i64ARB = epoxy_glProgramUniform1i64ARB_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM1I64NVPROC epoxy_glProgramUniform1i64NV = epoxy_glProgramUniform1i64NV_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM1I64VARBPROC epoxy_glProgramUniform1i64vARB = epoxy_glProgramUniform1i64vARB_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM1I64VNVPROC epoxy_glProgramUniform1i64vNV = epoxy_glProgramUniform1i64vNV_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM1IEXTPROC epoxy_glProgramUniform1iEXT = epoxy_glProgramUniform1iEXT_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM1IVPROC epoxy_glProgramUniform1iv = epoxy_glProgramUniform1iv_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM1IVEXTPROC epoxy_glProgramUniform1ivEXT = epoxy_glProgramUniform1ivEXT_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM1UIPROC epoxy_glProgramUniform1ui = epoxy_glProgramUniform1ui_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM1UI64ARBPROC epoxy_glProgramUniform1ui64ARB = epoxy_glProgramUniform1ui64ARB_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM1UI64NVPROC epoxy_glProgramUniform1ui64NV = epoxy_glProgramUniform1ui64NV_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM1UI64VARBPROC epoxy_glProgramUniform1ui64vARB = epoxy_glProgramUniform1ui64vARB_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM1UI64VNVPROC epoxy_glProgramUniform1ui64vNV = epoxy_glProgramUniform1ui64vNV_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM1UIEXTPROC epoxy_glProgramUniform1uiEXT = epoxy_glProgramUniform1uiEXT_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM1UIVPROC epoxy_glProgramUniform1uiv = epoxy_glProgramUniform1uiv_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM1UIVEXTPROC epoxy_glProgramUniform1uivEXT = epoxy_glProgramUniform1uivEXT_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM2DPROC epoxy_glProgramUniform2d = epoxy_glProgramUniform2d_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM2DEXTPROC epoxy_glProgramUniform2dEXT = epoxy_glProgramUniform2dEXT_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM2DVPROC epoxy_glProgramUniform2dv = epoxy_glProgramUniform2dv_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM2DVEXTPROC epoxy_glProgramUniform2dvEXT = epoxy_glProgramUniform2dvEXT_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM2FPROC epoxy_glProgramUniform2f = epoxy_glProgramUniform2f_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM2FEXTPROC epoxy_glProgramUniform2fEXT = epoxy_glProgramUniform2fEXT_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM2FVPROC epoxy_glProgramUniform2fv = epoxy_glProgramUniform2fv_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM2FVEXTPROC epoxy_glProgramUniform2fvEXT = epoxy_glProgramUniform2fvEXT_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM2IPROC epoxy_glProgramUniform2i = epoxy_glProgramUniform2i_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM2I64ARBPROC epoxy_glProgramUniform2i64ARB = epoxy_glProgramUniform2i64ARB_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM2I64NVPROC epoxy_glProgramUniform2i64NV = epoxy_glProgramUniform2i64NV_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM2I64VARBPROC epoxy_glProgramUniform2i64vARB = epoxy_glProgramUniform2i64vARB_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM2I64VNVPROC epoxy_glProgramUniform2i64vNV = epoxy_glProgramUniform2i64vNV_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM2IEXTPROC epoxy_glProgramUniform2iEXT = epoxy_glProgramUniform2iEXT_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM2IVPROC epoxy_glProgramUniform2iv = epoxy_glProgramUniform2iv_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM2IVEXTPROC epoxy_glProgramUniform2ivEXT = epoxy_glProgramUniform2ivEXT_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM2UIPROC epoxy_glProgramUniform2ui = epoxy_glProgramUniform2ui_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM2UI64ARBPROC epoxy_glProgramUniform2ui64ARB = epoxy_glProgramUniform2ui64ARB_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM2UI64NVPROC epoxy_glProgramUniform2ui64NV = epoxy_glProgramUniform2ui64NV_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM2UI64VARBPROC epoxy_glProgramUniform2ui64vARB = epoxy_glProgramUniform2ui64vARB_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM2UI64VNVPROC epoxy_glProgramUniform2ui64vNV = epoxy_glProgramUniform2ui64vNV_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM2UIEXTPROC epoxy_glProgramUniform2uiEXT = epoxy_glProgramUniform2uiEXT_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM2UIVPROC epoxy_glProgramUniform2uiv = epoxy_glProgramUniform2uiv_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM2UIVEXTPROC epoxy_glProgramUniform2uivEXT = epoxy_glProgramUniform2uivEXT_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM3DPROC epoxy_glProgramUniform3d = epoxy_glProgramUniform3d_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM3DEXTPROC epoxy_glProgramUniform3dEXT = epoxy_glProgramUniform3dEXT_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM3DVPROC epoxy_glProgramUniform3dv = epoxy_glProgramUniform3dv_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM3DVEXTPROC epoxy_glProgramUniform3dvEXT = epoxy_glProgramUniform3dvEXT_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM3FPROC epoxy_glProgramUniform3f = epoxy_glProgramUniform3f_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM3FEXTPROC epoxy_glProgramUniform3fEXT = epoxy_glProgramUniform3fEXT_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM3FVPROC epoxy_glProgramUniform3fv = epoxy_glProgramUniform3fv_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM3FVEXTPROC epoxy_glProgramUniform3fvEXT = epoxy_glProgramUniform3fvEXT_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM3IPROC epoxy_glProgramUniform3i = epoxy_glProgramUniform3i_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM3I64ARBPROC epoxy_glProgramUniform3i64ARB = epoxy_glProgramUniform3i64ARB_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM3I64NVPROC epoxy_glProgramUniform3i64NV = epoxy_glProgramUniform3i64NV_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM3I64VARBPROC epoxy_glProgramUniform3i64vARB = epoxy_glProgramUniform3i64vARB_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM3I64VNVPROC epoxy_glProgramUniform3i64vNV = epoxy_glProgramUniform3i64vNV_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM3IEXTPROC epoxy_glProgramUniform3iEXT = epoxy_glProgramUniform3iEXT_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM3IVPROC epoxy_glProgramUniform3iv = epoxy_glProgramUniform3iv_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM3IVEXTPROC epoxy_glProgramUniform3ivEXT = epoxy_glProgramUniform3ivEXT_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM3UIPROC epoxy_glProgramUniform3ui = epoxy_glProgramUniform3ui_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM3UI64ARBPROC epoxy_glProgramUniform3ui64ARB = epoxy_glProgramUniform3ui64ARB_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM3UI64NVPROC epoxy_glProgramUniform3ui64NV = epoxy_glProgramUniform3ui64NV_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM3UI64VARBPROC epoxy_glProgramUniform3ui64vARB = epoxy_glProgramUniform3ui64vARB_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM3UI64VNVPROC epoxy_glProgramUniform3ui64vNV = epoxy_glProgramUniform3ui64vNV_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM3UIEXTPROC epoxy_glProgramUniform3uiEXT = epoxy_glProgramUniform3uiEXT_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM3UIVPROC epoxy_glProgramUniform3uiv = epoxy_glProgramUniform3uiv_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM3UIVEXTPROC epoxy_glProgramUniform3uivEXT = epoxy_glProgramUniform3uivEXT_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM4DPROC epoxy_glProgramUniform4d = epoxy_glProgramUniform4d_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM4DEXTPROC epoxy_glProgramUniform4dEXT = epoxy_glProgramUniform4dEXT_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM4DVPROC epoxy_glProgramUniform4dv = epoxy_glProgramUniform4dv_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM4DVEXTPROC epoxy_glProgramUniform4dvEXT = epoxy_glProgramUniform4dvEXT_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM4FPROC epoxy_glProgramUniform4f = epoxy_glProgramUniform4f_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM4FEXTPROC epoxy_glProgramUniform4fEXT = epoxy_glProgramUniform4fEXT_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM4FVPROC epoxy_glProgramUniform4fv = epoxy_glProgramUniform4fv_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM4FVEXTPROC epoxy_glProgramUniform4fvEXT = epoxy_glProgramUniform4fvEXT_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM4IPROC epoxy_glProgramUniform4i = epoxy_glProgramUniform4i_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM4I64ARBPROC epoxy_glProgramUniform4i64ARB = epoxy_glProgramUniform4i64ARB_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM4I64NVPROC epoxy_glProgramUniform4i64NV = epoxy_glProgramUniform4i64NV_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM4I64VARBPROC epoxy_glProgramUniform4i64vARB = epoxy_glProgramUniform4i64vARB_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM4I64VNVPROC epoxy_glProgramUniform4i64vNV = epoxy_glProgramUniform4i64vNV_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM4IEXTPROC epoxy_glProgramUniform4iEXT = epoxy_glProgramUniform4iEXT_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM4IVPROC epoxy_glProgramUniform4iv = epoxy_glProgramUniform4iv_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM4IVEXTPROC epoxy_glProgramUniform4ivEXT = epoxy_glProgramUniform4ivEXT_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM4UIPROC epoxy_glProgramUniform4ui = epoxy_glProgramUniform4ui_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM4UI64ARBPROC epoxy_glProgramUniform4ui64ARB = epoxy_glProgramUniform4ui64ARB_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM4UI64NVPROC epoxy_glProgramUniform4ui64NV = epoxy_glProgramUniform4ui64NV_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM4UI64VARBPROC epoxy_glProgramUniform4ui64vARB = epoxy_glProgramUniform4ui64vARB_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM4UI64VNVPROC epoxy_glProgramUniform4ui64vNV = epoxy_glProgramUniform4ui64vNV_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM4UIEXTPROC epoxy_glProgramUniform4uiEXT = epoxy_glProgramUniform4uiEXT_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM4UIVPROC epoxy_glProgramUniform4uiv = epoxy_glProgramUniform4uiv_global_rewrite_ptr;

PFNGLPROGRAMUNIFORM4UIVEXTPROC epoxy_glProgramUniform4uivEXT = epoxy_glProgramUniform4uivEXT_global_rewrite_ptr;

PFNGLPROGRAMUNIFORMHANDLEUI64ARBPROC epoxy_glProgramUniformHandleui64ARB = epoxy_glProgramUniformHandleui64ARB_global_rewrite_ptr;

PFNGLPROGRAMUNIFORMHANDLEUI64IMGPROC epoxy_glProgramUniformHandleui64IMG = epoxy_glProgramUniformHandleui64IMG_global_rewrite_ptr;

PFNGLPROGRAMUNIFORMHANDLEUI64NVPROC epoxy_glProgramUniformHandleui64NV = epoxy_glProgramUniformHandleui64NV_global_rewrite_ptr;

PFNGLPROGRAMUNIFORMHANDLEUI64VARBPROC epoxy_glProgramUniformHandleui64vARB = epoxy_glProgramUniformHandleui64vARB_global_rewrite_ptr;

PFNGLPROGRAMUNIFORMHANDLEUI64VIMGPROC epoxy_glProgramUniformHandleui64vIMG = epoxy_glProgramUniformHandleui64vIMG_global_rewrite_ptr;

PFNGLPROGRAMUNIFORMHANDLEUI64VNVPROC epoxy_glProgramUniformHandleui64vNV = epoxy_glProgramUniformHandleui64vNV_global_rewrite_ptr;

PFNGLPROGRAMUNIFORMMATRIX2DVPROC epoxy_glProgramUniformMatrix2dv = epoxy_glProgramUniformMatrix2dv_global_rewrite_ptr;

PFNGLPROGRAMUNIFORMMATRIX2DVEXTPROC epoxy_glProgramUniformMatrix2dvEXT = epoxy_glProgramUniformMatrix2dvEXT_global_rewrite_ptr;

PFNGLPROGRAMUNIFORMMATRIX2FVPROC epoxy_glProgramUniformMatrix2fv = epoxy_glProgramUniformMatrix2fv_global_rewrite_ptr;

PFNGLPROGRAMUNIFORMMATRIX2FVEXTPROC epoxy_glProgramUniformMatrix2fvEXT = epoxy_glProgramUniformMatrix2fvEXT_global_rewrite_ptr;

PFNGLPROGRAMUNIFORMMATRIX2X3DVPROC epoxy_glProgramUniformMatrix2x3dv = epoxy_glProgramUniformMatrix2x3dv_global_rewrite_ptr;

PFNGLPROGRAMUNIFORMMATRIX2X3DVEXTPROC epoxy_glProgramUniformMatrix2x3dvEXT = epoxy_glProgramUniformMatrix2x3dvEXT_global_rewrite_ptr;

PFNGLPROGRAMUNIFORMMATRIX2X3FVPROC epoxy_glProgramUniformMatrix2x3fv = epoxy_glProgramUniformMatrix2x3fv_global_rewrite_ptr;

PFNGLPROGRAMUNIFORMMATRIX2X3FVEXTPROC epoxy_glProgramUniformMatrix2x3fvEXT = epoxy_glProgramUniformMatrix2x3fvEXT_global_rewrite_ptr;

PFNGLPROGRAMUNIFORMMATRIX2X4DVPROC epoxy_glProgramUniformMatrix2x4dv = epoxy_glProgramUniformMatrix2x4dv_global_rewrite_ptr;

PFNGLPROGRAMUNIFORMMATRIX2X4DVEXTPROC epoxy_glProgramUniformMatrix2x4dvEXT = epoxy_glProgramUniformMatrix2x4dvEXT_global_rewrite_ptr;

PFNGLPROGRAMUNIFORMMATRIX2X4FVPROC epoxy_glProgramUniformMatrix2x4fv = epoxy_glProgramUniformMatrix2x4fv_global_rewrite_ptr;

PFNGLPROGRAMUNIFORMMATRIX2X4FVEXTPROC epoxy_glProgramUniformMatrix2x4fvEXT = epoxy_glProgramUniformMatrix2x4fvEXT_global_rewrite_ptr;

PFNGLPROGRAMUNIFORMMATRIX3DVPROC epoxy_glProgramUniformMatrix3dv = epoxy_glProgramUniformMatrix3dv_global_rewrite_ptr;

PFNGLPROGRAMUNIFORMMATRIX3DVEXTPROC epoxy_glProgramUniformMatrix3dvEXT = epoxy_glProgramUniformMatrix3dvEXT_global_rewrite_ptr;

PFNGLPROGRAMUNIFORMMATRIX3FVPROC epoxy_glProgramUniformMatrix3fv = epoxy_glProgramUniformMatrix3fv_global_rewrite_ptr;

PFNGLPROGRAMUNIFORMMATRIX3FVEXTPROC epoxy_glProgramUniformMatrix3fvEXT = epoxy_glProgramUniformMatrix3fvEXT_global_rewrite_ptr;

PFNGLPROGRAMUNIFORMMATRIX3X2DVPROC epoxy_glProgramUniformMatrix3x2dv = epoxy_glProgramUniformMatrix3x2dv_global_rewrite_ptr;

PFNGLPROGRAMUNIFORMMATRIX3X2DVEXTPROC epoxy_glProgramUniformMatrix3x2dvEXT = epoxy_glProgramUniformMatrix3x2dvEXT_global_rewrite_ptr;

PFNGLPROGRAMUNIFORMMATRIX3X2FVPROC epoxy_glProgramUniformMatrix3x2fv = epoxy_glProgramUniformMatrix3x2fv_global_rewrite_ptr;

PFNGLPROGRAMUNIFORMMATRIX3X2FVEXTPROC epoxy_glProgramUniformMatrix3x2fvEXT = epoxy_glProgramUniformMatrix3x2fvEXT_global_rewrite_ptr;

PFNGLPROGRAMUNIFORMMATRIX3X4DVPROC epoxy_glProgramUniformMatrix3x4dv = epoxy_glProgramUniformMatrix3x4dv_global_rewrite_ptr;

PFNGLPROGRAMUNIFORMMATRIX3X4DVEXTPROC epoxy_glProgramUniformMatrix3x4dvEXT = epoxy_glProgramUniformMatrix3x4dvEXT_global_rewrite_ptr;

PFNGLPROGRAMUNIFORMMATRIX3X4FVPROC epoxy_glProgramUniformMatrix3x4fv = epoxy_glProgramUniformMatrix3x4fv_global_rewrite_ptr;

PFNGLPROGRAMUNIFORMMATRIX3X4FVEXTPROC epoxy_glProgramUniformMatrix3x4fvEXT = epoxy_glProgramUniformMatrix3x4fvEXT_global_rewrite_ptr;

PFNGLPROGRAMUNIFORMMATRIX4DVPROC epoxy_glProgramUniformMatrix4dv = epoxy_glProgramUniformMatrix4dv_global_rewrite_ptr;

PFNGLPROGRAMUNIFORMMATRIX4DVEXTPROC epoxy_glProgramUniformMatrix4dvEXT = epoxy_glProgramUniformMatrix4dvEXT_global_rewrite_ptr;

PFNGLPROGRAMUNIFORMMATRIX4FVPROC epoxy_glProgramUniformMatrix4fv = epoxy_glProgramUniformMatrix4fv_global_rewrite_ptr;

PFNGLPROGRAMUNIFORMMATRIX4FVEXTPROC epoxy_glProgramUniformMatrix4fvEXT = epoxy_glProgramUniformMatrix4fvEXT_global_rewrite_ptr;

PFNGLPROGRAMUNIFORMMATRIX4X2DVPROC epoxy_glProgramUniformMatrix4x2dv = epoxy_glProgramUniformMatrix4x2dv_global_rewrite_ptr;

PFNGLPROGRAMUNIFORMMATRIX4X2DVEXTPROC epoxy_glProgramUniformMatrix4x2dvEXT = epoxy_glProgramUniformMatrix4x2dvEXT_global_rewrite_ptr;

PFNGLPROGRAMUNIFORMMATRIX4X2FVPROC epoxy_glProgramUniformMatrix4x2fv = epoxy_glProgramUniformMatrix4x2fv_global_rewrite_ptr;

PFNGLPROGRAMUNIFORMMATRIX4X2FVEXTPROC epoxy_glProgramUniformMatrix4x2fvEXT = epoxy_glProgramUniformMatrix4x2fvEXT_global_rewrite_ptr;

PFNGLPROGRAMUNIFORMMATRIX4X3DVPROC epoxy_glProgramUniformMatrix4x3dv = epoxy_glProgramUniformMatrix4x3dv_global_rewrite_ptr;

PFNGLPROGRAMUNIFORMMATRIX4X3DVEXTPROC epoxy_glProgramUniformMatrix4x3dvEXT = epoxy_glProgramUniformMatrix4x3dvEXT_global_rewrite_ptr;

PFNGLPROGRAMUNIFORMMATRIX4X3FVPROC epoxy_glProgramUniformMatrix4x3fv = epoxy_glProgramUniformMatrix4x3fv_global_rewrite_ptr;

PFNGLPROGRAMUNIFORMMATRIX4X3FVEXTPROC epoxy_glProgramUniformMatrix4x3fvEXT = epoxy_glProgramUniformMatrix4x3fvEXT_global_rewrite_ptr;

PFNGLPROGRAMUNIFORMUI64NVPROC epoxy_glProgramUniformui64NV = epoxy_glProgramUniformui64NV_global_rewrite_ptr;

PFNGLPROGRAMUNIFORMUI64VNVPROC epoxy_glProgramUniformui64vNV = epoxy_glProgramUniformui64vNV_global_rewrite_ptr;

PFNGLPROGRAMVERTEXLIMITNVPROC epoxy_glProgramVertexLimitNV = epoxy_glProgramVertexLimitNV_global_rewrite_ptr;

PFNGLPROVOKINGVERTEXPROC epoxy_glProvokingVertex = epoxy_glProvokingVertex_global_rewrite_ptr;

PFNGLPROVOKINGVERTEXEXTPROC epoxy_glProvokingVertexEXT = epoxy_glProvokingVertexEXT_global_rewrite_ptr;

PFNGLPUSHATTRIBPROC epoxy_glPushAttrib = epoxy_glPushAttrib_global_rewrite_ptr;

PFNGLPUSHCLIENTATTRIBPROC epoxy_glPushClientAttrib = epoxy_glPushClientAttrib_global_rewrite_ptr;

PFNGLPUSHCLIENTATTRIBDEFAULTEXTPROC epoxy_glPushClientAttribDefaultEXT = epoxy_glPushClientAttribDefaultEXT_global_rewrite_ptr;

PFNGLPUSHDEBUGGROUPPROC epoxy_glPushDebugGroup = epoxy_glPushDebugGroup_global_rewrite_ptr;

PFNGLPUSHDEBUGGROUPKHRPROC epoxy_glPushDebugGroupKHR = epoxy_glPushDebugGroupKHR_global_rewrite_ptr;

PFNGLPUSHGROUPMARKEREXTPROC epoxy_glPushGroupMarkerEXT = epoxy_glPushGroupMarkerEXT_global_rewrite_ptr;

PFNGLPUSHMATRIXPROC epoxy_glPushMatrix = epoxy_glPushMatrix_global_rewrite_ptr;

PFNGLPUSHNAMEPROC epoxy_glPushName = epoxy_glPushName_global_rewrite_ptr;

PFNGLQUERYCOUNTERPROC epoxy_glQueryCounter = epoxy_glQueryCounter_global_rewrite_ptr;

PFNGLQUERYCOUNTEREXTPROC epoxy_glQueryCounterEXT = epoxy_glQueryCounterEXT_global_rewrite_ptr;

PFNGLQUERYMATRIXXOESPROC epoxy_glQueryMatrixxOES = epoxy_glQueryMatrixxOES_global_rewrite_ptr;

PFNGLQUERYOBJECTPARAMETERUIAMDPROC epoxy_glQueryObjectParameteruiAMD = epoxy_glQueryObjectParameteruiAMD_global_rewrite_ptr;

PFNGLQUERYRESOURCENVPROC epoxy_glQueryResourceNV = epoxy_glQueryResourceNV_global_rewrite_ptr;

PFNGLQUERYRESOURCETAGNVPROC epoxy_glQueryResourceTagNV = epoxy_glQueryResourceTagNV_global_rewrite_ptr;

PFNGLRASTERPOS2DPROC epoxy_glRasterPos2d = epoxy_glRasterPos2d_global_rewrite_ptr;

PFNGLRASTERPOS2DVPROC epoxy_glRasterPos2dv = epoxy_glRasterPos2dv_global_rewrite_ptr;

PFNGLRASTERPOS2FPROC epoxy_glRasterPos2f = epoxy_glRasterPos2f_global_rewrite_ptr;

PFNGLRASTERPOS2FVPROC epoxy_glRasterPos2fv = epoxy_glRasterPos2fv_global_rewrite_ptr;

PFNGLRASTERPOS2IPROC epoxy_glRasterPos2i = epoxy_glRasterPos2i_global_rewrite_ptr;

PFNGLRASTERPOS2IVPROC epoxy_glRasterPos2iv = epoxy_glRasterPos2iv_global_rewrite_ptr;

PFNGLRASTERPOS2SPROC epoxy_glRasterPos2s = epoxy_glRasterPos2s_global_rewrite_ptr;

PFNGLRASTERPOS2SVPROC epoxy_glRasterPos2sv = epoxy_glRasterPos2sv_global_rewrite_ptr;

PFNGLRASTERPOS2XOESPROC epoxy_glRasterPos2xOES = epoxy_glRasterPos2xOES_global_rewrite_ptr;

PFNGLRASTERPOS2XVOESPROC epoxy_glRasterPos2xvOES = epoxy_glRasterPos2xvOES_global_rewrite_ptr;

PFNGLRASTERPOS3DPROC epoxy_glRasterPos3d = epoxy_glRasterPos3d_global_rewrite_ptr;

PFNGLRASTERPOS3DVPROC epoxy_glRasterPos3dv = epoxy_glRasterPos3dv_global_rewrite_ptr;

PFNGLRASTERPOS3FPROC epoxy_glRasterPos3f = epoxy_glRasterPos3f_global_rewrite_ptr;

PFNGLRASTERPOS3FVPROC epoxy_glRasterPos3fv = epoxy_glRasterPos3fv_global_rewrite_ptr;

PFNGLRASTERPOS3IPROC epoxy_glRasterPos3i = epoxy_glRasterPos3i_global_rewrite_ptr;

PFNGLRASTERPOS3IVPROC epoxy_glRasterPos3iv = epoxy_glRasterPos3iv_global_rewrite_ptr;

PFNGLRASTERPOS3SPROC epoxy_glRasterPos3s = epoxy_glRasterPos3s_global_rewrite_ptr;

PFNGLRASTERPOS3SVPROC epoxy_glRasterPos3sv = epoxy_glRasterPos3sv_global_rewrite_ptr;

PFNGLRASTERPOS3XOESPROC epoxy_glRasterPos3xOES = epoxy_glRasterPos3xOES_global_rewrite_ptr;

PFNGLRASTERPOS3XVOESPROC epoxy_glRasterPos3xvOES = epoxy_glRasterPos3xvOES_global_rewrite_ptr;

PFNGLRASTERPOS4DPROC epoxy_glRasterPos4d = epoxy_glRasterPos4d_global_rewrite_ptr;

PFNGLRASTERPOS4DVPROC epoxy_glRasterPos4dv = epoxy_glRasterPos4dv_global_rewrite_ptr;

PFNGLRASTERPOS4FPROC epoxy_glRasterPos4f = epoxy_glRasterPos4f_global_rewrite_ptr;

PFNGLRASTERPOS4FVPROC epoxy_glRasterPos4fv = epoxy_glRasterPos4fv_global_rewrite_ptr;

PFNGLRASTERPOS4IPROC epoxy_glRasterPos4i = epoxy_glRasterPos4i_global_rewrite_ptr;

PFNGLRASTERPOS4IVPROC epoxy_glRasterPos4iv = epoxy_glRasterPos4iv_global_rewrite_ptr;

PFNGLRASTERPOS4SPROC epoxy_glRasterPos4s = epoxy_glRasterPos4s_global_rewrite_ptr;

PFNGLRASTERPOS4SVPROC epoxy_glRasterPos4sv = epoxy_glRasterPos4sv_global_rewrite_ptr;

PFNGLRASTERPOS4XOESPROC epoxy_glRasterPos4xOES = epoxy_glRasterPos4xOES_global_rewrite_ptr;

PFNGLRASTERPOS4XVOESPROC epoxy_glRasterPos4xvOES = epoxy_glRasterPos4xvOES_global_rewrite_ptr;

PFNGLRASTERSAMPLESEXTPROC epoxy_glRasterSamplesEXT = epoxy_glRasterSamplesEXT_global_rewrite_ptr;

PFNGLREADBUFFERPROC epoxy_glReadBuffer = epoxy_glReadBuffer_global_rewrite_ptr;

PFNGLREADBUFFERINDEXEDEXTPROC epoxy_glReadBufferIndexedEXT = epoxy_glReadBufferIndexedEXT_global_rewrite_ptr;

PFNGLREADBUFFERNVPROC epoxy_glReadBufferNV = epoxy_glReadBufferNV_global_rewrite_ptr;

PFNGLREADINSTRUMENTSSGIXPROC epoxy_glReadInstrumentsSGIX = epoxy_glReadInstrumentsSGIX_global_rewrite_ptr;

PFNGLREADPIXELSPROC epoxy_glReadPixels = epoxy_glReadPixels_global_rewrite_ptr;

PFNGLREADNPIXELSPROC epoxy_glReadnPixels = epoxy_glReadnPixels_global_rewrite_ptr;

PFNGLREADNPIXELSARBPROC epoxy_glReadnPixelsARB = epoxy_glReadnPixelsARB_global_rewrite_ptr;

PFNGLREADNPIXELSEXTPROC epoxy_glReadnPixelsEXT = epoxy_glReadnPixelsEXT_global_rewrite_ptr;

PFNGLREADNPIXELSKHRPROC epoxy_glReadnPixelsKHR = epoxy_glReadnPixelsKHR_global_rewrite_ptr;

PFNGLRECTDPROC epoxy_glRectd = epoxy_glRectd_global_rewrite_ptr;

PFNGLRECTDVPROC epoxy_glRectdv = epoxy_glRectdv_global_rewrite_ptr;

PFNGLRECTFPROC epoxy_glRectf = epoxy_glRectf_global_rewrite_ptr;

PFNGLRECTFVPROC epoxy_glRectfv = epoxy_glRectfv_global_rewrite_ptr;

PFNGLRECTIPROC epoxy_glRecti = epoxy_glRecti_global_rewrite_ptr;

PFNGLRECTIVPROC epoxy_glRectiv = epoxy_glRectiv_global_rewrite_ptr;

PFNGLRECTSPROC epoxy_glRects = epoxy_glRects_global_rewrite_ptr;

PFNGLRECTSVPROC epoxy_glRectsv = epoxy_glRectsv_global_rewrite_ptr;

PFNGLRECTXOESPROC epoxy_glRectxOES = epoxy_glRectxOES_global_rewrite_ptr;

PFNGLRECTXVOESPROC epoxy_glRectxvOES = epoxy_glRectxvOES_global_rewrite_ptr;

PFNGLREFERENCEPLANESGIXPROC epoxy_glReferencePlaneSGIX = epoxy_glReferencePlaneSGIX_global_rewrite_ptr;

PFNGLRELEASEKEYEDMUTEXWIN32EXTPROC epoxy_glReleaseKeyedMutexWin32EXT = epoxy_glReleaseKeyedMutexWin32EXT_global_rewrite_ptr;

PFNGLRELEASESHADERCOMPILERPROC epoxy_glReleaseShaderCompiler = epoxy_glReleaseShaderCompiler_global_rewrite_ptr;

PFNGLRENDERGPUMASKNVPROC epoxy_glRenderGpuMaskNV = epoxy_glRenderGpuMaskNV_global_rewrite_ptr;

PFNGLRENDERMODEPROC epoxy_glRenderMode = epoxy_glRenderMode_global_rewrite_ptr;

PFNGLRENDERBUFFERSTORAGEPROC epoxy_glRenderbufferStorage = epoxy_glRenderbufferStorage_global_rewrite_ptr;

PFNGLRENDERBUFFERSTORAGEEXTPROC epoxy_glRenderbufferStorageEXT = epoxy_glRenderbufferStorageEXT_global_rewrite_ptr;

PFNGLRENDERBUFFERSTORAGEMULTISAMPLEPROC epoxy_glRenderbufferStorageMultisample = epoxy_glRenderbufferStorageMultisample_global_rewrite_ptr;

PFNGLRENDERBUFFERSTORAGEMULTISAMPLEANGLEPROC epoxy_glRenderbufferStorageMultisampleANGLE = epoxy_glRenderbufferStorageMultisampleANGLE_global_rewrite_ptr;

PFNGLRENDERBUFFERSTORAGEMULTISAMPLEAPPLEPROC epoxy_glRenderbufferStorageMultisampleAPPLE = epoxy_glRenderbufferStorageMultisampleAPPLE_global_rewrite_ptr;

PFNGLRENDERBUFFERSTORAGEMULTISAMPLEADVANCEDAMDPROC epoxy_glRenderbufferStorageMultisampleAdvancedAMD = epoxy_glRenderbufferStorageMultisampleAdvancedAMD_global_rewrite_ptr;

PFNGLRENDERBUFFERSTORAGEMULTISAMPLECOVERAGENVPROC epoxy_glRenderbufferStorageMultisampleCoverageNV = epoxy_glRenderbufferStorageMultisampleCoverageNV_global_rewrite_ptr;

PFNGLRENDERBUFFERSTORAGEMULTISAMPLEEXTPROC epoxy_glRenderbufferStorageMultisampleEXT = epoxy_glRenderbufferStorageMultisampleEXT_global_rewrite_ptr;

PFNGLRENDERBUFFERSTORAGEMULTISAMPLEIMGPROC epoxy_glRenderbufferStorageMultisampleIMG = epoxy_glRenderbufferStorageMultisampleIMG_global_rewrite_ptr;

PFNGLRENDERBUFFERSTORAGEMULTISAMPLENVPROC epoxy_glRenderbufferStorageMultisampleNV = epoxy_glRenderbufferStorageMultisampleNV_global_rewrite_ptr;

PFNGLRENDERBUFFERSTORAGEOESPROC epoxy_glRenderbufferStorageOES = epoxy_glRenderbufferStorageOES_global_rewrite_ptr;

PFNGLREPLACEMENTCODEPOINTERSUNPROC epoxy_glReplacementCodePointerSUN = epoxy_glReplacementCodePointerSUN_global_rewrite_ptr;

PFNGLREPLACEMENTCODEUBSUNPROC epoxy_glReplacementCodeubSUN = epoxy_glReplacementCodeubSUN_global_rewrite_ptr;

PFNGLREPLACEMENTCODEUBVSUNPROC epoxy_glReplacementCodeubvSUN = epoxy_glReplacementCodeubvSUN_global_rewrite_ptr;

PFNGLREPLACEMENTCODEUICOLOR3FVERTEX3FSUNPROC epoxy_glReplacementCodeuiColor3fVertex3fSUN = epoxy_glReplacementCodeuiColor3fVertex3fSUN_global_rewrite_ptr;

PFNGLREPLACEMENTCODEUICOLOR3FVERTEX3FVSUNPROC epoxy_glReplacementCodeuiColor3fVertex3fvSUN = epoxy_glReplacementCodeuiColor3fVertex3fvSUN_global_rewrite_ptr;

PFNGLREPLACEMENTCODEUICOLOR4FNORMAL3FVERTEX3FSUNPROC epoxy_glReplacementCodeuiColor4fNormal3fVertex3fSUN = epoxy_glReplacementCodeuiColor4fNormal3fVertex3fSUN_global_rewrite_ptr;

PFNGLREPLACEMENTCODEUICOLOR4FNORMAL3FVERTEX3FVSUNPROC epoxy_glReplacementCodeuiColor4fNormal3fVertex3fvSUN = epoxy_glReplacementCodeuiColor4fNormal3fVertex3fvSUN_global_rewrite_ptr;

PFNGLREPLACEMENTCODEUICOLOR4UBVERTEX3FSUNPROC epoxy_glReplacementCodeuiColor4ubVertex3fSUN = epoxy_glReplacementCodeuiColor4ubVertex3fSUN_global_rewrite_ptr;

PFNGLREPLACEMENTCODEUICOLOR4UBVERTEX3FVSUNPROC epoxy_glReplacementCodeuiColor4ubVertex3fvSUN = epoxy_glReplacementCodeuiColor4ubVertex3fvSUN_global_rewrite_ptr;

PFNGLREPLACEMENTCODEUINORMAL3FVERTEX3FSUNPROC epoxy_glReplacementCodeuiNormal3fVertex3fSUN = epoxy_glReplacementCodeuiNormal3fVertex3fSUN_global_rewrite_ptr;

PFNGLREPLACEMENTCODEUINORMAL3FVERTEX3FVSUNPROC epoxy_glReplacementCodeuiNormal3fVertex3fvSUN = epoxy_glReplacementCodeuiNormal3fVertex3fvSUN_global_rewrite_ptr;

PFNGLREPLACEMENTCODEUISUNPROC epoxy_glReplacementCodeuiSUN = epoxy_glReplacementCodeuiSUN_global_rewrite_ptr;

PFNGLREPLACEMENTCODEUITEXCOORD2FCOLOR4FNORMAL3FVERTEX3FSUNPROC epoxy_glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fSUN = epoxy_glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fSUN_global_rewrite_ptr;

PFNGLREPLACEMENTCODEUITEXCOORD2FCOLOR4FNORMAL3FVERTEX3FVSUNPROC epoxy_glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fvSUN = epoxy_glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fvSUN_global_rewrite_ptr;

PFNGLREPLACEMENTCODEUITEXCOORD2FNORMAL3FVERTEX3FSUNPROC epoxy_glReplacementCodeuiTexCoord2fNormal3fVertex3fSUN = epoxy_glReplacementCodeuiTexCoord2fNormal3fVertex3fSUN_global_rewrite_ptr;

PFNGLREPLACEMENTCODEUITEXCOORD2FNORMAL3FVERTEX3FVSUNPROC epoxy_glReplacementCodeuiTexCoord2fNormal3fVertex3fvSUN = epoxy_glReplacementCodeuiTexCoord2fNormal3fVertex3fvSUN_global_rewrite_ptr;

PFNGLREPLACEMENTCODEUITEXCOORD2FVERTEX3FSUNPROC epoxy_glReplacementCodeuiTexCoord2fVertex3fSUN = epoxy_glReplacementCodeuiTexCoord2fVertex3fSUN_global_rewrite_ptr;

PFNGLREPLACEMENTCODEUITEXCOORD2FVERTEX3FVSUNPROC epoxy_glReplacementCodeuiTexCoord2fVertex3fvSUN = epoxy_glReplacementCodeuiTexCoord2fVertex3fvSUN_global_rewrite_ptr;

PFNGLREPLACEMENTCODEUIVERTEX3FSUNPROC epoxy_glReplacementCodeuiVertex3fSUN = epoxy_glReplacementCodeuiVertex3fSUN_global_rewrite_ptr;

PFNGLREPLACEMENTCODEUIVERTEX3FVSUNPROC epoxy_glReplacementCodeuiVertex3fvSUN = epoxy_glReplacementCodeuiVertex3fvSUN_global_rewrite_ptr;

PFNGLREPLACEMENTCODEUIVSUNPROC epoxy_glReplacementCodeuivSUN = epoxy_glReplacementCodeuivSUN_global_rewrite_ptr;

PFNGLREPLACEMENTCODEUSSUNPROC epoxy_glReplacementCodeusSUN = epoxy_glReplacementCodeusSUN_global_rewrite_ptr;

PFNGLREPLACEMENTCODEUSVSUNPROC epoxy_glReplacementCodeusvSUN = epoxy_glReplacementCodeusvSUN_global_rewrite_ptr;

PFNGLREQUESTRESIDENTPROGRAMSNVPROC epoxy_glRequestResidentProgramsNV = epoxy_glRequestResidentProgramsNV_global_rewrite_ptr;

PFNGLRESETHISTOGRAMPROC epoxy_glResetHistogram = epoxy_glResetHistogram_global_rewrite_ptr;

PFNGLRESETHISTOGRAMEXTPROC epoxy_glResetHistogramEXT = epoxy_glResetHistogramEXT_global_rewrite_ptr;

PFNGLRESETMEMORYOBJECTPARAMETERNVPROC epoxy_glResetMemoryObjectParameterNV = epoxy_glResetMemoryObjectParameterNV_global_rewrite_ptr;

PFNGLRESETMINMAXPROC epoxy_glResetMinmax = epoxy_glResetMinmax_global_rewrite_ptr;

PFNGLRESETMINMAXEXTPROC epoxy_glResetMinmaxEXT = epoxy_glResetMinmaxEXT_global_rewrite_ptr;

PFNGLRESIZEBUFFERSMESAPROC epoxy_glResizeBuffersMESA = epoxy_glResizeBuffersMESA_global_rewrite_ptr;

PFNGLRESOLVEDEPTHVALUESNVPROC epoxy_glResolveDepthValuesNV = epoxy_glResolveDepthValuesNV_global_rewrite_ptr;

PFNGLRESOLVEMULTISAMPLEFRAMEBUFFERAPPLEPROC epoxy_glResolveMultisampleFramebufferAPPLE = epoxy_glResolveMultisampleFramebufferAPPLE_global_rewrite_ptr;

PFNGLRESUMETRANSFORMFEEDBACKPROC epoxy_glResumeTransformFeedback = epoxy_glResumeTransformFeedback_global_rewrite_ptr;

PFNGLRESUMETRANSFORMFEEDBACKNVPROC epoxy_glResumeTransformFeedbackNV = epoxy_glResumeTransformFeedbackNV_global_rewrite_ptr;

PFNGLROTATEDPROC epoxy_glRotated = epoxy_glRotated_global_rewrite_ptr;

PFNGLROTATEFPROC epoxy_glRotatef = epoxy_glRotatef_global_rewrite_ptr;

PFNGLROTATEXPROC epoxy_glRotatex = epoxy_glRotatex_global_rewrite_ptr;

PFNGLROTATEXOESPROC epoxy_glRotatexOES = epoxy_glRotatexOES_global_rewrite_ptr;

PFNGLSAMPLECOVERAGEPROC epoxy_glSampleCoverage = epoxy_glSampleCoverage_global_rewrite_ptr;

PFNGLSAMPLECOVERAGEARBPROC epoxy_glSampleCoverageARB = epoxy_glSampleCoverageARB_global_rewrite_ptr;

PFNGLSAMPLECOVERAGEXPROC epoxy_glSampleCoveragex = epoxy_glSampleCoveragex_global_rewrite_ptr;

PFNGLSAMPLECOVERAGEXOESPROC epoxy_glSampleCoveragexOES = epoxy_glSampleCoveragexOES_global_rewrite_ptr;

PFNGLSAMPLEMAPATIPROC epoxy_glSampleMapATI = epoxy_glSampleMapATI_global_rewrite_ptr;

PFNGLSAMPLEMASKEXTPROC epoxy_glSampleMaskEXT = epoxy_glSampleMaskEXT_global_rewrite_ptr;

PFNGLSAMPLEMASKINDEXEDNVPROC epoxy_glSampleMaskIndexedNV = epoxy_glSampleMaskIndexedNV_global_rewrite_ptr;

PFNGLSAMPLEMASKSGISPROC epoxy_glSampleMaskSGIS = epoxy_glSampleMaskSGIS_global_rewrite_ptr;

PFNGLSAMPLEMASKIPROC epoxy_glSampleMaski = epoxy_glSampleMaski_global_rewrite_ptr;

PFNGLSAMPLEPATTERNEXTPROC epoxy_glSamplePatternEXT = epoxy_glSamplePatternEXT_global_rewrite_ptr;

PFNGLSAMPLEPATTERNSGISPROC epoxy_glSamplePatternSGIS = epoxy_glSamplePatternSGIS_global_rewrite_ptr;

PFNGLSAMPLERPARAMETERIIVPROC epoxy_glSamplerParameterIiv = epoxy_glSamplerParameterIiv_global_rewrite_ptr;

PFNGLSAMPLERPARAMETERIIVEXTPROC epoxy_glSamplerParameterIivEXT = epoxy_glSamplerParameterIivEXT_global_rewrite_ptr;

PFNGLSAMPLERPARAMETERIIVOESPROC epoxy_glSamplerParameterIivOES = epoxy_glSamplerParameterIivOES_global_rewrite_ptr;

PFNGLSAMPLERPARAMETERIUIVPROC epoxy_glSamplerParameterIuiv = epoxy_glSamplerParameterIuiv_global_rewrite_ptr;

PFNGLSAMPLERPARAMETERIUIVEXTPROC epoxy_glSamplerParameterIuivEXT = epoxy_glSamplerParameterIuivEXT_global_rewrite_ptr;

PFNGLSAMPLERPARAMETERIUIVOESPROC epoxy_glSamplerParameterIuivOES = epoxy_glSamplerParameterIuivOES_global_rewrite_ptr;

PFNGLSAMPLERPARAMETERFPROC epoxy_glSamplerParameterf = epoxy_glSamplerParameterf_global_rewrite_ptr;

PFNGLSAMPLERPARAMETERFVPROC epoxy_glSamplerParameterfv = epoxy_glSamplerParameterfv_global_rewrite_ptr;

PFNGLSAMPLERPARAMETERIPROC epoxy_glSamplerParameteri = epoxy_glSamplerParameteri_global_rewrite_ptr;

PFNGLSAMPLERPARAMETERIVPROC epoxy_glSamplerParameteriv = epoxy_glSamplerParameteriv_global_rewrite_ptr;

PFNGLSCALEDPROC epoxy_glScaled = epoxy_glScaled_global_rewrite_ptr;

PFNGLSCALEFPROC epoxy_glScalef = epoxy_glScalef_global_rewrite_ptr;

PFNGLSCALEXPROC epoxy_glScalex = epoxy_glScalex_global_rewrite_ptr;

PFNGLSCALEXOESPROC epoxy_glScalexOES = epoxy_glScalexOES_global_rewrite_ptr;

PFNGLSCISSORPROC epoxy_glScissor = epoxy_glScissor_global_rewrite_ptr;

PFNGLSCISSORARRAYVPROC epoxy_glScissorArrayv = epoxy_glScissorArrayv_global_rewrite_ptr;

PFNGLSCISSORARRAYVNVPROC epoxy_glScissorArrayvNV = epoxy_glScissorArrayvNV_global_rewrite_ptr;

PFNGLSCISSORARRAYVOESPROC epoxy_glScissorArrayvOES = epoxy_glScissorArrayvOES_global_rewrite_ptr;

PFNGLSCISSOREXCLUSIVEARRAYVNVPROC epoxy_glScissorExclusiveArrayvNV = epoxy_glScissorExclusiveArrayvNV_global_rewrite_ptr;

PFNGLSCISSOREXCLUSIVENVPROC epoxy_glScissorExclusiveNV = epoxy_glScissorExclusiveNV_global_rewrite_ptr;

PFNGLSCISSORINDEXEDPROC epoxy_glScissorIndexed = epoxy_glScissorIndexed_global_rewrite_ptr;

PFNGLSCISSORINDEXEDNVPROC epoxy_glScissorIndexedNV = epoxy_glScissorIndexedNV_global_rewrite_ptr;

PFNGLSCISSORINDEXEDOESPROC epoxy_glScissorIndexedOES = epoxy_glScissorIndexedOES_global_rewrite_ptr;

PFNGLSCISSORINDEXEDVPROC epoxy_glScissorIndexedv = epoxy_glScissorIndexedv_global_rewrite_ptr;

PFNGLSCISSORINDEXEDVNVPROC epoxy_glScissorIndexedvNV = epoxy_glScissorIndexedvNV_global_rewrite_ptr;

PFNGLSCISSORINDEXEDVOESPROC epoxy_glScissorIndexedvOES = epoxy_glScissorIndexedvOES_global_rewrite_ptr;

PFNGLSECONDARYCOLOR3BPROC epoxy_glSecondaryColor3b = epoxy_glSecondaryColor3b_global_rewrite_ptr;

PFNGLSECONDARYCOLOR3BEXTPROC epoxy_glSecondaryColor3bEXT = epoxy_glSecondaryColor3bEXT_global_rewrite_ptr;

PFNGLSECONDARYCOLOR3BVPROC epoxy_glSecondaryColor3bv = epoxy_glSecondaryColor3bv_global_rewrite_ptr;

PFNGLSECONDARYCOLOR3BVEXTPROC epoxy_glSecondaryColor3bvEXT = epoxy_glSecondaryColor3bvEXT_global_rewrite_ptr;

PFNGLSECONDARYCOLOR3DPROC epoxy_glSecondaryColor3d = epoxy_glSecondaryColor3d_global_rewrite_ptr;

PFNGLSECONDARYCOLOR3DEXTPROC epoxy_glSecondaryColor3dEXT = epoxy_glSecondaryColor3dEXT_global_rewrite_ptr;

PFNGLSECONDARYCOLOR3DVPROC epoxy_glSecondaryColor3dv = epoxy_glSecondaryColor3dv_global_rewrite_ptr;

PFNGLSECONDARYCOLOR3DVEXTPROC epoxy_glSecondaryColor3dvEXT = epoxy_glSecondaryColor3dvEXT_global_rewrite_ptr;

PFNGLSECONDARYCOLOR3FPROC epoxy_glSecondaryColor3f = epoxy_glSecondaryColor3f_global_rewrite_ptr;

PFNGLSECONDARYCOLOR3FEXTPROC epoxy_glSecondaryColor3fEXT = epoxy_glSecondaryColor3fEXT_global_rewrite_ptr;

PFNGLSECONDARYCOLOR3FVPROC epoxy_glSecondaryColor3fv = epoxy_glSecondaryColor3fv_global_rewrite_ptr;

PFNGLSECONDARYCOLOR3FVEXTPROC epoxy_glSecondaryColor3fvEXT = epoxy_glSecondaryColor3fvEXT_global_rewrite_ptr;

PFNGLSECONDARYCOLOR3HNVPROC epoxy_glSecondaryColor3hNV = epoxy_glSecondaryColor3hNV_global_rewrite_ptr;

PFNGLSECONDARYCOLOR3HVNVPROC epoxy_glSecondaryColor3hvNV = epoxy_glSecondaryColor3hvNV_global_rewrite_ptr;

PFNGLSECONDARYCOLOR3IPROC epoxy_glSecondaryColor3i = epoxy_glSecondaryColor3i_global_rewrite_ptr;

PFNGLSECONDARYCOLOR3IEXTPROC epoxy_glSecondaryColor3iEXT = epoxy_glSecondaryColor3iEXT_global_rewrite_ptr;

PFNGLSECONDARYCOLOR3IVPROC epoxy_glSecondaryColor3iv = epoxy_glSecondaryColor3iv_global_rewrite_ptr;

PFNGLSECONDARYCOLOR3IVEXTPROC epoxy_glSecondaryColor3ivEXT = epoxy_glSecondaryColor3ivEXT_global_rewrite_ptr;

PFNGLSECONDARYCOLOR3SPROC epoxy_glSecondaryColor3s = epoxy_glSecondaryColor3s_global_rewrite_ptr;

PFNGLSECONDARYCOLOR3SEXTPROC epoxy_glSecondaryColor3sEXT = epoxy_glSecondaryColor3sEXT_global_rewrite_ptr;

PFNGLSECONDARYCOLOR3SVPROC epoxy_glSecondaryColor3sv = epoxy_glSecondaryColor3sv_global_rewrite_ptr;

PFNGLSECONDARYCOLOR3SVEXTPROC epoxy_glSecondaryColor3svEXT = epoxy_glSecondaryColor3svEXT_global_rewrite_ptr;

PFNGLSECONDARYCOLOR3UBPROC epoxy_glSecondaryColor3ub = epoxy_glSecondaryColor3ub_global_rewrite_ptr;

PFNGLSECONDARYCOLOR3UBEXTPROC epoxy_glSecondaryColor3ubEXT = epoxy_glSecondaryColor3ubEXT_global_rewrite_ptr;

PFNGLSECONDARYCOLOR3UBVPROC epoxy_glSecondaryColor3ubv = epoxy_glSecondaryColor3ubv_global_rewrite_ptr;

PFNGLSECONDARYCOLOR3UBVEXTPROC epoxy_glSecondaryColor3ubvEXT = epoxy_glSecondaryColor3ubvEXT_global_rewrite_ptr;

PFNGLSECONDARYCOLOR3UIPROC epoxy_glSecondaryColor3ui = epoxy_glSecondaryColor3ui_global_rewrite_ptr;

PFNGLSECONDARYCOLOR3UIEXTPROC epoxy_glSecondaryColor3uiEXT = epoxy_glSecondaryColor3uiEXT_global_rewrite_ptr;

PFNGLSECONDARYCOLOR3UIVPROC epoxy_glSecondaryColor3uiv = epoxy_glSecondaryColor3uiv_global_rewrite_ptr;

PFNGLSECONDARYCOLOR3UIVEXTPROC epoxy_glSecondaryColor3uivEXT = epoxy_glSecondaryColor3uivEXT_global_rewrite_ptr;

PFNGLSECONDARYCOLOR3USPROC epoxy_glSecondaryColor3us = epoxy_glSecondaryColor3us_global_rewrite_ptr;

PFNGLSECONDARYCOLOR3USEXTPROC epoxy_glSecondaryColor3usEXT = epoxy_glSecondaryColor3usEXT_global_rewrite_ptr;

PFNGLSECONDARYCOLOR3USVPROC epoxy_glSecondaryColor3usv = epoxy_glSecondaryColor3usv_global_rewrite_ptr;

PFNGLSECONDARYCOLOR3USVEXTPROC epoxy_glSecondaryColor3usvEXT = epoxy_glSecondaryColor3usvEXT_global_rewrite_ptr;

PFNGLSECONDARYCOLORFORMATNVPROC epoxy_glSecondaryColorFormatNV = epoxy_glSecondaryColorFormatNV_global_rewrite_ptr;

PFNGLSECONDARYCOLORP3UIPROC epoxy_glSecondaryColorP3ui = epoxy_glSecondaryColorP3ui_global_rewrite_ptr;

PFNGLSECONDARYCOLORP3UIVPROC epoxy_glSecondaryColorP3uiv = epoxy_glSecondaryColorP3uiv_global_rewrite_ptr;

PFNGLSECONDARYCOLORPOINTERPROC epoxy_glSecondaryColorPointer = epoxy_glSecondaryColorPointer_global_rewrite_ptr;

PFNGLSECONDARYCOLORPOINTEREXTPROC epoxy_glSecondaryColorPointerEXT = epoxy_glSecondaryColorPointerEXT_global_rewrite_ptr;

PFNGLSECONDARYCOLORPOINTERLISTIBMPROC epoxy_glSecondaryColorPointerListIBM = epoxy_glSecondaryColorPointerListIBM_global_rewrite_ptr;

PFNGLSELECTBUFFERPROC epoxy_glSelectBuffer = epoxy_glSelectBuffer_global_rewrite_ptr;

PFNGLSELECTPERFMONITORCOUNTERSAMDPROC epoxy_glSelectPerfMonitorCountersAMD = epoxy_glSelectPerfMonitorCountersAMD_global_rewrite_ptr;

PFNGLSEMAPHOREPARAMETERUI64VEXTPROC epoxy_glSemaphoreParameterui64vEXT = epoxy_glSemaphoreParameterui64vEXT_global_rewrite_ptr;

PFNGLSEPARABLEFILTER2DPROC epoxy_glSeparableFilter2D = epoxy_glSeparableFilter2D_global_rewrite_ptr;

PFNGLSEPARABLEFILTER2DEXTPROC epoxy_glSeparableFilter2DEXT = epoxy_glSeparableFilter2DEXT_global_rewrite_ptr;

PFNGLSETFENCEAPPLEPROC epoxy_glSetFenceAPPLE = epoxy_glSetFenceAPPLE_global_rewrite_ptr;

PFNGLSETFENCENVPROC epoxy_glSetFenceNV = epoxy_glSetFenceNV_global_rewrite_ptr;

PFNGLSETFRAGMENTSHADERCONSTANTATIPROC epoxy_glSetFragmentShaderConstantATI = epoxy_glSetFragmentShaderConstantATI_global_rewrite_ptr;

PFNGLSETINVARIANTEXTPROC epoxy_glSetInvariantEXT = epoxy_glSetInvariantEXT_global_rewrite_ptr;

PFNGLSETLOCALCONSTANTEXTPROC epoxy_glSetLocalConstantEXT = epoxy_glSetLocalConstantEXT_global_rewrite_ptr;

PFNGLSETMULTISAMPLEFVAMDPROC epoxy_glSetMultisamplefvAMD = epoxy_glSetMultisamplefvAMD_global_rewrite_ptr;

PFNGLSHADEMODELPROC epoxy_glShadeModel = epoxy_glShadeModel_global_rewrite_ptr;

PFNGLSHADERBINARYPROC epoxy_glShaderBinary = epoxy_glShaderBinary_global_rewrite_ptr;

PFNGLSHADEROP1EXTPROC epoxy_glShaderOp1EXT = epoxy_glShaderOp1EXT_global_rewrite_ptr;

PFNGLSHADEROP2EXTPROC epoxy_glShaderOp2EXT = epoxy_glShaderOp2EXT_global_rewrite_ptr;

PFNGLSHADEROP3EXTPROC epoxy_glShaderOp3EXT = epoxy_glShaderOp3EXT_global_rewrite_ptr;

PFNGLSHADERSOURCEPROC epoxy_glShaderSource = epoxy_glShaderSource_global_rewrite_ptr;

PFNGLSHADERSOURCEARBPROC epoxy_glShaderSourceARB = epoxy_glShaderSourceARB_global_rewrite_ptr;

PFNGLSHADERSTORAGEBLOCKBINDINGPROC epoxy_glShaderStorageBlockBinding = epoxy_glShaderStorageBlockBinding_global_rewrite_ptr;

PFNGLSHADINGRATEIMAGEBARRIERNVPROC epoxy_glShadingRateImageBarrierNV = epoxy_glShadingRateImageBarrierNV_global_rewrite_ptr;

PFNGLSHADINGRATEIMAGEPALETTENVPROC epoxy_glShadingRateImagePaletteNV = epoxy_glShadingRateImagePaletteNV_global_rewrite_ptr;

PFNGLSHADINGRATESAMPLEORDERCUSTOMNVPROC epoxy_glShadingRateSampleOrderCustomNV = epoxy_glShadingRateSampleOrderCustomNV_global_rewrite_ptr;

PFNGLSHADINGRATESAMPLEORDERNVPROC epoxy_glShadingRateSampleOrderNV = epoxy_glShadingRateSampleOrderNV_global_rewrite_ptr;

PFNGLSHARPENTEXFUNCSGISPROC epoxy_glSharpenTexFuncSGIS = epoxy_glSharpenTexFuncSGIS_global_rewrite_ptr;

PFNGLSIGNALSEMAPHOREEXTPROC epoxy_glSignalSemaphoreEXT = epoxy_glSignalSemaphoreEXT_global_rewrite_ptr;

PFNGLSIGNALSEMAPHOREUI64NVXPROC epoxy_glSignalSemaphoreui64NVX = epoxy_glSignalSemaphoreui64NVX_global_rewrite_ptr;

PFNGLSIGNALVKFENCENVPROC epoxy_glSignalVkFenceNV = epoxy_glSignalVkFenceNV_global_rewrite_ptr;

PFNGLSIGNALVKSEMAPHORENVPROC epoxy_glSignalVkSemaphoreNV = epoxy_glSignalVkSemaphoreNV_global_rewrite_ptr;

PFNGLSPECIALIZESHADERPROC epoxy_glSpecializeShader = epoxy_glSpecializeShader_global_rewrite_ptr;

PFNGLSPECIALIZESHADERARBPROC epoxy_glSpecializeShaderARB = epoxy_glSpecializeShaderARB_global_rewrite_ptr;

PFNGLSPRITEPARAMETERFSGIXPROC epoxy_glSpriteParameterfSGIX = epoxy_glSpriteParameterfSGIX_global_rewrite_ptr;

PFNGLSPRITEPARAMETERFVSGIXPROC epoxy_glSpriteParameterfvSGIX = epoxy_glSpriteParameterfvSGIX_global_rewrite_ptr;

PFNGLSPRITEPARAMETERISGIXPROC epoxy_glSpriteParameteriSGIX = epoxy_glSpriteParameteriSGIX_global_rewrite_ptr;

PFNGLSPRITEPARAMETERIVSGIXPROC epoxy_glSpriteParameterivSGIX = epoxy_glSpriteParameterivSGIX_global_rewrite_ptr;

PFNGLSTARTINSTRUMENTSSGIXPROC epoxy_glStartInstrumentsSGIX = epoxy_glStartInstrumentsSGIX_global_rewrite_ptr;

PFNGLSTARTTILINGQCOMPROC epoxy_glStartTilingQCOM = epoxy_glStartTilingQCOM_global_rewrite_ptr;

PFNGLSTATECAPTURENVPROC epoxy_glStateCaptureNV = epoxy_glStateCaptureNV_global_rewrite_ptr;

PFNGLSTENCILCLEARTAGEXTPROC epoxy_glStencilClearTagEXT = epoxy_glStencilClearTagEXT_global_rewrite_ptr;

PFNGLSTENCILFILLPATHINSTANCEDNVPROC epoxy_glStencilFillPathInstancedNV = epoxy_glStencilFillPathInstancedNV_global_rewrite_ptr;

PFNGLSTENCILFILLPATHNVPROC epoxy_glStencilFillPathNV = epoxy_glStencilFillPathNV_global_rewrite_ptr;

PFNGLSTENCILFUNCPROC epoxy_glStencilFunc = epoxy_glStencilFunc_global_rewrite_ptr;

PFNGLSTENCILFUNCSEPARATEPROC epoxy_glStencilFuncSeparate = epoxy_glStencilFuncSeparate_global_rewrite_ptr;

PFNGLSTENCILFUNCSEPARATEATIPROC epoxy_glStencilFuncSeparateATI = epoxy_glStencilFuncSeparateATI_global_rewrite_ptr;

PFNGLSTENCILMASKPROC epoxy_glStencilMask = epoxy_glStencilMask_global_rewrite_ptr;

PFNGLSTENCILMASKSEPARATEPROC epoxy_glStencilMaskSeparate = epoxy_glStencilMaskSeparate_global_rewrite_ptr;

PFNGLSTENCILOPPROC epoxy_glStencilOp = epoxy_glStencilOp_global_rewrite_ptr;

PFNGLSTENCILOPSEPARATEPROC epoxy_glStencilOpSeparate = epoxy_glStencilOpSeparate_global_rewrite_ptr;

PFNGLSTENCILOPSEPARATEATIPROC epoxy_glStencilOpSeparateATI = epoxy_glStencilOpSeparateATI_global_rewrite_ptr;

PFNGLSTENCILOPVALUEAMDPROC epoxy_glStencilOpValueAMD = epoxy_glStencilOpValueAMD_global_rewrite_ptr;

PFNGLSTENCILSTROKEPATHINSTANCEDNVPROC epoxy_glStencilStrokePathInstancedNV = epoxy_glStencilStrokePathInstancedNV_global_rewrite_ptr;

PFNGLSTENCILSTROKEPATHNVPROC epoxy_glStencilStrokePathNV = epoxy_glStencilStrokePathNV_global_rewrite_ptr;

PFNGLSTENCILTHENCOVERFILLPATHINSTANCEDNVPROC epoxy_glStencilThenCoverFillPathInstancedNV = epoxy_glStencilThenCoverFillPathInstancedNV_global_rewrite_ptr;

PFNGLSTENCILTHENCOVERFILLPATHNVPROC epoxy_glStencilThenCoverFillPathNV = epoxy_glStencilThenCoverFillPathNV_global_rewrite_ptr;

PFNGLSTENCILTHENCOVERSTROKEPATHINSTANCEDNVPROC epoxy_glStencilThenCoverStrokePathInstancedNV = epoxy_glStencilThenCoverStrokePathInstancedNV_global_rewrite_ptr;

PFNGLSTENCILTHENCOVERSTROKEPATHNVPROC epoxy_glStencilThenCoverStrokePathNV = epoxy_glStencilThenCoverStrokePathNV_global_rewrite_ptr;

PFNGLSTOPINSTRUMENTSSGIXPROC epoxy_glStopInstrumentsSGIX = epoxy_glStopInstrumentsSGIX_global_rewrite_ptr;

PFNGLSTRINGMARKERGREMEDYPROC epoxy_glStringMarkerGREMEDY = epoxy_glStringMarkerGREMEDY_global_rewrite_ptr;

PFNGLSUBPIXELPRECISIONBIASNVPROC epoxy_glSubpixelPrecisionBiasNV = epoxy_glSubpixelPrecisionBiasNV_global_rewrite_ptr;

PFNGLSWIZZLEEXTPROC epoxy_glSwizzleEXT = epoxy_glSwizzleEXT_global_rewrite_ptr;

PFNGLSYNCTEXTUREINTELPROC epoxy_glSyncTextureINTEL = epoxy_glSyncTextureINTEL_global_rewrite_ptr;

PFNGLTAGSAMPLEBUFFERSGIXPROC epoxy_glTagSampleBufferSGIX = epoxy_glTagSampleBufferSGIX_global_rewrite_ptr;

PFNGLTANGENT3BEXTPROC epoxy_glTangent3bEXT = epoxy_glTangent3bEXT_global_rewrite_ptr;

PFNGLTANGENT3BVEXTPROC epoxy_glTangent3bvEXT = epoxy_glTangent3bvEXT_global_rewrite_ptr;

PFNGLTANGENT3DEXTPROC epoxy_glTangent3dEXT = epoxy_glTangent3dEXT_global_rewrite_ptr;

PFNGLTANGENT3DVEXTPROC epoxy_glTangent3dvEXT = epoxy_glTangent3dvEXT_global_rewrite_ptr;

PFNGLTANGENT3FEXTPROC epoxy_glTangent3fEXT = epoxy_glTangent3fEXT_global_rewrite_ptr;

PFNGLTANGENT3FVEXTPROC epoxy_glTangent3fvEXT = epoxy_glTangent3fvEXT_global_rewrite_ptr;

PFNGLTANGENT3IEXTPROC epoxy_glTangent3iEXT = epoxy_glTangent3iEXT_global_rewrite_ptr;

PFNGLTANGENT3IVEXTPROC epoxy_glTangent3ivEXT = epoxy_glTangent3ivEXT_global_rewrite_ptr;

PFNGLTANGENT3SEXTPROC epoxy_glTangent3sEXT = epoxy_glTangent3sEXT_global_rewrite_ptr;

PFNGLTANGENT3SVEXTPROC epoxy_glTangent3svEXT = epoxy_glTangent3svEXT_global_rewrite_ptr;

PFNGLTANGENTPOINTEREXTPROC epoxy_glTangentPointerEXT = epoxy_glTangentPointerEXT_global_rewrite_ptr;

PFNGLTBUFFERMASK3DFXPROC epoxy_glTbufferMask3DFX = epoxy_glTbufferMask3DFX_global_rewrite_ptr;

PFNGLTESSELLATIONFACTORAMDPROC epoxy_glTessellationFactorAMD = epoxy_glTessellationFactorAMD_global_rewrite_ptr;

PFNGLTESSELLATIONMODEAMDPROC epoxy_glTessellationModeAMD = epoxy_glTessellationModeAMD_global_rewrite_ptr;

PFNGLTESTFENCEAPPLEPROC epoxy_glTestFenceAPPLE = epoxy_glTestFenceAPPLE_global_rewrite_ptr;

PFNGLTESTFENCENVPROC epoxy_glTestFenceNV = epoxy_glTestFenceNV_global_rewrite_ptr;

PFNGLTESTOBJECTAPPLEPROC epoxy_glTestObjectAPPLE = epoxy_glTestObjectAPPLE_global_rewrite_ptr;

PFNGLTEXATTACHMEMORYNVPROC epoxy_glTexAttachMemoryNV = epoxy_glTexAttachMemoryNV_global_rewrite_ptr;

PFNGLTEXBUFFERPROC epoxy_glTexBuffer = epoxy_glTexBuffer_global_rewrite_ptr;

PFNGLTEXBUFFERARBPROC epoxy_glTexBufferARB = epoxy_glTexBufferARB_global_rewrite_ptr;

PFNGLTEXBUFFEREXTPROC epoxy_glTexBufferEXT = epoxy_glTexBufferEXT_global_rewrite_ptr;

PFNGLTEXBUFFEROESPROC epoxy_glTexBufferOES = epoxy_glTexBufferOES_global_rewrite_ptr;

PFNGLTEXBUFFERRANGEPROC epoxy_glTexBufferRange = epoxy_glTexBufferRange_global_rewrite_ptr;

PFNGLTEXBUFFERRANGEEXTPROC epoxy_glTexBufferRangeEXT = epoxy_glTexBufferRangeEXT_global_rewrite_ptr;

PFNGLTEXBUFFERRANGEOESPROC epoxy_glTexBufferRangeOES = epoxy_glTexBufferRangeOES_global_rewrite_ptr;

PFNGLTEXBUMPPARAMETERFVATIPROC epoxy_glTexBumpParameterfvATI = epoxy_glTexBumpParameterfvATI_global_rewrite_ptr;

PFNGLTEXBUMPPARAMETERIVATIPROC epoxy_glTexBumpParameterivATI = epoxy_glTexBumpParameterivATI_global_rewrite_ptr;

PFNGLTEXCOORD1BOESPROC epoxy_glTexCoord1bOES = epoxy_glTexCoord1bOES_global_rewrite_ptr;

PFNGLTEXCOORD1BVOESPROC epoxy_glTexCoord1bvOES = epoxy_glTexCoord1bvOES_global_rewrite_ptr;

PFNGLTEXCOORD1DPROC epoxy_glTexCoord1d = epoxy_glTexCoord1d_global_rewrite_ptr;

PFNGLTEXCOORD1DVPROC epoxy_glTexCoord1dv = epoxy_glTexCoord1dv_global_rewrite_ptr;

PFNGLTEXCOORD1FPROC epoxy_glTexCoord1f = epoxy_glTexCoord1f_global_rewrite_ptr;

PFNGLTEXCOORD1FVPROC epoxy_glTexCoord1fv = epoxy_glTexCoord1fv_global_rewrite_ptr;

PFNGLTEXCOORD1HNVPROC epoxy_glTexCoord1hNV = epoxy_glTexCoord1hNV_global_rewrite_ptr;

PFNGLTEXCOORD1HVNVPROC epoxy_glTexCoord1hvNV = epoxy_glTexCoord1hvNV_global_rewrite_ptr;

PFNGLTEXCOORD1IPROC epoxy_glTexCoord1i = epoxy_glTexCoord1i_global_rewrite_ptr;

PFNGLTEXCOORD1IVPROC epoxy_glTexCoord1iv = epoxy_glTexCoord1iv_global_rewrite_ptr;

PFNGLTEXCOORD1SPROC epoxy_glTexCoord1s = epoxy_glTexCoord1s_global_rewrite_ptr;

PFNGLTEXCOORD1SVPROC epoxy_glTexCoord1sv = epoxy_glTexCoord1sv_global_rewrite_ptr;

PFNGLTEXCOORD1XOESPROC epoxy_glTexCoord1xOES = epoxy_glTexCoord1xOES_global_rewrite_ptr;

PFNGLTEXCOORD1XVOESPROC epoxy_glTexCoord1xvOES = epoxy_glTexCoord1xvOES_global_rewrite_ptr;

PFNGLTEXCOORD2BOESPROC epoxy_glTexCoord2bOES = epoxy_glTexCoord2bOES_global_rewrite_ptr;

PFNGLTEXCOORD2BVOESPROC epoxy_glTexCoord2bvOES = epoxy_glTexCoord2bvOES_global_rewrite_ptr;

PFNGLTEXCOORD2DPROC epoxy_glTexCoord2d = epoxy_glTexCoord2d_global_rewrite_ptr;

PFNGLTEXCOORD2DVPROC epoxy_glTexCoord2dv = epoxy_glTexCoord2dv_global_rewrite_ptr;

PFNGLTEXCOORD2FPROC epoxy_glTexCoord2f = epoxy_glTexCoord2f_global_rewrite_ptr;

PFNGLTEXCOORD2FCOLOR3FVERTEX3FSUNPROC epoxy_glTexCoord2fColor3fVertex3fSUN = epoxy_glTexCoord2fColor3fVertex3fSUN_global_rewrite_ptr;

PFNGLTEXCOORD2FCOLOR3FVERTEX3FVSUNPROC epoxy_glTexCoord2fColor3fVertex3fvSUN = epoxy_glTexCoord2fColor3fVertex3fvSUN_global_rewrite_ptr;

PFNGLTEXCOORD2FCOLOR4FNORMAL3FVERTEX3FSUNPROC epoxy_glTexCoord2fColor4fNormal3fVertex3fSUN = epoxy_glTexCoord2fColor4fNormal3fVertex3fSUN_global_rewrite_ptr;

PFNGLTEXCOORD2FCOLOR4FNORMAL3FVERTEX3FVSUNPROC epoxy_glTexCoord2fColor4fNormal3fVertex3fvSUN = epoxy_glTexCoord2fColor4fNormal3fVertex3fvSUN_global_rewrite_ptr;

PFNGLTEXCOORD2FCOLOR4UBVERTEX3FSUNPROC epoxy_glTexCoord2fColor4ubVertex3fSUN = epoxy_glTexCoord2fColor4ubVertex3fSUN_global_rewrite_ptr;

PFNGLTEXCOORD2FCOLOR4UBVERTEX3FVSUNPROC epoxy_glTexCoord2fColor4ubVertex3fvSUN = epoxy_glTexCoord2fColor4ubVertex3fvSUN_global_rewrite_ptr;

PFNGLTEXCOORD2FNORMAL3FVERTEX3FSUNPROC epoxy_glTexCoord2fNormal3fVertex3fSUN = epoxy_glTexCoord2fNormal3fVertex3fSUN_global_rewrite_ptr;

PFNGLTEXCOORD2FNORMAL3FVERTEX3FVSUNPROC epoxy_glTexCoord2fNormal3fVertex3fvSUN = epoxy_glTexCoord2fNormal3fVertex3fvSUN_global_rewrite_ptr;

PFNGLTEXCOORD2FVERTEX3FSUNPROC epoxy_glTexCoord2fVertex3fSUN = epoxy_glTexCoord2fVertex3fSUN_global_rewrite_ptr;

PFNGLTEXCOORD2FVERTEX3FVSUNPROC epoxy_glTexCoord2fVertex3fvSUN = epoxy_glTexCoord2fVertex3fvSUN_global_rewrite_ptr;

PFNGLTEXCOORD2FVPROC epoxy_glTexCoord2fv = epoxy_glTexCoord2fv_global_rewrite_ptr;

PFNGLTEXCOORD2HNVPROC epoxy_glTexCoord2hNV = epoxy_glTexCoord2hNV_global_rewrite_ptr;

PFNGLTEXCOORD2HVNVPROC epoxy_glTexCoord2hvNV = epoxy_glTexCoord2hvNV_global_rewrite_ptr;

PFNGLTEXCOORD2IPROC epoxy_glTexCoord2i = epoxy_glTexCoord2i_global_rewrite_ptr;

PFNGLTEXCOORD2IVPROC epoxy_glTexCoord2iv = epoxy_glTexCoord2iv_global_rewrite_ptr;

PFNGLTEXCOORD2SPROC epoxy_glTexCoord2s = epoxy_glTexCoord2s_global_rewrite_ptr;

PFNGLTEXCOORD2SVPROC epoxy_glTexCoord2sv = epoxy_glTexCoord2sv_global_rewrite_ptr;

PFNGLTEXCOORD2XOESPROC epoxy_glTexCoord2xOES = epoxy_glTexCoord2xOES_global_rewrite_ptr;

PFNGLTEXCOORD2XVOESPROC epoxy_glTexCoord2xvOES = epoxy_glTexCoord2xvOES_global_rewrite_ptr;

PFNGLTEXCOORD3BOESPROC epoxy_glTexCoord3bOES = epoxy_glTexCoord3bOES_global_rewrite_ptr;

PFNGLTEXCOORD3BVOESPROC epoxy_glTexCoord3bvOES = epoxy_glTexCoord3bvOES_global_rewrite_ptr;

PFNGLTEXCOORD3DPROC epoxy_glTexCoord3d = epoxy_glTexCoord3d_global_rewrite_ptr;

PFNGLTEXCOORD3DVPROC epoxy_glTexCoord3dv = epoxy_glTexCoord3dv_global_rewrite_ptr;

PFNGLTEXCOORD3FPROC epoxy_glTexCoord3f = epoxy_glTexCoord3f_global_rewrite_ptr;

PFNGLTEXCOORD3FVPROC epoxy_glTexCoord3fv = epoxy_glTexCoord3fv_global_rewrite_ptr;

PFNGLTEXCOORD3HNVPROC epoxy_glTexCoord3hNV = epoxy_glTexCoord3hNV_global_rewrite_ptr;

PFNGLTEXCOORD3HVNVPROC epoxy_glTexCoord3hvNV = epoxy_glTexCoord3hvNV_global_rewrite_ptr;

PFNGLTEXCOORD3IPROC epoxy_glTexCoord3i = epoxy_glTexCoord3i_global_rewrite_ptr;

PFNGLTEXCOORD3IVPROC epoxy_glTexCoord3iv = epoxy_glTexCoord3iv_global_rewrite_ptr;

PFNGLTEXCOORD3SPROC epoxy_glTexCoord3s = epoxy_glTexCoord3s_global_rewrite_ptr;

PFNGLTEXCOORD3SVPROC epoxy_glTexCoord3sv = epoxy_glTexCoord3sv_global_rewrite_ptr;

PFNGLTEXCOORD3XOESPROC epoxy_glTexCoord3xOES = epoxy_glTexCoord3xOES_global_rewrite_ptr;

PFNGLTEXCOORD3XVOESPROC epoxy_glTexCoord3xvOES = epoxy_glTexCoord3xvOES_global_rewrite_ptr;

PFNGLTEXCOORD4BOESPROC epoxy_glTexCoord4bOES = epoxy_glTexCoord4bOES_global_rewrite_ptr;

PFNGLTEXCOORD4BVOESPROC epoxy_glTexCoord4bvOES = epoxy_glTexCoord4bvOES_global_rewrite_ptr;

PFNGLTEXCOORD4DPROC epoxy_glTexCoord4d = epoxy_glTexCoord4d_global_rewrite_ptr;

PFNGLTEXCOORD4DVPROC epoxy_glTexCoord4dv = epoxy_glTexCoord4dv_global_rewrite_ptr;

PFNGLTEXCOORD4FPROC epoxy_glTexCoord4f = epoxy_glTexCoord4f_global_rewrite_ptr;

PFNGLTEXCOORD4FCOLOR4FNORMAL3FVERTEX4FSUNPROC epoxy_glTexCoord4fColor4fNormal3fVertex4fSUN = epoxy_glTexCoord4fColor4fNormal3fVertex4fSUN_global_rewrite_ptr;

PFNGLTEXCOORD4FCOLOR4FNORMAL3FVERTEX4FVSUNPROC epoxy_glTexCoord4fColor4fNormal3fVertex4fvSUN = epoxy_glTexCoord4fColor4fNormal3fVertex4fvSUN_global_rewrite_ptr;

PFNGLTEXCOORD4FVERTEX4FSUNPROC epoxy_glTexCoord4fVertex4fSUN = epoxy_glTexCoord4fVertex4fSUN_global_rewrite_ptr;

PFNGLTEXCOORD4FVERTEX4FVSUNPROC epoxy_glTexCoord4fVertex4fvSUN = epoxy_glTexCoord4fVertex4fvSUN_global_rewrite_ptr;

PFNGLTEXCOORD4FVPROC epoxy_glTexCoord4fv = epoxy_glTexCoord4fv_global_rewrite_ptr;

PFNGLTEXCOORD4HNVPROC epoxy_glTexCoord4hNV = epoxy_glTexCoord4hNV_global_rewrite_ptr;

PFNGLTEXCOORD4HVNVPROC epoxy_glTexCoord4hvNV = epoxy_glTexCoord4hvNV_global_rewrite_ptr;

PFNGLTEXCOORD4IPROC epoxy_glTexCoord4i = epoxy_glTexCoord4i_global_rewrite_ptr;

PFNGLTEXCOORD4IVPROC epoxy_glTexCoord4iv = epoxy_glTexCoord4iv_global_rewrite_ptr;

PFNGLTEXCOORD4SPROC epoxy_glTexCoord4s = epoxy_glTexCoord4s_global_rewrite_ptr;

PFNGLTEXCOORD4SVPROC epoxy_glTexCoord4sv = epoxy_glTexCoord4sv_global_rewrite_ptr;

PFNGLTEXCOORD4XOESPROC epoxy_glTexCoord4xOES = epoxy_glTexCoord4xOES_global_rewrite_ptr;

PFNGLTEXCOORD4XVOESPROC epoxy_glTexCoord4xvOES = epoxy_glTexCoord4xvOES_global_rewrite_ptr;

PFNGLTEXCOORDFORMATNVPROC epoxy_glTexCoordFormatNV = epoxy_glTexCoordFormatNV_global_rewrite_ptr;

PFNGLTEXCOORDP1UIPROC epoxy_glTexCoordP1ui = epoxy_glTexCoordP1ui_global_rewrite_ptr;

PFNGLTEXCOORDP1UIVPROC epoxy_glTexCoordP1uiv = epoxy_glTexCoordP1uiv_global_rewrite_ptr;

PFNGLTEXCOORDP2UIPROC epoxy_glTexCoordP2ui = epoxy_glTexCoordP2ui_global_rewrite_ptr;

PFNGLTEXCOORDP2UIVPROC epoxy_glTexCoordP2uiv = epoxy_glTexCoordP2uiv_global_rewrite_ptr;

PFNGLTEXCOORDP3UIPROC epoxy_glTexCoordP3ui = epoxy_glTexCoordP3ui_global_rewrite_ptr;

PFNGLTEXCOORDP3UIVPROC epoxy_glTexCoordP3uiv = epoxy_glTexCoordP3uiv_global_rewrite_ptr;

PFNGLTEXCOORDP4UIPROC epoxy_glTexCoordP4ui = epoxy_glTexCoordP4ui_global_rewrite_ptr;

PFNGLTEXCOORDP4UIVPROC epoxy_glTexCoordP4uiv = epoxy_glTexCoordP4uiv_global_rewrite_ptr;

PFNGLTEXCOORDPOINTERPROC epoxy_glTexCoordPointer = epoxy_glTexCoordPointer_global_rewrite_ptr;

PFNGLTEXCOORDPOINTEREXTPROC epoxy_glTexCoordPointerEXT = epoxy_glTexCoordPointerEXT_global_rewrite_ptr;

PFNGLTEXCOORDPOINTERLISTIBMPROC epoxy_glTexCoordPointerListIBM = epoxy_glTexCoordPointerListIBM_global_rewrite_ptr;

PFNGLTEXCOORDPOINTERVINTELPROC epoxy_glTexCoordPointervINTEL = epoxy_glTexCoordPointervINTEL_global_rewrite_ptr;

PFNGLTEXENVFPROC epoxy_glTexEnvf = epoxy_glTexEnvf_global_rewrite_ptr;

PFNGLTEXENVFVPROC epoxy_glTexEnvfv = epoxy_glTexEnvfv_global_rewrite_ptr;

PFNGLTEXENVIPROC epoxy_glTexEnvi = epoxy_glTexEnvi_global_rewrite_ptr;

PFNGLTEXENVIVPROC epoxy_glTexEnviv = epoxy_glTexEnviv_global_rewrite_ptr;

PFNGLTEXENVXPROC epoxy_glTexEnvx = epoxy_glTexEnvx_global_rewrite_ptr;

PFNGLTEXENVXOESPROC epoxy_glTexEnvxOES = epoxy_glTexEnvxOES_global_rewrite_ptr;

PFNGLTEXENVXVPROC epoxy_glTexEnvxv = epoxy_glTexEnvxv_global_rewrite_ptr;

PFNGLTEXENVXVOESPROC epoxy_glTexEnvxvOES = epoxy_glTexEnvxvOES_global_rewrite_ptr;

PFNGLTEXFILTERFUNCSGISPROC epoxy_glTexFilterFuncSGIS = epoxy_glTexFilterFuncSGIS_global_rewrite_ptr;

PFNGLTEXGENDPROC epoxy_glTexGend = epoxy_glTexGend_global_rewrite_ptr;

PFNGLTEXGENDVPROC epoxy_glTexGendv = epoxy_glTexGendv_global_rewrite_ptr;

PFNGLTEXGENFPROC epoxy_glTexGenf = epoxy_glTexGenf_global_rewrite_ptr;

PFNGLTEXGENFOESPROC epoxy_glTexGenfOES = epoxy_glTexGenfOES_global_rewrite_ptr;

PFNGLTEXGENFVPROC epoxy_glTexGenfv = epoxy_glTexGenfv_global_rewrite_ptr;

PFNGLTEXGENFVOESPROC epoxy_glTexGenfvOES = epoxy_glTexGenfvOES_global_rewrite_ptr;

PFNGLTEXGENIPROC epoxy_glTexGeni = epoxy_glTexGeni_global_rewrite_ptr;

PFNGLTEXGENIOESPROC epoxy_glTexGeniOES = epoxy_glTexGeniOES_global_rewrite_ptr;

PFNGLTEXGENIVPROC epoxy_glTexGeniv = epoxy_glTexGeniv_global_rewrite_ptr;

PFNGLTEXGENIVOESPROC epoxy_glTexGenivOES = epoxy_glTexGenivOES_global_rewrite_ptr;

PFNGLTEXGENXOESPROC epoxy_glTexGenxOES = epoxy_glTexGenxOES_global_rewrite_ptr;

PFNGLTEXGENXVOESPROC epoxy_glTexGenxvOES = epoxy_glTexGenxvOES_global_rewrite_ptr;

PFNGLTEXIMAGE1DPROC epoxy_glTexImage1D = epoxy_glTexImage1D_global_rewrite_ptr;

PFNGLTEXIMAGE2DPROC epoxy_glTexImage2D = epoxy_glTexImage2D_global_rewrite_ptr;

PFNGLTEXIMAGE2DMULTISAMPLEPROC epoxy_glTexImage2DMultisample = epoxy_glTexImage2DMultisample_global_rewrite_ptr;

PFNGLTEXIMAGE2DMULTISAMPLECOVERAGENVPROC epoxy_glTexImage2DMultisampleCoverageNV = epoxy_glTexImage2DMultisampleCoverageNV_global_rewrite_ptr;

PFNGLTEXIMAGE3DPROC epoxy_glTexImage3D = epoxy_glTexImage3D_global_rewrite_ptr;

PFNGLTEXIMAGE3DEXTPROC epoxy_glTexImage3DEXT = epoxy_glTexImage3DEXT_global_rewrite_ptr;

PFNGLTEXIMAGE3DMULTISAMPLEPROC epoxy_glTexImage3DMultisample = epoxy_glTexImage3DMultisample_global_rewrite_ptr;

PFNGLTEXIMAGE3DMULTISAMPLECOVERAGENVPROC epoxy_glTexImage3DMultisampleCoverageNV = epoxy_glTexImage3DMultisampleCoverageNV_global_rewrite_ptr;

PFNGLTEXIMAGE3DOESPROC epoxy_glTexImage3DOES = epoxy_glTexImage3DOES_global_rewrite_ptr;

PFNGLTEXIMAGE4DSGISPROC epoxy_glTexImage4DSGIS = epoxy_glTexImage4DSGIS_global_rewrite_ptr;

PFNGLTEXPAGECOMMITMENTARBPROC epoxy_glTexPageCommitmentARB = epoxy_glTexPageCommitmentARB_global_rewrite_ptr;

PFNGLTEXPAGECOMMITMENTEXTPROC epoxy_glTexPageCommitmentEXT = epoxy_glTexPageCommitmentEXT_global_rewrite_ptr;

PFNGLTEXPARAMETERIIVPROC epoxy_glTexParameterIiv = epoxy_glTexParameterIiv_global_rewrite_ptr;

PFNGLTEXPARAMETERIIVEXTPROC epoxy_glTexParameterIivEXT = epoxy_glTexParameterIivEXT_global_rewrite_ptr;

PFNGLTEXPARAMETERIIVOESPROC epoxy_glTexParameterIivOES = epoxy_glTexParameterIivOES_global_rewrite_ptr;

PFNGLTEXPARAMETERIUIVPROC epoxy_glTexParameterIuiv = epoxy_glTexParameterIuiv_global_rewrite_ptr;

PFNGLTEXPARAMETERIUIVEXTPROC epoxy_glTexParameterIuivEXT = epoxy_glTexParameterIuivEXT_global_rewrite_ptr;

PFNGLTEXPARAMETERIUIVOESPROC epoxy_glTexParameterIuivOES = epoxy_glTexParameterIuivOES_global_rewrite_ptr;

PFNGLTEXPARAMETERFPROC epoxy_glTexParameterf = epoxy_glTexParameterf_global_rewrite_ptr;

PFNGLTEXPARAMETERFVPROC epoxy_glTexParameterfv = epoxy_glTexParameterfv_global_rewrite_ptr;

PFNGLTEXPARAMETERIPROC epoxy_glTexParameteri = epoxy_glTexParameteri_global_rewrite_ptr;

PFNGLTEXPARAMETERIVPROC epoxy_glTexParameteriv = epoxy_glTexParameteriv_global_rewrite_ptr;

PFNGLTEXPARAMETERXPROC epoxy_glTexParameterx = epoxy_glTexParameterx_global_rewrite_ptr;

PFNGLTEXPARAMETERXOESPROC epoxy_glTexParameterxOES = epoxy_glTexParameterxOES_global_rewrite_ptr;

PFNGLTEXPARAMETERXVPROC epoxy_glTexParameterxv = epoxy_glTexParameterxv_global_rewrite_ptr;

PFNGLTEXPARAMETERXVOESPROC epoxy_glTexParameterxvOES = epoxy_glTexParameterxvOES_global_rewrite_ptr;

PFNGLTEXRENDERBUFFERNVPROC epoxy_glTexRenderbufferNV = epoxy_glTexRenderbufferNV_global_rewrite_ptr;

PFNGLTEXSTORAGE1DPROC epoxy_glTexStorage1D = epoxy_glTexStorage1D_global_rewrite_ptr;

PFNGLTEXSTORAGE1DEXTPROC epoxy_glTexStorage1DEXT = epoxy_glTexStorage1DEXT_global_rewrite_ptr;

PFNGLTEXSTORAGE2DPROC epoxy_glTexStorage2D = epoxy_glTexStorage2D_global_rewrite_ptr;

PFNGLTEXSTORAGE2DEXTPROC epoxy_glTexStorage2DEXT = epoxy_glTexStorage2DEXT_global_rewrite_ptr;

PFNGLTEXSTORAGE2DMULTISAMPLEPROC epoxy_glTexStorage2DMultisample = epoxy_glTexStorage2DMultisample_global_rewrite_ptr;

PFNGLTEXSTORAGE3DPROC epoxy_glTexStorage3D = epoxy_glTexStorage3D_global_rewrite_ptr;

PFNGLTEXSTORAGE3DEXTPROC epoxy_glTexStorage3DEXT = epoxy_glTexStorage3DEXT_global_rewrite_ptr;

PFNGLTEXSTORAGE3DMULTISAMPLEPROC epoxy_glTexStorage3DMultisample = epoxy_glTexStorage3DMultisample_global_rewrite_ptr;

PFNGLTEXSTORAGE3DMULTISAMPLEOESPROC epoxy_glTexStorage3DMultisampleOES = epoxy_glTexStorage3DMultisampleOES_global_rewrite_ptr;

PFNGLTEXSTORAGEMEM1DEXTPROC epoxy_glTexStorageMem1DEXT = epoxy_glTexStorageMem1DEXT_global_rewrite_ptr;

PFNGLTEXSTORAGEMEM2DEXTPROC epoxy_glTexStorageMem2DEXT = epoxy_glTexStorageMem2DEXT_global_rewrite_ptr;

PFNGLTEXSTORAGEMEM2DMULTISAMPLEEXTPROC epoxy_glTexStorageMem2DMultisampleEXT = epoxy_glTexStorageMem2DMultisampleEXT_global_rewrite_ptr;

PFNGLTEXSTORAGEMEM3DEXTPROC epoxy_glTexStorageMem3DEXT = epoxy_glTexStorageMem3DEXT_global_rewrite_ptr;

PFNGLTEXSTORAGEMEM3DMULTISAMPLEEXTPROC epoxy_glTexStorageMem3DMultisampleEXT = epoxy_glTexStorageMem3DMultisampleEXT_global_rewrite_ptr;

PFNGLTEXSTORAGESPARSEAMDPROC epoxy_glTexStorageSparseAMD = epoxy_glTexStorageSparseAMD_global_rewrite_ptr;

PFNGLTEXSUBIMAGE1DPROC epoxy_glTexSubImage1D = epoxy_glTexSubImage1D_global_rewrite_ptr;

PFNGLTEXSUBIMAGE1DEXTPROC epoxy_glTexSubImage1DEXT = epoxy_glTexSubImage1DEXT_global_rewrite_ptr;

PFNGLTEXSUBIMAGE2DPROC epoxy_glTexSubImage2D = epoxy_glTexSubImage2D_global_rewrite_ptr;

PFNGLTEXSUBIMAGE2DEXTPROC epoxy_glTexSubImage2DEXT = epoxy_glTexSubImage2DEXT_global_rewrite_ptr;

PFNGLTEXSUBIMAGE3DPROC epoxy_glTexSubImage3D = epoxy_glTexSubImage3D_global_rewrite_ptr;

PFNGLTEXSUBIMAGE3DEXTPROC epoxy_glTexSubImage3DEXT = epoxy_glTexSubImage3DEXT_global_rewrite_ptr;

PFNGLTEXSUBIMAGE3DOESPROC epoxy_glTexSubImage3DOES = epoxy_glTexSubImage3DOES_global_rewrite_ptr;

PFNGLTEXSUBIMAGE4DSGISPROC epoxy_glTexSubImage4DSGIS = epoxy_glTexSubImage4DSGIS_global_rewrite_ptr;

PFNGLTEXTUREATTACHMEMORYNVPROC epoxy_glTextureAttachMemoryNV = epoxy_glTextureAttachMemoryNV_global_rewrite_ptr;

PFNGLTEXTUREBARRIERPROC epoxy_glTextureBarrier = epoxy_glTextureBarrier_global_rewrite_ptr;

PFNGLTEXTUREBARRIERNVPROC epoxy_glTextureBarrierNV = epoxy_glTextureBarrierNV_global_rewrite_ptr;

PFNGLTEXTUREBUFFERPROC epoxy_glTextureBuffer = epoxy_glTextureBuffer_global_rewrite_ptr;

PFNGLTEXTUREBUFFEREXTPROC epoxy_glTextureBufferEXT = epoxy_glTextureBufferEXT_global_rewrite_ptr;

PFNGLTEXTUREBUFFERRANGEPROC epoxy_glTextureBufferRange = epoxy_glTextureBufferRange_global_rewrite_ptr;

PFNGLTEXTUREBUFFERRANGEEXTPROC epoxy_glTextureBufferRangeEXT = epoxy_glTextureBufferRangeEXT_global_rewrite_ptr;

PFNGLTEXTURECOLORMASKSGISPROC epoxy_glTextureColorMaskSGIS = epoxy_glTextureColorMaskSGIS_global_rewrite_ptr;

PFNGLTEXTUREFOVEATIONPARAMETERSQCOMPROC epoxy_glTextureFoveationParametersQCOM = epoxy_glTextureFoveationParametersQCOM_global_rewrite_ptr;

PFNGLTEXTUREIMAGE1DEXTPROC epoxy_glTextureImage1DEXT = epoxy_glTextureImage1DEXT_global_rewrite_ptr;

PFNGLTEXTUREIMAGE2DEXTPROC epoxy_glTextureImage2DEXT = epoxy_glTextureImage2DEXT_global_rewrite_ptr;

PFNGLTEXTUREIMAGE2DMULTISAMPLECOVERAGENVPROC epoxy_glTextureImage2DMultisampleCoverageNV = epoxy_glTextureImage2DMultisampleCoverageNV_global_rewrite_ptr;

PFNGLTEXTUREIMAGE2DMULTISAMPLENVPROC epoxy_glTextureImage2DMultisampleNV = epoxy_glTextureImage2DMultisampleNV_global_rewrite_ptr;

PFNGLTEXTUREIMAGE3DEXTPROC epoxy_glTextureImage3DEXT = epoxy_glTextureImage3DEXT_global_rewrite_ptr;

PFNGLTEXTUREIMAGE3DMULTISAMPLECOVERAGENVPROC epoxy_glTextureImage3DMultisampleCoverageNV = epoxy_glTextureImage3DMultisampleCoverageNV_global_rewrite_ptr;

PFNGLTEXTUREIMAGE3DMULTISAMPLENVPROC epoxy_glTextureImage3DMultisampleNV = epoxy_glTextureImage3DMultisampleNV_global_rewrite_ptr;

PFNGLTEXTURELIGHTEXTPROC epoxy_glTextureLightEXT = epoxy_glTextureLightEXT_global_rewrite_ptr;

PFNGLTEXTUREMATERIALEXTPROC epoxy_glTextureMaterialEXT = epoxy_glTextureMaterialEXT_global_rewrite_ptr;

PFNGLTEXTURENORMALEXTPROC epoxy_glTextureNormalEXT = epoxy_glTextureNormalEXT_global_rewrite_ptr;

PFNGLTEXTUREPAGECOMMITMENTEXTPROC epoxy_glTexturePageCommitmentEXT = epoxy_glTexturePageCommitmentEXT_global_rewrite_ptr;

PFNGLTEXTUREPARAMETERIIVPROC epoxy_glTextureParameterIiv = epoxy_glTextureParameterIiv_global_rewrite_ptr;

PFNGLTEXTUREPARAMETERIIVEXTPROC epoxy_glTextureParameterIivEXT = epoxy_glTextureParameterIivEXT_global_rewrite_ptr;

PFNGLTEXTUREPARAMETERIUIVPROC epoxy_glTextureParameterIuiv = epoxy_glTextureParameterIuiv_global_rewrite_ptr;

PFNGLTEXTUREPARAMETERIUIVEXTPROC epoxy_glTextureParameterIuivEXT = epoxy_glTextureParameterIuivEXT_global_rewrite_ptr;

PFNGLTEXTUREPARAMETERFPROC epoxy_glTextureParameterf = epoxy_glTextureParameterf_global_rewrite_ptr;

PFNGLTEXTUREPARAMETERFEXTPROC epoxy_glTextureParameterfEXT = epoxy_glTextureParameterfEXT_global_rewrite_ptr;

PFNGLTEXTUREPARAMETERFVPROC epoxy_glTextureParameterfv = epoxy_glTextureParameterfv_global_rewrite_ptr;

PFNGLTEXTUREPARAMETERFVEXTPROC epoxy_glTextureParameterfvEXT = epoxy_glTextureParameterfvEXT_global_rewrite_ptr;

PFNGLTEXTUREPARAMETERIPROC epoxy_glTextureParameteri = epoxy_glTextureParameteri_global_rewrite_ptr;

PFNGLTEXTUREPARAMETERIEXTPROC epoxy_glTextureParameteriEXT = epoxy_glTextureParameteriEXT_global_rewrite_ptr;

PFNGLTEXTUREPARAMETERIVPROC epoxy_glTextureParameteriv = epoxy_glTextureParameteriv_global_rewrite_ptr;

PFNGLTEXTUREPARAMETERIVEXTPROC epoxy_glTextureParameterivEXT = epoxy_glTextureParameterivEXT_global_rewrite_ptr;

PFNGLTEXTURERANGEAPPLEPROC epoxy_glTextureRangeAPPLE = epoxy_glTextureRangeAPPLE_global_rewrite_ptr;

PFNGLTEXTURERENDERBUFFEREXTPROC epoxy_glTextureRenderbufferEXT = epoxy_glTextureRenderbufferEXT_global_rewrite_ptr;

PFNGLTEXTURESTORAGE1DPROC epoxy_glTextureStorage1D = epoxy_glTextureStorage1D_global_rewrite_ptr;

PFNGLTEXTURESTORAGE1DEXTPROC epoxy_glTextureStorage1DEXT = epoxy_glTextureStorage1DEXT_global_rewrite_ptr;

PFNGLTEXTURESTORAGE2DPROC epoxy_glTextureStorage2D = epoxy_glTextureStorage2D_global_rewrite_ptr;

PFNGLTEXTURESTORAGE2DEXTPROC epoxy_glTextureStorage2DEXT = epoxy_glTextureStorage2DEXT_global_rewrite_ptr;

PFNGLTEXTURESTORAGE2DMULTISAMPLEPROC epoxy_glTextureStorage2DMultisample = epoxy_glTextureStorage2DMultisample_global_rewrite_ptr;

PFNGLTEXTURESTORAGE2DMULTISAMPLEEXTPROC epoxy_glTextureStorage2DMultisampleEXT = epoxy_glTextureStorage2DMultisampleEXT_global_rewrite_ptr;

PFNGLTEXTURESTORAGE3DPROC epoxy_glTextureStorage3D = epoxy_glTextureStorage3D_global_rewrite_ptr;

PFNGLTEXTURESTORAGE3DEXTPROC epoxy_glTextureStorage3DEXT = epoxy_glTextureStorage3DEXT_global_rewrite_ptr;

PFNGLTEXTURESTORAGE3DMULTISAMPLEPROC epoxy_glTextureStorage3DMultisample = epoxy_glTextureStorage3DMultisample_global_rewrite_ptr;

PFNGLTEXTURESTORAGE3DMULTISAMPLEEXTPROC epoxy_glTextureStorage3DMultisampleEXT = epoxy_glTextureStorage3DMultisampleEXT_global_rewrite_ptr;

PFNGLTEXTURESTORAGEMEM1DEXTPROC epoxy_glTextureStorageMem1DEXT = epoxy_glTextureStorageMem1DEXT_global_rewrite_ptr;

PFNGLTEXTURESTORAGEMEM2DEXTPROC epoxy_glTextureStorageMem2DEXT = epoxy_glTextureStorageMem2DEXT_global_rewrite_ptr;

PFNGLTEXTURESTORAGEMEM2DMULTISAMPLEEXTPROC epoxy_glTextureStorageMem2DMultisampleEXT = epoxy_glTextureStorageMem2DMultisampleEXT_global_rewrite_ptr;

PFNGLTEXTURESTORAGEMEM3DEXTPROC epoxy_glTextureStorageMem3DEXT = epoxy_glTextureStorageMem3DEXT_global_rewrite_ptr;

PFNGLTEXTURESTORAGEMEM3DMULTISAMPLEEXTPROC epoxy_glTextureStorageMem3DMultisampleEXT = epoxy_glTextureStorageMem3DMultisampleEXT_global_rewrite_ptr;

PFNGLTEXTURESTORAGESPARSEAMDPROC epoxy_glTextureStorageSparseAMD = epoxy_glTextureStorageSparseAMD_global_rewrite_ptr;

PFNGLTEXTURESUBIMAGE1DPROC epoxy_glTextureSubImage1D = epoxy_glTextureSubImage1D_global_rewrite_ptr;

PFNGLTEXTURESUBIMAGE1DEXTPROC epoxy_glTextureSubImage1DEXT = epoxy_glTextureSubImage1DEXT_global_rewrite_ptr;

PFNGLTEXTURESUBIMAGE2DPROC epoxy_glTextureSubImage2D = epoxy_glTextureSubImage2D_global_rewrite_ptr;

PFNGLTEXTURESUBIMAGE2DEXTPROC epoxy_glTextureSubImage2DEXT = epoxy_glTextureSubImage2DEXT_global_rewrite_ptr;

PFNGLTEXTURESUBIMAGE3DPROC epoxy_glTextureSubImage3D = epoxy_glTextureSubImage3D_global_rewrite_ptr;

PFNGLTEXTURESUBIMAGE3DEXTPROC epoxy_glTextureSubImage3DEXT = epoxy_glTextureSubImage3DEXT_global_rewrite_ptr;

PFNGLTEXTUREVIEWPROC epoxy_glTextureView = epoxy_glTextureView_global_rewrite_ptr;

PFNGLTEXTUREVIEWEXTPROC epoxy_glTextureViewEXT = epoxy_glTextureViewEXT_global_rewrite_ptr;

PFNGLTEXTUREVIEWOESPROC epoxy_glTextureViewOES = epoxy_glTextureViewOES_global_rewrite_ptr;

PFNGLTRACKMATRIXNVPROC epoxy_glTrackMatrixNV = epoxy_glTrackMatrixNV_global_rewrite_ptr;

PFNGLTRANSFORMFEEDBACKATTRIBSNVPROC epoxy_glTransformFeedbackAttribsNV = epoxy_glTransformFeedbackAttribsNV_global_rewrite_ptr;

PFNGLTRANSFORMFEEDBACKBUFFERBASEPROC epoxy_glTransformFeedbackBufferBase = epoxy_glTransformFeedbackBufferBase_global_rewrite_ptr;

PFNGLTRANSFORMFEEDBACKBUFFERRANGEPROC epoxy_glTransformFeedbackBufferRange = epoxy_glTransformFeedbackBufferRange_global_rewrite_ptr;

PFNGLTRANSFORMFEEDBACKSTREAMATTRIBSNVPROC epoxy_glTransformFeedbackStreamAttribsNV = epoxy_glTransformFeedbackStreamAttribsNV_global_rewrite_ptr;

PFNGLTRANSFORMFEEDBACKVARYINGSPROC epoxy_glTransformFeedbackVaryings = epoxy_glTransformFeedbackVaryings_global_rewrite_ptr;

PFNGLTRANSFORMFEEDBACKVARYINGSEXTPROC epoxy_glTransformFeedbackVaryingsEXT = epoxy_glTransformFeedbackVaryingsEXT_global_rewrite_ptr;

PFNGLTRANSFORMFEEDBACKVARYINGSNVPROC epoxy_glTransformFeedbackVaryingsNV = epoxy_glTransformFeedbackVaryingsNV_global_rewrite_ptr;

PFNGLTRANSFORMPATHNVPROC epoxy_glTransformPathNV = epoxy_glTransformPathNV_global_rewrite_ptr;

PFNGLTRANSLATEDPROC epoxy_glTranslated = epoxy_glTranslated_global_rewrite_ptr;

PFNGLTRANSLATEFPROC epoxy_glTranslatef = epoxy_glTranslatef_global_rewrite_ptr;

PFNGLTRANSLATEXPROC epoxy_glTranslatex = epoxy_glTranslatex_global_rewrite_ptr;

PFNGLTRANSLATEXOESPROC epoxy_glTranslatexOES = epoxy_glTranslatexOES_global_rewrite_ptr;

PFNGLUNIFORM1DPROC epoxy_glUniform1d = epoxy_glUniform1d_global_rewrite_ptr;

PFNGLUNIFORM1DVPROC epoxy_glUniform1dv = epoxy_glUniform1dv_global_rewrite_ptr;

PFNGLUNIFORM1FPROC epoxy_glUniform1f = epoxy_glUniform1f_global_rewrite_ptr;

PFNGLUNIFORM1FARBPROC epoxy_glUniform1fARB = epoxy_glUniform1fARB_global_rewrite_ptr;

PFNGLUNIFORM1FVPROC epoxy_glUniform1fv = epoxy_glUniform1fv_global_rewrite_ptr;

PFNGLUNIFORM1FVARBPROC epoxy_glUniform1fvARB = epoxy_glUniform1fvARB_global_rewrite_ptr;

PFNGLUNIFORM1IPROC epoxy_glUniform1i = epoxy_glUniform1i_global_rewrite_ptr;

PFNGLUNIFORM1I64ARBPROC epoxy_glUniform1i64ARB = epoxy_glUniform1i64ARB_global_rewrite_ptr;

PFNGLUNIFORM1I64NVPROC epoxy_glUniform1i64NV = epoxy_glUniform1i64NV_global_rewrite_ptr;

PFNGLUNIFORM1I64VARBPROC epoxy_glUniform1i64vARB = epoxy_glUniform1i64vARB_global_rewrite_ptr;

PFNGLUNIFORM1I64VNVPROC epoxy_glUniform1i64vNV = epoxy_glUniform1i64vNV_global_rewrite_ptr;

PFNGLUNIFORM1IARBPROC epoxy_glUniform1iARB = epoxy_glUniform1iARB_global_rewrite_ptr;

PFNGLUNIFORM1IVPROC epoxy_glUniform1iv = epoxy_glUniform1iv_global_rewrite_ptr;

PFNGLUNIFORM1IVARBPROC epoxy_glUniform1ivARB = epoxy_glUniform1ivARB_global_rewrite_ptr;

PFNGLUNIFORM1UIPROC epoxy_glUniform1ui = epoxy_glUniform1ui_global_rewrite_ptr;

PFNGLUNIFORM1UI64ARBPROC epoxy_glUniform1ui64ARB = epoxy_glUniform1ui64ARB_global_rewrite_ptr;

PFNGLUNIFORM1UI64NVPROC epoxy_glUniform1ui64NV = epoxy_glUniform1ui64NV_global_rewrite_ptr;

PFNGLUNIFORM1UI64VARBPROC epoxy_glUniform1ui64vARB = epoxy_glUniform1ui64vARB_global_rewrite_ptr;

PFNGLUNIFORM1UI64VNVPROC epoxy_glUniform1ui64vNV = epoxy_glUniform1ui64vNV_global_rewrite_ptr;

PFNGLUNIFORM1UIEXTPROC epoxy_glUniform1uiEXT = epoxy_glUniform1uiEXT_global_rewrite_ptr;

PFNGLUNIFORM1UIVPROC epoxy_glUniform1uiv = epoxy_glUniform1uiv_global_rewrite_ptr;

PFNGLUNIFORM1UIVEXTPROC epoxy_glUniform1uivEXT = epoxy_glUniform1uivEXT_global_rewrite_ptr;

PFNGLUNIFORM2DPROC epoxy_glUniform2d = epoxy_glUniform2d_global_rewrite_ptr;

PFNGLUNIFORM2DVPROC epoxy_glUniform2dv = epoxy_glUniform2dv_global_rewrite_ptr;

PFNGLUNIFORM2FPROC epoxy_glUniform2f = epoxy_glUniform2f_global_rewrite_ptr;

PFNGLUNIFORM2FARBPROC epoxy_glUniform2fARB = epoxy_glUniform2fARB_global_rewrite_ptr;

PFNGLUNIFORM2FVPROC epoxy_glUniform2fv = epoxy_glUniform2fv_global_rewrite_ptr;

PFNGLUNIFORM2FVARBPROC epoxy_glUniform2fvARB = epoxy_glUniform2fvARB_global_rewrite_ptr;

PFNGLUNIFORM2IPROC epoxy_glUniform2i = epoxy_glUniform2i_global_rewrite_ptr;

PFNGLUNIFORM2I64ARBPROC epoxy_glUniform2i64ARB = epoxy_glUniform2i64ARB_global_rewrite_ptr;

PFNGLUNIFORM2I64NVPROC epoxy_glUniform2i64NV = epoxy_glUniform2i64NV_global_rewrite_ptr;

PFNGLUNIFORM2I64VARBPROC epoxy_glUniform2i64vARB = epoxy_glUniform2i64vARB_global_rewrite_ptr;

PFNGLUNIFORM2I64VNVPROC epoxy_glUniform2i64vNV = epoxy_glUniform2i64vNV_global_rewrite_ptr;

PFNGLUNIFORM2IARBPROC epoxy_glUniform2iARB = epoxy_glUniform2iARB_global_rewrite_ptr;

PFNGLUNIFORM2IVPROC epoxy_glUniform2iv = epoxy_glUniform2iv_global_rewrite_ptr;

PFNGLUNIFORM2IVARBPROC epoxy_glUniform2ivARB = epoxy_glUniform2ivARB_global_rewrite_ptr;

PFNGLUNIFORM2UIPROC epoxy_glUniform2ui = epoxy_glUniform2ui_global_rewrite_ptr;

PFNGLUNIFORM2UI64ARBPROC epoxy_glUniform2ui64ARB = epoxy_glUniform2ui64ARB_global_rewrite_ptr;

PFNGLUNIFORM2UI64NVPROC epoxy_glUniform2ui64NV = epoxy_glUniform2ui64NV_global_rewrite_ptr;

PFNGLUNIFORM2UI64VARBPROC epoxy_glUniform2ui64vARB = epoxy_glUniform2ui64vARB_global_rewrite_ptr;

PFNGLUNIFORM2UI64VNVPROC epoxy_glUniform2ui64vNV = epoxy_glUniform2ui64vNV_global_rewrite_ptr;

PFNGLUNIFORM2UIEXTPROC epoxy_glUniform2uiEXT = epoxy_glUniform2uiEXT_global_rewrite_ptr;

PFNGLUNIFORM2UIVPROC epoxy_glUniform2uiv = epoxy_glUniform2uiv_global_rewrite_ptr;

PFNGLUNIFORM2UIVEXTPROC epoxy_glUniform2uivEXT = epoxy_glUniform2uivEXT_global_rewrite_ptr;

PFNGLUNIFORM3DPROC epoxy_glUniform3d = epoxy_glUniform3d_global_rewrite_ptr;

PFNGLUNIFORM3DVPROC epoxy_glUniform3dv = epoxy_glUniform3dv_global_rewrite_ptr;

PFNGLUNIFORM3FPROC epoxy_glUniform3f = epoxy_glUniform3f_global_rewrite_ptr;

PFNGLUNIFORM3FARBPROC epoxy_glUniform3fARB = epoxy_glUniform3fARB_global_rewrite_ptr;

PFNGLUNIFORM3FVPROC epoxy_glUniform3fv = epoxy_glUniform3fv_global_rewrite_ptr;

PFNGLUNIFORM3FVARBPROC epoxy_glUniform3fvARB = epoxy_glUniform3fvARB_global_rewrite_ptr;

PFNGLUNIFORM3IPROC epoxy_glUniform3i = epoxy_glUniform3i_global_rewrite_ptr;

PFNGLUNIFORM3I64ARBPROC epoxy_glUniform3i64ARB = epoxy_glUniform3i64ARB_global_rewrite_ptr;

PFNGLUNIFORM3I64NVPROC epoxy_glUniform3i64NV = epoxy_glUniform3i64NV_global_rewrite_ptr;

PFNGLUNIFORM3I64VARBPROC epoxy_glUniform3i64vARB = epoxy_glUniform3i64vARB_global_rewrite_ptr;

PFNGLUNIFORM3I64VNVPROC epoxy_glUniform3i64vNV = epoxy_glUniform3i64vNV_global_rewrite_ptr;

PFNGLUNIFORM3IARBPROC epoxy_glUniform3iARB = epoxy_glUniform3iARB_global_rewrite_ptr;

PFNGLUNIFORM3IVPROC epoxy_glUniform3iv = epoxy_glUniform3iv_global_rewrite_ptr;

PFNGLUNIFORM3IVARBPROC epoxy_glUniform3ivARB = epoxy_glUniform3ivARB_global_rewrite_ptr;

PFNGLUNIFORM3UIPROC epoxy_glUniform3ui = epoxy_glUniform3ui_global_rewrite_ptr;

PFNGLUNIFORM3UI64ARBPROC epoxy_glUniform3ui64ARB = epoxy_glUniform3ui64ARB_global_rewrite_ptr;

PFNGLUNIFORM3UI64NVPROC epoxy_glUniform3ui64NV = epoxy_glUniform3ui64NV_global_rewrite_ptr;

PFNGLUNIFORM3UI64VARBPROC epoxy_glUniform3ui64vARB = epoxy_glUniform3ui64vARB_global_rewrite_ptr;

PFNGLUNIFORM3UI64VNVPROC epoxy_glUniform3ui64vNV = epoxy_glUniform3ui64vNV_global_rewrite_ptr;

PFNGLUNIFORM3UIEXTPROC epoxy_glUniform3uiEXT = epoxy_glUniform3uiEXT_global_rewrite_ptr;

PFNGLUNIFORM3UIVPROC epoxy_glUniform3uiv = epoxy_glUniform3uiv_global_rewrite_ptr;

PFNGLUNIFORM3UIVEXTPROC epoxy_glUniform3uivEXT = epoxy_glUniform3uivEXT_global_rewrite_ptr;

PFNGLUNIFORM4DPROC epoxy_glUniform4d = epoxy_glUniform4d_global_rewrite_ptr;

PFNGLUNIFORM4DVPROC epoxy_glUniform4dv = epoxy_glUniform4dv_global_rewrite_ptr;

PFNGLUNIFORM4FPROC epoxy_glUniform4f = epoxy_glUniform4f_global_rewrite_ptr;

PFNGLUNIFORM4FARBPROC epoxy_glUniform4fARB = epoxy_glUniform4fARB_global_rewrite_ptr;

PFNGLUNIFORM4FVPROC epoxy_glUniform4fv = epoxy_glUniform4fv_global_rewrite_ptr;

PFNGLUNIFORM4FVARBPROC epoxy_glUniform4fvARB = epoxy_glUniform4fvARB_global_rewrite_ptr;

PFNGLUNIFORM4IPROC epoxy_glUniform4i = epoxy_glUniform4i_global_rewrite_ptr;

PFNGLUNIFORM4I64ARBPROC epoxy_glUniform4i64ARB = epoxy_glUniform4i64ARB_global_rewrite_ptr;

PFNGLUNIFORM4I64NVPROC epoxy_glUniform4i64NV = epoxy_glUniform4i64NV_global_rewrite_ptr;

PFNGLUNIFORM4I64VARBPROC epoxy_glUniform4i64vARB = epoxy_glUniform4i64vARB_global_rewrite_ptr;

PFNGLUNIFORM4I64VNVPROC epoxy_glUniform4i64vNV = epoxy_glUniform4i64vNV_global_rewrite_ptr;

PFNGLUNIFORM4IARBPROC epoxy_glUniform4iARB = epoxy_glUniform4iARB_global_rewrite_ptr;

PFNGLUNIFORM4IVPROC epoxy_glUniform4iv = epoxy_glUniform4iv_global_rewrite_ptr;

PFNGLUNIFORM4IVARBPROC epoxy_glUniform4ivARB = epoxy_glUniform4ivARB_global_rewrite_ptr;

PFNGLUNIFORM4UIPROC epoxy_glUniform4ui = epoxy_glUniform4ui_global_rewrite_ptr;

PFNGLUNIFORM4UI64ARBPROC epoxy_glUniform4ui64ARB = epoxy_glUniform4ui64ARB_global_rewrite_ptr;

PFNGLUNIFORM4UI64NVPROC epoxy_glUniform4ui64NV = epoxy_glUniform4ui64NV_global_rewrite_ptr;

PFNGLUNIFORM4UI64VARBPROC epoxy_glUniform4ui64vARB = epoxy_glUniform4ui64vARB_global_rewrite_ptr;

PFNGLUNIFORM4UI64VNVPROC epoxy_glUniform4ui64vNV = epoxy_glUniform4ui64vNV_global_rewrite_ptr;

PFNGLUNIFORM4UIEXTPROC epoxy_glUniform4uiEXT = epoxy_glUniform4uiEXT_global_rewrite_ptr;

PFNGLUNIFORM4UIVPROC epoxy_glUniform4uiv = epoxy_glUniform4uiv_global_rewrite_ptr;

PFNGLUNIFORM4UIVEXTPROC epoxy_glUniform4uivEXT = epoxy_glUniform4uivEXT_global_rewrite_ptr;

PFNGLUNIFORMBLOCKBINDINGPROC epoxy_glUniformBlockBinding = epoxy_glUniformBlockBinding_global_rewrite_ptr;

PFNGLUNIFORMBUFFEREXTPROC epoxy_glUniformBufferEXT = epoxy_glUniformBufferEXT_global_rewrite_ptr;

PFNGLUNIFORMHANDLEUI64ARBPROC epoxy_glUniformHandleui64ARB = epoxy_glUniformHandleui64ARB_global_rewrite_ptr;

PFNGLUNIFORMHANDLEUI64IMGPROC epoxy_glUniformHandleui64IMG = epoxy_glUniformHandleui64IMG_global_rewrite_ptr;

PFNGLUNIFORMHANDLEUI64NVPROC epoxy_glUniformHandleui64NV = epoxy_glUniformHandleui64NV_global_rewrite_ptr;

PFNGLUNIFORMHANDLEUI64VARBPROC epoxy_glUniformHandleui64vARB = epoxy_glUniformHandleui64vARB_global_rewrite_ptr;

PFNGLUNIFORMHANDLEUI64VIMGPROC epoxy_glUniformHandleui64vIMG = epoxy_glUniformHandleui64vIMG_global_rewrite_ptr;

PFNGLUNIFORMHANDLEUI64VNVPROC epoxy_glUniformHandleui64vNV = epoxy_glUniformHandleui64vNV_global_rewrite_ptr;

PFNGLUNIFORMMATRIX2DVPROC epoxy_glUniformMatrix2dv = epoxy_glUniformMatrix2dv_global_rewrite_ptr;

PFNGLUNIFORMMATRIX2FVPROC epoxy_glUniformMatrix2fv = epoxy_glUniformMatrix2fv_global_rewrite_ptr;

PFNGLUNIFORMMATRIX2FVARBPROC epoxy_glUniformMatrix2fvARB = epoxy_glUniformMatrix2fvARB_global_rewrite_ptr;

PFNGLUNIFORMMATRIX2X3DVPROC epoxy_glUniformMatrix2x3dv = epoxy_glUniformMatrix2x3dv_global_rewrite_ptr;

PFNGLUNIFORMMATRIX2X3FVPROC epoxy_glUniformMatrix2x3fv = epoxy_glUniformMatrix2x3fv_global_rewrite_ptr;

PFNGLUNIFORMMATRIX2X3FVNVPROC epoxy_glUniformMatrix2x3fvNV = epoxy_glUniformMatrix2x3fvNV_global_rewrite_ptr;

PFNGLUNIFORMMATRIX2X4DVPROC epoxy_glUniformMatrix2x4dv = epoxy_glUniformMatrix2x4dv_global_rewrite_ptr;

PFNGLUNIFORMMATRIX2X4FVPROC epoxy_glUniformMatrix2x4fv = epoxy_glUniformMatrix2x4fv_global_rewrite_ptr;

PFNGLUNIFORMMATRIX2X4FVNVPROC epoxy_glUniformMatrix2x4fvNV = epoxy_glUniformMatrix2x4fvNV_global_rewrite_ptr;

PFNGLUNIFORMMATRIX3DVPROC epoxy_glUniformMatrix3dv = epoxy_glUniformMatrix3dv_global_rewrite_ptr;

PFNGLUNIFORMMATRIX3FVPROC epoxy_glUniformMatrix3fv = epoxy_glUniformMatrix3fv_global_rewrite_ptr;

PFNGLUNIFORMMATRIX3FVARBPROC epoxy_glUniformMatrix3fvARB = epoxy_glUniformMatrix3fvARB_global_rewrite_ptr;

PFNGLUNIFORMMATRIX3X2DVPROC epoxy_glUniformMatrix3x2dv = epoxy_glUniformMatrix3x2dv_global_rewrite_ptr;

PFNGLUNIFORMMATRIX3X2FVPROC epoxy_glUniformMatrix3x2fv = epoxy_glUniformMatrix3x2fv_global_rewrite_ptr;

PFNGLUNIFORMMATRIX3X2FVNVPROC epoxy_glUniformMatrix3x2fvNV = epoxy_glUniformMatrix3x2fvNV_global_rewrite_ptr;

PFNGLUNIFORMMATRIX3X4DVPROC epoxy_glUniformMatrix3x4dv = epoxy_glUniformMatrix3x4dv_global_rewrite_ptr;

PFNGLUNIFORMMATRIX3X4FVPROC epoxy_glUniformMatrix3x4fv = epoxy_glUniformMatrix3x4fv_global_rewrite_ptr;

PFNGLUNIFORMMATRIX3X4FVNVPROC epoxy_glUniformMatrix3x4fvNV = epoxy_glUniformMatrix3x4fvNV_global_rewrite_ptr;

PFNGLUNIFORMMATRIX4DVPROC epoxy_glUniformMatrix4dv = epoxy_glUniformMatrix4dv_global_rewrite_ptr;

PFNGLUNIFORMMATRIX4FVPROC epoxy_glUniformMatrix4fv = epoxy_glUniformMatrix4fv_global_rewrite_ptr;

PFNGLUNIFORMMATRIX4FVARBPROC epoxy_glUniformMatrix4fvARB = epoxy_glUniformMatrix4fvARB_global_rewrite_ptr;

PFNGLUNIFORMMATRIX4X2DVPROC epoxy_glUniformMatrix4x2dv = epoxy_glUniformMatrix4x2dv_global_rewrite_ptr;

PFNGLUNIFORMMATRIX4X2FVPROC epoxy_glUniformMatrix4x2fv = epoxy_glUniformMatrix4x2fv_global_rewrite_ptr;

PFNGLUNIFORMMATRIX4X2FVNVPROC epoxy_glUniformMatrix4x2fvNV = epoxy_glUniformMatrix4x2fvNV_global_rewrite_ptr;

PFNGLUNIFORMMATRIX4X3DVPROC epoxy_glUniformMatrix4x3dv = epoxy_glUniformMatrix4x3dv_global_rewrite_ptr;

PFNGLUNIFORMMATRIX4X3FVPROC epoxy_glUniformMatrix4x3fv = epoxy_glUniformMatrix4x3fv_global_rewrite_ptr;

PFNGLUNIFORMMATRIX4X3FVNVPROC epoxy_glUniformMatrix4x3fvNV = epoxy_glUniformMatrix4x3fvNV_global_rewrite_ptr;

PFNGLUNIFORMSUBROUTINESUIVPROC epoxy_glUniformSubroutinesuiv = epoxy_glUniformSubroutinesuiv_global_rewrite_ptr;

PFNGLUNIFORMUI64NVPROC epoxy_glUniformui64NV = epoxy_glUniformui64NV_global_rewrite_ptr;

PFNGLUNIFORMUI64VNVPROC epoxy_glUniformui64vNV = epoxy_glUniformui64vNV_global_rewrite_ptr;

PFNGLUNLOCKARRAYSEXTPROC epoxy_glUnlockArraysEXT = epoxy_glUnlockArraysEXT_global_rewrite_ptr;

PFNGLUNMAPBUFFERPROC epoxy_glUnmapBuffer = epoxy_glUnmapBuffer_global_rewrite_ptr;

PFNGLUNMAPBUFFERARBPROC epoxy_glUnmapBufferARB = epoxy_glUnmapBufferARB_global_rewrite_ptr;

PFNGLUNMAPBUFFEROESPROC epoxy_glUnmapBufferOES = epoxy_glUnmapBufferOES_global_rewrite_ptr;

PFNGLUNMAPNAMEDBUFFERPROC epoxy_glUnmapNamedBuffer = epoxy_glUnmapNamedBuffer_global_rewrite_ptr;

PFNGLUNMAPNAMEDBUFFEREXTPROC epoxy_glUnmapNamedBufferEXT = epoxy_glUnmapNamedBufferEXT_global_rewrite_ptr;

PFNGLUNMAPOBJECTBUFFERATIPROC epoxy_glUnmapObjectBufferATI = epoxy_glUnmapObjectBufferATI_global_rewrite_ptr;

PFNGLUNMAPTEXTURE2DINTELPROC epoxy_glUnmapTexture2DINTEL = epoxy_glUnmapTexture2DINTEL_global_rewrite_ptr;

PFNGLUPDATEOBJECTBUFFERATIPROC epoxy_glUpdateObjectBufferATI = epoxy_glUpdateObjectBufferATI_global_rewrite_ptr;

PFNGLUPLOADGPUMASKNVXPROC epoxy_glUploadGpuMaskNVX = epoxy_glUploadGpuMaskNVX_global_rewrite_ptr;

PFNGLUSEPROGRAMPROC epoxy_glUseProgram = epoxy_glUseProgram_global_rewrite_ptr;

PFNGLUSEPROGRAMOBJECTARBPROC epoxy_glUseProgramObjectARB = epoxy_glUseProgramObjectARB_global_rewrite_ptr;

PFNGLUSEPROGRAMSTAGESPROC epoxy_glUseProgramStages = epoxy_glUseProgramStages_global_rewrite_ptr;

PFNGLUSEPROGRAMSTAGESEXTPROC epoxy_glUseProgramStagesEXT = epoxy_glUseProgramStagesEXT_global_rewrite_ptr;

PFNGLUSESHADERPROGRAMEXTPROC epoxy_glUseShaderProgramEXT = epoxy_glUseShaderProgramEXT_global_rewrite_ptr;

PFNGLVDPAUFININVPROC epoxy_glVDPAUFiniNV = epoxy_glVDPAUFiniNV_global_rewrite_ptr;

PFNGLVDPAUGETSURFACEIVNVPROC epoxy_glVDPAUGetSurfaceivNV = epoxy_glVDPAUGetSurfaceivNV_global_rewrite_ptr;

PFNGLVDPAUINITNVPROC epoxy_glVDPAUInitNV = epoxy_glVDPAUInitNV_global_rewrite_ptr;

PFNGLVDPAUISSURFACENVPROC epoxy_glVDPAUIsSurfaceNV = epoxy_glVDPAUIsSurfaceNV_global_rewrite_ptr;

PFNGLVDPAUMAPSURFACESNVPROC epoxy_glVDPAUMapSurfacesNV = epoxy_glVDPAUMapSurfacesNV_global_rewrite_ptr;

PFNGLVDPAUREGISTEROUTPUTSURFACENVPROC epoxy_glVDPAURegisterOutputSurfaceNV = epoxy_glVDPAURegisterOutputSurfaceNV_global_rewrite_ptr;

PFNGLVDPAUREGISTERVIDEOSURFACENVPROC epoxy_glVDPAURegisterVideoSurfaceNV = epoxy_glVDPAURegisterVideoSurfaceNV_global_rewrite_ptr;

PFNGLVDPAUREGISTERVIDEOSURFACEWITHPICTURESTRUCTURENVPROC epoxy_glVDPAURegisterVideoSurfaceWithPictureStructureNV = epoxy_glVDPAURegisterVideoSurfaceWithPictureStructureNV_global_rewrite_ptr;

PFNGLVDPAUSURFACEACCESSNVPROC epoxy_glVDPAUSurfaceAccessNV = epoxy_glVDPAUSurfaceAccessNV_global_rewrite_ptr;

PFNGLVDPAUUNMAPSURFACESNVPROC epoxy_glVDPAUUnmapSurfacesNV = epoxy_glVDPAUUnmapSurfacesNV_global_rewrite_ptr;

PFNGLVDPAUUNREGISTERSURFACENVPROC epoxy_glVDPAUUnregisterSurfaceNV = epoxy_glVDPAUUnregisterSurfaceNV_global_rewrite_ptr;

PFNGLVALIDATEPROGRAMPROC epoxy_glValidateProgram = epoxy_glValidateProgram_global_rewrite_ptr;

PFNGLVALIDATEPROGRAMARBPROC epoxy_glValidateProgramARB = epoxy_glValidateProgramARB_global_rewrite_ptr;

PFNGLVALIDATEPROGRAMPIPELINEPROC epoxy_glValidateProgramPipeline = epoxy_glValidateProgramPipeline_global_rewrite_ptr;

PFNGLVALIDATEPROGRAMPIPELINEEXTPROC epoxy_glValidateProgramPipelineEXT = epoxy_glValidateProgramPipelineEXT_global_rewrite_ptr;

PFNGLVARIANTARRAYOBJECTATIPROC epoxy_glVariantArrayObjectATI = epoxy_glVariantArrayObjectATI_global_rewrite_ptr;

PFNGLVARIANTPOINTEREXTPROC epoxy_glVariantPointerEXT = epoxy_glVariantPointerEXT_global_rewrite_ptr;

PFNGLVARIANTBVEXTPROC epoxy_glVariantbvEXT = epoxy_glVariantbvEXT_global_rewrite_ptr;

PFNGLVARIANTDVEXTPROC epoxy_glVariantdvEXT = epoxy_glVariantdvEXT_global_rewrite_ptr;

PFNGLVARIANTFVEXTPROC epoxy_glVariantfvEXT = epoxy_glVariantfvEXT_global_rewrite_ptr;

PFNGLVARIANTIVEXTPROC epoxy_glVariantivEXT = epoxy_glVariantivEXT_global_rewrite_ptr;

PFNGLVARIANTSVEXTPROC epoxy_glVariantsvEXT = epoxy_glVariantsvEXT_global_rewrite_ptr;

PFNGLVARIANTUBVEXTPROC epoxy_glVariantubvEXT = epoxy_glVariantubvEXT_global_rewrite_ptr;

PFNGLVARIANTUIVEXTPROC epoxy_glVariantuivEXT = epoxy_glVariantuivEXT_global_rewrite_ptr;

PFNGLVARIANTUSVEXTPROC epoxy_glVariantusvEXT = epoxy_glVariantusvEXT_global_rewrite_ptr;

PFNGLVERTEX2BOESPROC epoxy_glVertex2bOES = epoxy_glVertex2bOES_global_rewrite_ptr;

PFNGLVERTEX2BVOESPROC epoxy_glVertex2bvOES = epoxy_glVertex2bvOES_global_rewrite_ptr;

PFNGLVERTEX2DPROC epoxy_glVertex2d = epoxy_glVertex2d_global_rewrite_ptr;

PFNGLVERTEX2DVPROC epoxy_glVertex2dv = epoxy_glVertex2dv_global_rewrite_ptr;

PFNGLVERTEX2FPROC epoxy_glVertex2f = epoxy_glVertex2f_global_rewrite_ptr;

PFNGLVERTEX2FVPROC epoxy_glVertex2fv = epoxy_glVertex2fv_global_rewrite_ptr;

PFNGLVERTEX2HNVPROC epoxy_glVertex2hNV = epoxy_glVertex2hNV_global_rewrite_ptr;

PFNGLVERTEX2HVNVPROC epoxy_glVertex2hvNV = epoxy_glVertex2hvNV_global_rewrite_ptr;

PFNGLVERTEX2IPROC epoxy_glVertex2i = epoxy_glVertex2i_global_rewrite_ptr;

PFNGLVERTEX2IVPROC epoxy_glVertex2iv = epoxy_glVertex2iv_global_rewrite_ptr;

PFNGLVERTEX2SPROC epoxy_glVertex2s = epoxy_glVertex2s_global_rewrite_ptr;

PFNGLVERTEX2SVPROC epoxy_glVertex2sv = epoxy_glVertex2sv_global_rewrite_ptr;

PFNGLVERTEX2XOESPROC epoxy_glVertex2xOES = epoxy_glVertex2xOES_global_rewrite_ptr;

PFNGLVERTEX2XVOESPROC epoxy_glVertex2xvOES = epoxy_glVertex2xvOES_global_rewrite_ptr;

PFNGLVERTEX3BOESPROC epoxy_glVertex3bOES = epoxy_glVertex3bOES_global_rewrite_ptr;

PFNGLVERTEX3BVOESPROC epoxy_glVertex3bvOES = epoxy_glVertex3bvOES_global_rewrite_ptr;

PFNGLVERTEX3DPROC epoxy_glVertex3d = epoxy_glVertex3d_global_rewrite_ptr;

PFNGLVERTEX3DVPROC epoxy_glVertex3dv = epoxy_glVertex3dv_global_rewrite_ptr;

PFNGLVERTEX3FPROC epoxy_glVertex3f = epoxy_glVertex3f_global_rewrite_ptr;

PFNGLVERTEX3FVPROC epoxy_glVertex3fv = epoxy_glVertex3fv_global_rewrite_ptr;

PFNGLVERTEX3HNVPROC epoxy_glVertex3hNV = epoxy_glVertex3hNV_global_rewrite_ptr;

PFNGLVERTEX3HVNVPROC epoxy_glVertex3hvNV = epoxy_glVertex3hvNV_global_rewrite_ptr;

PFNGLVERTEX3IPROC epoxy_glVertex3i = epoxy_glVertex3i_global_rewrite_ptr;

PFNGLVERTEX3IVPROC epoxy_glVertex3iv = epoxy_glVertex3iv_global_rewrite_ptr;

PFNGLVERTEX3SPROC epoxy_glVertex3s = epoxy_glVertex3s_global_rewrite_ptr;

PFNGLVERTEX3SVPROC epoxy_glVertex3sv = epoxy_glVertex3sv_global_rewrite_ptr;

PFNGLVERTEX3XOESPROC epoxy_glVertex3xOES = epoxy_glVertex3xOES_global_rewrite_ptr;

PFNGLVERTEX3XVOESPROC epoxy_glVertex3xvOES = epoxy_glVertex3xvOES_global_rewrite_ptr;

PFNGLVERTEX4BOESPROC epoxy_glVertex4bOES = epoxy_glVertex4bOES_global_rewrite_ptr;

PFNGLVERTEX4BVOESPROC epoxy_glVertex4bvOES = epoxy_glVertex4bvOES_global_rewrite_ptr;

PFNGLVERTEX4DPROC epoxy_glVertex4d = epoxy_glVertex4d_global_rewrite_ptr;

PFNGLVERTEX4DVPROC epoxy_glVertex4dv = epoxy_glVertex4dv_global_rewrite_ptr;

PFNGLVERTEX4FPROC epoxy_glVertex4f = epoxy_glVertex4f_global_rewrite_ptr;

PFNGLVERTEX4FVPROC epoxy_glVertex4fv = epoxy_glVertex4fv_global_rewrite_ptr;

PFNGLVERTEX4HNVPROC epoxy_glVertex4hNV = epoxy_glVertex4hNV_global_rewrite_ptr;

PFNGLVERTEX4HVNVPROC epoxy_glVertex4hvNV = epoxy_glVertex4hvNV_global_rewrite_ptr;

PFNGLVERTEX4IPROC epoxy_glVertex4i = epoxy_glVertex4i_global_rewrite_ptr;

PFNGLVERTEX4IVPROC epoxy_glVertex4iv = epoxy_glVertex4iv_global_rewrite_ptr;

PFNGLVERTEX4SPROC epoxy_glVertex4s = epoxy_glVertex4s_global_rewrite_ptr;

PFNGLVERTEX4SVPROC epoxy_glVertex4sv = epoxy_glVertex4sv_global_rewrite_ptr;

PFNGLVERTEX4XOESPROC epoxy_glVertex4xOES = epoxy_glVertex4xOES_global_rewrite_ptr;

PFNGLVERTEX4XVOESPROC epoxy_glVertex4xvOES = epoxy_glVertex4xvOES_global_rewrite_ptr;

PFNGLVERTEXARRAYATTRIBBINDINGPROC epoxy_glVertexArrayAttribBinding = epoxy_glVertexArrayAttribBinding_global_rewrite_ptr;

PFNGLVERTEXARRAYATTRIBFORMATPROC epoxy_glVertexArrayAttribFormat = epoxy_glVertexArrayAttribFormat_global_rewrite_ptr;

PFNGLVERTEXARRAYATTRIBIFORMATPROC epoxy_glVertexArrayAttribIFormat = epoxy_glVertexArrayAttribIFormat_global_rewrite_ptr;

PFNGLVERTEXARRAYATTRIBLFORMATPROC epoxy_glVertexArrayAttribLFormat = epoxy_glVertexArrayAttribLFormat_global_rewrite_ptr;

PFNGLVERTEXARRAYBINDVERTEXBUFFEREXTPROC epoxy_glVertexArrayBindVertexBufferEXT = epoxy_glVertexArrayBindVertexBufferEXT_global_rewrite_ptr;

PFNGLVERTEXARRAYBINDINGDIVISORPROC epoxy_glVertexArrayBindingDivisor = epoxy_glVertexArrayBindingDivisor_global_rewrite_ptr;

PFNGLVERTEXARRAYCOLOROFFSETEXTPROC epoxy_glVertexArrayColorOffsetEXT = epoxy_glVertexArrayColorOffsetEXT_global_rewrite_ptr;

PFNGLVERTEXARRAYEDGEFLAGOFFSETEXTPROC epoxy_glVertexArrayEdgeFlagOffsetEXT = epoxy_glVertexArrayEdgeFlagOffsetEXT_global_rewrite_ptr;

PFNGLVERTEXARRAYELEMENTBUFFERPROC epoxy_glVertexArrayElementBuffer = epoxy_glVertexArrayElementBuffer_global_rewrite_ptr;

PFNGLVERTEXARRAYFOGCOORDOFFSETEXTPROC epoxy_glVertexArrayFogCoordOffsetEXT = epoxy_glVertexArrayFogCoordOffsetEXT_global_rewrite_ptr;

PFNGLVERTEXARRAYINDEXOFFSETEXTPROC epoxy_glVertexArrayIndexOffsetEXT = epoxy_glVertexArrayIndexOffsetEXT_global_rewrite_ptr;

PFNGLVERTEXARRAYMULTITEXCOORDOFFSETEXTPROC epoxy_glVertexArrayMultiTexCoordOffsetEXT = epoxy_glVertexArrayMultiTexCoordOffsetEXT_global_rewrite_ptr;

PFNGLVERTEXARRAYNORMALOFFSETEXTPROC epoxy_glVertexArrayNormalOffsetEXT = epoxy_glVertexArrayNormalOffsetEXT_global_rewrite_ptr;

PFNGLVERTEXARRAYPARAMETERIAPPLEPROC epoxy_glVertexArrayParameteriAPPLE = epoxy_glVertexArrayParameteriAPPLE_global_rewrite_ptr;

PFNGLVERTEXARRAYRANGEAPPLEPROC epoxy_glVertexArrayRangeAPPLE = epoxy_glVertexArrayRangeAPPLE_global_rewrite_ptr;

PFNGLVERTEXARRAYRANGENVPROC epoxy_glVertexArrayRangeNV = epoxy_glVertexArrayRangeNV_global_rewrite_ptr;

PFNGLVERTEXARRAYSECONDARYCOLOROFFSETEXTPROC epoxy_glVertexArraySecondaryColorOffsetEXT = epoxy_glVertexArraySecondaryColorOffsetEXT_global_rewrite_ptr;

PFNGLVERTEXARRAYTEXCOORDOFFSETEXTPROC epoxy_glVertexArrayTexCoordOffsetEXT = epoxy_glVertexArrayTexCoordOffsetEXT_global_rewrite_ptr;

PFNGLVERTEXARRAYVERTEXATTRIBBINDINGEXTPROC epoxy_glVertexArrayVertexAttribBindingEXT = epoxy_glVertexArrayVertexAttribBindingEXT_global_rewrite_ptr;

PFNGLVERTEXARRAYVERTEXATTRIBDIVISOREXTPROC epoxy_glVertexArrayVertexAttribDivisorEXT = epoxy_glVertexArrayVertexAttribDivisorEXT_global_rewrite_ptr;

PFNGLVERTEXARRAYVERTEXATTRIBFORMATEXTPROC epoxy_glVertexArrayVertexAttribFormatEXT = epoxy_glVertexArrayVertexAttribFormatEXT_global_rewrite_ptr;

PFNGLVERTEXARRAYVERTEXATTRIBIFORMATEXTPROC epoxy_glVertexArrayVertexAttribIFormatEXT = epoxy_glVertexArrayVertexAttribIFormatEXT_global_rewrite_ptr;

PFNGLVERTEXARRAYVERTEXATTRIBIOFFSETEXTPROC epoxy_glVertexArrayVertexAttribIOffsetEXT = epoxy_glVertexArrayVertexAttribIOffsetEXT_global_rewrite_ptr;

PFNGLVERTEXARRAYVERTEXATTRIBLFORMATEXTPROC epoxy_glVertexArrayVertexAttribLFormatEXT = epoxy_glVertexArrayVertexAttribLFormatEXT_global_rewrite_ptr;

PFNGLVERTEXARRAYVERTEXATTRIBLOFFSETEXTPROC epoxy_glVertexArrayVertexAttribLOffsetEXT = epoxy_glVertexArrayVertexAttribLOffsetEXT_global_rewrite_ptr;

PFNGLVERTEXARRAYVERTEXATTRIBOFFSETEXTPROC epoxy_glVertexArrayVertexAttribOffsetEXT = epoxy_glVertexArrayVertexAttribOffsetEXT_global_rewrite_ptr;

PFNGLVERTEXARRAYVERTEXBINDINGDIVISOREXTPROC epoxy_glVertexArrayVertexBindingDivisorEXT = epoxy_glVertexArrayVertexBindingDivisorEXT_global_rewrite_ptr;

PFNGLVERTEXARRAYVERTEXBUFFERPROC epoxy_glVertexArrayVertexBuffer = epoxy_glVertexArrayVertexBuffer_global_rewrite_ptr;

PFNGLVERTEXARRAYVERTEXBUFFERSPROC epoxy_glVertexArrayVertexBuffers = epoxy_glVertexArrayVertexBuffers_global_rewrite_ptr;

PFNGLVERTEXARRAYVERTEXOFFSETEXTPROC epoxy_glVertexArrayVertexOffsetEXT = epoxy_glVertexArrayVertexOffsetEXT_global_rewrite_ptr;

PFNGLVERTEXATTRIB1DPROC epoxy_glVertexAttrib1d = epoxy_glVertexAttrib1d_global_rewrite_ptr;

PFNGLVERTEXATTRIB1DARBPROC epoxy_glVertexAttrib1dARB = epoxy_glVertexAttrib1dARB_global_rewrite_ptr;

PFNGLVERTEXATTRIB1DNVPROC epoxy_glVertexAttrib1dNV = epoxy_glVertexAttrib1dNV_global_rewrite_ptr;

PFNGLVERTEXATTRIB1DVPROC epoxy_glVertexAttrib1dv = epoxy_glVertexAttrib1dv_global_rewrite_ptr;

PFNGLVERTEXATTRIB1DVARBPROC epoxy_glVertexAttrib1dvARB = epoxy_glVertexAttrib1dvARB_global_rewrite_ptr;

PFNGLVERTEXATTRIB1DVNVPROC epoxy_glVertexAttrib1dvNV = epoxy_glVertexAttrib1dvNV_global_rewrite_ptr;

PFNGLVERTEXATTRIB1FPROC epoxy_glVertexAttrib1f = epoxy_glVertexAttrib1f_global_rewrite_ptr;

PFNGLVERTEXATTRIB1FARBPROC epoxy_glVertexAttrib1fARB = epoxy_glVertexAttrib1fARB_global_rewrite_ptr;

PFNGLVERTEXATTRIB1FNVPROC epoxy_glVertexAttrib1fNV = epoxy_glVertexAttrib1fNV_global_rewrite_ptr;

PFNGLVERTEXATTRIB1FVPROC epoxy_glVertexAttrib1fv = epoxy_glVertexAttrib1fv_global_rewrite_ptr;

PFNGLVERTEXATTRIB1FVARBPROC epoxy_glVertexAttrib1fvARB = epoxy_glVertexAttrib1fvARB_global_rewrite_ptr;

PFNGLVERTEXATTRIB1FVNVPROC epoxy_glVertexAttrib1fvNV = epoxy_glVertexAttrib1fvNV_global_rewrite_ptr;

PFNGLVERTEXATTRIB1HNVPROC epoxy_glVertexAttrib1hNV = epoxy_glVertexAttrib1hNV_global_rewrite_ptr;

PFNGLVERTEXATTRIB1HVNVPROC epoxy_glVertexAttrib1hvNV = epoxy_glVertexAttrib1hvNV_global_rewrite_ptr;

PFNGLVERTEXATTRIB1SPROC epoxy_glVertexAttrib1s = epoxy_glVertexAttrib1s_global_rewrite_ptr;

PFNGLVERTEXATTRIB1SARBPROC epoxy_glVertexAttrib1sARB = epoxy_glVertexAttrib1sARB_global_rewrite_ptr;

PFNGLVERTEXATTRIB1SNVPROC epoxy_glVertexAttrib1sNV = epoxy_glVertexAttrib1sNV_global_rewrite_ptr;

PFNGLVERTEXATTRIB1SVPROC epoxy_glVertexAttrib1sv = epoxy_glVertexAttrib1sv_global_rewrite_ptr;

PFNGLVERTEXATTRIB1SVARBPROC epoxy_glVertexAttrib1svARB = epoxy_glVertexAttrib1svARB_global_rewrite_ptr;

PFNGLVERTEXATTRIB1SVNVPROC epoxy_glVertexAttrib1svNV = epoxy_glVertexAttrib1svNV_global_rewrite_ptr;

PFNGLVERTEXATTRIB2DPROC epoxy_glVertexAttrib2d = epoxy_glVertexAttrib2d_global_rewrite_ptr;

PFNGLVERTEXATTRIB2DARBPROC epoxy_glVertexAttrib2dARB = epoxy_glVertexAttrib2dARB_global_rewrite_ptr;

PFNGLVERTEXATTRIB2DNVPROC epoxy_glVertexAttrib2dNV = epoxy_glVertexAttrib2dNV_global_rewrite_ptr;

PFNGLVERTEXATTRIB2DVPROC epoxy_glVertexAttrib2dv = epoxy_glVertexAttrib2dv_global_rewrite_ptr;

PFNGLVERTEXATTRIB2DVARBPROC epoxy_glVertexAttrib2dvARB = epoxy_glVertexAttrib2dvARB_global_rewrite_ptr;

PFNGLVERTEXATTRIB2DVNVPROC epoxy_glVertexAttrib2dvNV = epoxy_glVertexAttrib2dvNV_global_rewrite_ptr;

PFNGLVERTEXATTRIB2FPROC epoxy_glVertexAttrib2f = epoxy_glVertexAttrib2f_global_rewrite_ptr;

PFNGLVERTEXATTRIB2FARBPROC epoxy_glVertexAttrib2fARB = epoxy_glVertexAttrib2fARB_global_rewrite_ptr;

PFNGLVERTEXATTRIB2FNVPROC epoxy_glVertexAttrib2fNV = epoxy_glVertexAttrib2fNV_global_rewrite_ptr;

PFNGLVERTEXATTRIB2FVPROC epoxy_glVertexAttrib2fv = epoxy_glVertexAttrib2fv_global_rewrite_ptr;

PFNGLVERTEXATTRIB2FVARBPROC epoxy_glVertexAttrib2fvARB = epoxy_glVertexAttrib2fvARB_global_rewrite_ptr;

PFNGLVERTEXATTRIB2FVNVPROC epoxy_glVertexAttrib2fvNV = epoxy_glVertexAttrib2fvNV_global_rewrite_ptr;

PFNGLVERTEXATTRIB2HNVPROC epoxy_glVertexAttrib2hNV = epoxy_glVertexAttrib2hNV_global_rewrite_ptr;

PFNGLVERTEXATTRIB2HVNVPROC epoxy_glVertexAttrib2hvNV = epoxy_glVertexAttrib2hvNV_global_rewrite_ptr;

PFNGLVERTEXATTRIB2SPROC epoxy_glVertexAttrib2s = epoxy_glVertexAttrib2s_global_rewrite_ptr;

PFNGLVERTEXATTRIB2SARBPROC epoxy_glVertexAttrib2sARB = epoxy_glVertexAttrib2sARB_global_rewrite_ptr;

PFNGLVERTEXATTRIB2SNVPROC epoxy_glVertexAttrib2sNV = epoxy_glVertexAttrib2sNV_global_rewrite_ptr;

PFNGLVERTEXATTRIB2SVPROC epoxy_glVertexAttrib2sv = epoxy_glVertexAttrib2sv_global_rewrite_ptr;

PFNGLVERTEXATTRIB2SVARBPROC epoxy_glVertexAttrib2svARB = epoxy_glVertexAttrib2svARB_global_rewrite_ptr;

PFNGLVERTEXATTRIB2SVNVPROC epoxy_glVertexAttrib2svNV = epoxy_glVertexAttrib2svNV_global_rewrite_ptr;

PFNGLVERTEXATTRIB3DPROC epoxy_glVertexAttrib3d = epoxy_glVertexAttrib3d_global_rewrite_ptr;

PFNGLVERTEXATTRIB3DARBPROC epoxy_glVertexAttrib3dARB = epoxy_glVertexAttrib3dARB_global_rewrite_ptr;

PFNGLVERTEXATTRIB3DNVPROC epoxy_glVertexAttrib3dNV = epoxy_glVertexAttrib3dNV_global_rewrite_ptr;

PFNGLVERTEXATTRIB3DVPROC epoxy_glVertexAttrib3dv = epoxy_glVertexAttrib3dv_global_rewrite_ptr;

PFNGLVERTEXATTRIB3DVARBPROC epoxy_glVertexAttrib3dvARB = epoxy_glVertexAttrib3dvARB_global_rewrite_ptr;

PFNGLVERTEXATTRIB3DVNVPROC epoxy_glVertexAttrib3dvNV = epoxy_glVertexAttrib3dvNV_global_rewrite_ptr;

PFNGLVERTEXATTRIB3FPROC epoxy_glVertexAttrib3f = epoxy_glVertexAttrib3f_global_rewrite_ptr;

PFNGLVERTEXATTRIB3FARBPROC epoxy_glVertexAttrib3fARB = epoxy_glVertexAttrib3fARB_global_rewrite_ptr;

PFNGLVERTEXATTRIB3FNVPROC epoxy_glVertexAttrib3fNV = epoxy_glVertexAttrib3fNV_global_rewrite_ptr;

PFNGLVERTEXATTRIB3FVPROC epoxy_glVertexAttrib3fv = epoxy_glVertexAttrib3fv_global_rewrite_ptr;

PFNGLVERTEXATTRIB3FVARBPROC epoxy_glVertexAttrib3fvARB = epoxy_glVertexAttrib3fvARB_global_rewrite_ptr;

PFNGLVERTEXATTRIB3FVNVPROC epoxy_glVertexAttrib3fvNV = epoxy_glVertexAttrib3fvNV_global_rewrite_ptr;

PFNGLVERTEXATTRIB3HNVPROC epoxy_glVertexAttrib3hNV = epoxy_glVertexAttrib3hNV_global_rewrite_ptr;

PFNGLVERTEXATTRIB3HVNVPROC epoxy_glVertexAttrib3hvNV = epoxy_glVertexAttrib3hvNV_global_rewrite_ptr;

PFNGLVERTEXATTRIB3SPROC epoxy_glVertexAttrib3s = epoxy_glVertexAttrib3s_global_rewrite_ptr;

PFNGLVERTEXATTRIB3SARBPROC epoxy_glVertexAttrib3sARB = epoxy_glVertexAttrib3sARB_global_rewrite_ptr;

PFNGLVERTEXATTRIB3SNVPROC epoxy_glVertexAttrib3sNV = epoxy_glVertexAttrib3sNV_global_rewrite_ptr;

PFNGLVERTEXATTRIB3SVPROC epoxy_glVertexAttrib3sv = epoxy_glVertexAttrib3sv_global_rewrite_ptr;

PFNGLVERTEXATTRIB3SVARBPROC epoxy_glVertexAttrib3svARB = epoxy_glVertexAttrib3svARB_global_rewrite_ptr;

PFNGLVERTEXATTRIB3SVNVPROC epoxy_glVertexAttrib3svNV = epoxy_glVertexAttrib3svNV_global_rewrite_ptr;

PFNGLVERTEXATTRIB4NBVPROC epoxy_glVertexAttrib4Nbv = epoxy_glVertexAttrib4Nbv_global_rewrite_ptr;

PFNGLVERTEXATTRIB4NBVARBPROC epoxy_glVertexAttrib4NbvARB = epoxy_glVertexAttrib4NbvARB_global_rewrite_ptr;

PFNGLVERTEXATTRIB4NIVPROC epoxy_glVertexAttrib4Niv = epoxy_glVertexAttrib4Niv_global_rewrite_ptr;

PFNGLVERTEXATTRIB4NIVARBPROC epoxy_glVertexAttrib4NivARB = epoxy_glVertexAttrib4NivARB_global_rewrite_ptr;

PFNGLVERTEXATTRIB4NSVPROC epoxy_glVertexAttrib4Nsv = epoxy_glVertexAttrib4Nsv_global_rewrite_ptr;

PFNGLVERTEXATTRIB4NSVARBPROC epoxy_glVertexAttrib4NsvARB = epoxy_glVertexAttrib4NsvARB_global_rewrite_ptr;

PFNGLVERTEXATTRIB4NUBPROC epoxy_glVertexAttrib4Nub = epoxy_glVertexAttrib4Nub_global_rewrite_ptr;

PFNGLVERTEXATTRIB4NUBARBPROC epoxy_glVertexAttrib4NubARB = epoxy_glVertexAttrib4NubARB_global_rewrite_ptr;

PFNGLVERTEXATTRIB4NUBVPROC epoxy_glVertexAttrib4Nubv = epoxy_glVertexAttrib4Nubv_global_rewrite_ptr;

PFNGLVERTEXATTRIB4NUBVARBPROC epoxy_glVertexAttrib4NubvARB = epoxy_glVertexAttrib4NubvARB_global_rewrite_ptr;

PFNGLVERTEXATTRIB4NUIVPROC epoxy_glVertexAttrib4Nuiv = epoxy_glVertexAttrib4Nuiv_global_rewrite_ptr;

PFNGLVERTEXATTRIB4NUIVARBPROC epoxy_glVertexAttrib4NuivARB = epoxy_glVertexAttrib4NuivARB_global_rewrite_ptr;

PFNGLVERTEXATTRIB4NUSVPROC epoxy_glVertexAttrib4Nusv = epoxy_glVertexAttrib4Nusv_global_rewrite_ptr;

PFNGLVERTEXATTRIB4NUSVARBPROC epoxy_glVertexAttrib4NusvARB = epoxy_glVertexAttrib4NusvARB_global_rewrite_ptr;

PFNGLVERTEXATTRIB4BVPROC epoxy_glVertexAttrib4bv = epoxy_glVertexAttrib4bv_global_rewrite_ptr;

PFNGLVERTEXATTRIB4BVARBPROC epoxy_glVertexAttrib4bvARB = epoxy_glVertexAttrib4bvARB_global_rewrite_ptr;

PFNGLVERTEXATTRIB4DPROC epoxy_glVertexAttrib4d = epoxy_glVertexAttrib4d_global_rewrite_ptr;

PFNGLVERTEXATTRIB4DARBPROC epoxy_glVertexAttrib4dARB = epoxy_glVertexAttrib4dARB_global_rewrite_ptr;

PFNGLVERTEXATTRIB4DNVPROC epoxy_glVertexAttrib4dNV = epoxy_glVertexAttrib4dNV_global_rewrite_ptr;

PFNGLVERTEXATTRIB4DVPROC epoxy_glVertexAttrib4dv = epoxy_glVertexAttrib4dv_global_rewrite_ptr;

PFNGLVERTEXATTRIB4DVARBPROC epoxy_glVertexAttrib4dvARB = epoxy_glVertexAttrib4dvARB_global_rewrite_ptr;

PFNGLVERTEXATTRIB4DVNVPROC epoxy_glVertexAttrib4dvNV = epoxy_glVertexAttrib4dvNV_global_rewrite_ptr;

PFNGLVERTEXATTRIB4FPROC epoxy_glVertexAttrib4f = epoxy_glVertexAttrib4f_global_rewrite_ptr;

PFNGLVERTEXATTRIB4FARBPROC epoxy_glVertexAttrib4fARB = epoxy_glVertexAttrib4fARB_global_rewrite_ptr;

PFNGLVERTEXATTRIB4FNVPROC epoxy_glVertexAttrib4fNV = epoxy_glVertexAttrib4fNV_global_rewrite_ptr;

PFNGLVERTEXATTRIB4FVPROC epoxy_glVertexAttrib4fv = epoxy_glVertexAttrib4fv_global_rewrite_ptr;

PFNGLVERTEXATTRIB4FVARBPROC epoxy_glVertexAttrib4fvARB = epoxy_glVertexAttrib4fvARB_global_rewrite_ptr;

PFNGLVERTEXATTRIB4FVNVPROC epoxy_glVertexAttrib4fvNV = epoxy_glVertexAttrib4fvNV_global_rewrite_ptr;

PFNGLVERTEXATTRIB4HNVPROC epoxy_glVertexAttrib4hNV = epoxy_glVertexAttrib4hNV_global_rewrite_ptr;

PFNGLVERTEXATTRIB4HVNVPROC epoxy_glVertexAttrib4hvNV = epoxy_glVertexAttrib4hvNV_global_rewrite_ptr;

PFNGLVERTEXATTRIB4IVPROC epoxy_glVertexAttrib4iv = epoxy_glVertexAttrib4iv_global_rewrite_ptr;

PFNGLVERTEXATTRIB4IVARBPROC epoxy_glVertexAttrib4ivARB = epoxy_glVertexAttrib4ivARB_global_rewrite_ptr;

PFNGLVERTEXATTRIB4SPROC epoxy_glVertexAttrib4s = epoxy_glVertexAttrib4s_global_rewrite_ptr;

PFNGLVERTEXATTRIB4SARBPROC epoxy_glVertexAttrib4sARB = epoxy_glVertexAttrib4sARB_global_rewrite_ptr;

PFNGLVERTEXATTRIB4SNVPROC epoxy_glVertexAttrib4sNV = epoxy_glVertexAttrib4sNV_global_rewrite_ptr;

PFNGLVERTEXATTRIB4SVPROC epoxy_glVertexAttrib4sv = epoxy_glVertexAttrib4sv_global_rewrite_ptr;

PFNGLVERTEXATTRIB4SVARBPROC epoxy_glVertexAttrib4svARB = epoxy_glVertexAttrib4svARB_global_rewrite_ptr;

PFNGLVERTEXATTRIB4SVNVPROC epoxy_glVertexAttrib4svNV = epoxy_glVertexAttrib4svNV_global_rewrite_ptr;

PFNGLVERTEXATTRIB4UBNVPROC epoxy_glVertexAttrib4ubNV = epoxy_glVertexAttrib4ubNV_global_rewrite_ptr;

PFNGLVERTEXATTRIB4UBVPROC epoxy_glVertexAttrib4ubv = epoxy_glVertexAttrib4ubv_global_rewrite_ptr;

PFNGLVERTEXATTRIB4UBVARBPROC epoxy_glVertexAttrib4ubvARB = epoxy_glVertexAttrib4ubvARB_global_rewrite_ptr;

PFNGLVERTEXATTRIB4UBVNVPROC epoxy_glVertexAttrib4ubvNV = epoxy_glVertexAttrib4ubvNV_global_rewrite_ptr;

PFNGLVERTEXATTRIB4UIVPROC epoxy_glVertexAttrib4uiv = epoxy_glVertexAttrib4uiv_global_rewrite_ptr;

PFNGLVERTEXATTRIB4UIVARBPROC epoxy_glVertexAttrib4uivARB = epoxy_glVertexAttrib4uivARB_global_rewrite_ptr;

PFNGLVERTEXATTRIB4USVPROC epoxy_glVertexAttrib4usv = epoxy_glVertexAttrib4usv_global_rewrite_ptr;

PFNGLVERTEXATTRIB4USVARBPROC epoxy_glVertexAttrib4usvARB = epoxy_glVertexAttrib4usvARB_global_rewrite_ptr;

PFNGLVERTEXATTRIBARRAYOBJECTATIPROC epoxy_glVertexAttribArrayObjectATI = epoxy_glVertexAttribArrayObjectATI_global_rewrite_ptr;

PFNGLVERTEXATTRIBBINDINGPROC epoxy_glVertexAttribBinding = epoxy_glVertexAttribBinding_global_rewrite_ptr;

PFNGLVERTEXATTRIBDIVISORPROC epoxy_glVertexAttribDivisor = epoxy_glVertexAttribDivisor_global_rewrite_ptr;

PFNGLVERTEXATTRIBDIVISORANGLEPROC epoxy_glVertexAttribDivisorANGLE = epoxy_glVertexAttribDivisorANGLE_global_rewrite_ptr;

PFNGLVERTEXATTRIBDIVISORARBPROC epoxy_glVertexAttribDivisorARB = epoxy_glVertexAttribDivisorARB_global_rewrite_ptr;

PFNGLVERTEXATTRIBDIVISOREXTPROC epoxy_glVertexAttribDivisorEXT = epoxy_glVertexAttribDivisorEXT_global_rewrite_ptr;

PFNGLVERTEXATTRIBDIVISORNVPROC epoxy_glVertexAttribDivisorNV = epoxy_glVertexAttribDivisorNV_global_rewrite_ptr;

PFNGLVERTEXATTRIBFORMATPROC epoxy_glVertexAttribFormat = epoxy_glVertexAttribFormat_global_rewrite_ptr;

PFNGLVERTEXATTRIBFORMATNVPROC epoxy_glVertexAttribFormatNV = epoxy_glVertexAttribFormatNV_global_rewrite_ptr;

PFNGLVERTEXATTRIBI1IPROC epoxy_glVertexAttribI1i = epoxy_glVertexAttribI1i_global_rewrite_ptr;

PFNGLVERTEXATTRIBI1IEXTPROC epoxy_glVertexAttribI1iEXT = epoxy_glVertexAttribI1iEXT_global_rewrite_ptr;

PFNGLVERTEXATTRIBI1IVPROC epoxy_glVertexAttribI1iv = epoxy_glVertexAttribI1iv_global_rewrite_ptr;

PFNGLVERTEXATTRIBI1IVEXTPROC epoxy_glVertexAttribI1ivEXT = epoxy_glVertexAttribI1ivEXT_global_rewrite_ptr;

PFNGLVERTEXATTRIBI1UIPROC epoxy_glVertexAttribI1ui = epoxy_glVertexAttribI1ui_global_rewrite_ptr;

PFNGLVERTEXATTRIBI1UIEXTPROC epoxy_glVertexAttribI1uiEXT = epoxy_glVertexAttribI1uiEXT_global_rewrite_ptr;

PFNGLVERTEXATTRIBI1UIVPROC epoxy_glVertexAttribI1uiv = epoxy_glVertexAttribI1uiv_global_rewrite_ptr;

PFNGLVERTEXATTRIBI1UIVEXTPROC epoxy_glVertexAttribI1uivEXT = epoxy_glVertexAttribI1uivEXT_global_rewrite_ptr;

PFNGLVERTEXATTRIBI2IPROC epoxy_glVertexAttribI2i = epoxy_glVertexAttribI2i_global_rewrite_ptr;

PFNGLVERTEXATTRIBI2IEXTPROC epoxy_glVertexAttribI2iEXT = epoxy_glVertexAttribI2iEXT_global_rewrite_ptr;

PFNGLVERTEXATTRIBI2IVPROC epoxy_glVertexAttribI2iv = epoxy_glVertexAttribI2iv_global_rewrite_ptr;

PFNGLVERTEXATTRIBI2IVEXTPROC epoxy_glVertexAttribI2ivEXT = epoxy_glVertexAttribI2ivEXT_global_rewrite_ptr;

PFNGLVERTEXATTRIBI2UIPROC epoxy_glVertexAttribI2ui = epoxy_glVertexAttribI2ui_global_rewrite_ptr;

PFNGLVERTEXATTRIBI2UIEXTPROC epoxy_glVertexAttribI2uiEXT = epoxy_glVertexAttribI2uiEXT_global_rewrite_ptr;

PFNGLVERTEXATTRIBI2UIVPROC epoxy_glVertexAttribI2uiv = epoxy_glVertexAttribI2uiv_global_rewrite_ptr;

PFNGLVERTEXATTRIBI2UIVEXTPROC epoxy_glVertexAttribI2uivEXT = epoxy_glVertexAttribI2uivEXT_global_rewrite_ptr;

PFNGLVERTEXATTRIBI3IPROC epoxy_glVertexAttribI3i = epoxy_glVertexAttribI3i_global_rewrite_ptr;

PFNGLVERTEXATTRIBI3IEXTPROC epoxy_glVertexAttribI3iEXT = epoxy_glVertexAttribI3iEXT_global_rewrite_ptr;

PFNGLVERTEXATTRIBI3IVPROC epoxy_glVertexAttribI3iv = epoxy_glVertexAttribI3iv_global_rewrite_ptr;

PFNGLVERTEXATTRIBI3IVEXTPROC epoxy_glVertexAttribI3ivEXT = epoxy_glVertexAttribI3ivEXT_global_rewrite_ptr;

PFNGLVERTEXATTRIBI3UIPROC epoxy_glVertexAttribI3ui = epoxy_glVertexAttribI3ui_global_rewrite_ptr;

PFNGLVERTEXATTRIBI3UIEXTPROC epoxy_glVertexAttribI3uiEXT = epoxy_glVertexAttribI3uiEXT_global_rewrite_ptr;

PFNGLVERTEXATTRIBI3UIVPROC epoxy_glVertexAttribI3uiv = epoxy_glVertexAttribI3uiv_global_rewrite_ptr;

PFNGLVERTEXATTRIBI3UIVEXTPROC epoxy_glVertexAttribI3uivEXT = epoxy_glVertexAttribI3uivEXT_global_rewrite_ptr;

PFNGLVERTEXATTRIBI4BVPROC epoxy_glVertexAttribI4bv = epoxy_glVertexAttribI4bv_global_rewrite_ptr;

PFNGLVERTEXATTRIBI4BVEXTPROC epoxy_glVertexAttribI4bvEXT = epoxy_glVertexAttribI4bvEXT_global_rewrite_ptr;

PFNGLVERTEXATTRIBI4IPROC epoxy_glVertexAttribI4i = epoxy_glVertexAttribI4i_global_rewrite_ptr;

PFNGLVERTEXATTRIBI4IEXTPROC epoxy_glVertexAttribI4iEXT = epoxy_glVertexAttribI4iEXT_global_rewrite_ptr;

PFNGLVERTEXATTRIBI4IVPROC epoxy_glVertexAttribI4iv = epoxy_glVertexAttribI4iv_global_rewrite_ptr;

PFNGLVERTEXATTRIBI4IVEXTPROC epoxy_glVertexAttribI4ivEXT = epoxy_glVertexAttribI4ivEXT_global_rewrite_ptr;

PFNGLVERTEXATTRIBI4SVPROC epoxy_glVertexAttribI4sv = epoxy_glVertexAttribI4sv_global_rewrite_ptr;

PFNGLVERTEXATTRIBI4SVEXTPROC epoxy_glVertexAttribI4svEXT = epoxy_glVertexAttribI4svEXT_global_rewrite_ptr;

PFNGLVERTEXATTRIBI4UBVPROC epoxy_glVertexAttribI4ubv = epoxy_glVertexAttribI4ubv_global_rewrite_ptr;

PFNGLVERTEXATTRIBI4UBVEXTPROC epoxy_glVertexAttribI4ubvEXT = epoxy_glVertexAttribI4ubvEXT_global_rewrite_ptr;

PFNGLVERTEXATTRIBI4UIPROC epoxy_glVertexAttribI4ui = epoxy_glVertexAttribI4ui_global_rewrite_ptr;

PFNGLVERTEXATTRIBI4UIEXTPROC epoxy_glVertexAttribI4uiEXT = epoxy_glVertexAttribI4uiEXT_global_rewrite_ptr;

PFNGLVERTEXATTRIBI4UIVPROC epoxy_glVertexAttribI4uiv = epoxy_glVertexAttribI4uiv_global_rewrite_ptr;

PFNGLVERTEXATTRIBI4UIVEXTPROC epoxy_glVertexAttribI4uivEXT = epoxy_glVertexAttribI4uivEXT_global_rewrite_ptr;

PFNGLVERTEXATTRIBI4USVPROC epoxy_glVertexAttribI4usv = epoxy_glVertexAttribI4usv_global_rewrite_ptr;

PFNGLVERTEXATTRIBI4USVEXTPROC epoxy_glVertexAttribI4usvEXT = epoxy_glVertexAttribI4usvEXT_global_rewrite_ptr;

PFNGLVERTEXATTRIBIFORMATPROC epoxy_glVertexAttribIFormat = epoxy_glVertexAttribIFormat_global_rewrite_ptr;

PFNGLVERTEXATTRIBIFORMATNVPROC epoxy_glVertexAttribIFormatNV = epoxy_glVertexAttribIFormatNV_global_rewrite_ptr;

PFNGLVERTEXATTRIBIPOINTERPROC epoxy_glVertexAttribIPointer = epoxy_glVertexAttribIPointer_global_rewrite_ptr;

PFNGLVERTEXATTRIBIPOINTEREXTPROC epoxy_glVertexAttribIPointerEXT = epoxy_glVertexAttribIPointerEXT_global_rewrite_ptr;

PFNGLVERTEXATTRIBL1DPROC epoxy_glVertexAttribL1d = epoxy_glVertexAttribL1d_global_rewrite_ptr;

PFNGLVERTEXATTRIBL1DEXTPROC epoxy_glVertexAttribL1dEXT = epoxy_glVertexAttribL1dEXT_global_rewrite_ptr;

PFNGLVERTEXATTRIBL1DVPROC epoxy_glVertexAttribL1dv = epoxy_glVertexAttribL1dv_global_rewrite_ptr;

PFNGLVERTEXATTRIBL1DVEXTPROC epoxy_glVertexAttribL1dvEXT = epoxy_glVertexAttribL1dvEXT_global_rewrite_ptr;

PFNGLVERTEXATTRIBL1I64NVPROC epoxy_glVertexAttribL1i64NV = epoxy_glVertexAttribL1i64NV_global_rewrite_ptr;

PFNGLVERTEXATTRIBL1I64VNVPROC epoxy_glVertexAttribL1i64vNV = epoxy_glVertexAttribL1i64vNV_global_rewrite_ptr;

PFNGLVERTEXATTRIBL1UI64ARBPROC epoxy_glVertexAttribL1ui64ARB = epoxy_glVertexAttribL1ui64ARB_global_rewrite_ptr;

PFNGLVERTEXATTRIBL1UI64NVPROC epoxy_glVertexAttribL1ui64NV = epoxy_glVertexAttribL1ui64NV_global_rewrite_ptr;

PFNGLVERTEXATTRIBL1UI64VARBPROC epoxy_glVertexAttribL1ui64vARB = epoxy_glVertexAttribL1ui64vARB_global_rewrite_ptr;

PFNGLVERTEXATTRIBL1UI64VNVPROC epoxy_glVertexAttribL1ui64vNV = epoxy_glVertexAttribL1ui64vNV_global_rewrite_ptr;

PFNGLVERTEXATTRIBL2DPROC epoxy_glVertexAttribL2d = epoxy_glVertexAttribL2d_global_rewrite_ptr;

PFNGLVERTEXATTRIBL2DEXTPROC epoxy_glVertexAttribL2dEXT = epoxy_glVertexAttribL2dEXT_global_rewrite_ptr;

PFNGLVERTEXATTRIBL2DVPROC epoxy_glVertexAttribL2dv = epoxy_glVertexAttribL2dv_global_rewrite_ptr;

PFNGLVERTEXATTRIBL2DVEXTPROC epoxy_glVertexAttribL2dvEXT = epoxy_glVertexAttribL2dvEXT_global_rewrite_ptr;

PFNGLVERTEXATTRIBL2I64NVPROC epoxy_glVertexAttribL2i64NV = epoxy_glVertexAttribL2i64NV_global_rewrite_ptr;

PFNGLVERTEXATTRIBL2I64VNVPROC epoxy_glVertexAttribL2i64vNV = epoxy_glVertexAttribL2i64vNV_global_rewrite_ptr;

PFNGLVERTEXATTRIBL2UI64NVPROC epoxy_glVertexAttribL2ui64NV = epoxy_glVertexAttribL2ui64NV_global_rewrite_ptr;

PFNGLVERTEXATTRIBL2UI64VNVPROC epoxy_glVertexAttribL2ui64vNV = epoxy_glVertexAttribL2ui64vNV_global_rewrite_ptr;

PFNGLVERTEXATTRIBL3DPROC epoxy_glVertexAttribL3d = epoxy_glVertexAttribL3d_global_rewrite_ptr;

PFNGLVERTEXATTRIBL3DEXTPROC epoxy_glVertexAttribL3dEXT = epoxy_glVertexAttribL3dEXT_global_rewrite_ptr;

PFNGLVERTEXATTRIBL3DVPROC epoxy_glVertexAttribL3dv = epoxy_glVertexAttribL3dv_global_rewrite_ptr;

PFNGLVERTEXATTRIBL3DVEXTPROC epoxy_glVertexAttribL3dvEXT = epoxy_glVertexAttribL3dvEXT_global_rewrite_ptr;

PFNGLVERTEXATTRIBL3I64NVPROC epoxy_glVertexAttribL3i64NV = epoxy_glVertexAttribL3i64NV_global_rewrite_ptr;

PFNGLVERTEXATTRIBL3I64VNVPROC epoxy_glVertexAttribL3i64vNV = epoxy_glVertexAttribL3i64vNV_global_rewrite_ptr;

PFNGLVERTEXATTRIBL3UI64NVPROC epoxy_glVertexAttribL3ui64NV = epoxy_glVertexAttribL3ui64NV_global_rewrite_ptr;

PFNGLVERTEXATTRIBL3UI64VNVPROC epoxy_glVertexAttribL3ui64vNV = epoxy_glVertexAttribL3ui64vNV_global_rewrite_ptr;

PFNGLVERTEXATTRIBL4DPROC epoxy_glVertexAttribL4d = epoxy_glVertexAttribL4d_global_rewrite_ptr;

PFNGLVERTEXATTRIBL4DEXTPROC epoxy_glVertexAttribL4dEXT = epoxy_glVertexAttribL4dEXT_global_rewrite_ptr;

PFNGLVERTEXATTRIBL4DVPROC epoxy_glVertexAttribL4dv = epoxy_glVertexAttribL4dv_global_rewrite_ptr;

PFNGLVERTEXATTRIBL4DVEXTPROC epoxy_glVertexAttribL4dvEXT = epoxy_glVertexAttribL4dvEXT_global_rewrite_ptr;

PFNGLVERTEXATTRIBL4I64NVPROC epoxy_glVertexAttribL4i64NV = epoxy_glVertexAttribL4i64NV_global_rewrite_ptr;

PFNGLVERTEXATTRIBL4I64VNVPROC epoxy_glVertexAttribL4i64vNV = epoxy_glVertexAttribL4i64vNV_global_rewrite_ptr;

PFNGLVERTEXATTRIBL4UI64NVPROC epoxy_glVertexAttribL4ui64NV = epoxy_glVertexAttribL4ui64NV_global_rewrite_ptr;

PFNGLVERTEXATTRIBL4UI64VNVPROC epoxy_glVertexAttribL4ui64vNV = epoxy_glVertexAttribL4ui64vNV_global_rewrite_ptr;

PFNGLVERTEXATTRIBLFORMATPROC epoxy_glVertexAttribLFormat = epoxy_glVertexAttribLFormat_global_rewrite_ptr;

PFNGLVERTEXATTRIBLFORMATNVPROC epoxy_glVertexAttribLFormatNV = epoxy_glVertexAttribLFormatNV_global_rewrite_ptr;

PFNGLVERTEXATTRIBLPOINTERPROC epoxy_glVertexAttribLPointer = epoxy_glVertexAttribLPointer_global_rewrite_ptr;

PFNGLVERTEXATTRIBLPOINTEREXTPROC epoxy_glVertexAttribLPointerEXT = epoxy_glVertexAttribLPointerEXT_global_rewrite_ptr;

PFNGLVERTEXATTRIBP1UIPROC epoxy_glVertexAttribP1ui = epoxy_glVertexAttribP1ui_global_rewrite_ptr;

PFNGLVERTEXATTRIBP1UIVPROC epoxy_glVertexAttribP1uiv = epoxy_glVertexAttribP1uiv_global_rewrite_ptr;

PFNGLVERTEXATTRIBP2UIPROC epoxy_glVertexAttribP2ui = epoxy_glVertexAttribP2ui_global_rewrite_ptr;

PFNGLVERTEXATTRIBP2UIVPROC epoxy_glVertexAttribP2uiv = epoxy_glVertexAttribP2uiv_global_rewrite_ptr;

PFNGLVERTEXATTRIBP3UIPROC epoxy_glVertexAttribP3ui = epoxy_glVertexAttribP3ui_global_rewrite_ptr;

PFNGLVERTEXATTRIBP3UIVPROC epoxy_glVertexAttribP3uiv = epoxy_glVertexAttribP3uiv_global_rewrite_ptr;

PFNGLVERTEXATTRIBP4UIPROC epoxy_glVertexAttribP4ui = epoxy_glVertexAttribP4ui_global_rewrite_ptr;

PFNGLVERTEXATTRIBP4UIVPROC epoxy_glVertexAttribP4uiv = epoxy_glVertexAttribP4uiv_global_rewrite_ptr;

PFNGLVERTEXATTRIBPARAMETERIAMDPROC epoxy_glVertexAttribParameteriAMD = epoxy_glVertexAttribParameteriAMD_global_rewrite_ptr;

PFNGLVERTEXATTRIBPOINTERPROC epoxy_glVertexAttribPointer = epoxy_glVertexAttribPointer_global_rewrite_ptr;

PFNGLVERTEXATTRIBPOINTERARBPROC epoxy_glVertexAttribPointerARB = epoxy_glVertexAttribPointerARB_global_rewrite_ptr;

PFNGLVERTEXATTRIBPOINTERNVPROC epoxy_glVertexAttribPointerNV = epoxy_glVertexAttribPointerNV_global_rewrite_ptr;

PFNGLVERTEXATTRIBS1DVNVPROC epoxy_glVertexAttribs1dvNV = epoxy_glVertexAttribs1dvNV_global_rewrite_ptr;

PFNGLVERTEXATTRIBS1FVNVPROC epoxy_glVertexAttribs1fvNV = epoxy_glVertexAttribs1fvNV_global_rewrite_ptr;

PFNGLVERTEXATTRIBS1HVNVPROC epoxy_glVertexAttribs1hvNV = epoxy_glVertexAttribs1hvNV_global_rewrite_ptr;

PFNGLVERTEXATTRIBS1SVNVPROC epoxy_glVertexAttribs1svNV = epoxy_glVertexAttribs1svNV_global_rewrite_ptr;

PFNGLVERTEXATTRIBS2DVNVPROC epoxy_glVertexAttribs2dvNV = epoxy_glVertexAttribs2dvNV_global_rewrite_ptr;

PFNGLVERTEXATTRIBS2FVNVPROC epoxy_glVertexAttribs2fvNV = epoxy_glVertexAttribs2fvNV_global_rewrite_ptr;

PFNGLVERTEXATTRIBS2HVNVPROC epoxy_glVertexAttribs2hvNV = epoxy_glVertexAttribs2hvNV_global_rewrite_ptr;

PFNGLVERTEXATTRIBS2SVNVPROC epoxy_glVertexAttribs2svNV = epoxy_glVertexAttribs2svNV_global_rewrite_ptr;

PFNGLVERTEXATTRIBS3DVNVPROC epoxy_glVertexAttribs3dvNV = epoxy_glVertexAttribs3dvNV_global_rewrite_ptr;

PFNGLVERTEXATTRIBS3FVNVPROC epoxy_glVertexAttribs3fvNV = epoxy_glVertexAttribs3fvNV_global_rewrite_ptr;

PFNGLVERTEXATTRIBS3HVNVPROC epoxy_glVertexAttribs3hvNV = epoxy_glVertexAttribs3hvNV_global_rewrite_ptr;

PFNGLVERTEXATTRIBS3SVNVPROC epoxy_glVertexAttribs3svNV = epoxy_glVertexAttribs3svNV_global_rewrite_ptr;

PFNGLVERTEXATTRIBS4DVNVPROC epoxy_glVertexAttribs4dvNV = epoxy_glVertexAttribs4dvNV_global_rewrite_ptr;

PFNGLVERTEXATTRIBS4FVNVPROC epoxy_glVertexAttribs4fvNV = epoxy_glVertexAttribs4fvNV_global_rewrite_ptr;

PFNGLVERTEXATTRIBS4HVNVPROC epoxy_glVertexAttribs4hvNV = epoxy_glVertexAttribs4hvNV_global_rewrite_ptr;

PFNGLVERTEXATTRIBS4SVNVPROC epoxy_glVertexAttribs4svNV = epoxy_glVertexAttribs4svNV_global_rewrite_ptr;

PFNGLVERTEXATTRIBS4UBVNVPROC epoxy_glVertexAttribs4ubvNV = epoxy_glVertexAttribs4ubvNV_global_rewrite_ptr;

PFNGLVERTEXBINDINGDIVISORPROC epoxy_glVertexBindingDivisor = epoxy_glVertexBindingDivisor_global_rewrite_ptr;

PFNGLVERTEXBLENDARBPROC epoxy_glVertexBlendARB = epoxy_glVertexBlendARB_global_rewrite_ptr;

PFNGLVERTEXBLENDENVFATIPROC epoxy_glVertexBlendEnvfATI = epoxy_glVertexBlendEnvfATI_global_rewrite_ptr;

PFNGLVERTEXBLENDENVIATIPROC epoxy_glVertexBlendEnviATI = epoxy_glVertexBlendEnviATI_global_rewrite_ptr;

PFNGLVERTEXFORMATNVPROC epoxy_glVertexFormatNV = epoxy_glVertexFormatNV_global_rewrite_ptr;

PFNGLVERTEXP2UIPROC epoxy_glVertexP2ui = epoxy_glVertexP2ui_global_rewrite_ptr;

PFNGLVERTEXP2UIVPROC epoxy_glVertexP2uiv = epoxy_glVertexP2uiv_global_rewrite_ptr;

PFNGLVERTEXP3UIPROC epoxy_glVertexP3ui = epoxy_glVertexP3ui_global_rewrite_ptr;

PFNGLVERTEXP3UIVPROC epoxy_glVertexP3uiv = epoxy_glVertexP3uiv_global_rewrite_ptr;

PFNGLVERTEXP4UIPROC epoxy_glVertexP4ui = epoxy_glVertexP4ui_global_rewrite_ptr;

PFNGLVERTEXP4UIVPROC epoxy_glVertexP4uiv = epoxy_glVertexP4uiv_global_rewrite_ptr;

PFNGLVERTEXPOINTERPROC epoxy_glVertexPointer = epoxy_glVertexPointer_global_rewrite_ptr;

PFNGLVERTEXPOINTEREXTPROC epoxy_glVertexPointerEXT = epoxy_glVertexPointerEXT_global_rewrite_ptr;

PFNGLVERTEXPOINTERLISTIBMPROC epoxy_glVertexPointerListIBM = epoxy_glVertexPointerListIBM_global_rewrite_ptr;

PFNGLVERTEXPOINTERVINTELPROC epoxy_glVertexPointervINTEL = epoxy_glVertexPointervINTEL_global_rewrite_ptr;

PFNGLVERTEXSTREAM1DATIPROC epoxy_glVertexStream1dATI = epoxy_glVertexStream1dATI_global_rewrite_ptr;

PFNGLVERTEXSTREAM1DVATIPROC epoxy_glVertexStream1dvATI = epoxy_glVertexStream1dvATI_global_rewrite_ptr;

PFNGLVERTEXSTREAM1FATIPROC epoxy_glVertexStream1fATI = epoxy_glVertexStream1fATI_global_rewrite_ptr;

PFNGLVERTEXSTREAM1FVATIPROC epoxy_glVertexStream1fvATI = epoxy_glVertexStream1fvATI_global_rewrite_ptr;

PFNGLVERTEXSTREAM1IATIPROC epoxy_glVertexStream1iATI = epoxy_glVertexStream1iATI_global_rewrite_ptr;

PFNGLVERTEXSTREAM1IVATIPROC epoxy_glVertexStream1ivATI = epoxy_glVertexStream1ivATI_global_rewrite_ptr;

PFNGLVERTEXSTREAM1SATIPROC epoxy_glVertexStream1sATI = epoxy_glVertexStream1sATI_global_rewrite_ptr;

PFNGLVERTEXSTREAM1SVATIPROC epoxy_glVertexStream1svATI = epoxy_glVertexStream1svATI_global_rewrite_ptr;

PFNGLVERTEXSTREAM2DATIPROC epoxy_glVertexStream2dATI = epoxy_glVertexStream2dATI_global_rewrite_ptr;

PFNGLVERTEXSTREAM2DVATIPROC epoxy_glVertexStream2dvATI = epoxy_glVertexStream2dvATI_global_rewrite_ptr;

PFNGLVERTEXSTREAM2FATIPROC epoxy_glVertexStream2fATI = epoxy_glVertexStream2fATI_global_rewrite_ptr;

PFNGLVERTEXSTREAM2FVATIPROC epoxy_glVertexStream2fvATI = epoxy_glVertexStream2fvATI_global_rewrite_ptr;

PFNGLVERTEXSTREAM2IATIPROC epoxy_glVertexStream2iATI = epoxy_glVertexStream2iATI_global_rewrite_ptr;

PFNGLVERTEXSTREAM2IVATIPROC epoxy_glVertexStream2ivATI = epoxy_glVertexStream2ivATI_global_rewrite_ptr;

PFNGLVERTEXSTREAM2SATIPROC epoxy_glVertexStream2sATI = epoxy_glVertexStream2sATI_global_rewrite_ptr;

PFNGLVERTEXSTREAM2SVATIPROC epoxy_glVertexStream2svATI = epoxy_glVertexStream2svATI_global_rewrite_ptr;

PFNGLVERTEXSTREAM3DATIPROC epoxy_glVertexStream3dATI = epoxy_glVertexStream3dATI_global_rewrite_ptr;

PFNGLVERTEXSTREAM3DVATIPROC epoxy_glVertexStream3dvATI = epoxy_glVertexStream3dvATI_global_rewrite_ptr;

PFNGLVERTEXSTREAM3FATIPROC epoxy_glVertexStream3fATI = epoxy_glVertexStream3fATI_global_rewrite_ptr;

PFNGLVERTEXSTREAM3FVATIPROC epoxy_glVertexStream3fvATI = epoxy_glVertexStream3fvATI_global_rewrite_ptr;

PFNGLVERTEXSTREAM3IATIPROC epoxy_glVertexStream3iATI = epoxy_glVertexStream3iATI_global_rewrite_ptr;

PFNGLVERTEXSTREAM3IVATIPROC epoxy_glVertexStream3ivATI = epoxy_glVertexStream3ivATI_global_rewrite_ptr;

PFNGLVERTEXSTREAM3SATIPROC epoxy_glVertexStream3sATI = epoxy_glVertexStream3sATI_global_rewrite_ptr;

PFNGLVERTEXSTREAM3SVATIPROC epoxy_glVertexStream3svATI = epoxy_glVertexStream3svATI_global_rewrite_ptr;

PFNGLVERTEXSTREAM4DATIPROC epoxy_glVertexStream4dATI = epoxy_glVertexStream4dATI_global_rewrite_ptr;

PFNGLVERTEXSTREAM4DVATIPROC epoxy_glVertexStream4dvATI = epoxy_glVertexStream4dvATI_global_rewrite_ptr;

PFNGLVERTEXSTREAM4FATIPROC epoxy_glVertexStream4fATI = epoxy_glVertexStream4fATI_global_rewrite_ptr;

PFNGLVERTEXSTREAM4FVATIPROC epoxy_glVertexStream4fvATI = epoxy_glVertexStream4fvATI_global_rewrite_ptr;

PFNGLVERTEXSTREAM4IATIPROC epoxy_glVertexStream4iATI = epoxy_glVertexStream4iATI_global_rewrite_ptr;

PFNGLVERTEXSTREAM4IVATIPROC epoxy_glVertexStream4ivATI = epoxy_glVertexStream4ivATI_global_rewrite_ptr;

PFNGLVERTEXSTREAM4SATIPROC epoxy_glVertexStream4sATI = epoxy_glVertexStream4sATI_global_rewrite_ptr;

PFNGLVERTEXSTREAM4SVATIPROC epoxy_glVertexStream4svATI = epoxy_glVertexStream4svATI_global_rewrite_ptr;

PFNGLVERTEXWEIGHTPOINTEREXTPROC epoxy_glVertexWeightPointerEXT = epoxy_glVertexWeightPointerEXT_global_rewrite_ptr;

PFNGLVERTEXWEIGHTFEXTPROC epoxy_glVertexWeightfEXT = epoxy_glVertexWeightfEXT_global_rewrite_ptr;

PFNGLVERTEXWEIGHTFVEXTPROC epoxy_glVertexWeightfvEXT = epoxy_glVertexWeightfvEXT_global_rewrite_ptr;

PFNGLVERTEXWEIGHTHNVPROC epoxy_glVertexWeighthNV = epoxy_glVertexWeighthNV_global_rewrite_ptr;

PFNGLVERTEXWEIGHTHVNVPROC epoxy_glVertexWeighthvNV = epoxy_glVertexWeighthvNV_global_rewrite_ptr;

PFNGLVIDEOCAPTURENVPROC epoxy_glVideoCaptureNV = epoxy_glVideoCaptureNV_global_rewrite_ptr;

PFNGLVIDEOCAPTURESTREAMPARAMETERDVNVPROC epoxy_glVideoCaptureStreamParameterdvNV = epoxy_glVideoCaptureStreamParameterdvNV_global_rewrite_ptr;

PFNGLVIDEOCAPTURESTREAMPARAMETERFVNVPROC epoxy_glVideoCaptureStreamParameterfvNV = epoxy_glVideoCaptureStreamParameterfvNV_global_rewrite_ptr;

PFNGLVIDEOCAPTURESTREAMPARAMETERIVNVPROC epoxy_glVideoCaptureStreamParameterivNV = epoxy_glVideoCaptureStreamParameterivNV_global_rewrite_ptr;

PFNGLVIEWPORTPROC epoxy_glViewport = epoxy_glViewport_global_rewrite_ptr;

PFNGLVIEWPORTARRAYVPROC epoxy_glViewportArrayv = epoxy_glViewportArrayv_global_rewrite_ptr;

PFNGLVIEWPORTARRAYVNVPROC epoxy_glViewportArrayvNV = epoxy_glViewportArrayvNV_global_rewrite_ptr;

PFNGLVIEWPORTARRAYVOESPROC epoxy_glViewportArrayvOES = epoxy_glViewportArrayvOES_global_rewrite_ptr;

PFNGLVIEWPORTINDEXEDFPROC epoxy_glViewportIndexedf = epoxy_glViewportIndexedf_global_rewrite_ptr;

PFNGLVIEWPORTINDEXEDFNVPROC epoxy_glViewportIndexedfNV = epoxy_glViewportIndexedfNV_global_rewrite_ptr;

PFNGLVIEWPORTINDEXEDFOESPROC epoxy_glViewportIndexedfOES = epoxy_glViewportIndexedfOES_global_rewrite_ptr;

PFNGLVIEWPORTINDEXEDFVPROC epoxy_glViewportIndexedfv = epoxy_glViewportIndexedfv_global_rewrite_ptr;

PFNGLVIEWPORTINDEXEDFVNVPROC epoxy_glViewportIndexedfvNV = epoxy_glViewportIndexedfvNV_global_rewrite_ptr;

PFNGLVIEWPORTINDEXEDFVOESPROC epoxy_glViewportIndexedfvOES = epoxy_glViewportIndexedfvOES_global_rewrite_ptr;

PFNGLVIEWPORTPOSITIONWSCALENVPROC epoxy_glViewportPositionWScaleNV = epoxy_glViewportPositionWScaleNV_global_rewrite_ptr;

PFNGLVIEWPORTSWIZZLENVPROC epoxy_glViewportSwizzleNV = epoxy_glViewportSwizzleNV_global_rewrite_ptr;

PFNGLWAITSEMAPHOREEXTPROC epoxy_glWaitSemaphoreEXT = epoxy_glWaitSemaphoreEXT_global_rewrite_ptr;

PFNGLWAITSEMAPHOREUI64NVXPROC epoxy_glWaitSemaphoreui64NVX = epoxy_glWaitSemaphoreui64NVX_global_rewrite_ptr;

PFNGLWAITSYNCPROC epoxy_glWaitSync = epoxy_glWaitSync_global_rewrite_ptr;

PFNGLWAITSYNCAPPLEPROC epoxy_glWaitSyncAPPLE = epoxy_glWaitSyncAPPLE_global_rewrite_ptr;

PFNGLWAITVKSEMAPHORENVPROC epoxy_glWaitVkSemaphoreNV = epoxy_glWaitVkSemaphoreNV_global_rewrite_ptr;

PFNGLWEIGHTPATHSNVPROC epoxy_glWeightPathsNV = epoxy_glWeightPathsNV_global_rewrite_ptr;

PFNGLWEIGHTPOINTERARBPROC epoxy_glWeightPointerARB = epoxy_glWeightPointerARB_global_rewrite_ptr;

PFNGLWEIGHTPOINTEROESPROC epoxy_glWeightPointerOES = epoxy_glWeightPointerOES_global_rewrite_ptr;

PFNGLWEIGHTBVARBPROC epoxy_glWeightbvARB = epoxy_glWeightbvARB_global_rewrite_ptr;

PFNGLWEIGHTDVARBPROC epoxy_glWeightdvARB = epoxy_glWeightdvARB_global_rewrite_ptr;

PFNGLWEIGHTFVARBPROC epoxy_glWeightfvARB = epoxy_glWeightfvARB_global_rewrite_ptr;

PFNGLWEIGHTIVARBPROC epoxy_glWeightivARB = epoxy_glWeightivARB_global_rewrite_ptr;

PFNGLWEIGHTSVARBPROC epoxy_glWeightsvARB = epoxy_glWeightsvARB_global_rewrite_ptr;

PFNGLWEIGHTUBVARBPROC epoxy_glWeightubvARB = epoxy_glWeightubvARB_global_rewrite_ptr;

PFNGLWEIGHTUIVARBPROC epoxy_glWeightuivARB = epoxy_glWeightuivARB_global_rewrite_ptr;

PFNGLWEIGHTUSVARBPROC epoxy_glWeightusvARB = epoxy_glWeightusvARB_global_rewrite_ptr;

PFNGLWINDOWPOS2DPROC epoxy_glWindowPos2d = epoxy_glWindowPos2d_global_rewrite_ptr;

PFNGLWINDOWPOS2DARBPROC epoxy_glWindowPos2dARB = epoxy_glWindowPos2dARB_global_rewrite_ptr;

PFNGLWINDOWPOS2DMESAPROC epoxy_glWindowPos2dMESA = epoxy_glWindowPos2dMESA_global_rewrite_ptr;

PFNGLWINDOWPOS2DVPROC epoxy_glWindowPos2dv = epoxy_glWindowPos2dv_global_rewrite_ptr;

PFNGLWINDOWPOS2DVARBPROC epoxy_glWindowPos2dvARB = epoxy_glWindowPos2dvARB_global_rewrite_ptr;

PFNGLWINDOWPOS2DVMESAPROC epoxy_glWindowPos2dvMESA = epoxy_glWindowPos2dvMESA_global_rewrite_ptr;

PFNGLWINDOWPOS2FPROC epoxy_glWindowPos2f = epoxy_glWindowPos2f_global_rewrite_ptr;

PFNGLWINDOWPOS2FARBPROC epoxy_glWindowPos2fARB = epoxy_glWindowPos2fARB_global_rewrite_ptr;

PFNGLWINDOWPOS2FMESAPROC epoxy_glWindowPos2fMESA = epoxy_glWindowPos2fMESA_global_rewrite_ptr;

PFNGLWINDOWPOS2FVPROC epoxy_glWindowPos2fv = epoxy_glWindowPos2fv_global_rewrite_ptr;

PFNGLWINDOWPOS2FVARBPROC epoxy_glWindowPos2fvARB = epoxy_glWindowPos2fvARB_global_rewrite_ptr;

PFNGLWINDOWPOS2FVMESAPROC epoxy_glWindowPos2fvMESA = epoxy_glWindowPos2fvMESA_global_rewrite_ptr;

PFNGLWINDOWPOS2IPROC epoxy_glWindowPos2i = epoxy_glWindowPos2i_global_rewrite_ptr;

PFNGLWINDOWPOS2IARBPROC epoxy_glWindowPos2iARB = epoxy_glWindowPos2iARB_global_rewrite_ptr;

PFNGLWINDOWPOS2IMESAPROC epoxy_glWindowPos2iMESA = epoxy_glWindowPos2iMESA_global_rewrite_ptr;

PFNGLWINDOWPOS2IVPROC epoxy_glWindowPos2iv = epoxy_glWindowPos2iv_global_rewrite_ptr;

PFNGLWINDOWPOS2IVARBPROC epoxy_glWindowPos2ivARB = epoxy_glWindowPos2ivARB_global_rewrite_ptr;

PFNGLWINDOWPOS2IVMESAPROC epoxy_glWindowPos2ivMESA = epoxy_glWindowPos2ivMESA_global_rewrite_ptr;

PFNGLWINDOWPOS2SPROC epoxy_glWindowPos2s = epoxy_glWindowPos2s_global_rewrite_ptr;

PFNGLWINDOWPOS2SARBPROC epoxy_glWindowPos2sARB = epoxy_glWindowPos2sARB_global_rewrite_ptr;

PFNGLWINDOWPOS2SMESAPROC epoxy_glWindowPos2sMESA = epoxy_glWindowPos2sMESA_global_rewrite_ptr;

PFNGLWINDOWPOS2SVPROC epoxy_glWindowPos2sv = epoxy_glWindowPos2sv_global_rewrite_ptr;

PFNGLWINDOWPOS2SVARBPROC epoxy_glWindowPos2svARB = epoxy_glWindowPos2svARB_global_rewrite_ptr;

PFNGLWINDOWPOS2SVMESAPROC epoxy_glWindowPos2svMESA = epoxy_glWindowPos2svMESA_global_rewrite_ptr;

PFNGLWINDOWPOS3DPROC epoxy_glWindowPos3d = epoxy_glWindowPos3d_global_rewrite_ptr;

PFNGLWINDOWPOS3DARBPROC epoxy_glWindowPos3dARB = epoxy_glWindowPos3dARB_global_rewrite_ptr;

PFNGLWINDOWPOS3DMESAPROC epoxy_glWindowPos3dMESA = epoxy_glWindowPos3dMESA_global_rewrite_ptr;

PFNGLWINDOWPOS3DVPROC epoxy_glWindowPos3dv = epoxy_glWindowPos3dv_global_rewrite_ptr;

PFNGLWINDOWPOS3DVARBPROC epoxy_glWindowPos3dvARB = epoxy_glWindowPos3dvARB_global_rewrite_ptr;

PFNGLWINDOWPOS3DVMESAPROC epoxy_glWindowPos3dvMESA = epoxy_glWindowPos3dvMESA_global_rewrite_ptr;

PFNGLWINDOWPOS3FPROC epoxy_glWindowPos3f = epoxy_glWindowPos3f_global_rewrite_ptr;

PFNGLWINDOWPOS3FARBPROC epoxy_glWindowPos3fARB = epoxy_glWindowPos3fARB_global_rewrite_ptr;

PFNGLWINDOWPOS3FMESAPROC epoxy_glWindowPos3fMESA = epoxy_glWindowPos3fMESA_global_rewrite_ptr;

PFNGLWINDOWPOS3FVPROC epoxy_glWindowPos3fv = epoxy_glWindowPos3fv_global_rewrite_ptr;

PFNGLWINDOWPOS3FVARBPROC epoxy_glWindowPos3fvARB = epoxy_glWindowPos3fvARB_global_rewrite_ptr;

PFNGLWINDOWPOS3FVMESAPROC epoxy_glWindowPos3fvMESA = epoxy_glWindowPos3fvMESA_global_rewrite_ptr;

PFNGLWINDOWPOS3IPROC epoxy_glWindowPos3i = epoxy_glWindowPos3i_global_rewrite_ptr;

PFNGLWINDOWPOS3IARBPROC epoxy_glWindowPos3iARB = epoxy_glWindowPos3iARB_global_rewrite_ptr;

PFNGLWINDOWPOS3IMESAPROC epoxy_glWindowPos3iMESA = epoxy_glWindowPos3iMESA_global_rewrite_ptr;

PFNGLWINDOWPOS3IVPROC epoxy_glWindowPos3iv = epoxy_glWindowPos3iv_global_rewrite_ptr;

PFNGLWINDOWPOS3IVARBPROC epoxy_glWindowPos3ivARB = epoxy_glWindowPos3ivARB_global_rewrite_ptr;

PFNGLWINDOWPOS3IVMESAPROC epoxy_glWindowPos3ivMESA = epoxy_glWindowPos3ivMESA_global_rewrite_ptr;

PFNGLWINDOWPOS3SPROC epoxy_glWindowPos3s = epoxy_glWindowPos3s_global_rewrite_ptr;

PFNGLWINDOWPOS3SARBPROC epoxy_glWindowPos3sARB = epoxy_glWindowPos3sARB_global_rewrite_ptr;

PFNGLWINDOWPOS3SMESAPROC epoxy_glWindowPos3sMESA = epoxy_glWindowPos3sMESA_global_rewrite_ptr;

PFNGLWINDOWPOS3SVPROC epoxy_glWindowPos3sv = epoxy_glWindowPos3sv_global_rewrite_ptr;

PFNGLWINDOWPOS3SVARBPROC epoxy_glWindowPos3svARB = epoxy_glWindowPos3svARB_global_rewrite_ptr;

PFNGLWINDOWPOS3SVMESAPROC epoxy_glWindowPos3svMESA = epoxy_glWindowPos3svMESA_global_rewrite_ptr;

PFNGLWINDOWPOS4DMESAPROC epoxy_glWindowPos4dMESA = epoxy_glWindowPos4dMESA_global_rewrite_ptr;

PFNGLWINDOWPOS4DVMESAPROC epoxy_glWindowPos4dvMESA = epoxy_glWindowPos4dvMESA_global_rewrite_ptr;

PFNGLWINDOWPOS4FMESAPROC epoxy_glWindowPos4fMESA = epoxy_glWindowPos4fMESA_global_rewrite_ptr;

PFNGLWINDOWPOS4FVMESAPROC epoxy_glWindowPos4fvMESA = epoxy_glWindowPos4fvMESA_global_rewrite_ptr;

PFNGLWINDOWPOS4IMESAPROC epoxy_glWindowPos4iMESA = epoxy_glWindowPos4iMESA_global_rewrite_ptr;

PFNGLWINDOWPOS4IVMESAPROC epoxy_glWindowPos4ivMESA = epoxy_glWindowPos4ivMESA_global_rewrite_ptr;

PFNGLWINDOWPOS4SMESAPROC epoxy_glWindowPos4sMESA = epoxy_glWindowPos4sMESA_global_rewrite_ptr;

PFNGLWINDOWPOS4SVMESAPROC epoxy_glWindowPos4svMESA = epoxy_glWindowPos4svMESA_global_rewrite_ptr;

PFNGLWINDOWRECTANGLESEXTPROC epoxy_glWindowRectanglesEXT = epoxy_glWindowRectanglesEXT_global_rewrite_ptr;

PFNGLWRITEMASKEXTPROC epoxy_glWriteMaskEXT = epoxy_glWriteMaskEXT_global_rewrite_ptr;

